@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -59,7 +59,6 @@
 /////////////////////// Local includes
 #include "MsXpS/export-import-config.h"
 
-
 namespace MsXpS
 {
 namespace libXpertMassCore
@@ -76,18 +75,18 @@ class DECLSPEC CleavageAgent: public QObject
   Q_OBJECT
 
   public:
-  CleavageAgent(QObject *parent = nullptr);
-  CleavageAgent(PolChemDefCstSPtr pol_chem_def_csp,
-                const QDomElement &element,
-                int version,
-                QObject *parent = nullptr);
-  CleavageAgent(PolChemDefCstSPtr pol_chem_def_csp,
-                const QString &name    = QString(),
-                const QString &pattern = QString(),
-                QObject *parent        = nullptr);
+  explicit CleavageAgent(QObject *parent = nullptr);
+  explicit CleavageAgent(PolChemDefCstSPtr pol_chem_def_csp,
+                         const QDomElement &element,
+                         int version,
+                         QObject *parent = nullptr);
+  explicit CleavageAgent(PolChemDefCstSPtr pol_chem_def_csp,
+                         const QString &name    = QString(),
+                         const QString &pattern = QString(),
+                         QObject *parent        = nullptr);
 
   // Pseudo copy-constructor that does not copy the QObject base class.
-  CleavageAgent(const CleavageAgent &other, QObject *parent = nullptr);
+  explicit CleavageAgent(const CleavageAgent &other, QObject *parent = nullptr);
 
   // Prevent accidental copying
   CleavageAgent(const CleavageAgent &other) = delete;
