@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -42,7 +42,6 @@
 #include "MsXpS/libXpertMassCore/IndexRangeCollection.hpp"
 #include "MsXpS/libXpertMassCore/Monomer.hpp"
 
-
 namespace MsXpS
 {
 namespace libXpertMassCore
@@ -79,13 +78,13 @@ class DECLSPEC CrossLink
 
   CrossLink(PolChemDefCstSPtr pol_chem_def_csp,
             PolymerCstQSPtr polymer_cqsp = nullptr,
-            const QString &name        = QString(),
-            const QString &formula     = QString(),
-            const QString &comment     = QString());
+            const QString &name          = QString(),
+            const QString &formula       = QString(),
+            const QString &comment       = QString());
 
   CrossLink(CrossLinkerCstSPtr cross_linker_csp,
             PolymerCstQSPtr polymer_cqsp = nullptr,
-            const QString &comment     = QString());
+            const QString &comment       = QString());
 
   CrossLink(const CrossLink &other);
 
@@ -120,8 +119,8 @@ class DECLSPEC CrossLink
   QString continuumOfLocationsOfInclusiveSequenceMonomersAsText(
     Enums::LocationType location_type) const;
 
-  std::vector<std::size_t>
-   locationsOfOnlyExtremeSequenceMonomers(Enums::LocationType location_type) const;
+  std::vector<std::size_t> locationsOfOnlyExtremeSequenceMonomers(
+    Enums::LocationType location_type) const;
   QString locationsOfOnlyExtremeSequenceMonomersAsText(
     Enums::LocationType location_type) const;
 
@@ -136,10 +135,11 @@ class DECLSPEC CrossLink
   bool operator!=(const CrossLink &) const;
 
   //////////////// CROSS-LINK LOGIC /////////////////////
-  Enums::CrossLinkEncompassed isEncompassedByIndexRange(std::size_t start,
-                                                 std::size_t end,
-                                                 std::size_t &in_count,
-                                                 std::size_t &out_count) const;
+  Enums::CrossLinkEncompassed
+  isEncompassedByIndexRange(std::size_t start,
+                            std::size_t end,
+                            std::size_t &in_count,
+                            std::size_t &out_count) const;
   Enums::CrossLinkEncompassed
   isEncompassedByIndexRangeCollection(const IndexRangeCollection &index_ranges,
                                       std::size_t &in_count,
@@ -175,7 +175,7 @@ class DECLSPEC CrossLink
 
   protected:
   CrossLinkerCstSPtr mcsp_crossLinker = nullptr;
-  PolymerCstQSPtr mcsp_polymer         = nullptr;
+  PolymerCstQSPtr mcsp_polymer        = nullptr;
   QString m_comment;
 
   std::vector<MonomerCstSPtr> m_monomers;
@@ -206,7 +206,6 @@ typedef std::shared_ptr<const CrossLink> CrossLinkCstSPtr;
 } // namespace libXpertMassCore
 } // namespace MsXpS
 
-
 Q_DECLARE_METATYPE(MsXpS::libXpertMassCore::CrossLink);
 extern int crossLinkMetaTypeId;
 
