@@ -3,7 +3,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -43,7 +43,6 @@
 
 /////////////////////// Qt includes
 #include <QDomElement>
-#include <QtQml>
 
 
 /////////////////////// pappsomspp includes
@@ -119,14 +118,9 @@ class DECLSPEC Formula: public QObject
   Q_INVOKABLE QString extractTitle() const;
   Q_INVOKABLE QString removeTitle();
 
-  //////////////// THE ATOM INDEX LOGIC /////////////////////
-  Q_INVOKABLE void setForceCountIndex(bool forceCountIndex);
-  Q_INVOKABLE bool isForceCountIndex() const;
-
   //////////////// THE SYNTAX CHECKING LOGIC /////////////////////
-  Q_INVOKABLE static bool checkSyntax(const QString &formula,
-                                      bool forceCountIndex = false);
   Q_INVOKABLE bool checkSyntax() const;
+  Q_INVOKABLE static bool checkSyntax(const QString &formula_string);
 
   //////////////// OPERATORS /////////////////////
   virtual Formula &operator=(const Formula &other);
@@ -134,18 +128,17 @@ class DECLSPEC Formula: public QObject
   virtual bool operator!=(const Formula &other) const;
 
   //////////////// THE SUB-FORMULAS OPERATIONS /////////////////////
-  SplitResult
-  splitActionParts(IsotopicDataCstSPtr isotopic_data_csp,
-                   QString &plus_formula,
-                   QString &minus_formula,
-                   std::map<QString, double> &symbol_count_map,
-                   double times = 1,
-                   bool store   = false,
-                   bool reset   = false) const;
   SplitResult splitActionParts(IsotopicDataCstSPtr isotopic_data_csp,
-                                      double times = 1,
-                                      bool store   = false,
-                                      bool reset   = false);
+                               QString &plus_formula,
+                               QString &minus_formula,
+                               std::map<QString, double> &symbol_count_map,
+                               double times = 1,
+                               bool store   = false,
+                               bool reset   = false) const;
+  SplitResult splitActionParts(IsotopicDataCstSPtr isotopic_data_csp,
+                               double times = 1,
+                               bool store   = false,
+                               bool reset   = false);
   Q_INVOKABLE static QChar actions(const QString &formula);
   Q_INVOKABLE QChar actions() const;
   Q_INVOKABLE bool hasNetMinusPart();
@@ -220,10 +213,6 @@ class DECLSPEC Formula: public QObject
   // their count in the formula(e). The count can be a double or an int.
   std::map<QString, double> m_symbolCountMap;
 
-  // Tells if single atoms in a formula need nonetheless an index (H2O1, for
-  // example)
-  bool m_forceCountIndex = false;
-
   mutable bool m_isValid = false;
 
   //////////////// PRIVATE FUNCTIONS /////////////////////
