@@ -39,7 +39,6 @@
 
 /////////////////////// Qt includes
 #include <QString>
-#include <QtQml>
 
 
 /////////////////////// pappsomspp includes
@@ -51,7 +50,6 @@
 #include "MsXpS/libXpertMassCore/jsclassregistrar.h"
 #include "MsXpS/libXpertMassCore/globals.hpp"
 
-
 namespace MsXpS
 {
 namespace libXpertMassCore
@@ -152,14 +150,13 @@ class DECLSPEC Isotope: public QObject
   Q_INVOKABLE Isotope(const QString &text, QObject *parent = nullptr);
 
   // Pseudo copy constructor
-   Isotope(const Isotope &other, QObject *parent = nullptr);
-   Isotope(const Isotope *other_p, QObject *parent = nullptr);
+  Isotope(const Isotope &other, QObject *parent = nullptr);
+  Isotope(const Isotope *other_p, QObject *parent = nullptr);
 
   virtual ~Isotope();
 
   Q_INVOKABLE Isotope *clone(QObject *parent = nullptr) const;
-  static Isotope *clone(const Isotope &other,
-                                    QObject *parent = nullptr);
+  static Isotope *clone(const Isotope &other, QObject *parent = nullptr);
 
   Q_INVOKABLE bool initialize(const QString &name,
                               const QString &symbol,
@@ -200,7 +197,7 @@ class DECLSPEC Isotope: public QObject
   QString m_symbol     = "";
   double m_mass        = -1.0;
   double m_probability = -1.0;
-  bool m_isValid = false;
+  bool m_isValid       = false;
 };
 
 typedef QSharedPointer<Isotope> IsotopeQSPtr;
@@ -217,7 +214,6 @@ MSXPS_REGISTER_JS_CLASS(MsXpS::libXpertMassCore, Isotope)
 
 } // namespace MsXpS
 
-
 Q_DECLARE_METATYPE(MsXpS::libXpertMassCore::Isotope);
 extern int isotopeMetaTypeId;
 
