@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -125,6 +125,11 @@ class DECLSPEC Utils: public QObject
 
   static QString xmlIndentationToken;
 
+  static QString configSettingsFilePath;
+
+  static void
+  initializeConfigSettingsFilePath(const QString &config_settings_file_path);
+
   static void messageOutputFormat(QtMsgType type,
                                   const QMessageLogContext &context,
                                   const QString &msg);
@@ -172,6 +177,7 @@ class DECLSPEC Utils: public QObject
                                        const QString &delimitor = "...");
 
   Q_INVOKABLE static QString stanzify(const QString &text, int width);
+  Q_INVOKABLE static QString stanzifyOld(const QString &text, int width);
 
   Q_INVOKABLE static QString stanzifyParagraphs(const QString &text, int width);
 
@@ -196,8 +202,6 @@ class DECLSPEC Utils: public QObject
   template <typename T>
   static T *stringAsPointer(const QString &str);
 
-  static QString craftConfigSettingsFilePath(const QString &module_name);
-
   static int testDiffBetweenTwoTextFiles(const QString &file_path_1,
                                          const QString &file_path_2);
 
