@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -35,7 +35,6 @@
 
 ////////////////////////////// Stdlib includes
 #include <map>
-#include <sstream>
 
 
 ////////////////////////////// Qt includes
@@ -75,6 +74,7 @@ namespace MsXpS
 namespace libXpertMassCore
 {
 
+
 // Macro to fake qFatal() << streaming in Qt 6.4
 #if QT_VERSION < QT_VERSION_CHECK(6, 8, 0) // If Qt < 6.8
 #define qFatalStream()                             \
@@ -85,11 +85,6 @@ namespace libXpertMassCore
 #define qFatalStream() qFatal()
 #endif
 
-void myMessageOutputFormat(QtMsgType type,
-                           const QMessageLogContext &context,
-                           const QString &msg);
-
-void configureDebugMessagesFormat();
 
 /////////////////////////// namespace Enums ////////////////////////////
 /////////////////////////// namespace Enums ////////////////////////////
@@ -343,15 +338,23 @@ extern DECLSPEC std::map<Enums::ChemicalGroupTrapped, QString>
   chemicalGroupTrappedMap;
 extern DECLSPEC std::map<Enums::ChemicalGroupFate, QString>
   chemicalGroupFateMap;
-extern DECLSPEC std::map<Enums::MassPeakShapeType, QString> massPeakShapeTypeMap;
-extern DECLSPEC std::map<Enums::MassPeakWidthLogic, QString> massPeakWidthLogicMap;
+extern DECLSPEC std::map<Enums::MassPeakShapeType, QString>
+  massPeakShapeTypeMap;
+extern DECLSPEC std::map<Enums::MassPeakWidthLogic, QString>
+  massPeakWidthLogicMap;
 extern DECLSPEC std::map<Enums::MassDataType, QString> massDataTypeMap;
 
 
+extern DECLSPEC int DEFAULT_DEC_PLACES;
 extern DECLSPEC int ATOM_DEC_PLACES;
 extern DECLSPEC int OLIGOMER_DEC_PLACES;
 extern DECLSPEC int POLYMER_DEC_PLACES;
 extern DECLSPEC int PKA_PH_PI_DEC_PLACES;
+extern DECLSPEC int MZ_DEC_PLACES;
+extern DECLSPEC int DELTA_MZ_DEC_PLACES;
+extern DECLSPEC int RT_MINUTES_DEC_PLACES;
+extern DECLSPEC int RT_SECONDS_DEC_PLACES;
+extern DECLSPEC int INTENSITY_DEC_PLACES;
 
 typedef QStringList ErrorList;
 
