@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -34,7 +34,6 @@
 /////////////////////// Local includes
 #include "MsXpS/libXpertMassCore/ChemicalGroup.hpp"
 
-
 namespace MsXpS
 {
 
@@ -189,7 +188,7 @@ ChemicalGroup::ChemicalGroup(const QString &name,
   ErrorList error_list;
   m_isValid = validate(&error_list);
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "The ChemicalGroup right constructed did not validate successfully.";
 }
 
@@ -260,7 +259,7 @@ ChemicalGroup::setName(QString name)
 
   if(!m_isValid)
     {
-      qCritical()
+      qDebug()
         << "After setting name, the object did not validate successfully.";
     }
 }
@@ -287,7 +286,7 @@ ChemicalGroup::setPka(float pka)
 
   if(!m_isValid)
     {
-      qCritical()
+      qDebug()
         << "After setting pKa, the object did not validate successfully.";
     }
 }
@@ -316,8 +315,8 @@ ChemicalGroup::setAcidCharged(bool acid_charged)
 
   if(!m_isValid)
     {
-      qCritical() << "After setting acid charged bool, the object did not "
-                     "validate successfully.";
+      qDebug() << "After setting acid charged bool, the object did not "
+                  "validate successfully.";
     }
 }
 
@@ -348,8 +347,9 @@ ChemicalGroup::setPolRule(Enums::ChemicalGroupTrapped pol_rule)
 
   if(!m_isValid)
     {
-      qCritical() << "After setting Enums::ChemicalGroupTrapped, the object did not "
-                     "validate successfully.";
+      qDebug()
+        << "After setting Enums::ChemicalGroupTrapped, the object did not "
+           "validate successfully.";
     }
 }
 
@@ -372,7 +372,6 @@ ChemicalGroup::getRulesCstRef() const
   return m_rules;
 }
 
-
 /*!
 \brief Returns a reference to the container of ChemicalGroupRule instances.
 */
@@ -455,7 +454,6 @@ ChemicalGroup::findRuleByName(const QString &name, std::size_t &index) const
   return nullptr;
 }
 
-
 /*!
 \brief Searches by \a entity and \a name for a ChemicalGroupRule instance.
 
@@ -511,14 +509,14 @@ ChemicalGroup::validate(ErrorList *error_list_p) const
 
   if(m_name.isEmpty())
     {
-      qCritical() << "The ChemicalGroup cannot validate with an empty name.";
+      qDebug() << "The ChemicalGroup cannot validate with an empty name.";
       error_list_p->push_back(
         "The ChemicalGroup cannot validate with an empty name");
     }
 
   if(m_pka <= 0 && m_pka >= 14)
     {
-      qCritical()
+      qDebug()
         << "The ChemicalGroup cannot validate with an invalid pKa value.";
       error_list_p->push_back(
         "The ChemicalGroup cannot validate with an invalid pKa value.");
@@ -529,7 +527,6 @@ ChemicalGroup::validate(ErrorList *error_list_p) const
   return m_isValid;
 }
 
-
 /*!
 \brief Returns the validity status of this instance.
  */
@@ -698,12 +695,12 @@ ChemicalGroup::renderXmlMnmElement(const QDomElement &element)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Failed to validate successfully, with errors:" << Utils::joinErrorList(error_list);
+    qDebug() << "Failed to validate successfully, with errors:"
+             << Utils::joinErrorList(error_list);
 
   return m_isValid;
 }
 
-
 /*!
 \brief Parses the ChemicalGroup XML \a element \e{related to a \l Modif}.
 
@@ -807,12 +804,12 @@ ChemicalGroup::renderXmlMdfElement(const QDomElement &element)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Failed to validate successfully, with errors:" << Utils::joinErrorList(error_list);
+    qDebug() << "Failed to validate successfully, with errors:"
+             << Utils::joinErrorList(error_list);
 
   return m_isValid;
 }
 
-
 //////////////////////// ChemicalGroupProp ////////////////////////
 //////////////////////// ChemicalGroupProp ////////////////////////
 
@@ -841,7 +838,6 @@ ChemicalGroupProp::ChemicalGroupProp(const QString &name, ChemicalGroup *data)
   mpa_data = static_cast<void *>(data);
 }
 
-
 /*!
 \brief Constructs a ChemicalGroupProp instance as a copy of \a other.
 
@@ -913,7 +909,6 @@ ChemicalGroupProp::operator=(const ChemicalGroupProp &other)
   return *this;
 }
 
-
 /*!
 \brief Duplicates this ChemicalGroupProp instance and returns its pointer.
 */
