@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -34,7 +34,6 @@
 /////////////////////// Local includes
 #include "MsXpS/libXpertMassCore/ChemicalGroupRule.hpp"
 
-
 namespace MsXpS
 {
 
@@ -197,12 +196,11 @@ ChemicalGroupRule::setName(const QString &name)
 
   if(!m_isValid)
     {
-      qCritical()
+      qDebug()
         << "After setting name, the object did not validate successfully.";
     }
 }
 
-
 /*!
 \brief Returns the name.
 */
@@ -212,7 +210,6 @@ ChemicalGroupRule::getName()
   return m_name;
 }
 
-
 /*!
 \brief Sets the \a entity.
 */
@@ -226,7 +223,7 @@ ChemicalGroupRule::setEntity(const QString &entity)
 
   if(!m_isValid)
     {
-      qCritical()
+      qDebug()
         << "After setting entity, the object did not validate successfully.";
     }
 }
@@ -253,7 +250,7 @@ ChemicalGroupRule::setFate(Enums::ChemicalGroupFate fate)
 
   if(!m_isValid)
     {
-      qCritical()
+      qDebug()
         << "After setting fate, the object did not validate successfully.";
     }
 }
@@ -300,16 +297,14 @@ ChemicalGroupRule::validate(ErrorList *error_list_p) const
 
   if(m_name.isEmpty())
     {
-      qCritical()
-        << "The ChemicalGroupRule cannot validate with an empty name.";
+      qDebug() << "The ChemicalGroupRule cannot validate with an empty name.";
       error_list_p->push_back(
         "The ChemicalGroupRule cannot validate with an empty name");
     }
 
   if(m_entity.isEmpty())
     {
-      qCritical()
-        << "The ChemicalGroupRule cannot validate with an empty entity.";
+      qDebug() << "The ChemicalGroupRule cannot validate with an empty entity.";
       error_list_p->push_back(
         "The ChemicalGroupRule cannot validate with an empty entity");
     }
@@ -371,8 +366,8 @@ ChemicalGroupRule::renderXmlElement(const QDomElement &element)
 
   if(element.tagName() != "chemgrouprule")
     {
-      qCritical() << "Failed to render <chemgrouprule> element: "
-                     "<chemgrouprule> element not found.";
+      qDebug() << "Failed to render <chemgrouprule> element: "
+                  "<chemgrouprule> element not found.";
       return false;
     }
 
@@ -380,8 +375,8 @@ ChemicalGroupRule::renderXmlElement(const QDomElement &element)
 
   if(child.isNull())
     {
-      qCritical() << "Failed to render <chemgrouprule> element: <entity> "
-                     "element not found.";
+      qDebug() << "Failed to render <chemgrouprule> element: <entity> "
+                  "element not found.";
       return false;
     }
 
@@ -391,8 +386,8 @@ ChemicalGroupRule::renderXmlElement(const QDomElement &element)
 
   if(child.isNull() || child.tagName() != "name")
     {
-      qCritical() << "Failed to render <chemgrouprule> element: <name> element "
-                     "not found.";
+      qDebug() << "Failed to render <chemgrouprule> element: <name> element "
+                  "not found.";
       return false;
     }
 
@@ -402,8 +397,8 @@ ChemicalGroupRule::renderXmlElement(const QDomElement &element)
 
   if(child.isNull() || child.tagName() != "outcome")
     {
-      qCritical() << "Failed to render <chemgrouprule> element: <outcome> "
-                     "element not found.";
+      qDebug() << "Failed to render <chemgrouprule> element: <outcome> "
+                  "element not found.";
       return false;
     }
 
@@ -413,8 +408,8 @@ ChemicalGroupRule::renderXmlElement(const QDomElement &element)
     m_chemicalGroupFate = Enums::ChemicalGroupFate::PRESERVED;
   else
     {
-      qCritical() << "Failed to render <chemgrouprule> element: <outcome> "
-                     "element had bad value.";
+      qDebug() << "Failed to render <chemgrouprule> element: <outcome> "
+                  "element had bad value.";
       return false;
     }
 
