@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009, ..., 2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -181,14 +181,14 @@ CleavageAgent::CleavageAgent(PolChemDefCstSPtr pol_chem_def_csp,
   : QObject(parent), mcsp_polChemDef(pol_chem_def_csp)
 {
   if(mcsp_polChemDef == nullptr || mcsp_polChemDef.get() == nullptr)
-    qCritical() << "Constructing CleavageAgent with no PolChemDef.";
+    qDebug() << "Constructing CleavageAgent with no PolChemDef.";
 
   if(version == 1)
     {
       qDebug() << "Rendering XmlClsElement version" << version;
 
       if(!renderXmlClsElement(element, version))
-        qCritical()
+        qDebug()
           << "Failed to fully render or validate the CleavageAgent XML element "
              "for construction of CleavageAgent instance.";
     }
@@ -197,7 +197,7 @@ CleavageAgent::CleavageAgent(PolChemDefCstSPtr pol_chem_def_csp,
       qDebug() << "Rendering XmlClaElement version" << version;
 
       if(!renderXmlClaElement(element, version))
-        qCritical()
+        qDebug()
           << "Failed to fully render or validate the CleavageAgent XML element "
              "for construction of CleavageAgent instance.";
     }
@@ -229,15 +229,14 @@ CleavageAgent::CleavageAgent(PolChemDefCstSPtr pol_chem_def_csp,
     m_pattern(pattern)
 {
   if(!parse())
-    qCritical()
-      << "Upon construction of the CleavageAgent, the pattern could not "
-         "be parsed.";
+    qDebug() << "Upon construction of the CleavageAgent, the pattern could not "
+                "be parsed.";
 
   ErrorList error_list;
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "Upon construction of the CleavageAgent, the instance failed to "
          "validate with errors:"
       << Utils::joinErrorList(error_list, ", ");
@@ -264,7 +263,7 @@ CleavageAgent::CleavageAgent(const CleavageAgent &other, QObject *parent)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "Upon copy-construction of the CleavageAgent, the instance failed to "
          "validate with errors:"
       << Utils::joinErrorList(error_list, ", ");
@@ -296,7 +295,7 @@ CleavageAgent::initialize(const CleavageAgent &other)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Failed to initalize the CleavageAgent instance.";
+    qDebug() << "Failed to initalize the CleavageAgent instance.";
 
   return m_isValid;
 }
@@ -317,7 +316,7 @@ CleavageAgent::setPolchemDefCstSPtr(PolChemDefCstSPtr pol_chem_def_csp)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "Upon setting PolChemDef of CleavageAgent, the instance failed to "
          "validate with errors:"
       << Utils::joinErrorList(error_list, ", ");
@@ -348,9 +347,9 @@ CleavageAgent::setName(const QString &name)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Upon setting name of CleavageAgent, the instance failed to "
-                   "validate with errors:"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Upon setting name of CleavageAgent, the instance failed to "
+                "validate with errors:"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
 /*!
@@ -375,16 +374,15 @@ CleavageAgent::setPattern(const QString &pattern)
   m_pattern = pattern;
 
   if(!parse())
-    qCritical() << "The pattern that was set could not be parsed.";
+    qDebug() << "The pattern that was set could not be parsed.";
 
   ErrorList error_list;
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
-      << "Upon setting pattern of CleavageAgent, the instance failed to "
-         "validate with errors:"
-      << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Upon setting pattern of CleavageAgent, the instance failed to "
+                "validate with errors:"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
 /*!
@@ -534,7 +532,7 @@ CleavageAgent::parse()
 
       if(iter_cleavage_site.length() < 2)
         {
-          qCritical() << iter_cleavage_site << "is an invalid cleavage site.";
+          qDebug() << iter_cleavage_site << "is an invalid cleavage site.";
 
           m_isValid = false;
           return false;
@@ -543,8 +541,7 @@ CleavageAgent::parse()
       int count = iter_cleavage_site.count(QChar('/'));
       if(count != 1)
         {
-          qCritical()
-            << "The must be one and only one '/' in the cleavage site.";
+          qDebug() << "The must be one and only one '/' in the cleavage site.";
 
           m_isValid = false;
           return false;
@@ -560,7 +557,7 @@ CleavageAgent::parse()
       count = iter_cleavage_site.count(QChar('-'));
       if(count > 1)
         {
-          qCritical() << "There must be at most one '-' in the cleavage site.";
+          qDebug() << "There must be at most one '-' in the cleavage site.";
 
           m_isValid = false;
           return false;
@@ -570,8 +567,8 @@ CleavageAgent::parse()
           if(iter_cleavage_site.indexOf(QChar('-'), 0, Qt::CaseInsensitive) !=
              0)
             {
-              qCritical() << "The '-' in the cleavage site must be at the "
-                             "beginning of the cleavage site.";
+              qDebug() << "The '-' in the cleavage site must be at the "
+                          "beginning of the cleavage site.";
 
               m_isValid = false;
               return false;
@@ -593,9 +590,9 @@ CleavageAgent::parse()
 
       if(!cleavage_motif_sp->isValid())
         {
-          qCritical() << "Failed to create a valid CleavageMotif by parsing "
-                         "cleavage site:"
-                      << iter_cleavage_site;
+          qDebug() << "Failed to create a valid CleavageMotif by parsing "
+                      "cleavage site:"
+                   << iter_cleavage_site;
           cleavage_motif_sp.reset();
           return false;
         }
@@ -799,8 +796,8 @@ CleavageAgent::validate(ErrorList *error_list_p) const
 
   if(mcsp_polChemDef == nullptr || mcsp_polChemDef.get() == nullptr)
     {
-      qCritical() << "A CleavageAgent with no PolChemDef available cannot "
-                     "validate successfully.";
+      qDebug() << "A CleavageAgent with no PolChemDef available cannot "
+                  "validate successfully.";
       error_list_p->push_back(
         "A CleavageAgent with no PolChemDef available cannot validate "
         "successfully");
@@ -808,15 +805,14 @@ CleavageAgent::validate(ErrorList *error_list_p) const
 
   if(m_name.isEmpty())
     {
-      qCritical()
-        << "A CleavageAgent with no name cannot validate successfully.";
+      qDebug() << "A CleavageAgent with no name cannot validate successfully.";
       error_list_p->push_back(
         "A CleavageAgent with no name cannot validate successfully");
     }
 
   if(m_pattern.isEmpty())
     {
-      qCritical()
+      qDebug()
         << "A CleavageAgent with no pattern cannot validate successfully.";
       error_list_p->push_back(
         "A CleavageAgent with no pattern cannot validate successfully");
@@ -827,8 +823,8 @@ CleavageAgent::validate(ErrorList *error_list_p) const
     {
       if(!cleavage_motif_sp->validate(error_list_p))
         {
-          qCritical() << "A CleavageAgent with invalid CleavageMotif instances "
-                         "cannot validate successfully.";
+          qDebug() << "A CleavageAgent with invalid CleavageMotif instances "
+                      "cannot validate successfully.";
           error_list_p->push_back(
             "A CleavageAgent with invalid CleavageMotif instances cannot "
             "validate "
@@ -842,8 +838,8 @@ CleavageAgent::validate(ErrorList *error_list_p) const
     {
       if(!cleavage_rule_sp->validate(error_list_p))
         {
-          qCritical() << "A CleavageAgent with invalid CleavageRule instances "
-                         "cannot validate successfully.";
+          qDebug() << "A CleavageAgent with invalid CleavageRule instances "
+                      "cannot validate successfully.";
           error_list_p->push_back(
             "A CleavageAgent with invalid CleavageRule instances cannot "
             "validate "
@@ -914,7 +910,7 @@ CleavageAgent::renderXmlClsElement(const QDomElement &element,
 
   if(element.tagName() != "cls")
     {
-      qCritical() << "The expected <cls> element is not found.";
+      qDebug() << "The expected <cls> element is not found.";
       m_isValid = false;
       return m_isValid;
     }
@@ -923,9 +919,8 @@ CleavageAgent::renderXmlClsElement(const QDomElement &element,
 
   if(child.isNull() || child.text().isEmpty())
     {
-      qCritical()
-        << "The CleaveSpec did not render correctly: problem with the "
-           "<name> element.";
+      qDebug() << "The CleaveSpec did not render correctly: problem with the "
+                  "<name> element.";
       m_isValid = false;
       return m_isValid;
     }
@@ -936,9 +931,8 @@ CleavageAgent::renderXmlClsElement(const QDomElement &element,
 
   if(child.isNull() || child.text().isEmpty())
     {
-      qCritical()
-        << "The CleaveSpec did not render correctly: problem with the "
-           "<pattern> element.";
+      qDebug() << "The CleaveSpec did not render correctly: problem with the "
+                  "<pattern> element.";
       m_isValid = false;
       return m_isValid;
     }
@@ -946,8 +940,8 @@ CleavageAgent::renderXmlClsElement(const QDomElement &element,
 
   if(!parse())
     {
-      qCritical() << "The CleaveSpec being initialized with a <cls> XML "
-                     "element had an unparseable pattern.";
+      qDebug() << "The CleaveSpec being initialized with a <cls> XML "
+                  "element had an unparseable pattern.";
       m_isValid = false;
       return false;
     }
@@ -962,7 +956,7 @@ CleavageAgent::renderXmlClsElement(const QDomElement &element,
 
       if(!cleavage_rule_sp->renderXmlClrElement(child, version))
         {
-          qCritical() << "Failed to render CleaveRule from <clr> XML element.";
+          qDebug() << "Failed to render CleaveRule from <clr> XML element.";
           m_isValid = false;
           cleavage_rule_sp.reset();
           return false;
@@ -971,8 +965,8 @@ CleavageAgent::renderXmlClsElement(const QDomElement &element,
       ErrorList error_list;
       if(!cleavage_rule_sp->validate(&error_list))
         {
-          qCritical() << "Failed to validate CleaveRule rendered from <clr> "
-                         "XML element, with errors:";
+          qDebug() << "Failed to validate CleaveRule rendered from <clr> "
+                      "XML element, with errors:";
           Utils::joinErrorList(error_list, ", ");
           cleavage_rule_sp.reset();
           return false;
@@ -987,9 +981,9 @@ CleavageAgent::renderXmlClsElement(const QDomElement &element,
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Failed to validate CleaveSpec instance right after "
-                   "rendering it from <cls> XML element, with errors:"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Failed to validate CleaveSpec instance right after "
+                "rendering it from <cls> XML element, with errors:"
+             << Utils::joinErrorList(error_list, ", ");
 
   return m_isValid;
 }
@@ -1041,7 +1035,7 @@ CleavageAgent::renderXmlClaElement(const QDomElement &element,
 
   if(element.tagName() != "cla")
     {
-      qCritical() << "The expected <cla> element is not found.";
+      qDebug() << "The expected <cla> element is not found.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1050,7 +1044,7 @@ CleavageAgent::renderXmlClaElement(const QDomElement &element,
 
   if(child.isNull() || child.text().isEmpty())
     {
-      qCritical()
+      qDebug()
         << "The CleavageAgent did not render correctly: problem with the "
            "<name> element.";
       m_isValid = false;
@@ -1063,7 +1057,7 @@ CleavageAgent::renderXmlClaElement(const QDomElement &element,
 
   if(child.isNull() || child.text().isEmpty())
     {
-      qCritical()
+      qDebug()
         << "The CleavageAgent did not render correctly: problem with the "
            "<pattern> element.";
       m_isValid = false;
@@ -1074,8 +1068,8 @@ CleavageAgent::renderXmlClaElement(const QDomElement &element,
 
   if(!parse())
     {
-      qCritical() << "The CleavageAgent being initialized with a <cls> XML "
-                     "element had an unparseable pattern.";
+      qDebug() << "The CleavageAgent being initialized with a <cls> XML "
+                  "element had an unparseable pattern.";
       m_isValid = false;
       return false;
     }
@@ -1095,8 +1089,7 @@ CleavageAgent::renderXmlClaElement(const QDomElement &element,
 
       if(!cleavage_rule_sp->renderXmlClrElement(child, version))
         {
-          qCritical()
-            << "Failed to render CleavageRule from <clr> XML element.";
+          qDebug() << "Failed to render CleavageRule from <clr> XML element.";
           m_isValid = false;
           cleavage_rule_sp.reset();
           return false;
@@ -1107,8 +1100,8 @@ CleavageAgent::renderXmlClaElement(const QDomElement &element,
       ErrorList error_list;
       if(!cleavage_rule_sp->validate(&error_list))
         {
-          qCritical() << "Failed to validate CleavageRule rendered from <clr> "
-                         "XML element, with errors:";
+          qDebug() << "Failed to validate CleavageRule rendered from <clr> "
+                      "XML element, with errors:";
           Utils::joinErrorList(error_list, ", ");
           cleavage_rule_sp.reset();
           return false;
@@ -1125,9 +1118,9 @@ CleavageAgent::renderXmlClaElement(const QDomElement &element,
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Failed to validate CleavageAgent instance right after "
-                   "rendering it from <cls> XML element, with errors:"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Failed to validate CleavageAgent instance right after "
+                "rendering it from <cls> XML element, with errors:"
+             << Utils::joinErrorList(error_list, ", ");
   else
     qDebug() << "Successfully parsed the <cla> element.";
 
@@ -1236,7 +1229,7 @@ CleavageAgent::registerJsConstructor(QJSEngine *engine)
 {
   if(!engine)
     {
-      qWarning() << "Cannot register CleavageAgent class: engine is null";
+      qDebug() << "Cannot register CleavageAgent class: engine is null";
       return;
     }
 
