@@ -2,7 +2,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -180,7 +180,7 @@ CleavageConfig::initialize(const CleavageConfig &other)
   bool ok = CleavageAgent::initialize(other);
 
   if(!ok)
-    qCritical() << "Failed to initalize the CleavageConfig instance.";
+    qDebug() << "Failed to initalize the CleavageConfig instance.";
 
   m_partials         = other.m_partials;
   m_startIonizeLevel = other.m_startIonizeLevel;
@@ -201,7 +201,7 @@ CleavageConfig::setCleavageAgent(const CleavageAgent &cleavage_agent)
   bool ok = CleavageAgent::initialize(cleavage_agent);
 
   if(!ok)
-    qCritical() << "Failed to initalize the CleavageConfig instance.";
+    qDebug() << "Failed to initalize the CleavageConfig instance.";
 
   return ok;
 }
@@ -322,7 +322,8 @@ CleavageConfig::isSequenceEmbedded() const
 //////////////// OPERATORS /////////////////////
 
 /*!
-\brief Returns true if this CleavageConfig instance and \a other are identical, false otherwise.
+\brief Returns true if this CleavageConfig instance and \a other are identical,
+false otherwise.
 \sa operator!=()
 */
 bool
@@ -356,7 +357,7 @@ CleavageConfig::registerJsConstructor(QJSEngine *engine)
 {
   if(!engine)
     {
-      qWarning() << "Cannot register CleavageConfig class: engine is null";
+      qDebug() << "Cannot register CleavageConfig class: engine is null";
       return;
     }
 
