@@ -2,7 +2,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009, ..., 2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -273,7 +273,7 @@ Cleaver::cleave(bool reset)
   // If the polymer sequence is empty, just return.
   if(!mcsp_polymer->size())
     {
-      qCritical() << "The polymer sequence is empty: nothing to cleave.";
+      qDebug() << "The polymer sequence is empty: nothing to cleave.";
       return true;
     }
 
@@ -283,7 +283,7 @@ Cleaver::cleave(bool reset)
     {
       if(!m_cleavageConfig.parse())
         {
-          qCritical() << "Failed to parse the cleavage options";
+          qDebug() << "Failed to parse the cleavage options";
 
           return false;
         }
@@ -326,7 +326,7 @@ Cleaver::cleave(bool reset)
 
       if(cleavePartial(iter) == -1)
         {
-          qCritical() << "Failed to perform partial cleavage" << iter;
+          qDebug() << "Failed to perform partial cleavage" << iter;
 
           return false;
         }
@@ -944,7 +944,7 @@ Cleaver::cleavePartial(int partial_cleavage)
 
       if(!ok)
         {
-          qWarning() << "Failed to account formula:" << elemental_composition;
+          qDebug() << "Failed to account formula:" << elemental_composition;
           oligomer_sp.reset();
 
           return -1;
@@ -1024,7 +1024,7 @@ Cleaver::cleavePartial(int partial_cleavage)
 
   if(!ok)
     {
-      qWarning() << "Failed to account formula:" << elemental_composition;
+      qDebug() << "Failed to account formula:" << elemental_composition;
       oligomer_sp.reset();
       return -1;
     }
@@ -1111,7 +1111,8 @@ Cleaver::cleavePartial(int partial_cleavage)
           //          << "Oligomer mono mass BEFORE accounting it:"
           //          << iter_oligomer_sp->getMass(Enums::MassType::MONO)
           //          << "and internal formula is:"
-          //          << iter_oligomer_sp->getFormulaCstRef().getActionFormula();
+          //          <<
+          //          iter_oligomer_sp->getFormulaCstRef().getActionFormula();
 
           // Note that the accounting of the cleavage rule is
           // performed as if the oligomer was charged 1. This is why
@@ -1126,7 +1127,8 @@ Cleaver::cleavePartial(int partial_cleavage)
           //          << "Oligomer mono mass AFTER accounting it:"
           //          << iter_oligomer_sp->getMass(Enums::MassType::MONO)
           //          << "and internal formula has become:"
-          //          << iter_oligomer_sp->getFormulaCstRef().getActionFormula();
+          //          <<
+          //          iter_oligomer_sp->getFormulaCstRef().getActionFormula();
         }
 
       // qDebug() << "Done iterating in the CleavageRule instances.";
@@ -1168,7 +1170,7 @@ Cleaver::cleavePartial(int partial_cleavage)
 
           if(new_oligomer_sp->ionize() == Enums::IonizationOutcome::FAILED)
             {
-              qCritical() << "Failed to ionize the oligomer.";
+              qDebug() << "Failed to ionize the oligomer.";
 
               new_oligomer_sp.reset();
 
@@ -1185,8 +1187,8 @@ Cleaver::cleavePartial(int partial_cleavage)
 
           if(!ok)
             {
-              qWarning() << "Failed to account the ionizer formula:"
-                         << temp_ionizer.getFormulaCstRef().getActionFormula();
+              qDebug() << "Failed to account the ionizer formula:"
+                       << temp_ionizer.getFormulaCstRef().getActionFormula();
               new_oligomer_sp.reset();
 
               return -1;
@@ -1196,7 +1198,8 @@ Cleaver::cleavePartial(int partial_cleavage)
           //          << "Oligomer mono mass:"
           //          << iter_oligomer_sp->getMass(Enums::MassType::MONO)
           //          << "and internal formula has become:"
-          //          << iter_oligomer_sp->getFormulaCstRef().getActionFormula();
+          //          <<
+          //          iter_oligomer_sp->getFormulaCstRef().getActionFormula();
 
           // The name was set already during the creation of the
           // template oligomer. All we have to add to the name is the
@@ -1792,7 +1795,8 @@ Cleaver::analyzeCrossLinkedOligomer(OligomerSPtr oligomer_sp,
 //////////////// OPERATORS /////////////////////
 
 /*!
-\brief Returns a reference to this Cleaver instance after initialization using \a other.
+\brief Returns a reference to this Cleaver instance after initialization using
+\a other.
 */
 Cleaver &
 Cleaver::operator=(const Cleaver &other)
