@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -399,7 +399,7 @@ CrossLink::removeMonomer(MonomerCstSPtr monomer_csp)
 
   if(the_iterator_cst == m_monomers.end())
     {
-      qCritical() << "The MonomerCstSPtr was not found in the container.";
+      qDebug() << "The MonomerCstSPtr was not found in the container.";
 
       if(!uuid.isEmpty())
         qFatalStream()
@@ -457,7 +457,7 @@ CrossLink::fillInMonomers(QString monomer_indices_text, bool &ok)
 
   if(indices_list.size() < 2)
     {
-      qCritical() << "The count of indices must be greater than 2.";
+      qDebug() << "The count of indices must be greater than 2.";
 
       ok = false;
       return 0;
@@ -730,7 +730,7 @@ CrossLink::operator=(const CrossLink &other)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "The assignment operator copying produced a CrossLink that is not "
          "valid, with errors:"
       << Utils::joinErrorList(error_list, ", ");
@@ -996,7 +996,7 @@ CrossLink::validate(ErrorList *error_list_p) const
       error_list_p->push_back(
         "A CrossLink involving on one Monomer is invalid");
 
-      qCritical() << "A CrossLink involving on one Monomer is invalid.";
+      qDebug() << "A CrossLink involving on one Monomer is invalid.";
 
       m_isValid = false;
     }
@@ -1005,7 +1005,7 @@ CrossLink::validate(ErrorList *error_list_p) const
     {
       error_list_p->push_back("A CrossLink with no Polymer is invalid");
 
-      qCritical() << "A CrossLink with no Polymer is invalid.";
+      qDebug() << "A CrossLink with no Polymer is invalid.";
 
       m_isValid = false;
     }
@@ -1017,7 +1017,7 @@ CrossLink::validate(ErrorList *error_list_p) const
           error_list_p->push_back(
             "A CrossLink involving invalid Monomer instances is invalid");
 
-          qCritical()
+          qDebug()
             << "A CrossLink involving invalid Monomer instances is invalid.";
 
           m_isValid = false;
@@ -1028,7 +1028,7 @@ CrossLink::validate(ErrorList *error_list_p) const
     {
       error_list_p->push_back("A CrossLink with no CrossLinker is invalid");
 
-      qCritical() << "A CrossLink with no CrossLinker is invalid.";
+      qDebug() << "A CrossLink with no CrossLinker is invalid.";
 
       m_isValid = false;
       return m_isValid;
@@ -1040,7 +1040,7 @@ CrossLink::validate(ErrorList *error_list_p) const
           error_list_p->push_back(
             "A CrossLink with an invalid CrossLinker is invalid");
 
-          qCritical() << "A CrossLink with an invalid CrossLinker is invalid.";
+          qDebug() << "A CrossLink with an invalid CrossLinker is invalid.";
 
           m_isValid = false;
           return m_isValid;
@@ -1071,9 +1071,9 @@ CrossLink::validate(ErrorList *error_list_p) const
                 "does not match the number of "
                 "Monomer is invalid");
 
-              qCritical() << "A CrossLink where the number of Modif "
-                             "does not match the number of "
-                             "Monomer is invalid.";
+              qDebug() << "A CrossLink where the number of Modif "
+                          "does not match the number of "
+                          "Monomer is invalid.";
 
               m_isValid = false;
               return m_isValid;
@@ -1090,8 +1090,8 @@ CrossLink::validate(ErrorList *error_list_p) const
                     "A CrossLink where the Monomer is not a target of Modif is "
                     "invalid");
 
-                  qCritical() << "A CrossLink where the Monomer is not a "
-                                 "target of Modif is invalid";
+                  qDebug() << "A CrossLink where the Monomer is not a "
+                              "target of Modif is invalid";
 
                   m_isValid = false;
                   return m_isValid;
