@@ -2,7 +2,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -34,7 +34,6 @@
 /////////////////////// Local includes
 #include "MsXpS/libXpertMassCore/CrossLinkedRegion.hpp"
 
-
 namespace MsXpS
 {
 namespace libXpertMassCore
@@ -129,7 +128,7 @@ CrossLinkedRegion::CrossLinkedRegion(std::size_t index_start,
 }
 
 /*!
-\brief Constructs a CrossLinkedRegion instance as a copy of \a other.
+\brief Constructs a CrossLinkedRegion instance as a copy of \a other.
 
 The copy of the CrossLink instances is shallow (the shared pointers are copied).
 */
@@ -183,7 +182,6 @@ CrossLinkedRegion::getStopIndex()
   return m_stopIndex;
 }
 
-
 /*!
 \brief Returns a const reference to the container of CrossLink instances.
 */
@@ -193,7 +191,6 @@ CrossLinkedRegion::getCrossLinksCstRef() const
   return m_crossLinks;
 }
 
-
 /*!
 \brief Returns a reference to the container of CrossLink instances.
 */
@@ -203,9 +200,9 @@ CrossLinkedRegion::getCrossLinksRef()
   return m_crossLinks;
 }
 
-
 /*!
-\brief Adds a the \a cross_link_sp CrossLink to the back of the CrossLink container.
+\brief Adds a the \a cross_link_sp CrossLink to the back of the CrossLink
+container.
 
 Returns the size of the container of CrossLink instances.
 */
