@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -35,7 +35,6 @@
 #include "MsXpS/libXpertMassCore/CrossLinker.hpp"
 #include "MsXpS/libXpertMassCore/PolChemDef.hpp"
 
-
 namespace MsXpS
 {
 namespace libXpertMassCore
@@ -153,15 +152,14 @@ CrossLinker::CrossLinker(PolChemDefCstSPtr pol_chem_def_csp,
   : mcsp_polChemDef(pol_chem_def_csp)
 {
   if(mcsp_polChemDef == nullptr || mcsp_polChemDef.get() == nullptr)
-    qCritical() << "Constructing CrossLinker with no PolChemDef.";
+    qDebug() << "Constructing CrossLinker with no PolChemDef.";
 
   if(!renderXmlClkElement(element, version))
-    qCritical()
+    qDebug()
       << "Failed to fully render or validate the CrossLinker XML element "
          "for construction of CrossLinker instance.";
 }
 
-
 /*!
 \brief Constructs a CrossLinker instance.
 
@@ -215,12 +213,11 @@ CrossLinker::CrossLinker(const CrossLinker &other)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "The copy constructor instantiated a CrossLink that is not "
-                   "valid,  with errors:"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "The copy constructor instantiated a CrossLink that is not "
+                "valid,  with errors:"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
-
 /*!
 \brief Destructs this CrossLinker instance
 */
@@ -230,7 +227,8 @@ CrossLinker::~CrossLinker()
 }
 
 /*!
-\brief Initializes this CrossLinker instance using \a element, according to  \a version.
+\brief Initializes this CrossLinker instance using \a element, according to  \a
+version.
 
 Returns true if the rendering of \a element was successful, false otherwise.
 
@@ -240,13 +238,13 @@ bool
 CrossLinker::initialize(const QDomElement &element, int version)
 {
   if(!renderXmlClkElement(element, version))
-  {
-    qCritical()
-      << "Failed to fully render or validate the CrossLinker XML element "
-         "for construction of CrossLinker instance.";
+    {
+      qDebug()
+        << "Failed to fully render or validate the CrossLinker XML element "
+           "for construction of CrossLinker instance.";
 
       return false;
-  }
+    }
 
   return true;
 }
@@ -265,8 +263,8 @@ CrossLinker::setPolChemDefCstSPtr(PolChemDefCstSPtr pol_chem_def_csp)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Failed to validate the CrossLinker with errors:\n"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Failed to validate the CrossLinker with errors:\n"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
 /*!
@@ -292,8 +290,8 @@ CrossLinker::setName(const QString &name)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Failed to validate the CrossLinker with errors:\n"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Failed to validate the CrossLinker with errors:\n"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
 /*!
@@ -318,8 +316,8 @@ CrossLinker::setFormula(const QString &formula_string)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Failed to validate the CrossLinker with errors:\n"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Failed to validate the CrossLinker with errors:\n"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
 /*
@@ -401,7 +399,6 @@ CrossLinker::getModifAt(std::size_t index) const
   return m_modifs.at(index);
 }
 
-
 /*!
 \brief Removes the \l Modif instance at \a index.
 
@@ -435,7 +432,6 @@ CrossLinker::hasModif(const QString &modif_name)
   return the_iterator_cst != m_modifs.cend();
 }
 
-
 /*!
 \brief Returns the index of the found \l Modif instance by \a modif_name in
 the container, -1 otherwise.
@@ -454,7 +450,6 @@ CrossLinker::modifIndex(const QString &modif_name)
   return std::distance(m_modifs.cbegin(), the_iterator_cst);
 }
 
-
 //////////////// OPERATORS /////////////////////
 /*!
 \brief Assigns \a other to this CrossLinker instance.
@@ -492,7 +487,7 @@ CrossLinker::operator=(const CrossLinker &other)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "The assignment operator copying produced a CrossLink that is not "
          "valid,  with errors:"
       << Utils::joinErrorList(error_list, ", ");
@@ -531,7 +526,6 @@ CrossLinker::operator==(const CrossLinker &other) const
   return true;
 }
 
-
 /*!
 \brief Returns true if this CrossLinker and \a other are different.
 
@@ -580,7 +574,6 @@ CrossLinker::getFromPolChemDefByName() const
   return (*the_iterator_cst);
 }
 
-
 /*!
 \brief Returns the status of this CrossLinker instance the polymer chemistry
 definition registered in this instance.
@@ -606,7 +599,6 @@ CrossLinker::isKnownByNameInPolChemDef() const
   return Enums::PolChemDefEntityStatus::ENTITY_NOT_KNOWN;
 };
 
-
 /*!
 \brief Returns true if this CrossLinker instance validates successfully,
 false otherwise.
@@ -635,8 +627,9 @@ CrossLinker::validate(ErrorList *error_list_p) const
      mcsp_polChemDef->getIsotopicDataCstSPtr().get() == nullptr ||
      !mcsp_polChemDef->getIsotopicDataCstSPtr()->size())
     {
-      error_list_p->push_back("The PolChemDef or IsotopicData are not available");
-      qCritical()
+      error_list_p->push_back(
+        "The PolChemDef or IsotopicData are not available");
+      qDebug()
         << "The polymer chemistry definition member datum is nullptr or "
            "its isotopic data are be either nullptr or empty. CrossLinker "
            "validation "
@@ -648,7 +641,7 @@ CrossLinker::validate(ErrorList *error_list_p) const
 
   if(m_name.isEmpty())
     {
-      qCritical() << "The CrossLinker name is empty.";
+      qDebug() << "The CrossLinker name is empty.";
       error_list_p->push_back("The CrossLinker name is empty");
     }
 
@@ -660,7 +653,7 @@ CrossLinker::validate(ErrorList *error_list_p) const
       if(!temp_formula.validate(mcsp_polChemDef->getIsotopicDataCstSPtr(),
                                 error_list_p))
         {
-          qCritical() << "The CrossLinker formula failed to validate.";
+          qDebug() << "The CrossLinker formula failed to validate.";
           error_list_p->push_back("The CrossLinker formula failed to validate");
         }
     }
@@ -670,7 +663,7 @@ CrossLinker::validate(ErrorList *error_list_p) const
 
   if(!calculateMasses(mcsp_polChemDef->getIsotopicDataCstSPtr(), mono, avg))
     {
-      qCritical() << "Failed to calculate the CrossLinker masses.";
+      qDebug() << "Failed to calculate the CrossLinker masses.";
       error_list_p->push_back("Failed to calculate the CrossLinker masses");
     }
 
@@ -688,8 +681,8 @@ CrossLinker::validate(ErrorList *error_list_p) const
 
   if(size > 0 && size < 2)
     {
-      qCritical() << "The CrossLinker may have either zero or more at least "
-                     "two Modif instances.";
+      qDebug() << "The CrossLinker may have either zero or more at least "
+                  "two Modif instances.";
       error_list_p->push_back(
         "The CrossLinker may have either zero or at least two Modif instances");
 
@@ -702,19 +695,20 @@ CrossLinker::validate(ErrorList *error_list_p) const
       //  The modif must be in the context of our PolChemDef.
       if(modif_csp->getPolChemDefCstSPtr() != mcsp_polChemDef)
         {
-          qCritical()
+          qDebug()
             << "One Modif:" << modif_csp->getName()
             << "has not the same PolChemDef as that of this CrossLinker.";
-          error_list_p->push_back(QString("One Modif: %1 has not the same "
-                                       "PolChemDef as that of this CrossLinker")
-                                 .arg(modif_csp->getName()));
+          error_list_p->push_back(
+            QString("One Modif: %1 has not the same "
+                    "PolChemDef as that of this CrossLinker")
+              .arg(modif_csp->getName()));
           m_isValid = false;
           return m_isValid;
         }
       if(!modif_csp->validate(error_list_p))
         {
-          qCritical() << "One Modif:" << modif_csp->getName()
-                      << "failed to validate successfully.";
+          qDebug() << "One Modif:" << modif_csp->getName()
+                   << "failed to validate successfully.";
           error_list_p->push_back(
             QString("One Modif: %1 ailed to validate successfully")
               .arg(modif_csp->getName()));
@@ -736,7 +730,6 @@ CrossLinker::isValid() const
   return m_isValid;
 }
 
-
 //////////////// MASS OPERATIONS /////////////////////
 
 /*!
@@ -764,7 +757,7 @@ CrossLinker::calculateMasses(const IsotopicDataCstSPtr &isotopic_data_csp,
       if(local_isotopic_data_csp == nullptr ||
          local_isotopic_data_csp.get() == nullptr)
         {
-          qCritical() << "Failed to find usable isotopic data.";
+          qDebug() << "Failed to find usable isotopic data.";
           m_isValid = false;
           return m_isValid;
         }
@@ -784,8 +777,8 @@ CrossLinker::calculateMasses(const IsotopicDataCstSPtr &isotopic_data_csp,
 
       if(!ok)
         {
-          qCritical() << "Failed accounting masses for CrossLinker:" << m_name
-                      << "and formula:" << m_formula;
+          qDebug() << "Failed accounting masses for CrossLinker:" << m_name
+                   << "and formula:" << m_formula;
           m_isValid = false;
           return m_isValid;
         }
@@ -835,7 +828,7 @@ CrossLinker::calculateMasses(const IsotopicDataCstSPtr &isotopic_data_csp)
       if(local_isotopic_data_csp == nullptr ||
          local_isotopic_data_csp.get() == nullptr)
         {
-          qCritical() << "Failed to find usable isotopic data.";
+          qDebug() << "Failed to find usable isotopic data.";
           m_isValid = false;
           return m_isValid;
         }
@@ -856,8 +849,8 @@ CrossLinker::calculateMasses(const IsotopicDataCstSPtr &isotopic_data_csp)
 
       if(!ok)
         {
-          qCritical() << "Failed accounting masses for CrossLinker:" << m_name
-                      << "and formula:" << m_formula;
+          qDebug() << "Failed accounting masses for CrossLinker:" << m_name
+                   << "and formula:" << m_formula;
           m_isValid = false;
           return m_isValid;
         }
@@ -904,7 +897,6 @@ CrossLinker::accountMasses(double *mono_p, double *avg_p, int times) const
   return *this;
 }
 
-
 /*!
 \brief Increases \a mono and \a avg by the corresponding member masses
 first compounded by \a times.
@@ -918,7 +910,7 @@ CrossLinker::accountMasses(double &mono, double &avg, int times) const
   //<< "avg:" << m_avg << "by" << times << "times.";
 
   mono += m_mono * times;
-  avg += m_avg * times;
+  avg  += m_avg * times;
 
   return *this;
 }
@@ -934,8 +926,8 @@ CrossLinker::getMass(Enums::MassType mass_type) const
   else if(mass_type == Enums::MassType::AVG)
     return m_avg;
 
-  qFatalStream()
-    << "Mass cannot be anything else than Enums::MassType::MONO or Enums::MassType::AVG.";
+  qFatalStream() << "Mass cannot be anything else than Enums::MassType::MONO "
+                    "or Enums::MassType::AVG.";
 
   return -1;
 }
@@ -985,8 +977,8 @@ CrossLinker::renderXmlClkElement(const QDomElement &element,
 
   if(child.isNull())
     {
-      qCritical() << "The CrossLinker did not render correctly: the <formula> "
-                     "element tag was not found.";
+      qDebug() << "The CrossLinker did not render correctly: the <formula> "
+                  "element tag was not found.";
       m_isValid = false;
       return m_isValid;
     }
@@ -999,7 +991,7 @@ CrossLinker::renderXmlClkElement(const QDomElement &element,
 
       if(!temp_formula.renderXmlFormulaElement(child))
         {
-          qCritical()
+          qDebug()
             << "The CrossLinker did not render correctly: the formula did not "
                "render correctly.";
           m_isValid = false;
@@ -1011,7 +1003,7 @@ CrossLinker::renderXmlClkElement(const QDomElement &element,
       if(!temp_formula.validate(mcsp_polChemDef->getIsotopicDataCstSPtr(),
                                 &error_list))
         {
-          qCritical()
+          qDebug()
             << "The CrossLinker did not render correctly: the formula did not "
                "render correctly with errors:"
             << Utils::joinErrorList(error_list);
@@ -1028,7 +1020,7 @@ CrossLinker::renderXmlClkElement(const QDomElement &element,
 
   if(mcsp_polChemDef == nullptr || mcsp_polChemDef.get() == nullptr)
     {
-      qCritical() << "The PolChemDef is unavailable,  cannot render any Modif.";
+      qDebug() << "The PolChemDef is unavailable,  cannot render any Modif.";
       return false;
     }
 
@@ -1071,8 +1063,8 @@ CrossLinker::renderXmlClkElement(const QDomElement &element,
     {
       if(child.tagName() != "modifname")
         {
-          qCritical() << "The CrossLinker did not render correctly: the "
-                         "<modifname> element tag was not found.";
+          qDebug() << "The CrossLinker did not render correctly: the "
+                      "<modifname> element tag was not found.";
 
           return false;
         }
@@ -1087,8 +1079,8 @@ CrossLinker::renderXmlClkElement(const QDomElement &element,
         m_modifs.push_back(modif_csp);
       else
         {
-          qCritical() << "The CrossLinker references a Modif by name that "
-                         "could not be found in the PolChemDef.";
+          qDebug() << "The CrossLinker references a Modif by name that "
+                      "could not be found in the PolChemDef.";
 
           return false;
         }
@@ -1108,9 +1100,9 @@ CrossLinker::renderXmlClkElement(const QDomElement &element,
 
   if(!validate(&error_list))
     {
-      qCritical() << "The CrossLinker rendered as an XML <clk> element failed "
-                     "to validate with errors:"
-                  << Utils::joinErrorList(error_list, ", ");
+      qDebug() << "The CrossLinker rendered as an XML <clk> element failed "
+                  "to validate with errors:"
+               << Utils::joinErrorList(error_list, ", ");
 
       m_isValid = false;
       return m_isValid;
