@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -209,7 +209,7 @@ Formula::Formula(const QDomElement &element, int version, QObject *parent)
   bool result = renderXmlFormulaElement(element, version);
 
   if(!result)
-    qCritical()
+    qDebug()
       << "Failed rendering XML element for construction of Formula instance.";
 }
 
@@ -228,20 +228,20 @@ Formula::Formula(const QString &formula_string, QObject *parent)
   : QObject(parent), m_actionFormula{formula_string}
 {
   m_title = removeTitle();
-  // qDebug() <<  "The title:" <<  m_title;
+  qDebug() << "The title:" << m_title;
 
   removeSpaces();
-  // qDebug() <<  "Formula after removing spaces:" <<  m_actionFormula;
+  qDebug() << "Formula after removing spaces:" << m_actionFormula;
 
   if(m_actionFormula.isEmpty())
     {
-      qCritical() << "Formula created empty.";
+      qDebug() << "Formula created empty.";
     }
 
-  if(!checkSyntax())
+  if(!checkSyntax(m_actionFormula))
     {
-      qCritical() << "Formula constructed with an action formula that does not "
-                     "pass the checkSyntax test.";
+      qDebug() << "Formula constructed with an action formula that does not "
+                  "pass the checkSyntax test.";
     }
 
   //  Because there has been no validation with IsotopicData,  the default
@@ -267,7 +267,7 @@ Formula::Formula(const Formula &other, QObject *parent)
   //  Sanity check
   if(!removeTitle().isEmpty())
     {
-      qCritical() << "The formula string still has a title.";
+      qDebug() << "The formula string still has a title.";
       m_isValid = false;
     }
   // GCOV_EXCL_STOP
@@ -276,14 +276,13 @@ Formula::Formula(const Formula &other, QObject *parent)
 
   if(m_actionFormula.isEmpty())
     {
-      qCritical()
-        << "Copy-constructed Formula created with empty action-formula.";
+      qDebug() << "Copy-constructed Formula created with empty action-formula.";
       m_isValid = false;
     }
 
-  if(!checkSyntax())
+  if(!checkSyntax(m_actionFormula))
     {
-      qCritical()
+      qDebug()
         << "Formula constructed with an action formula that does not pass the "
            "checkSyntax test.";
       m_isValid = false;
@@ -300,7 +299,8 @@ Formula::~Formula()
 }
 
 /*!
-\brief Return a newly allocated Formula that is initialized using \a other and setting its parent to \a parent.
+\brief Return a newly allocated Formula that is initialized using \a other and
+setting its parent to \a parent.
 */
 Formula *
 Formula::clone(const Formula &other, QObject *parent)
@@ -311,7 +311,8 @@ Formula::clone(const Formula &other, QObject *parent)
 }
 
 /*!
-\brief Return a reference to this Formula after having initialized it using \a other.
+\brief Return a reference to this Formula after having initialized it using \a
+other.
 */
 Formula &
 Formula::initialize(const Formula &other)
@@ -330,7 +331,7 @@ Formula::initialize(const Formula &other)
   //  Sanity check
   if(!removeTitle().isEmpty())
     {
-      qCritical() << "The formula string still has a title.";
+      qDebug() << "The formula string still has a title.";
       m_isValid = false;
     }
   // GCOV_EXCL_STOP
@@ -339,14 +340,14 @@ Formula::initialize(const Formula &other)
 
   if(m_actionFormula.isEmpty())
     {
-      qCritical() << "Formula created empty.";
+      qDebug() << "Formula created empty.";
       m_isValid = false;
     }
 
-  if(!checkSyntax())
+  if(!checkSyntax(m_actionFormula))
     {
-      qCritical() << "Formula set to an action formula that does not pass the "
-                     "checkSyntax test.";
+      qDebug() << "Formula set to an action formula that does not pass the "
+                  "checkSyntax test.";
       m_isValid = false;
     }
 
@@ -370,12 +371,12 @@ Formula::setActionFormula(const QString &formula)
 
   if(m_actionFormula.isEmpty())
     {
-      qCritical() << "Formula set to an empty string.";
+      qDebug() << "Formula set to an empty string.";
     }
 
-  if(!checkSyntax())
-    qCritical() << "Formula set to an action formula that does not pass the "
-                   "checkSyntax test.";
+  if(!checkSyntax(m_actionFormula))
+    qDebug() << "Formula set to an action formula that does not pass the "
+                "checkSyntax test.";
 
   m_isValid = false;
 }
@@ -394,12 +395,12 @@ Formula::setActionFormula(const Formula &formula)
 
   if(m_actionFormula.isEmpty())
     {
-      qCritical() << "Formula set to an empty string.";
+      qDebug() << "Formula set to an empty string.";
     }
 
-  if(!checkSyntax())
-    qCritical() << "Formula set to an action formula that does not pass the "
-                   "checkSyntax test.";
+  if(!checkSyntax(m_actionFormula))
+    qDebug() << "Formula set to an action formula that does not pass the "
+                "checkSyntax test.";
 
   m_isValid = false;
 }
@@ -441,7 +442,7 @@ Formula::appendActionFormula(const QString &action_formula)
 
   if(!temp_formula.checkSyntax())
     {
-      qCritical()
+      qDebug()
         << "Cannot append formula that does not pass the checkSyntax test.";
 
       return false;
@@ -556,35 +557,6 @@ Formula::removeTitle()
   return title;
 }
 
-//////////////// THE ATOM INDEX LOGIC /////////////////////
-
-/*!
-\brief Sets m_forceCountIndex to \a forceCountIndex.
-
-When a formula contains a chemical element in a single copy, it is standard
-practice to omit the count index: H2O is the same as H2O1. If forceCountIndex is
-true, then the formula has to be in the form H2O1. This is required for some
-specific calculations. The status (m_isValid) is set to false.
-*/
-void
-Formula::setForceCountIndex(bool forceCountIndex)
-{
-  m_forceCountIndex = forceCountIndex;
-}
-
-/*!
-\brief Returns true if single atoms should have a count index, false otherwise.
-
-The force count index is set to true,  when a formula needs to have atom indices
-set even if the count for these atoms is 1. For example,  H2O1 as compared to
-H2O.
-*/
-bool
-Formula::isForceCountIndex() const
-{
-  return m_forceCountIndex;
-}
-
 //////////////// THE SYNTAX CHECKING LOGIC /////////////////////
 
 #if 0
@@ -737,29 +709,10 @@ Formula::checkSyntax(const QString &formula, bool forceCountIndex)
 }
 #endif
 
-/*!
-  \brief Returns true if the member action-formula is syntactically valid, false
-otherwise.
-
-  \sa checkSyntax(const QString &formula, bool force_count_index)
-*/
-bool
-Formula::checkSyntax() const
-{
-  // The default formula is always m_actionFormula.
-
-  return checkSyntax(m_actionFormula, m_forceCountIndex);
-}
-
 /*!
 \brief Returns true if the \a formula_string action-formula is syntactically
 valid, false otherwise.
 
-If \a force_count_index is true, the syntax check accounts for the
-requirement that all the symbols in the formula must be indexed, even if that
-symbol's count is 1. This means that H2O would not pass the check, while H2O1
-would.
-
 The formula is first stripped of its title (if any), then all the spaces are
 removed.
 
@@ -773,7 +726,7 @@ the Cz chemical element does not exist.
 \sa validate()
 */
 bool
-Formula::checkSyntax(const QString &formula_string, bool force_count_index)
+Formula::checkSyntax(const QString &formula_string)
 {
   // qDebug() << "Checking syntax of formula string" << formula_string;
 
@@ -798,7 +751,7 @@ Formula::checkSyntax(const QString &formula_string, bool force_count_index)
 
   if(local_formula_string.isEmpty())
     {
-      qWarning() << "The action formula string is empty.";
+      qDebug() << "The action formula string is empty.";
       return false;
     }
 
@@ -822,7 +775,7 @@ Formula::checkSyntax(const QString &formula_string, bool force_count_index)
   QRegularExpressionMatch match = start_of_formula.match(local_formula_string);
   if(!match.hasMatch())
     {
-      qCritical() << "Error at start of formula string" << formula_string;
+      qDebug() << "Error at start of formula string" << formula_string;
 
       return false;
     }
@@ -832,7 +785,7 @@ Formula::checkSyntax(const QString &formula_string, bool force_count_index)
   match = end_of_formula.match(local_formula_string);
   if(!match.hasMatch())
     {
-      qCritical() << "Error at end of formula string.";
+      qDebug() << "Error at end of formula string.";
 
       return false;
     }
@@ -848,28 +801,14 @@ Formula::checkSyntax(const QString &formula_string, bool force_count_index)
       QString symbol       = match.captured(2);
       QString count_string = match.captured(3);
 
-      if(!count_string.isEmpty())
-        {
-          bool ok = false;
-          // Verify that it correctly converts to double.
-          count_string.toDouble(&ok);
-          if(!ok)
-            return false;
-        }
-      else
-        {
-          if(force_count_index)
-            {
-              qCritical() << "Error: symbol" << symbol << "has no index.";
+      if(count_string.isEmpty())
+        count_string = "1";
 
-              return false;
-            }
-          else
-            {
-              // qDebug() << "Symbol" << symbol
-              //          << "has no index but that is tolerated.";
-            }
-        }
+      bool ok = false;
+      // Verify that it correctly converts to double.
+      count_string.toDouble(&ok);
+      if(!ok)
+        return false;
 
       // qDebug() << "Sign:" << match.captured(1) << "Symbol:" <<
       // match.captured(2)
@@ -884,6 +823,28 @@ Formula::checkSyntax(const QString &formula_string, bool force_count_index)
   return true;
 }
 
+/*!
+ * \brief Returns true if the member action-formula is syntactically
+ * valid, false otherwise.
+ *
+ * The formula is first stripped of its title (if any), then all the spaces are
+ * removed.
+ *
+ * MsXpS::libXpertMassCore::Formula::subFormulaRegExp is then used to extract
+ * each "plus" and / or "minus" component while checking its syntactic validity.
+ *
+ * \note The syntax checking code does not verify that the action-formula is
+ * chemically valid, that is, the "Cz4" symbol / count pair would check even if
+ * the Cz chemical element does not exist.
+ *
+ * \sa checkSyntax(const QString &formula_string)
+ */
+bool
+Formula::checkSyntax() const
+{
+  return Formula::checkSyntax(m_actionFormula);
+}
+
 //////////////// OPERATORS /////////////////////
 /*!
   \brief Initializes all the member data of this formula by copying to it the
@@ -911,7 +872,7 @@ Formula::operator=(const Formula &other)
   //  Sanity check
   if(!removeTitle().isEmpty())
     {
-      qCritical() << "The formula string still has a title.";
+      qDebug() << "The formula string still has a title.";
       m_isValid = false;
     }
   // GCOV_EXCL_STOP
@@ -920,14 +881,14 @@ Formula::operator=(const Formula &other)
 
   if(m_actionFormula.isEmpty())
     {
-      qCritical() << "Formula created empty.";
+      qDebug() << "Formula created empty.";
       m_isValid = false;
     }
 
-  if(!checkSyntax())
+  if(!checkSyntax(m_actionFormula))
     {
-      qCritical() << "Formula set to an action formula that does not pass the "
-                     "checkSyntax test.";
+      qDebug() << "Formula set to an action formula that does not pass the "
+                  "checkSyntax test.";
       m_isValid = false;
     }
 
@@ -1358,7 +1319,7 @@ Formula::validate(IsotopicDataCstSPtr isotopic_data_csp,
   if(isotopic_data_csp == nullptr || isotopic_data_csp.get() == nullptr ||
      !isotopic_data_csp->size())
     {
-      qCritical()
+      qDebug()
         << "Cannot validate a Formula if the isotopic data are unavailable.";
       error_list_p->push_back(
         "Cannot validate a Formula if the isotopic data are unavailable");
@@ -1368,14 +1329,13 @@ Formula::validate(IsotopicDataCstSPtr isotopic_data_csp,
 
   if(m_actionFormula.isEmpty())
     {
-      qCritical() << "Cannot validate a Formula that is empty.";
+      qDebug() << "Cannot validate a Formula that is empty.";
       error_list_p->push_back("Cannot validate a Formula that is empty");
     }
 
   if(!checkSyntax())
     {
-      qCritical()
-        << "Cannot validate a Formula that fails the syntax check test.";
+      qDebug() << "Cannot validate a Formula that fails the syntax check test.";
       error_list_p->push_back(
         "Cannot validate a Formula that fails the syntax check test");
     }
@@ -1388,23 +1348,23 @@ Formula::validate(IsotopicDataCstSPtr isotopic_data_csp,
   std::map<QString, double> symbol_count_map;
 
   SplitResult result = splitActionParts(isotopic_data_csp,
-                                               plus_formula,
-                                               minus_formula,
-                                               symbol_count_map,
-                                               1,
-                                               /*store*/ false,
-                                               /*reset*/ true);
+                                        plus_formula,
+                                        minus_formula,
+                                        symbol_count_map,
+                                        1,
+                                        /*store*/ false,
+                                        /*reset*/ true);
 
   if(result == SplitResult::FAILURE)
     {
-      qCritical() << "Failed splitting the Formula.";
+      qDebug() << "Failed splitting the Formula.";
       error_list_p->push_back("Failed splitting the Formula");
     }
 
   // Both the action formulas cannot be empty.
   if(!plus_formula.size() && !minus_formula.size())
     {
-      qCritical() << "Both the plus and minus formulas are empty.";
+      qDebug() << "Both the plus and minus formulas are empty.";
       error_list_p->push_back("Both the plus and minus formulas are empty");
     }
 
@@ -1437,7 +1397,7 @@ Formula::validate(IsotopicDataCstSPtr isotopic_data_csp,
   if(isotopic_data_csp == nullptr || isotopic_data_csp.get() == nullptr ||
      !isotopic_data_csp->size())
     {
-      qCritical()
+      qDebug()
         << "Cannot validate a Formula if the isotopic data are unavailable.";
       error_list_p->push_back(
         "Cannot validate a Formula if the isotopic data are unavailable");
@@ -1447,14 +1407,13 @@ Formula::validate(IsotopicDataCstSPtr isotopic_data_csp,
 
   if(m_actionFormula.isEmpty())
     {
-      qCritical() << "Cannot validate a Formula that is empty.";
+      qDebug() << "Cannot validate a Formula that is empty.";
       error_list_p->push_back("Cannot validate a Formula that is empty");
     }
 
   if(!checkSyntax())
     {
-      qCritical()
-        << "Cannot validate a Formula that fails the syntax check test.";
+      qDebug() << "Cannot validate a Formula that fails the syntax check test.";
       error_list_p->push_back(
         "Cannot validate a Formula that fails the syntax check test");
     }
@@ -1463,23 +1422,23 @@ Formula::validate(IsotopicDataCstSPtr isotopic_data_csp,
   // parts.";
 
   SplitResult result = splitActionParts(isotopic_data_csp,
-                                               m_plusFormula,
-                                               m_minusFormula,
-                                               m_symbolCountMap,
-                                               1,
-                                               /*store*/ store,
-                                               /*reset*/ reset);
+                                        m_plusFormula,
+                                        m_minusFormula,
+                                        m_symbolCountMap,
+                                        1,
+                                        /*store*/ store,
+                                        /*reset*/ reset);
 
   if(result == SplitResult::FAILURE)
     {
-      qCritical() << "Failed splitting the Formula.";
+      qDebug() << "Failed splitting the Formula.";
       error_list_p->push_back("Failed splitting the Formula");
     }
 
   // Both the action formulas cannot be empty.
   if(!m_plusFormula.size() && !m_minusFormula.size())
     {
-      qCritical() << "Both the plus and minus formulas are empty.";
+      qDebug() << "Both the plus and minus formulas are empty.";
       error_list_p->push_back("Both the plus and minus formulas are empty");
     }
 
@@ -1707,9 +1666,9 @@ Formula::accountFormula(const QString &formula_string,
                             /*reset*/ true,
                             &error_list))
     {
-      qCritical() << "Formula:" << formula_string
-                  << "failed to validate with errors:"
-                  << Utils::joinErrorList(error_list, ", ");
+      qDebug() << "Formula:" << formula_string
+               << "failed to validate with errors:"
+               << Utils::joinErrorList(error_list, ", ");
       ok = false;
       return 0;
     }
@@ -2166,7 +2125,7 @@ Formula::accountMasses(bool &ok,
         isotopic_data_csp->getMonoMassBySymbol(iter->first, res);
       if(!res)
         {
-          qWarning() << "Failed to get the mono mass.";
+          qDebug() << "Failed to get the mono mass.";
           ok = false;
           return *this;
         }
@@ -2177,7 +2136,7 @@ Formula::accountMasses(bool &ok,
       double avg_mass = isotopic_data_csp->getAvgMassBySymbol(iter->first, res);
       if(!res)
         {
-          qWarning() << "Failed to get the avg mass.";
+          qDebug() << "Failed to get the avg mass.";
           ok = false;
           return *this;
         }
@@ -2281,7 +2240,7 @@ Formula::accountMasses(Formula &formula,
         isotopic_data_csp->getMonoMassBySymbol(iter->first, res);
       if(!res)
         {
-          qWarning() << "Failed to get the mono mass.";
+          qDebug() << "Failed to get the mono mass.";
           ok = false;
           return formula;
         }
@@ -2292,7 +2251,7 @@ Formula::accountMasses(Formula &formula,
       double avg_mass = isotopic_data_csp->getAvgMassBySymbol(iter->first, res);
       if(!res)
         {
-          qWarning() << "Failed to get the avg mass.";
+          qDebug() << "Failed to get the avg mass.";
           ok = false;
           return formula;
         }
@@ -2324,7 +2283,7 @@ Formula::renderXmlFormulaElement(const QDomElement &element,
 {
   if(element.tagName() != "formula")
     {
-      qCritical() << "The element tag is not 'formula'";
+      qDebug() << "The element tag is not 'formula'";
       return false;
     }
 
@@ -2344,7 +2303,7 @@ Formula::renderXmlFormulaElement(const QDomElement &element,
 
   if(!checkSyntax())
     {
-      qCritical() << "Failed to check syntax for formula:" << m_actionFormula;
+      qDebug() << "Failed to check syntax for formula:" << m_actionFormula;
       return false;
     }
 
@@ -2465,7 +2424,6 @@ Formula::clear()
   m_actionFormula.clear();
   m_plusFormula.clear();
   m_minusFormula.clear();
-  m_forceCountIndex = false;
   m_symbolCountMap.clear();
 
   m_isValid = false;
@@ -2476,7 +2434,7 @@ Formula::registerJsConstructor(QJSEngine *engine)
 {
   if(!engine)
     {
-      qWarning() << "Cannot register class: engine is null";
+      qDebug() << "Cannot register class: engine is null";
       return;
     }
 
