@@ -2,7 +2,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -35,7 +35,6 @@
 #include "MsXpS/libXpertMassCore/FragmentationConfig.hpp"
 #include "MsXpS/libXpertMassCore/PolChemDef.hpp"
 
-
 namespace MsXpS
 {
 namespace libXpertMassCore
@@ -116,17 +115,22 @@ ammonia and/or of water).
 \brief Constructs a fragmentation configuration with a number of parameters.
 
 \list
-\li \a pol_chem_def_csp Polymer chemistry definition that is passed to the FragmentationPathway base class. Cannot be nullptr (fatal error if so).
+\li \a pol_chem_def_csp Polymer chemistry definition that is passed to the
+FragmentationPathway base class. Cannot be nullptr (fatal error if so).
 
-\li \a name Name that is passed to the FragmentationPathway base class. Cannot be empty.
+\li \a name Name that is passed to the FragmentationPathway base class. Cannot
+be empty.
 
 \li \a formula Formula that is passed to the FragmentationPathway base class.
 
-\li \a frag_end The end of the Oligomer undergoing fragmentation that is found in the product ions. Used to initialize the FragmentationPathway base class.
+\li \a frag_end The end of the Oligomer undergoing fragmentation that is found
+in the product ions. Used to initialize the FragmentationPathway base class.
 
-\li \a comment Comment that is passed to the FragmentationPathway base class. Defaults to the null string.
+\li \a comment Comment that is passed to the FragmentationPathway base class.
+Defaults to the null string.
 
-\li \a sequence_embedded Indicates if the product ion sequence needs to be stored in the fragment Oligomer.
+\li \a sequence_embedded Indicates if the product ion sequence needs to be
+stored in the fragment Oligomer.
 \endlist
 
 \sa FragmentationPathway
@@ -144,21 +148,25 @@ FragmentationConfig::FragmentationConfig(PolChemDefCstSPtr pol_chem_def_csp,
     qFatalStream() << "Programming error. Pointer cannot be nullptr;";
 }
 
-
 /*!
 \brief Constructs a fragmentation configuration with a number of parameters.
 
 \list
-\li \a fragmentation_pathway Fragmentation pathway that will become the base class instance of this instance.
+\li \a fragmentation_pathway Fragmentation pathway that will become the base
+class instance of this instance.
 
-\li \a start_index Start position (index) in the Polymer Sequence that delimits the Oligomer undergoing fragmentation.
+\li \a start_index Start position (index) in the Polymer Sequence that delimits
+the Oligomer undergoing fragmentation.
 
-\li \a stop_index Stop position (index) in the Polymer Sequence that delimits the Oligomer undergoing fragmentation.
+\li \a stop_index Stop position (index) in the Polymer Sequence that delimits
+the Oligomer undergoing fragmentation.
 
-\li \a sequence_embedded Indicates if the product ion sequence needs to be stored in the fragment Oligomer.
+\li \a sequence_embedded Indicates if the product ion sequence needs to be
+stored in the fragment Oligomer.
 \endlist
 
-The PolChemDef member of the FragmentationPathway base class is tested. If it is nullptr,  that is a fatal error.
+The PolChemDef member of the FragmentationPathway base class is tested. If it is
+nullptr,  that is a fatal error.
 
 \sa FragmentationPathway
 */
@@ -176,11 +184,11 @@ FragmentationConfig::FragmentationConfig(
     qFatalStream() << "Programming error. Pointer cannot be nullptr;";
 }
 
-
 /*!
 \brief Constructs a fragmentation configuration as a copy of \a other.
 
-The PolChemDef member of the FragmentationPathway base class is tested. If it is nullptr,  that is a fatal error.
+The PolChemDef member of the FragmentationPathway base class is tested. If it is
+nullptr,  that is a fatal error.
 
 \sa FragmentationPathway
 */
@@ -197,7 +205,6 @@ FragmentationConfig::FragmentationConfig(const FragmentationConfig &other)
     qFatalStream() << "Programming error. Pointer cannot be nullptr;";
 }
 
-
 /*!
 \brief Constructs this fragmentation configuration.
 */
@@ -240,7 +247,6 @@ FragmentationConfig::setStartIndex(std::size_t index)
   m_startIndex = index;
 }
 
-
 /*!
 \brief Returns the Oligomer start index in the Polymer Sequence.
 */
@@ -250,7 +256,6 @@ FragmentationConfig::getStartIndex() const
   return m_startIndex;
 }
 
-
 /*!
 \brief Sets the Oligomer stop \a index in the Polymer Sequence.
 */
@@ -260,7 +265,6 @@ FragmentationConfig::setStopIndex(std::size_t index)
   m_stopIndex = index;
 }
 
-
 /*!
 \brief Returns the Oligomer stop index in the Polymer Sequence.
 */
@@ -287,7 +291,6 @@ FragmentationConfig::setStartIonizeLevel(std::size_t value)
     }
 }
 
-
 /*!
 \brief Returns the start value of the ionization range.
 */
@@ -297,7 +300,6 @@ FragmentationConfig::getStartIonizeLevel() const
   return m_startIonizeLevel;
 }
 
-
 /*!
 \brief Sets the stop \a value of the ionization range.
 */
@@ -315,7 +317,6 @@ FragmentationConfig::setStopIonizeLevel(std::size_t value)
     }
 }
 
-
 /*!
 \brief Returns the stop value of the ionization range.
 */
@@ -353,9 +354,9 @@ FragmentationConfig::addFormula(const Formula &formula)
 
   if(!formula.validate(isotopic_data_csp, &error_list))
     {
-      qCritical() << "Formula" << formula.getActionFormula()
-                  << "failed to validate with errors:"
-                  << Utils::joinErrorList(error_list);
+      qDebug() << "Formula" << formula.getActionFormula()
+               << "failed to validate with errors:"
+               << Utils::joinErrorList(error_list);
 
       return false;
     }
@@ -381,7 +382,8 @@ FragmentationConfig::addFormula(const Formula &formula)
 }
 
 /*!
-\brief Adds a Formula to the container of Formula instances using \a formula_string.
+\brief Adds a Formula to the container of Formula instances using \a
+formula_string.
 */
 bool
 FragmentationConfig::addFormula(const QString &formula_string)
@@ -412,7 +414,8 @@ FragmentationConfig::getFormulasRef()
 }
 
 /*!
-\brief Sets if the product ion Oligomer's sequence needs to be stored to \a value.
+\brief Sets if the product ion Oligomer's sequence needs to be stored to \a
+value.
 */
 void
 FragmentationConfig::setSequenceEmbedded(bool value)
@@ -420,7 +423,6 @@ FragmentationConfig::setSequenceEmbedded(bool value)
   m_sequenceEmbedded = value;
 }
 
-
 /*!
 \brief Returns if the product ion Oligomer's sequence needs to be stored.
 */
