@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009, ..., 2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -35,7 +35,6 @@
 #include "MsXpS/libXpertMassCore/FragmentationPathway.hpp"
 #include "MsXpS/libXpertMassCore/PolChemDef.hpp"
 
-
 namespace MsXpS
 {
 namespace libXpertMassCore
@@ -178,25 +177,26 @@ FragmentationPathway::FragmentationPathway(PolChemDefCstSPtr pol_chem_def_csp,
   : mcsp_polChemDef(pol_chem_def_csp)
 {
   if(mcsp_polChemDef == nullptr || mcsp_polChemDef.get() == nullptr)
-    qCritical() << "Constructing FragmentationPathway with no PolChemDef.";
+    qDebug() << "Constructing FragmentationPathway with no PolChemDef.";
 
   if(version == 1)
     {
       if(!renderXmlFgsElement(element, version))
-        qCritical()
+        qDebug()
           << "Failed to fully render or validate the FragSpec XML element "
              "for construction of FragSpec instance.";
     }
   else if(version == 2)
     {
       if(!renderXmlFgpElement(element, version))
-        qCritical() << "Failed to fully render or validate the "
-                       "FragmentationPathway XML element "
-                       "for construction of FragmentationPathway instance.";
+        qDebug() << "Failed to fully render or validate the "
+                    "FragmentationPathway XML element "
+                    "for construction of FragmentationPathway instance.";
     }
   else
-    qFatalStream() << "Programming error. The polymer chemistry definition version "
-                "is not correct.";
+    qFatalStream()
+      << "Programming error. The polymer chemistry definition version "
+         "is not correct.";
 }
 
 /*!
@@ -242,13 +242,12 @@ FragmentationPathway::FragmentationPathway(PolChemDefCstSPtr pol_chem_def_csp,
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Upon construction of the FragmentationPathway, the "
-                   "instance failed to "
-                   "validate with errors:"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Upon construction of the FragmentationPathway, the "
+                "instance failed to "
+                "validate with errors:"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
-
 /*!
 \brief Constructs a FragmentationPathway instance as a copy of \a other.
 
@@ -271,13 +270,12 @@ FragmentationPathway::FragmentationPathway(const FragmentationPathway &other)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Upon copy-construction of the FragmentationPathway, the "
-                   "instance failed to "
-                   "validate with errors:"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Upon copy-construction of the FragmentationPathway, the "
+                "instance failed to "
+                "validate with errors:"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
-
 /*!
 \brief Destroys this FragmentationPathway instance.
 */
@@ -305,10 +303,10 @@ FragmentationPathway::setPolchemDefCstSPtr(PolChemDefCstSPtr pol_chem_def_csp)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Upon setting PolChemDef of FragmentationPathway, the "
-                   "instance failed to "
-                   "validate with errors:"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Upon setting PolChemDef of FragmentationPathway, the "
+                "instance failed to "
+                "validate with errors:"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
 /*!
@@ -338,7 +336,7 @@ FragmentationPathway::setName(const QString &name)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "Upon setting name of FragmentationPathway, the instance failed to "
          "validate with errors:"
       << Utils::joinErrorList(error_list, ", ");
@@ -371,7 +369,7 @@ FragmentationPathway::setFormula(const Formula &formula)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "Upon setting Formula of FragmentationPathway, the instance failed to "
          "validate with errors:"
       << Utils::joinErrorList(error_list, ", ");
@@ -394,7 +392,7 @@ FragmentationPathway::setFormula(const QString &formula_string)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "Upon setting Formula of FragmentationPathway, the instance failed to "
          "validate with errors:"
       << Utils::joinErrorList(error_list, ", ");
@@ -436,7 +434,6 @@ FragmentationPathway::setFragEnd(Enums::FragEnd frag_end)
   m_fragEnd = frag_end;
 }
 
-
 /*!
 \brief Returns the \l Enums::FragEnd.
 */
@@ -522,7 +519,6 @@ FragmentationPathway::getRulesRef()
   return m_rules;
 }
 
-
 //////////////// OPERATORS /////////////////////
 /*!
 \brief Assigns \a other to this FragmentationPathway instance.
@@ -553,7 +549,7 @@ FragmentationPathway::operator=(const FragmentationPathway &other)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "Upon assignment-configuration of the FragmentationPathway, the "
          "instance failed to "
          "validate with errors:"
@@ -629,14 +625,13 @@ FragmentationPathway::addRule(FragmentationRuleSPtr frag_rule_sp)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "Upon assignment-configuration of the FragmentationPathway, the "
          "instance failed to "
          "validate with errors:"
       << Utils::joinErrorList(error_list, ", ");
 }
 
-
 /*!
 \brief Inserts in the container of FragmentationRule instances at \a index the
 \a frag_rule_sp FragmentationRule instance. If index is the container size, the
@@ -664,7 +659,7 @@ FragmentationPathway::insertRuleAt(FragmentationRuleSPtr frag_rule_sp,
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "Upon assignment-configuration of the FragmentationPathway, the "
          "instance failed to "
          "validate with errors:"
@@ -684,7 +679,6 @@ FragmentationPathway::removeRuleAt(size_t index)
   m_rules.erase(m_rules.begin() + index);
 }
 
-
 //////////////// VALIDATIONS /////////////////////
 /*!
 \brief Returns the FragmentationPathway instance from the polymer chemistry
@@ -734,7 +728,6 @@ FragmentationPathway::isKnownByNameInPolChemDef() const
   return Enums::PolChemDefEntityStatus::ENTITY_NOT_KNOWN;
 }
 
-
 /*!
 \brief Validates the FragmentationPathway, recording any error with a message in
 \a error_list_p.
@@ -765,9 +758,8 @@ FragmentationPathway::validate(ErrorList *error_list_p) const
 
   if(mcsp_polChemDef == nullptr || mcsp_polChemDef.get() == nullptr)
     {
-      qCritical()
-        << "A FragmentationPathway with no PolChemDef available cannot "
-           "validate successfully.";
+      qDebug() << "A FragmentationPathway with no PolChemDef available cannot "
+                  "validate successfully.";
       error_list_p->push_back(
         "A FragmentationPathway with no PolChemDef available cannot validate "
         "successfully");
@@ -775,7 +767,7 @@ FragmentationPathway::validate(ErrorList *error_list_p) const
 
   if(m_name.isEmpty())
     {
-      qCritical()
+      qDebug()
         << "A FragmentationPathway with no name cannot validate successfully.";
       error_list_p->push_back(
         "A FragmentationPathway with no name cannot validate successfully");
@@ -783,8 +775,8 @@ FragmentationPathway::validate(ErrorList *error_list_p) const
 
   if(m_formula.getActionFormula().isEmpty())
     {
-      qCritical() << "A FragmentationPathway with no formula cannot "
-                     "validate successfully.";
+      qDebug() << "A FragmentationPathway with no formula cannot "
+                  "validate successfully.";
       error_list_p->push_back(
         "A FragmentationPathway with no formula cannot validate "
         "successfully");
@@ -793,8 +785,8 @@ FragmentationPathway::validate(ErrorList *error_list_p) const
           !m_formula.validate(mcsp_polChemDef->getIsotopicDataCstSPtr(),
                               error_list_p))
     {
-      qCritical() << "A FragmentationPathway with an invalid formula cannot "
-                     "validate successfully.";
+      qDebug() << "A FragmentationPathway with an invalid formula cannot "
+                  "validate successfully.";
       error_list_p->push_back(
         "A FragmentationPathway with an invalid formula cannot validate "
         "successfully");
@@ -809,9 +801,9 @@ FragmentationPathway::validate(ErrorList *error_list_p) const
     {
       if(!frag_rule_sp->validate(error_list_p))
         {
-          qCritical() << "A FragmentationPathway with an invalid fragmentation "
-                         "rule cannot "
-                         "validate successfully.";
+          qDebug() << "A FragmentationPathway with an invalid fragmentation "
+                      "rule cannot "
+                      "validate successfully.";
           error_list_p->push_back(
             "A FragmentationPathway with an invalid fragmentation rule cannot "
             "validate "
@@ -833,7 +825,6 @@ FragmentationPathway::isValid() const
   return m_isValid;
 }
 
-
 //////////////// UTILITIES /////////////////////
 
 /*!
@@ -940,7 +931,7 @@ FragmentationPathway::renderXmlFgsElement(const QDomElement &element,
 
   if(element.tagName() != "fgs")
     {
-      qCritical() << "The expected <fgs> element is not found.";
+      qDebug() << "The expected <fgs> element is not found.";
       m_isValid = false;
       return m_isValid;
     }
@@ -949,8 +940,8 @@ FragmentationPathway::renderXmlFgsElement(const QDomElement &element,
 
   if(child.isNull() || child.text().isEmpty())
     {
-      qCritical() << "The FragSpec did not render correctly: problem with the "
-                     "<name> element.";
+      qDebug() << "The FragSpec did not render correctly: problem with the "
+                  "<name> element.";
       m_isValid = false;
       return m_isValid;
     }
@@ -961,8 +952,8 @@ FragmentationPathway::renderXmlFgsElement(const QDomElement &element,
 
   if(child.isNull() || child.text().isEmpty() || child.tagName() != "end")
     {
-      qCritical() << "The FragSpec did not render correctly: problem with the "
-                     "<end> element.";
+      qDebug() << "The FragSpec did not render correctly: problem with the "
+                  "<end> element.";
       m_isValid = false;
       return m_isValid;
     }
@@ -977,8 +968,8 @@ FragmentationPathway::renderXmlFgsElement(const QDomElement &element,
     m_fragEnd = Enums::FragEnd::BE;
   else
     {
-      qCritical() << "The FragSpec did not render correctly: problem with the "
-                     "<end> element's text value.";
+      qDebug() << "The FragSpec did not render correctly: problem with the "
+                  "<end> element's text value.";
       m_isValid = false;
       return m_isValid;
     }
@@ -987,17 +978,16 @@ FragmentationPathway::renderXmlFgsElement(const QDomElement &element,
 
   if(child.isNull() || child.text().isEmpty() || child.tagName() != "formula")
     {
-      qCritical() << "The FragSpec did not render correctly: problem with the "
-                     "<formula> element.";
+      qDebug() << "The FragSpec did not render correctly: problem with the "
+                  "<formula> element.";
       m_isValid = false;
       return m_isValid;
     }
 
   if(!m_formula.renderXmlFormulaElement(child))
     {
-      qCritical()
-        << "The FragSpec did not render correctly: the formula did not "
-           "render correctly.";
+      qDebug() << "The FragSpec did not render correctly: the formula did not "
+                  "render correctly.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1007,8 +997,8 @@ FragmentationPathway::renderXmlFgsElement(const QDomElement &element,
   if(child.isNull() || child.text().isEmpty() ||
      child.tagName() != "sidechaincontrib")
     {
-      qCritical() << "The FragSpec did not render correctly: problem with the "
-                     "<sidechaincontrib> element.";
+      qDebug() << "The FragSpec did not render correctly: problem with the "
+                  "<sidechaincontrib> element.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1018,8 +1008,8 @@ FragmentationPathway::renderXmlFgsElement(const QDomElement &element,
 
   if(!m_monomerContribution && !ok)
     {
-      qCritical() << "The FragSpec did not render correctly: problem with the "
-                     "<sidechaincontrib> element's value.";
+      qDebug() << "The FragSpec did not render correctly: problem with the "
+                  "<sidechaincontrib> element's value.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1037,9 +1027,8 @@ FragmentationPathway::renderXmlFgsElement(const QDomElement &element,
         {
           if(comment_was_parsed)
             {
-              qCritical()
-                << "The FragSpec did not render correctly: problem with "
-                   "multiple <comment> elements.";
+              qDebug() << "The FragSpec did not render correctly: problem with "
+                          "multiple <comment> elements.";
               m_isValid = false;
               return m_isValid;
             }
@@ -1060,9 +1049,8 @@ FragmentationPathway::renderXmlFgsElement(const QDomElement &element,
             std::make_shared<FragmentationRule>(mcsp_polChemDef, child, 1);
           if(!frag_rule_sp->isValid())
             {
-              qCritical()
-                << "The FragSpec did not render correctly: problem with "
-                   "a <fgr> FragRule element.";
+              qDebug() << "The FragSpec did not render correctly: problem with "
+                          "a <fgr> FragRule element.";
               frag_rule_sp.reset();
               m_isValid = false;
               return m_isValid;
@@ -1078,14 +1066,13 @@ FragmentationPathway::renderXmlFgsElement(const QDomElement &element,
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Failed to validate FragSpec instance right after "
-                   "rendering it from <fgs> XML element, with errors:"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Failed to validate FragSpec instance right after "
+                "rendering it from <fgs> XML element, with errors:"
+             << Utils::joinErrorList(error_list, ", ");
 
   return m_isValid;
 }
 
-
 /*!
 \brief Parses a fragmentation pathway XML \a element using a
 \a{version}ed function.
@@ -1155,7 +1142,7 @@ FragmentationPathway::renderXmlFgpElement(const QDomElement &element,
 
   if(element.tagName() != "fgp")
     {
-      qCritical() << "The expected <fgp> element is not found.";
+      qDebug() << "The expected <fgp> element is not found.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1164,9 +1151,9 @@ FragmentationPathway::renderXmlFgpElement(const QDomElement &element,
 
   if(child.isNull() || child.text().isEmpty())
     {
-      qCritical() << "The FragmentationPathway did not render correctly: "
-                     "problem with the "
-                     "<name> element.";
+      qDebug() << "The FragmentationPathway did not render correctly: "
+                  "problem with the "
+                  "<name> element.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1177,9 +1164,9 @@ FragmentationPathway::renderXmlFgpElement(const QDomElement &element,
 
   if(child.isNull() || child.text().isEmpty() || child.tagName() != "end")
     {
-      qCritical() << "The FragmentationPathway did not render correctly: "
-                     "problem with the "
-                     "<end> element.";
+      qDebug() << "The FragmentationPathway did not render correctly: "
+                  "problem with the "
+                  "<end> element.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1194,9 +1181,9 @@ FragmentationPathway::renderXmlFgpElement(const QDomElement &element,
     m_fragEnd = Enums::FragEnd::BE;
   else
     {
-      qCritical() << "The FragmentationPathway did not render correctly: "
-                     "problem with the "
-                     "<end> element's text value.";
+      qDebug() << "The FragmentationPathway did not render correctly: "
+                  "problem with the "
+                  "<end> element's text value.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1205,18 +1192,18 @@ FragmentationPathway::renderXmlFgpElement(const QDomElement &element,
 
   if(child.isNull() || child.text().isEmpty() || child.tagName() != "formula")
     {
-      qCritical() << "The FragmentationPathway did not render correctly: "
-                     "problem with the "
-                     "<formula> element.";
+      qDebug() << "The FragmentationPathway did not render correctly: "
+                  "problem with the "
+                  "<formula> element.";
       m_isValid = false;
       return m_isValid;
     }
 
   if(!m_formula.renderXmlFormulaElement(child))
     {
-      qCritical() << "The FragmentationPathway did not render correctly: the "
-                     "formula did not "
-                     "render correctly.";
+      qDebug() << "The FragmentationPathway did not render correctly: the "
+                  "formula did not "
+                  "render correctly.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1226,9 +1213,9 @@ FragmentationPathway::renderXmlFgpElement(const QDomElement &element,
   if(child.isNull() || child.text().isEmpty() ||
      child.tagName() != "sidechaincontrib")
     {
-      qCritical() << "The FragmentationPathway did not render correctly: "
-                     "problem with the "
-                     "<sidechaincontrib> element.";
+      qDebug() << "The FragmentationPathway did not render correctly: "
+                  "problem with the "
+                  "<sidechaincontrib> element.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1238,9 +1225,9 @@ FragmentationPathway::renderXmlFgpElement(const QDomElement &element,
 
   if(!m_monomerContribution && !ok)
     {
-      qCritical() << "The FragmentationPathway did not render correctly: "
-                     "problem with the "
-                     "<sidechaincontrib> element's value.";
+      qDebug() << "The FragmentationPathway did not render correctly: "
+                  "problem with the "
+                  "<sidechaincontrib> element's value.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1258,9 +1245,9 @@ FragmentationPathway::renderXmlFgpElement(const QDomElement &element,
         {
           if(comment_was_parsed)
             {
-              qCritical() << "The FragmentationPathway did not render "
-                             "correctly: problem with "
-                             "multiple <comment> elements.";
+              qDebug() << "The FragmentationPathway did not render "
+                          "correctly: problem with "
+                          "multiple <comment> elements.";
               m_isValid = false;
               return m_isValid;
             }
@@ -1281,9 +1268,9 @@ FragmentationPathway::renderXmlFgpElement(const QDomElement &element,
             std::make_shared<FragmentationRule>(mcsp_polChemDef, child, 1);
           if(!frag_rule_sp->isValid())
             {
-              qCritical() << "The FragmentationPathway did not render "
-                             "correctly: problem with "
-                             "a <fgr> FragmentationRule element.";
+              qDebug() << "The FragmentationPathway did not render "
+                          "correctly: problem with "
+                          "a <fgr> FragmentationRule element.";
               frag_rule_sp.reset();
               m_isValid = false;
               return m_isValid;
@@ -1299,10 +1286,9 @@ FragmentationPathway::renderXmlFgpElement(const QDomElement &element,
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
-      << "Failed to validate FragmentationPathway instance right after "
-         "rendering it from <fgp> XML element, with errors:"
-      << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Failed to validate FragmentationPathway instance right after "
+                "rendering it from <fgp> XML element, with errors:"
+             << Utils::joinErrorList(error_list, ", ");
 
   return m_isValid;
 }
