@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009, ..., 2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -35,7 +35,6 @@
 #include "MsXpS/libXpertMassCore/FragmentationRule.hpp"
 #include "MsXpS/libXpertMassCore/PolChemDef.hpp"
 
-
 namespace MsXpS
 {
 
@@ -180,13 +179,12 @@ FragmentationRule::FragmentationRule(PolChemDefCstSPtr pol_chem_def_csp,
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "Upon construction of FragmentationRule, the instance failed to "
          "validate with errors:"
       << Utils::joinErrorList(error_list, ", ");
 }
 
-
 /*!
 \brief Constructs a FragmentationRule instance starting from an XML <fgr> \a
 element according to \a version and using the reference  \a pol_chem_def_csp
@@ -217,10 +215,10 @@ FragmentationRule::FragmentationRule(PolChemDefCstSPtr pol_chem_def_csp,
   : mcsp_polChemDef(pol_chem_def_csp)
 {
   if(mcsp_polChemDef == nullptr || mcsp_polChemDef.get() == nullptr)
-    qCritical() << "Constructing FragmentationRule with no PolChemDef.";
+    qDebug() << "Constructing FragmentationRule with no PolChemDef.";
 
   if(!renderXmlFgrElement(element))
-    qCritical()
+    qDebug()
       << "Failed to fully render or validate the FragmentationRule XML element "
          "for construction of FragmentationRule instance.";
 }
@@ -244,13 +242,12 @@ FragmentationRule::FragmentationRule(const FragmentationRule &other)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "Upon construction of FragmentationRule, the instance failed to "
          "validate with errors:"
       << Utils::joinErrorList(error_list, ", ");
 }
 
-
 /*!
 \brief Destructs the fragmentation rule.
 */
@@ -270,7 +267,7 @@ FragmentationRule::setPolchemDefCstSPtr(PolChemDefCstSPtr pol_chem_def_csp)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "Upon setting PolChemDef of FragmentationRule, the instance failed to "
          "validate with errors:"
       << Utils::joinErrorList(error_list, ", ");
@@ -297,7 +294,7 @@ FragmentationRule::setName(const QString &name)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "Upon setting name of FragmentationRule, the instance failed to "
          "validate with errors:"
       << Utils::joinErrorList(error_list, ", ");
@@ -327,13 +324,12 @@ FragmentationRule::setPrevCode(const QString &code)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Upon setting previous code of FragmentationRule, the "
-                   "instance failed to "
-                   "validate with errors:"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Upon setting previous code of FragmentationRule, the "
+                "instance failed to "
+                "validate with errors:"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
-
 /*!
 \brief Returns the previous monomer code.
 */
@@ -343,7 +339,6 @@ FragmentationRule::getPrevCode() const
   return m_prevCode;
 }
 
-
 /*!
 \brief Sets the current monomer \a code.
 
@@ -359,13 +354,12 @@ FragmentationRule::setCurrCode(const QString &code)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Upon setting current code of FragmentationRule, the "
-                   "instance failed to "
-                   "validate with errors:"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Upon setting current code of FragmentationRule, the "
+                "instance failed to "
+                "validate with errors:"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
-
 /*!
 \brief Returns the current monomer code.
 */
@@ -375,7 +369,6 @@ FragmentationRule::getCurrCode() const
   return m_currCode;
 }
 
-
 /*!
 \brief Sets the next monomer \a code.
 
@@ -391,13 +384,12 @@ FragmentationRule::setNextCode(const QString &code)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "Upon setting next code of FragmentationRule, the instance failed to "
          "validate with errors:"
       << Utils::joinErrorList(error_list, ", ");
 }
 
-
 /*!
 \brief Returns the next monomer code.
 */
@@ -407,7 +399,6 @@ FragmentationRule::getNextCode() const
   return m_nextCode;
 }
 
-
 /*!
 \brief Sets the \a comment.
 */
@@ -417,7 +408,6 @@ FragmentationRule::setComment(const QString &comment)
   m_comment = comment;
 }
 
-
 /*!
 \brief Returns the comment.
 */
@@ -442,7 +432,7 @@ FragmentationRule::setFormula(const Formula &formula)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "Upon setting Formula of FragmentationRule, the instance failed to "
          "validate with errors:"
       << Utils::joinErrorList(error_list, ", ");
@@ -463,7 +453,7 @@ FragmentationRule::setFormula(const QString &formula_string)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
+    qDebug()
       << "Upon setting Formula of FragmentationRule, the instance failed to "
          "validate with errors:"
       << Utils::joinErrorList(error_list, ", ");
@@ -514,10 +504,9 @@ FragmentationRule::operator=(const FragmentationRule &other)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical()
-      << "Upon assignment of FragmentationRule, the instance failed to "
-         "validate with errors:"
-      << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Upon assignment of FragmentationRule, the instance failed to "
+                "validate with errors:"
+             << Utils::joinErrorList(error_list, ", ");
 
   return *this;
 }
@@ -551,10 +540,10 @@ FragmentationRule::operator!=(const FragmentationRule &other) const
   return !operator==(other);
 }
 
-
 //////////////// VALIDATIONS /////////////////////
 /*!
-\brief Validates the FragmentationRule, recording any error as a message in \a error_list_p.
+\brief Validates the FragmentationRule, recording any error as a message in \a
+error_list_p.
 
 The validation involves checking that:
 
@@ -581,8 +570,8 @@ FragmentationRule::validate(ErrorList *error_list_p) const
 
   if(mcsp_polChemDef == nullptr || mcsp_polChemDef.get() == nullptr)
     {
-      qCritical() << "A FragmentationRule with no PolChemDef available cannot "
-                     "validate successfully.";
+      qDebug() << "A FragmentationRule with no PolChemDef available cannot "
+                  "validate successfully.";
       error_list_p->push_back(
         "A FragmentationRule with no PolChemDef available cannot validate "
         "successfully");
@@ -590,7 +579,7 @@ FragmentationRule::validate(ErrorList *error_list_p) const
 
   if(m_name.isEmpty())
     {
-      qCritical()
+      qDebug()
         << "A FragmentationRule with no name cannot validate successfully.";
       error_list_p->push_back(
         "A FragmentationRule with no name cannot validate successfully");
@@ -598,8 +587,8 @@ FragmentationRule::validate(ErrorList *error_list_p) const
 
   if(m_prevCode.isEmpty() && m_currCode.isEmpty() && m_nextCode.isEmpty())
     {
-      qCritical() << "A FragmentationRule with not a single Monomer code "
-                     "cannot validate successfully.";
+      qDebug() << "A FragmentationRule with not a single Monomer code "
+                  "cannot validate successfully.";
       error_list_p->push_back(
         "A FragmentationRule with not a single Monomer code cannot validate "
         "successfully");
@@ -610,7 +599,7 @@ FragmentationRule::validate(ErrorList *error_list_p) const
     {
       if(mcsp_polChemDef->getMonomerCstSPtrByCode(m_prevCode) == nullptr)
         {
-          qCritical()
+          qDebug()
             << "A FragmentationRule with an unknown previous monomer code "
                "cannot validate successfully.";
           error_list_p->push_back(
@@ -625,7 +614,7 @@ FragmentationRule::validate(ErrorList *error_list_p) const
     {
       if(mcsp_polChemDef->getMonomerCstSPtrByCode(m_currCode) == nullptr)
         {
-          qCritical()
+          qDebug()
             << "A FragmentationRule with an unknown current monomer code "
                "cannot validate successfully.";
           error_list_p->push_back(
@@ -640,9 +629,8 @@ FragmentationRule::validate(ErrorList *error_list_p) const
     {
       if(mcsp_polChemDef->getMonomerCstSPtrByCode(m_nextCode) == nullptr)
         {
-          qCritical()
-            << "A FragmentationRule with an unknown next monomer code "
-               "cannot validate successfully.";
+          qDebug() << "A FragmentationRule with an unknown next monomer code "
+                      "cannot validate successfully.";
           error_list_p->push_back(
             "A FragmentationRule with an unknown next monomer code cannot "
             "validate "
@@ -652,9 +640,8 @@ FragmentationRule::validate(ErrorList *error_list_p) const
 
   if(m_formula.getActionFormula().isEmpty())
     {
-      qCritical()
-        << "A FragmentationRule with no Formula does not make sense and "
-           "cannot validate successfully.";
+      qDebug() << "A FragmentationRule with no Formula does not make sense and "
+                  "cannot validate successfully.";
       error_list_p->push_back(
         "A FragmentationRule with no Formula does not make sense and cannot "
         "validate "
@@ -662,10 +649,11 @@ FragmentationRule::validate(ErrorList *error_list_p) const
     }
 
   if(mcsp_polChemDef != nullptr && mcsp_polChemDef.get() != nullptr &&
-     !m_formula.validate(mcsp_polChemDef->getIsotopicDataCstSPtr(), error_list_p))
+     !m_formula.validate(mcsp_polChemDef->getIsotopicDataCstSPtr(),
+                         error_list_p))
     {
-      qCritical() << "A FragmentationRule with a non-empty invalid Formula "
-                     "cannot validate successfully.";
+      qDebug() << "A FragmentationRule with a non-empty invalid Formula "
+                  "cannot validate successfully.";
       error_list_p->push_back(
         "A FragmentationRule with a non-empty invalid Formula cannot validate "
         "successfully");
@@ -676,7 +664,6 @@ FragmentationRule::validate(ErrorList *error_list_p) const
   return m_isValid;
 }
 
-
 /*!
 \brief Returns the validity status of this FragmentationRule.
 */
@@ -686,7 +673,7 @@ FragmentationRule::isValid() const
   return m_isValid;
 }
 
-  //////////////// UTILITIES /////////////////////
+//////////////// UTILITIES /////////////////////
 /*!
 \brief Returns a string with the textual representation of this
 FragmentationRule instance.
@@ -696,12 +683,20 @@ FragmentationRule::toString() const
 {
   QString text = "Fragmentation rule:\n";
 
-  text += QString("name: %1 - prev code: %2 - curr code: %3 - next code: %4 - formula: %5 - comment: %6 - is valid? %7\n").arg(m_name).arg(m_prevCode).arg(m_currCode).arg(m_nextCode).arg(m_formula.getActionFormula(/*with_title*/ true)).arg(m_comment).arg(m_isValid ? "true" : "false");
+  text += QString(
+            "name: %1 - prev code: %2 - curr code: %3 - next code: %4 - "
+            "formula: %5 - comment: %6 - is valid? %7\n")
+            .arg(m_name)
+            .arg(m_prevCode)
+            .arg(m_currCode)
+            .arg(m_nextCode)
+            .arg(m_formula.getActionFormula(/*with_title*/ true))
+            .arg(m_comment)
+            .arg(m_isValid ? "true" : "false");
 
   return text;
 }
 
-
 /*!
 \brief Parses the FragmentationRule XML \a element.
 
@@ -820,14 +815,13 @@ FragmentationRule::renderXmlFgrElement(const QDomElement &element)
   m_isValid = validate(&error_list);
   if(!m_isValid)
     {
-      qCritical()
+      qDebug()
         << "The FragmentationRule rendered from <clr> element is invalid.";
     }
 
   return m_isValid;
 }
 
-
 /*!
 \brief Formats a string suitable to use as an XML element.
 
