@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -111,10 +111,15 @@ IndexRange::IndexRange(qsizetype index_start,
 /*!
 \brief Constructs an IndexRange instance using \a other as a template and \a
 parent as the parent of this new instance.
+
+The values are sorted in ascending order upon construction.
+
+\sa sortAscending(), sortDescending()
 */
 IndexRange::IndexRange(const IndexRange &other, QObject *parent)
   : QObject(parent), m_start(other.m_start), m_stop(other.m_stop)
 {
+  sortAscending();
 }
 
 /*!
@@ -127,35 +132,50 @@ IndexRange::~IndexRange()
 /*!
 \brief Initializes this instance using \a other. The parent of this instance is
 unchanged.
+
+The values are sorted in ascending order upon initialization.
+
+\sa sortAscending(), sortDescending()
 */
 void
 IndexRange::initialize(const IndexRange &other)
 {
   m_start = other.m_start;
   m_stop  = other.m_stop;
+  sortAscending();
 }
 
 /*!
 \brief Allocates an returns a new IndexRange instance, initializing it using
 this instance's member values and setting its parent to \a parent.
+
+The values are sorted in ascending order in the clone.
+
+\sa sortAscending(), sortDescending()
  */
 IndexRange *
 IndexRange::clone(QObject *parent)
 {
   IndexRange *copy_p = new IndexRange(parent);
   copy_p->initialize(*this);
+  copy_p->sortAscending();
   return copy_p;
 }
 
 /*!
  \ br*ief Allocates an returns a new IndexRange instance, initializing it using
  \a other and setting its parent to \a parent.
+
+ The values are sorted in ascending order in the clone.
+
+ \sa sortAscending(), sortDescending()
  */
 IndexRange *
 IndexRange::clone(const IndexRange &other, QObject *parent)
 {
   IndexRange *copy_p = new IndexRange(parent);
   copy_p->initialize(other);
+  copy_p->sortAscending();
   return copy_p;
 }
 
@@ -227,7 +247,8 @@ IndexRange::reset()
 }
 
 /*!
-\brief Returns a string representing this IndexRange instance in the form "[start-stop]".
+\brief Returns a string representing this IndexRange instance in the form
+"[start-stop]".
 
 The start and stop values are indices (not positions).
 
@@ -243,7 +264,9 @@ IndexRange::indicesAsText() const
 \brief Returns a string representing this IndexRange instance in the form
 "[start-stop]".
 
-\note The start and stop values are positions (not indices). This means that the returned values correspond to \l m_start and \l m_stop both incremented by one unit.
+\note The start and stop values are positions (not indices). This means that the
+returned values correspond to \l m_start and \l m_stop both incremented by one
+unit.
 
 \sa indicesAsText()
 */
@@ -253,14 +276,13 @@ IndexRange::positionsAsText() const
   return QString("[%1-%2]").arg(m_start + 1).arg(m_stop + 1);
 };
 
-
 void
 IndexRange::registerJsConstructor(QJSEngine *engine)
 
 {
   if(!engine)
     {
-      qWarning() << "Cannot register IndexRange class: engine is null";
+      qDebug() << "Cannot register IndexRange class: engine is null";
       return;
     }
 
