@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -260,8 +260,8 @@ IndexRangeCollection::parseIndexRanges(const QString &index_ranges_string,
 
   if(opening_brackets_count != closing_brackets_count)
     {
-      qCritical() << "The string does not represent bona fide IndexRange "
-                     "descriptions.";
+      qDebug() << "The string does not represent bona fide IndexRange "
+                  "descriptions.";
 
       return QList<IndexRange *>();
     }
@@ -307,8 +307,8 @@ IndexRangeCollection::parseIndexRanges(const QString &index_ranges_string,
   //  Sanity check
   if(parsed_index_ranges.size() != opening_brackets_count)
     {
-      qWarning() << "The string does not represent bona fide IndexRange "
-                    "descriptions.";
+      qDebug() << "The string does not represent bona fide IndexRange "
+                  "descriptions.";
       parsed_index_ranges.clear();
     }
 
@@ -353,7 +353,7 @@ IndexRangeCollection::operator!=(const IndexRangeCollection &other) const
 
 /*!
 \brief Clears this IndexRangeCollection's container of IndexRange instances and
-adds one IndexRange using \a start and \a stop.
+adds one IndexRange using \a start and \a stop.
 */
 void
 IndexRangeCollection::setIndexRange(qsizetype start, qsizetype stop)
@@ -878,8 +878,7 @@ IndexRangeCollection::registerJsConstructor(QJSEngine *engine)
 {
   if(!engine)
     {
-      qWarning()
-        << "Cannot register IndexRangeCollection class: engine is null";
+      qDebug() << "Cannot register IndexRangeCollection class: engine is null";
       return;
     }
 
