@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -68,7 +68,7 @@ Ionizations are chemical reactions that bring a charge (or more
 charges) to an analyte. In this Ionizer class, that process is modelled along
 with the idea that a previously ionized analyte might be re-ionized with
 a different ionization chemistry (that is, either a different ionization agent,
-or a different ionization nominal charge or a different ionization level.
+or a different ionization nominal charge or a different ionization level).
 
 To provide the basis for re-ionization, the class provides two ionization
 rules describing the ionization state (present and future) of the analyte
@@ -232,7 +232,7 @@ For example, applying this Ionizer to a molecule
 \endlist
 
 would protonate it 4 times, with a charge of 4 and an increment in mass of the
-mass of 4 times 1 proton. The m_level should be construed as "how many times
+mass of 4 times 1 proton. The m_level should be construed as "how many times
 should the ionization reaction (formula / nominal charge) be performed."
 */
 
@@ -313,9 +313,11 @@ Ionizer::Ionizer(IsotopicDataCstSPtr isotopic_data_csp,
   ErrorList error_list;
   m_isValid = validate(&error_list);
 
+  // qDebug() << "The ionizer formula:" << m_formula.getActionFormula();
+
   if(!m_isValid)
-    qCritical() << "The Ionizer just constructed is invalid, with errors:"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "The Ionizer just constructed is invalid, with errors:"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
 /*!
@@ -348,9 +350,11 @@ Ionizer::Ionizer(IsotopicDataCstSPtr isotopic_data_csp,
   ErrorList error_list;
   m_isValid = validate(&error_list);
 
+  // qDebug() << "The ionizer formula:" << m_formula.getActionFormula();
+
   if(!m_isValid)
-    qCritical() << "The Ionizer just constructed is invalid, with errors:"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "The Ionizer just constructed is invalid, with errors:"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
 /*!
@@ -374,12 +378,15 @@ Ionizer::Ionizer(const Ionizer &other, QObject *parent)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "The Ionizer just constructed is invalid, with errors:"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "The Ionizer just constructed is invalid, with errors:"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
 /*!
-\brief Initializes this Ionizer instance using \a other.
+ \ brief Initializes this Ionizer instance using* \a other.
+
+ After setting the member data, \l validate() is called and the \l m_isValid
+ member is set to the result of the validation.
 */
 void
 Ionizer::initialize(const Ionizer &other)
@@ -392,6 +399,13 @@ Ionizer::initialize(const Ionizer &other)
   m_currentStateNominalCharge = other.m_currentStateNominalCharge;
   m_currentStateLevel         = other.m_currentStateLevel;
   m_isCurrentStateValid       = other.m_isCurrentStateValid;
+
+  ErrorList error_list;
+  m_isValid = validate(&error_list);
+
+  if(!m_isValid)
+    qDebug() << "The Ionizer just constructed is invalid, with errors:"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
 /*!
@@ -409,8 +423,8 @@ Ionizer::setIsotopicDataCstSPtr(IsotopicDataCstSPtr isotopic_data_csp)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "The Ionizer is invalid, with errors:"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "The Ionizer is invalid, with errors:"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
 /*!
@@ -441,8 +455,8 @@ Ionizer::setFormula(const Formula &formula)
 
   if(!m_isValid)
     {
-      qCritical() << "The Ionizer did not validate successfully, with errors:"
-                  << Utils::joinErrorList(error_list, ", ");
+      qDebug() << "The Ionizer did not validate successfully, with errors:"
+               << Utils::joinErrorList(error_list, ", ");
     }
 }
 
@@ -466,8 +480,8 @@ Ionizer::setFormula(const QString &formula_string)
 
   if(!m_isValid)
     {
-      qCritical() << "The Ionizer did not validate successfully, with errors:"
-                  << Utils::joinErrorList(error_list, ", ");
+      qDebug() << "The Ionizer did not validate successfully, with errors:"
+               << Utils::joinErrorList(error_list, ", ");
     }
 }
 
@@ -520,8 +534,8 @@ Ionizer::setNominalCharge(int nominal_charge)
 
   if(!m_isValid)
     {
-      qCritical() << "The Ionizer did not validate successfully, with errors:"
-                  << Utils::joinErrorList(error_list, ", ");
+      qDebug() << "The Ionizer did not validate successfully, with errors:"
+               << Utils::joinErrorList(error_list, ", ");
     }
 }
 
@@ -645,8 +659,8 @@ Ionizer::setLevel(int level)
 
   if(!m_isValid)
     {
-      qCritical() << "The Ionizer did not validate successfully, with errors:"
-                  << Utils::joinErrorList(error_list, ", ");
+      qDebug() << "The Ionizer did not validate successfully, with errors:"
+               << Utils::joinErrorList(error_list, ", ");
     }
 }
 
@@ -679,10 +693,10 @@ Ionizer::getCurrentStateLevel() const
 /*!
 \brief
 
-Allocates on the stack an Ionizer instance an initializes its ionization-to-come
-data using the current state data from this Ionizer. The current ionization
-state of the returned Ionizer instance are reset to nothing, effectively setting
-the managed analyte to a non-ionized state.
+Allocates on the stack an Ionizer instance and initializes its
+ionization-to-come data using the current state data from this Ionizer. The
+current ionization state of the returned Ionizer instance are reset to nothing,
+effectively setting the managed analyte to a non-ionized state.
 
 Returns the allocated Ionizer instance.
 */
@@ -697,6 +711,10 @@ Ionizer::makeIonizerWithCurrentStateData()
 
   // All the current state of the new Ionizer are set to un-ionized,
   // which is good.
+  ErrorList error_list;
+
+  if(!ionizer.validate(&error_list))
+    qFatal() << "The created ionizer is not valid.";
 
   return ionizer;
 }
@@ -738,16 +756,20 @@ passed to the function.
 Enums::IonizationOutcome
 Ionizer::ionize(double &mono, double &avg) const
 {
+  // qDebug() << "Ionizing with this ionizer:" << toString()
+  //          << "The current masses are:" << mono << "-" << avg;
+
   if(!m_isValid)
     {
-      qCritical() << "Cannot perform ionization with invalid Ionizer.";
+      qDebug() << "Cannot perform ionization with invalid Ionizer.";
       return Enums::IonizationOutcome::FAILED;
     }
 
   if(currentStateCharge())
     {
-      qInfo() << "Asking for ionization of an analyte that is already ionized. "
-                 "Performing deionization first.";
+      // qDebug() << "Asking for ionization of an analyte that is already
+      // ionized. "
+      //            "Performing deionization first.";
 
       Enums::IonizationOutcome ionization_outcome = deionize(mono, avg);
 
@@ -757,15 +779,16 @@ Ionizer::ionize(double &mono, double &avg) const
 
   if(!charge())
     {
-      qInfo()
-        << "Asking for ionization of an analyte with ionization charge 0. "
-           "Performing no action.";
+      // qDebug()
+      //   << "Asking for ionization of an analyte with ionization charge 0. "
+      //      "Performing no action.";
+
       return Enums::IonizationOutcome::UNCHANGED;
     }
 
-  qDebug() << qSetRealNumberPrecision(10)
-           << "Before ionization, Ionizer:" << toString()
-           << "with entering masses: " << mono << "-" << avg << "\n\n";
+  // qDebug() << qSetRealNumberPrecision(10)
+  //          << "Before ionization, Ionizer:" << toString()
+  //          << "with entering masses: " << mono << "-" << avg << "\n\n";
 
   double temp_mono = 0;
   double temp_avg  = 0;
@@ -782,29 +805,31 @@ Ionizer::ionize(double &mono, double &avg) const
     ok, mcsp_isotopicData, temp_mono, temp_avg, m_level);
   if(!ok)
     {
-      qCritical() << "Failed to account the masses of the ionizer formula.";
+      qDebug() << "Failed to account the masses of the ionizer formula.";
       return Enums::IonizationOutcome::FAILED;
     }
 
-  qDebug() << qSetRealNumberPrecision(10)
-           << "The ionization formula:" << temp_formula.getActionFormula()
-           << "resolved to computed masses:" << temp_mono << "-" << temp_avg;
+    /*qDebug() << qSetRealNumberPrecision(10)
+             << "The ionization formula:" << temp_formula.getActionFormula()
+             << "resolved to computed masses:" << temp_mono << "-" << temp_avg*/
+    ;
 
   // Add the ionization mass to the the masses of the entity to be ionized.
 
   temp_mono += mono;
   temp_avg  += avg;
 
-  qDebug() << qSetRealNumberPrecision(10)
-           << "The ionized analyte has masses:" << temp_mono << "-" << temp_avg;
+  // qDebug() << qSetRealNumberPrecision(10)
+  //          << "The ionized analyte has masses:" << temp_mono << "-" <<
+  //          temp_avg;
 
   //  Now account for the charge and thus produce m/z instead of m.
 
   temp_mono /= charge();
   temp_avg  /= charge();
 
-  qDebug() << qSetRealNumberPrecision(10)
-           << "The ionized analyte has m/z:" << temp_mono << "-" << temp_avg;
+  // qDebug() << qSetRealNumberPrecision(10)
+  //          << "The ionized analyte has m/z:" << temp_mono << "-" << temp_avg;
 
   //  Now establish if we did actually change something in the process:
   if((temp_mono != mono && temp_avg == avg) ||
@@ -824,10 +849,10 @@ Ionizer::ionize(double &mono, double &avg) const
   // m_wasIonized        = true;
   m_isCurrentStateValid       = true;
 
-  qDebug() << qSetRealNumberPrecision(10)
-           << "After ionization, "
-              "with exiting masses: "
-           << mono << "-" << avg << "\n\n";
+  // qDebug() << qSetRealNumberPrecision(10)
+  //          << "After ionization, "
+  //             "exiting masses: "
+  //          << mono << "-" << avg << "\n\n";
 
   return Enums::IonizationOutcome::IONIZED;
 }
@@ -866,14 +891,14 @@ Ionizer::deionize(double &mono, double &avg) const
 
   if(!m_isValid)
     {
-      qCritical() << "Cannot perform ionization with invalid Ionizer.";
+      qDebug() << "Cannot perform ionization with invalid Ionizer.";
       return Enums::IonizationOutcome::FAILED;
     }
 
   if(!currentStateCharge())
     {
-      qInfo() << "Asking for deionization of an analyte that is not ionized. "
-                 "Performing no action.";
+      qDebug() << "Asking for deionization of an analyte that is not ionized. "
+                  "Performing no action.";
       return Enums::IonizationOutcome::UNCHANGED;
     }
 
@@ -948,8 +973,8 @@ Ionizer::molecularMasses(double &mono, double &avg) const
 
   if(!currentStateCharge())
     {
-      qInfo() << "Asking for molecular masses of a non-ionized analyte. "
-                 "Leaving them unchanged.";
+      qDebug() << "Asking for molecular masses of a non-ionized analyte. "
+                  "Leaving them unchanged.";
       return Enums::IonizationOutcome::UNCHANGED;
     }
 
@@ -1134,8 +1159,8 @@ Ionizer::renderXmlIonizeRuleElement(const QDomElement &element)
 
   if(element.tagName() != "ionizerule")
     {
-      qCritical() << "Cannot render ionization rule. Problem with the "
-                     "<ionizerule> element.";
+      qDebug() << "Cannot render ionization rule. Problem with the "
+                  "<ionizerule> element.";
 
       m_isValid = false;
       return m_isValid;
@@ -1145,8 +1170,8 @@ Ionizer::renderXmlIonizeRuleElement(const QDomElement &element)
   child = element.firstChildElement();
   if(child.tagName() != "formula")
     {
-      qCritical() << "Cannot render ionization rule. Problem with the "
-                     "<formula> element.";
+      qDebug() << "Cannot render ionization rule. Problem with the "
+                  "<formula> element.";
 
       m_isValid = false;
       return m_isValid;
@@ -1154,9 +1179,8 @@ Ionizer::renderXmlIonizeRuleElement(const QDomElement &element)
 
   if(!m_formula.renderXmlFormulaElement(child))
     {
-      qCritical()
-        << "Cannot render ionization rule. Problem with the validation"
-           "of the Formula.";
+      qDebug() << "Cannot render ionization rule. Problem with the validation"
+                  "of the Formula.";
 
       m_isValid = false;
     }
@@ -1166,8 +1190,8 @@ Ionizer::renderXmlIonizeRuleElement(const QDomElement &element)
   child = child.nextSiblingElement();
   if(child.tagName() != "charge")
     {
-      qCritical() << "Cannot render ionization rule. Problem with the "
-                     "<charge> element.";
+      qDebug() << "Cannot render ionization rule. Problem with the "
+                  "<charge> element.";
 
       m_isValid = false;
       return m_isValid;
@@ -1177,8 +1201,8 @@ Ionizer::renderXmlIonizeRuleElement(const QDomElement &element)
   m_nominalCharge = child.text().toInt(&ok);
   if(!m_nominalCharge && !ok)
     {
-      qCritical() << "Cannot render ionization rule. Problem with the "
-                     "nominal charge value.";
+      qDebug() << "Cannot render ionization rule. Problem with the "
+                  "nominal charge value.";
 
       m_isValid = false;
     }
@@ -1188,8 +1212,8 @@ Ionizer::renderXmlIonizeRuleElement(const QDomElement &element)
   child = child.nextSiblingElement();
   if(child.tagName() != "level")
     {
-      qCritical() << "Cannot render ionization rule. Problem with the "
-                     "<level> element.";
+      qDebug() << "Cannot render ionization rule. Problem with the "
+                  "<level> element.";
 
       m_isValid = false;
       return m_isValid;
@@ -1199,8 +1223,8 @@ Ionizer::renderXmlIonizeRuleElement(const QDomElement &element)
   m_level = child.text().toInt(&ok);
   if(!m_level && !ok)
     {
-      qCritical() << "Cannot render ionization rule. Problem with the "
-                     "level value.";
+      qDebug() << "Cannot render ionization rule. Problem with the "
+                  "level value.";
 
       m_isValid = false;
     }
@@ -1212,8 +1236,8 @@ Ionizer::renderXmlIonizeRuleElement(const QDomElement &element)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Failed to successfully render <ionizerule> with errors:"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Failed to successfully render <ionizerule> with errors:"
+             << Utils::joinErrorList(error_list, ", ");
 
   return m_isValid;
 }
@@ -1358,7 +1382,7 @@ Ionizer::validate(ErrorList *error_list_p) const
   if(mcsp_isotopicData == nullptr || mcsp_isotopicData.get() == nullptr ||
      !mcsp_isotopicData->size())
     {
-      qCritical() << "Cannot validate Ionizer without available IsotopicData.";
+      qDebug() << "Cannot validate Ionizer without available IsotopicData.";
       error_list_p->push_back(
         "Cannot validate Ionizer without available IsotopicData");
       m_isValid = false;
@@ -1373,7 +1397,7 @@ Ionizer::validate(ErrorList *error_list_p) const
       QString msg =
         QString("The ionizer formula %1 failed to validate successfully")
           .arg(m_formula.getActionFormula());
-      qCritical() << msg;
+      qDebug() << msg;
       error_list_p->push_back(msg);
     }
 
@@ -1384,7 +1408,7 @@ Ionizer::validate(ErrorList *error_list_p) const
   qDebug() << "Going to validate the nominal charge:" << m_nominalCharge;
   if(!m_nominalCharge)
     {
-      qCritical()
+      qDebug()
         << "Cannot validate Ionizer that has its nominal charge equal to 0.";
       error_list_p->push_back(
         "Cannot validate Ionizer that has its nominal charge equal to 0");
@@ -1435,15 +1459,20 @@ Returns true if validation succeeded, false otherwise.
 bool
 Ionizer::validateCurrentState(ErrorList *error_list_p) const
 {
-  qsizetype error_count = error_list_p->size();
+  m_isCurrentStateValid = true;
 
   if(mcsp_isotopicData == nullptr || mcsp_isotopicData.get() == nullptr ||
      !mcsp_isotopicData->size())
     {
-      qCritical() << "Cannot validate Ionizer without available IsotopicData.";
-      error_list_p->push_back(
-        "Cannot validate Ionizer without available IsotopicData");
+      qDebug() << "Cannot validate Ionizer without available IsotopicData.";
+
+      if(error_list_p != Q_NULLPTR)
+        error_list_p->push_back(
+          "Cannot validate Ionizer without available IsotopicData");
+
       m_isCurrentStateValid = false;
+
+      // We really cannot go on with looking into this state.
       return m_isCurrentStateValid;
     }
 
@@ -1460,21 +1489,30 @@ Ionizer::validateCurrentState(ErrorList *error_list_p) const
                           "The ionizer current state formula %1 failed to "
                           "validate successfully")
                           .arg(m_currentStateFormula.getActionFormula());
-          qCritical() << msg;
-          error_list_p->push_back(msg);
+
+          qDebug() << msg;
+
+          if(error_list_p != Q_NULLPTR)
+            error_list_p->push_back(msg);
+
+          m_isCurrentStateValid = false;
         }
     }
 
+
   // The current state nominal charge and the current state level might be
   // 0 because the user might want to set up the Ionizer in such a way
   // that the analyte is not charged at all.
 
-  //  If we added errors, then that means that the Monomer was not valid.
-  m_isCurrentStateValid = (error_list_p->size() > error_count ? false : true);
-
   if(!m_isCurrentStateValid)
-    qDebug() << "Failed to validate this Ionizer current state, with errors:"
-             << Utils::joinErrorList(*error_list_p);
+    {
+      if(error_list_p != Q_NULLPTR)
+        qDebug()
+          << "Failed to validate this Ionizer current state, with errors:"
+          << Utils::joinErrorList(*error_list_p);
+    }
+  else
+    qDebug() << "The current state formula was validated successfully.";
 
   return m_isCurrentStateValid;
 }
@@ -1559,7 +1597,7 @@ Ionizer::registerJsConstructor(QJSEngine *engine)
 {
   if(!engine)
     {
-      qWarning() << "Cannot register Ionizer class: engine is null";
+      qDebug() << "Cannot register Ionizer class: engine is null";
       return;
     }
 
