@@ -69,7 +69,6 @@
 #include "MsXpS/libXpertMassCore/IsotopicDataUserConfigHandler.hpp"
 #include "MsXpS/libXpertMassCore/IsotopicDataManualConfigHandler.hpp"
 
-
 namespace MsXpS
 {
 namespace libXpertMassCore
@@ -149,14 +148,16 @@ than the two above, that actually crafts the isotopes starting from scratch.
 */
 
 /*!
-\variable MsXpS::libXpertMassCore::IsotopicClusterGenerator::m_maxSummedProbability
+\variable
+MsXpS::libXpertMassCore::IsotopicClusterGenerator::m_maxSummedProbability
 
 \brief The summed probability of all the isotopic cluster peaks. The
 computation stops when this probability is reached.
 */
 
 /*!
-\variable MsXpS::libXpertMassCore::IsotopicClusterGenerator::m_normalizeIntensity
+\variable
+MsXpS::libXpertMassCore::IsotopicClusterGenerator::m_normalizeIntensity
 
 \brief The most intense cluster peak's intensity that is used to normalize all
 the other cluster peaks.
@@ -175,19 +176,20 @@ the other cluster peaks.
 */
 
 /*!
-\variable MsXpS::libXpertMassCore::IsotopicClusterGenerator::m_formulaChargePairs
+\variable
+MsXpS::libXpertMassCore::IsotopicClusterGenerator::m_formulaChargePairs
 
 \brief The set of (elemental composition, charge) pairs.
 */
 
 /*!
-\variable MsXpS::libXpertMassCore::IsotopicClusterGenerator::m_isotopicClusterChargePairs
+\variable
+MsXpS::libXpertMassCore::IsotopicClusterGenerator::m_isotopicClusterChargePairs
 
 \brief The set of (isotopic cluster, charge) pairs.
 */
 
 
-
 /*!
 \brief Constructs a IsotopicClusterGenerator instance.
 */
@@ -226,7 +228,6 @@ IsotopicClusterGenerator::setIsotopicDataType(
   m_isotopicDataType = isotopic_data_type;
 }
 
-
 /*!
 \brief Sets the isotopic data to \a isotopic_data_sp.
 */
@@ -237,7 +238,6 @@ IsotopicClusterGenerator::setIsotopicData(
   msp_isotopicData = isotopic_data_sp;
 }
 
-
 /*!
 \brief Returns the isotopic data.
 */
@@ -247,7 +247,6 @@ IsotopicClusterGenerator::getIsotopicData() const
   return msp_isotopicData;
 }
 
-
 /*!
 \brief Adds the (elemental composition, charge) pair \a
 formula_charge_pair to the member list of FormulaChargePair instances.
@@ -350,14 +349,16 @@ IsotopicClusterGenerator::validateFormula(Formula &formula)
   //<< "against an isotopic data set of " << msp_isotopicData->size()
   //<< "isotopes";
 
+  // As of 1.4.3, the formula syntax check will automatically set to 1
+  // any missing index for any element symbol in the formula.
+  //
   // Check the syntax of the formula. Note that we need an obligatory count
   // index even for elements that are present a single time (H2O1 note the
   // 1).
-
+  //
   // IsoSpec requires that even single-count element be qualified with an
   // index (H2O1)
-
-  formula.setForceCountIndex(true);
+  //   formula.setForceCountIndex(true);
 
   // We have to validate because the formula might be "C5H6N3-O1", in which case
   // if would fail the simple checkSyntax() call (that call needs to be used on
@@ -365,8 +366,10 @@ IsotopicClusterGenerator::validateFormula(Formula &formula)
 
   ErrorList error_list;
 
-  if(!formula.validate(
-       msp_isotopicData, true /*store atom count*/, true /*reset counts*/, &error_list))
+  if(!formula.validate(msp_isotopicData,
+                       true /*store atom count*/,
+                       true /*reset counts*/,
+                       &error_list))
     return false;
 
   return true;
@@ -672,7 +675,7 @@ IsotopicClusterGenerator::generateIsotopicClusterCentroids(
       // qDebug() << "Old " << iter->first << "double version:" << iter->second
       //          << "new int version:" << symbol_int_count_map[iter->first];
 
-               ++iter;
+      ++iter;
     }
 
   // We pass the array pointers by reference.
@@ -725,7 +728,6 @@ IsotopicClusterGenerator::generateIsotopicClusterCentroids(
   return std::pair(isotopic_cluster_sp, formula_charge_pair.second);
 }
 
-
 /*!
 \brief Configures the isotopic data in a set of arrays for the (symbol,count)
 pairs in \a symbol_count_map.
@@ -1020,7 +1022,6 @@ IsotopicClusterGenerator::clusterToString(
   return text;
 }
 
-
 /*!
 \brief Returns a string containing a space-separated set of m/z, intensity
 pairs, representing the isotopic clusters in the member isotopic clusters \l
@@ -1070,8 +1071,8 @@ IsotopicClusterGenerator::run()
 
       if(!pair.first->size())
         {
-          qFatal("The isotopic cluster is empty for formula: %s",
-                 formula_charge_pair.first.toLatin1().data());
+          qFatal() << "The isotopic cluster is empty for formula: %s",
+            formula_charge_pair.first.toLatin1().data();
         }
 
       m_isotopicClusterChargePairs.push_back(pair);
