@@ -90,14 +90,15 @@ points in the different traces.
 */
 
 /*!
-\variable
+\variable \
 MsXpS::libXpertMassCore::IsotopicClusterShaper::m_isotopicClusterChargePairs
 
 \brief Vector of pappso::Trace instances in pair with charges.
 */
 
 /*!
-\variable MsXpS::libXpertMassCore::IsotopicClusterShaper::mp_massPeakShaperConfig
+\variable
+MsXpS::libXpertMassCore::IsotopicClusterShaper::mp_massPeakShaperConfig
 
 \brief The configuration driving the mass peak shaping process.
 */
