@@ -913,7 +913,7 @@ IsotopicData::getCumulatedProbabilities(IsotopeListCstIteratorPair iter_pair,
 
   if(iter_pair.first == m_isotopes.cend())
     {
-      qWarning() << "First iterator is actually end of m_isotopes.";
+      qDebug() << "First iterator is actually end of m_isotopes.";
 
       error_list_p->push_back(
         QString("First iterator is actually end of m_isotopes."));
@@ -1405,7 +1405,7 @@ IsotopicData::operator==(const IsotopicData &other) const
 
       if(*m_isotopes.at(iter) != *other.m_isotopes.at(iter))
         {
-          qWarning() << "At least one isotope differs in each data set.";
+          qDebug() << "At least one isotope differs in each data set.";
           return false;
         }
     }
@@ -1683,7 +1683,7 @@ IsotopicData::registerJsConstructor(QJSEngine *engine)
 {
   if(!engine)
     {
-      qWarning() << "Cannot register IsotopicData class: engine is null";
+      qDebug() << "Cannot register IsotopicData class: engine is null";
       return;
     }
 
