@@ -44,7 +44,6 @@
 #include "MsXpS/libXpertMassCore/globals.hpp"
 #include "MsXpS/libXpertMassCore/IsotopicDataBaseHandler.hpp"
 
-
 namespace MsXpS
 {
 
@@ -84,7 +83,8 @@ IsotopicDataManualConfigHandler
 */
 
 /*!
-   \variable int MsXpS::libXpertMassCore::IsotopicDataBaseHandler::msp_isotopicData
+   \variable int
+   MsXpS::libXpertMassCore::IsotopicDataBaseHandler::msp_isotopicData
 
    \brief The msp_isotopicData is a pointer to \l{IsotopicData}.
 */
