@@ -155,11 +155,11 @@ IsotopicDataLibraryHandler::loadData([[maybe_unused]] const QString &filename)
   qsizetype count = loadData(count_non_isotope_skipped_items);
 
   if(count)
-    qCritical() << "Not a single Isotope could be loaded from file.";
+    qDebug() << "Not a single Isotope could be loaded from file.";
 
   if(count_non_isotope_skipped_items)
-    qInfo() << "There were " << count_non_isotope_skipped_items
-            << "non-Isotope items in the tables.";
+    qDebug() << "There were " << count_non_isotope_skipped_items
+             << "non-Isotope items in the tables.";
 
   return count;
 }
@@ -352,7 +352,8 @@ IsotopicDataLibraryHandler::checkConsistency()
   // All the tables in the header file of the IsoSpec library must
   // have exactly the same size.
 
-  if((qsizetype)IsoSpec::isospec_number_of_isotopic_entries != array_length)
+  if(static_cast<qsizetype>(IsoSpec::isospec_number_of_isotopic_entries) !=
+     array_length)
     {
       qFatal(
         "Found corruption: the size of IsoSpec arrays is not like expected.");
