@@ -132,7 +132,8 @@ Alias for to std::map<QString, int>.
 */
 
 /*!
-  \variable MsXpS::libXpertMassCore::IsotopicDataManualConfigHandler::m_symbolCountMap
+  \variable
+MsXpS::libXpertMassCore::IsotopicDataManualConfigHandler::m_symbolCountMap
 
   Holds symbol/count pairs to document the count of any symbol in the isotopic
 data. This symbol count is stored in the file using the following format:
