@@ -2,7 +2,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -36,7 +36,6 @@
 #include "MsXpS/libXpertMassCore/Utils.hpp"
 #include "MsXpS/libXpertMassCore/MassCollection.hpp"
 
-
 namespace MsXpS
 {
 namespace libXpertMassCore
@@ -106,14 +105,14 @@ MassCollection::MassCollection(const QString &name, const QString &mass_text)
   ErrorList error_list;
 
   if(textToMasses(mass_text, &error_list) == -1)
-    qCritical() << "Constructing a MassCollection with text not suitable for "
-                   "representing mass double values.";
+    qDebug() << "Constructing a MassCollection with text not suitable for "
+                "representing mass double values.";
 
   //  Will set m_isValid to the right value.
   if(!validate(&error_list))
-    qWarning() << "Constructing a MassCollection that does not validate "
-                  "successfully,  with errors:"
-               << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Constructing a MassCollection that does not validate "
+                "successfully,  with errors:"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
 /*!
@@ -189,7 +188,6 @@ MassCollection::getName() const
   return m_name;
 }
 
-
 /*!
  \brief Sets the comment to \a comment.
  */
@@ -235,7 +233,6 @@ MassCollection::getMassesRef()
   return m_masses;
 }
 
-
 /*!
  \brief Returns the mass at the \a index in the container.
 
@@ -250,7 +247,6 @@ MassCollection::getMassAtIndex(std::size_t index) const
   return m_masses.at(index);
 }
 
-
 /*!
 \brief Returns the count of masses successfully obtained by converting the \a
 text to double values.
@@ -293,8 +289,7 @@ MassCollection::textToMasses(const QString &text, ErrorList *error_list_p)
 
       if(!ok)
         {
-          qCritical() << "This text element failed to convert to double:"
-                      << line;
+          qDebug() << "This text element failed to convert to double:" << line;
           error_list_p->push_back(line);
           break;
         }
@@ -377,7 +372,6 @@ MassCollection::removeLessThan(double threshold)
     }
 }
 
-
 /*!
 \brief Validates this MassCollection and returns true if successful or false
 otherwise.
