@@ -37,7 +37,7 @@
 /////////////////////// Qt includes
 #include <QDebug>
 #include <QFileInfo>
-
+#include <QThread>
 
 /////////////////////// IsoSpec
 
@@ -89,8 +89,8 @@ following key/value pairs:
 \list
 
 \li "DATA_TYPE" / value (quint64) : this quint64
-(QCborStreamReader::UnsignedInteger) value is only got as the very first data bit
-in the file and represents the Enums::MassDataType::MASS_SPECTRUM value
+(QCborStreamReader::UnsignedInteger) value is only got as the very first data
+bit in the file and represents the Enums::MassDataType::MASS_SPECTRUM value
 describing the kind of data encoded in the CBOR container.
 
 \li "TITLE" / value (text string): the title of the mass spectrum that should be
