@@ -97,8 +97,8 @@ namespace libXpertMassCore
 \brief Constructs a MassDataClient instance.
 
 \list
-\li \a ip_address: the server (\l{MassDataServer}) IP address at which the client
-needs to try a connection.
+\li \a ip_address: the server (\l{MassDataServer}) IP address at which the
+client needs to try a connection.
 \li \a port_number: the port number for the connection.
 \li \a parent: the parent QObject.
 \endlist
