@@ -1092,8 +1092,7 @@ MassPeakShaperConfig::registerJsConstructor(QJSEngine *engine)
 {
   if(!engine)
     {
-      qWarning()
-        << "Cannot register MassPeakShaperConfig class: engine is null";
+      qDebug() << "Cannot register MassPeakShaperConfig class: engine is null";
       return;
     }
 
