@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -54,7 +54,6 @@ int modifMetaTypeId = qRegisterMetaType<MsXpS::libXpertMassCore::Modif>(
 int modifPtrMetaTypeId = qRegisterMetaType<MsXpS::libXpertMassCore::Modif *>(
   "MsXpS::libXpertMassCore::ModifPtr");
 
-
 namespace MsXpS
 {
 namespace libXpertMassCore
@@ -181,12 +180,12 @@ Modif::Modif(PolChemDefCstSPtr pol_chem_def_csp,
   : mcsp_polChemDef(pol_chem_def_csp)
 {
   if(mcsp_polChemDef == nullptr || mcsp_polChemDef.get() == nullptr)
-    qCritical() << "Constructing Modif with no PolChemDef.";
+    qDebug() << "Constructing Modif with no PolChemDef.";
 
   if(!renderXmlMdfElement(element, version))
     {
-      qCritical() << "Failed to fully render or validate the Modif XML element "
-                     "for construction of Modif instance.";
+      qDebug() << "Failed to fully render or validate the Modif XML element "
+                  "for construction of Modif instance.";
     }
 }
 
@@ -235,8 +234,8 @@ Modif::Modif(PolChemDefCstSPtr pol_chem_def_csp,
 
   if(!m_isValid)
     {
-      qCritical() << "Construction of Modif with validation errors:\n"
-                  << Utils::joinErrorList(error_list, ", ");
+      qDebug() << "Construction of Modif with validation errors:\n"
+               << Utils::joinErrorList(error_list, ", ");
     }
 
   // Validation tries to compute masses but does not update member data.
@@ -244,8 +243,8 @@ Modif::Modif(PolChemDefCstSPtr pol_chem_def_csp,
   if(!calculateMasses(nullptr))
     {
       m_isValid = false;
-      qCritical() << "Construction of Modif with masses that failed to be "
-                     "calculated.";
+      qDebug() << "Construction of Modif with masses that failed to be "
+                  "calculated.";
     }
 }
 
@@ -272,8 +271,8 @@ Modif::Modif(const Modif &other)
 
   if(!m_isValid)
     {
-      qCritical() << "Construction of Modif with validation errors:\n"
-                  << Utils::joinErrorList(error_list, ", ");
+      qDebug() << "Construction of Modif with validation errors:\n"
+               << Utils::joinErrorList(error_list, ", ");
     }
 
   // Validation tries to compute masses but does not update member data.
@@ -281,8 +280,8 @@ Modif::Modif(const Modif &other)
   if(!calculateMasses(nullptr))
     {
       m_isValid = false;
-      qCritical() << "Construction of Modif with masses that failed to be "
-                     "calculated.";
+      qDebug() << "Construction of Modif with masses that failed to be "
+                  "calculated.";
     }
 }
 
@@ -293,7 +292,6 @@ Modif::~Modif()
 {
 }
 
-
 /*!
 \brief Sets the polymer chemistry definition to \a pol_chem_def_csp.
 
@@ -309,8 +307,8 @@ Modif::setPolChemDefCstSPtr(PolChemDefCstSPtr pol_chem_def_csp)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Failed to validate the Modif with errors:\n"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Failed to validate the Modif with errors:\n"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
 /*!
@@ -339,8 +337,8 @@ Modif::setName(const QString &name)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Failed to validate the Modif with errors:\n"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Failed to validate the Modif with errors:\n"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
 /*!
@@ -370,8 +368,8 @@ Modif::setFormula(const QString &formula_string)
 
   if(!m_isValid)
     {
-      qCritical() << "Failed to validate the Modif with errors:\n"
-                  << Utils::joinErrorList(error_list, ", ");
+      qDebug() << "Failed to validate the Modif with errors:\n"
+               << Utils::joinErrorList(error_list, ", ");
     }
 
   // Validation tries to compute masses but does not update member data.
@@ -380,7 +378,7 @@ Modif::setFormula(const QString &formula_string)
     {
       m_isValid = false;
 
-      qCritical()
+      qDebug()
         << "Failed to calculate the masses after setting formula to Modif.";
     }
 }
@@ -445,8 +443,8 @@ Modif::setTargets(const QString &targets)
 
   if(!ok)
     {
-      qCritical() << "The validation of the Modif targets failed:"
-                  << local_targets_string;
+      qDebug() << "The validation of the Modif targets failed:"
+               << local_targets_string;
       m_targets = QString();
     }
   else
@@ -456,8 +454,8 @@ Modif::setTargets(const QString &targets)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Failed to validate the Modif with errors:"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Failed to validate the Modif with errors:"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
 /*!
@@ -510,8 +508,8 @@ Modif::setMaxCount(int value)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Failed to validate the Modif with errors:"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Failed to validate the Modif with errors:"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
 /*!
@@ -554,14 +552,13 @@ Modif::operator=(const Modif &other)
 
   if(!m_isValid)
     {
-      qCritical() << "Assignment of Modif with validation errors:\n"
-                  << Utils::joinErrorList(error_list, ", ");
+      qDebug() << "Assignment of Modif with validation errors:\n"
+               << Utils::joinErrorList(error_list, ", ");
     }
 
   return *this;
 }
 
-
 /*!
 \brief Returns true if this and the \a other modifications are identical,
 false otherwise.
@@ -679,7 +676,7 @@ Modif::validateTargets(const QString &targets_string,
 {
   if(mcsp_polChemDef == nullptr || mcsp_polChemDef.get() == nullptr)
     {
-      qCritical()
+      qDebug()
         << "Cannot validate the targets because no PolChemDef is defined.";
       m_isValid = false;
       return QString();
@@ -699,7 +696,7 @@ Modif::validateTargets(const QString &targets_string,
   // character. We check that immediately.
   if(local_targets_string.contains('*') && local_targets_string.contains('!'))
     {
-      qWarning()
+      qDebug()
         << "A modification targets string cannot contain both '*' and '!'.";
 
       ok = false;
@@ -868,7 +865,7 @@ Modif::validate(ErrorList *error_list_p) const
     {
       error_list_p->push_back(
         "The PolChemDef or the IsotopicData are not available");
-      qCritical()
+      qDebug()
         << "The polymer chemistry definition member datum is nullptr or "
            "its isotopic data are be either nullptr or empty. Modif validation "
            "failed.";
@@ -878,7 +875,7 @@ Modif::validate(ErrorList *error_list_p) const
 
   if(m_name.isEmpty())
     {
-      qCritical() << "The Modif name is empty.";
+      qDebug() << "The Modif name is empty.";
       error_list_p->push_back("The Modif name is empty");
     }
 
@@ -886,7 +883,7 @@ Modif::validate(ErrorList *error_list_p) const
   if(!temp_formula.validate(mcsp_polChemDef->getIsotopicDataCstSPtr(),
                             error_list_p))
     {
-      qCritical() << "The Modif formula failed to validate.";
+      qDebug() << "The Modif formula failed to validate.";
       error_list_p->push_back("The Modif formula failed to validate");
     }
 
@@ -895,7 +892,7 @@ Modif::validate(ErrorList *error_list_p) const
 
   if(!calculateMasses(mcsp_polChemDef->getIsotopicDataCstSPtr(), mono, avg))
     {
-      qCritical() << "Failed to calculate the Modif masses.";
+      qDebug() << "Failed to calculate the Modif masses.";
       error_list_p->push_back("Failed to calculate the Modif masses");
     }
 
@@ -907,14 +904,15 @@ Modif::validate(ErrorList *error_list_p) const
 
   if(!ok)
     {
-      qCritical() << "The Modif targets failed to validate.";
+      qDebug() << "The Modif targets failed to validate.";
       error_list_p->push_back("The Modif targets failed to validate");
     }
 
   if(m_maxCount <= 0)
     {
-      qCritical() << "The maximum modification count failed to validate.";
-      error_list_p->push_back("The maximum modification count failed to validate");
+      qDebug() << "The maximum modification count failed to validate.";
+      error_list_p->push_back(
+        "The maximum modification count failed to validate");
     }
 
   m_isValid = (error_list_p->size() > error_count ? false : true);
@@ -931,7 +929,6 @@ Modif::isValid() const
   return m_isValid;
 }
 
-
 //////////////// MASS CALCULATIONS /////////////////////
 /*!
 \brief Calculates the net masses of this modification and sets the results in
@@ -967,7 +964,7 @@ Modif::calculateMasses(const IsotopicDataCstSPtr &isotopic_data_csp,
       if(local_isotopic_data_csp == nullptr ||
          local_isotopic_data_csp.get() == nullptr)
         {
-          qCritical() << "Failed to find usable isotopic data.";
+          qDebug() << "Failed to find usable isotopic data.";
           m_isValid = false;
           return false;
         }
@@ -985,8 +982,8 @@ Modif::calculateMasses(const IsotopicDataCstSPtr &isotopic_data_csp,
 
   if(!ok)
     {
-      qCritical() << "Failed accounting masses for Modif:" << m_name
-                  << "and formula:" << m_formula;
+      qDebug() << "Failed accounting masses for Modif:" << m_name
+               << "and formula:" << m_formula;
       m_isValid = false;
     }
 
@@ -1026,7 +1023,7 @@ Modif::calculateMasses(const IsotopicDataCstSPtr &isotopic_data_csp)
       if(local_isotopic_data_csp == nullptr ||
          local_isotopic_data_csp.get() == nullptr)
         {
-          qCritical() << "Failed to find usable isotopic data.";
+          qDebug() << "Failed to find usable isotopic data.";
           return false;
         }
     }
@@ -1043,8 +1040,8 @@ Modif::calculateMasses(const IsotopicDataCstSPtr &isotopic_data_csp)
 
   if(!ok)
     {
-      qCritical() << "Failed accounting masses for Modif:" << m_name
-                  << "and formula:" << m_formula;
+      qDebug() << "Failed accounting masses for Modif:" << m_name
+               << "and formula:" << m_formula;
       m_isValid = false;
     }
 
@@ -1084,7 +1081,7 @@ Modif::calculateMasses(bool &ok, const IsotopicDataCstSPtr &isotopic_data_csp)
       if(local_isotopic_data_csp == nullptr ||
          local_isotopic_data_csp.get() == nullptr)
         {
-          qCritical() << "Failed to find usable isotopic data.";
+          qDebug() << "Failed to find usable isotopic data.";
           ok = false;
           return *this;
         }
@@ -1100,8 +1097,8 @@ Modif::calculateMasses(bool &ok, const IsotopicDataCstSPtr &isotopic_data_csp)
 
   if(!ok)
     {
-      qCritical() << "Failed accounting masses for Modif:" << m_name
-                  << "and formula:" << m_formula;
+      qDebug() << "Failed accounting masses for Modif:" << m_name
+               << "and formula:" << m_formula;
       m_isValid = false;
     }
 
@@ -1142,12 +1139,11 @@ const Modif &
 Modif::accountMasses(double &mono, double &avg, int times) const
 {
   mono += m_mono * times;
-  avg += m_avg * times;
+  avg  += m_avg * times;
 
   return *this;
 }
 
-
 /*!
 \brief Returns the mass of the type defined by \a mass_type.
 */
@@ -1211,7 +1207,7 @@ Modif::renderXmlMdfElement(const QDomElement &element,
 
   if(element.tagName() != "mdf")
     {
-      qCritical() << "The element tag name is not 'mdf'";
+      qDebug() << "The element tag name is not 'mdf'";
       m_isValid = false;
       return m_isValid;
     }
@@ -1222,8 +1218,8 @@ Modif::renderXmlMdfElement(const QDomElement &element,
 
   if(child.isNull() || child.text().isEmpty())
     {
-      qCritical() << "The Modif did not render correctly: problem with the "
-                     "<name> element.";
+      qDebug() << "The Modif did not render correctly: problem with the "
+                  "<name> element.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1234,8 +1230,8 @@ Modif::renderXmlMdfElement(const QDomElement &element,
 
   if(child.isNull())
     {
-      qCritical() << "The Modif did not render correctly: problem with the "
-                     "<formula> element.";
+      qDebug() << "The Modif did not render correctly: problem with the "
+                  "<formula> element.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1244,8 +1240,8 @@ Modif::renderXmlMdfElement(const QDomElement &element,
 
   if(!temp_formula.renderXmlFormulaElement(child))
     {
-      qCritical() << "The Modif did not render correctly: the formula did not "
-                     "render correctly.";
+      qDebug() << "The Modif did not render correctly: the formula did not "
+                  "render correctly.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1256,8 +1252,8 @@ Modif::renderXmlMdfElement(const QDomElement &element,
 
   if(child.isNull() || child.text().isEmpty())
     {
-      qCritical() << "The Modif did not render correctly: problem with the "
-                     "<targets> element.";
+      qDebug() << "The Modif did not render correctly: problem with the "
+                  "<targets> element.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1272,8 +1268,8 @@ Modif::renderXmlMdfElement(const QDomElement &element,
 
   if(!ok)
     {
-      qCritical() << "The Modif did not render correctly: the targets could "
-                     "not validate successfully.";
+      qDebug() << "The Modif did not render correctly: the targets could "
+                  "not validate successfully.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1283,8 +1279,8 @@ Modif::renderXmlMdfElement(const QDomElement &element,
 
   if(child.isNull() || child.text().isEmpty())
     {
-      qCritical() << "The Modif did not render correctly: problem with the "
-                     "<maxcount> element.";
+      qDebug() << "The Modif did not render correctly: problem with the "
+                  "<maxcount> element.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1296,8 +1292,8 @@ Modif::renderXmlMdfElement(const QDomElement &element,
 
   if(!ok || max_count_int <= 0)
     {
-      qCritical() << "The Modif did not render correctly: the maxcount value "
-                     "is less than 0.";
+      qDebug() << "The Modif did not render correctly: the maxcount value "
+                  "is less than 0.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1307,8 +1303,8 @@ Modif::renderXmlMdfElement(const QDomElement &element,
   m_isValid = validate(&error_list);
   if(!m_isValid)
     {
-      qCritical() << "The Modif did not validate successfully after "
-                     "rendering, with errors:";
+      qDebug() << "The Modif did not validate successfully after "
+                  "rendering, with errors:";
       Utils::joinErrorList(error_list, ", ");
     }
   else
@@ -1320,7 +1316,7 @@ Modif::renderXmlMdfElement(const QDomElement &element,
 
       if(!calculateMasses(nullptr))
         {
-          qCritical() << "The Modif's masses could not be calculated.";
+          qDebug() << "The Modif's masses could not be calculated.";
         }
     }
 
@@ -1329,7 +1325,6 @@ Modif::renderXmlMdfElement(const QDomElement &element,
   return m_isValid;
 }
 
-
 /*!
 \brief Formats this modification's data as a string suitable to be used as a
 \c mdf XML element in the polymer chemistry definition or a polymer sequence
@@ -1425,7 +1420,7 @@ Modif::formatXmlMdfElement(int offset, const QString &indent) const
 
   // QString debug_message =
   //   QString("%1\n%2\n").arg("Returning string:").arg(text);
-  // qCritical().noquote() << debug_message;
+  // qDebug().noquote() << debug_message;
 
   return text;
 }
