@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009, ..., 2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -51,7 +51,6 @@
 int monomerMetaTypeId = qRegisterMetaType<MsXpS::libXpertMassCore::Monomer>(
   "MsXpS::libXpertMassCore::Monomer");
 
-
 namespace MsXpS
 {
 namespace libXpertMassCore
@@ -213,19 +212,18 @@ Monomer::Monomer(PolChemDefCstSPtr pol_chem_def_csp,
   : mcsp_polChemDef(pol_chem_def_csp)
 {
   if(mcsp_polChemDef == nullptr || mcsp_polChemDef.get() == nullptr)
-    qCritical() << "Constructing Monomer with no PolChemDef.";
+    qDebug() << "Constructing Monomer with no PolChemDef.";
 
   if(!renderXmlMnmElement(element, version))
-    qCritical() << "Failed to fully render or validate the Monomer XML element "
-                   "for construction of Monomer instance.";
+    qDebug() << "Failed to fully render or validate the Monomer XML element "
+                "for construction of Monomer instance.";
 
   // We cannot ask for validation because the polymer chemistry definition
   // might be unavailable when using the XML element rendering.
 
-  qDebug() << "Constructed Monomer" << m_name << ":" << toString();
+  // qDebug() << "Constructed Monomer" << m_name << ":" << toString();
 }
 
-
 /*!
 \brief Constructs a monomer with its member data set to \a name, \a code, \a
 formula_string,
@@ -254,8 +252,8 @@ Monomer::Monomer(PolChemDefCstSPtr pol_chem_def_csp,
 
       if(!m_isValid)
         {
-          qCritical() << "Construction of Monomer with validation errors:\n"
-                      << Utils::joinErrorList(error_list, ", ");
+          qDebug() << "Construction of Monomer with validation errors:\n"
+                   << Utils::joinErrorList(error_list, ", ");
         }
     }
   else
@@ -275,7 +273,7 @@ Monomer::Monomer(const Monomer &other)
     m_avg(other.m_avg)
 {
   if(mcsp_polChemDef == nullptr || mcsp_polChemDef.get() == nullptr)
-    qCritical() << "Copy-constructing Monomer with no PolChemDef.";
+    qDebug() << "Copy-constructing Monomer with no PolChemDef.";
 
   // We do a real duplication of the Modif instances.
   for(ModifSPtr modif_sp : other.m_modifs)
@@ -286,8 +284,8 @@ Monomer::Monomer(const Monomer &other)
 
   if(!m_isValid)
     {
-      qCritical() << "Copy-construction of Monomer with validation errors:\n"
-                  << Utils::joinErrorList(error_list, ", ");
+      qDebug() << "Copy-construction of Monomer with validation errors:\n"
+               << Utils::joinErrorList(error_list, ", ");
     }
 }
 
@@ -299,7 +297,6 @@ Monomer::~Monomer()
   m_modifs.clear();
 }
 
-
 //////////////// THE POLCHEMDEF /////////////////////
 /*!
 \brief Sets the polymer chemistry definition to \a pol_chem_def_csp.
@@ -313,8 +310,8 @@ Monomer::setPolChemDefCstSPtr(PolChemDefCstSPtr &pol_chem_def_csp)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Failed to validate the Monomer with errors:\n"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Failed to validate the Monomer with errors:\n"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
 /*!
@@ -340,8 +337,8 @@ Monomer::setName(const QString &name)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Failed to validate the Monomer with errors:\n"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Failed to validate the Monomer with errors:\n"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
 /*!
@@ -353,7 +350,6 @@ Monomer::getName() const
   return m_name;
 }
 
-
 //////////////// THE CODE /////////////////////
 /*!
 \brief Sets the code to \a code
@@ -368,11 +364,10 @@ Monomer::setCode(const QString &code)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Failed to validate the Monomer with errors:\n"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Failed to validate the Monomer with errors:\n"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
-
 /*!
 \brief Returns the code
 */
@@ -382,7 +377,6 @@ Monomer::getCode() const
   return m_code;
 }
 
-
 /*!
 \brief Checks the code's syntactic validity.
 
@@ -417,14 +411,14 @@ Monomer::checkCodeSyntax(int code_length) const
         }
       else
         {
-          qCritical() << "Checking code syntax with unlimited length because "
-                         "Monomer has no PolChemDef.";
+          qDebug() << "Checking code syntax with unlimited length because "
+                      "Monomer has no PolChemDef.";
           local_code_length = 1000;
         }
     }
 
-  qDebug() << "Checking code syntax:" << m_code
-           << "with code length:" << local_code_length;
+  // qDebug() << "Checking code syntax:" << m_code
+  //          << "with code length:" << local_code_length;
 
   // The code has to be at least one character long.
 
@@ -434,9 +428,9 @@ Monomer::checkCodeSyntax(int code_length) const
 
   if(m_code.length() < 1 || m_code.length() > local_code_length)
     {
-      qCritical() << "The code has a length:" << m_code.length()
-                  << "that does not match the expected code length:"
-                  << local_code_length;
+      qDebug() << "The code has a length:" << m_code.length()
+               << "that does not match the expected code length:"
+               << local_code_length;
       m_isValid = false;
       return false;
     }
@@ -452,8 +446,8 @@ Monomer::checkCodeSyntax(int code_length) const
 
   if(match.hasMatch())
     {
-      qDebug() << "First uppercase char:" << match.captured(1);
-      qDebug() << "Remaining lowercase chars:" << match.captured(2);
+      // qDebug() << "First uppercase char:" << match.captured(1);
+      // qDebug() << "Remaining lowercase chars:" << match.captured(2);
 
       return true;
     }
@@ -512,8 +506,8 @@ Monomer::setFormula(const QString &formula_string)
   m_isValid = validate(&error_list);
 
   if(!m_isValid)
-    qCritical() << "Failed to validate the Monomer with errors:\n"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "Failed to validate the Monomer with errors:\n"
+             << Utils::joinErrorList(error_list, ", ");
 }
 
 /*
@@ -525,7 +519,6 @@ Monomer::getFormula() const
   return m_formula;
 }
 
-
 //////////////// THE MODIFICATIONS /////////////////////
 
 /*!
@@ -537,7 +530,6 @@ Monomer::getModifsCstRef() const
   return m_modifs;
 }
 
-
 /*!
 \brief Returns the list of Modif names in the same order as the Modif instances
 are stored in the member container.
@@ -553,7 +545,6 @@ Monomer::modifNamesInOrder() const
   return names;
 }
 
-
 /*
 \brief Returns true if this monomer is a target of Modif \a modif, false
 otherwise.
@@ -567,7 +558,6 @@ Monomer::isModifTarget(const Modif &modif) const
   return modif.doesTargetMonomer(m_code);
 }
 
-
 /*!
 \brief Modifies this monomer using \a modif.
 
@@ -639,7 +629,6 @@ Monomer::modify(const Modif &modif, bool override, ErrorList *error_list_p)
   return uuid;
 }
 
-
 /*!
 \brief Modifies this monomer using \a modif_name.
 
@@ -651,13 +640,15 @@ If such a Modif is found, it is used to modify this Monomer.
 Returns a string with the Uuid of the allocated Modif instance.
  */
 QString
-Monomer::modify(const QString &modif_name, bool override, ErrorList *error_list_p)
+Monomer::modify(const QString &modif_name,
+                bool override,
+                ErrorList *error_list_p)
 {
   ModifCstSPtr modif_csp = mcsp_polChemDef->getModifCstSPtrByName(modif_name);
 
   if(modif_csp == nullptr)
     {
-      qCritical() << "Modif by name" << modif_name << "is not known.";
+      qDebug() << "Modif by name" << modif_name << "is not known.";
       return QString();
     }
 
@@ -673,14 +664,16 @@ Returns true if the unmodification was actually performed, false otherwise.
 bool
 Monomer::unmodify(const QString &uuid)
 {
-  std::vector<UuidModifWPtrPair>::iterator the_iterator = std::find_if(
-    m_uuidModifPairs.begin(),
-    m_uuidModifPairs.end(),
-    [uuid](UuidModifWPtrPair &pair) { return pair.first == uuid; });
+  std::vector<UuidModifWPtrPair>::iterator the_iterator =
+    std::find_if(m_uuidModifPairs.begin(),
+                 m_uuidModifPairs.end(),
+                 [uuid](UuidModifWPtrPair &pair) {
+                   return pair.first == uuid;
+                 });
 
   if(the_iterator == m_uuidModifPairs.end())
     {
-      qCritical() << "The modification was not found.";
+      qDebug() << "The modification was not found.";
       return false;
     }
 
@@ -696,7 +689,6 @@ Monomer::unmodify(const QString &uuid)
   return true;
 }
 
-
 /*!
 \brief Removes \e{all} the modification from this monomer.
 
@@ -718,7 +710,6 @@ Monomer::unmodify()
   return modif_count != 0;
 }
 
-
 /*!
 \brief Returns true if this monomer has at least one modification, false
 otherwise.
@@ -744,7 +735,6 @@ Monomer::countModifsByName(const QString &modif_name)
   return count;
 }
 
-
 //////////////// OPERATORS /////////////////////
 
 /*!
@@ -782,8 +772,8 @@ Monomer::operator=(const Monomer &other)
 
   if(!m_isValid)
     {
-      qCritical() << "Assignment of Monomer with validation errors:\n"
-                  << Utils::joinErrorList(error_list, ", ");
+      qDebug() << "Assignment of Monomer with validation errors:\n"
+               << Utils::joinErrorList(error_list, ", ");
     }
 
   // qDebug() << "Assignment of Monomer produced *this Monomer:" << toString();
@@ -791,7 +781,6 @@ Monomer::operator=(const Monomer &other)
   return *this;
 }
 
-
 /*!
 \brief Returns true if this monomer and \a other are identical, false
 otherwise.
@@ -834,7 +823,6 @@ Monomer::operator==(const Monomer &other) const
   return true;
 }
 
-
 /*!
 \brief Returns true if \c this monomer and \a other differ, false
 otherwise.
@@ -850,7 +838,6 @@ Monomer::operator!=(const Monomer &other) const
   return !operator==(other);
 }
 
-
 //////////////// VALIDATIONS /////////////////////
 /*!
 \brief Returns the Monomer instance from the polymer chemistry definition
@@ -946,7 +933,6 @@ Monomer::isKnownByCodeInPolChemDef() const
   return Enums::PolChemDefEntityStatus::ENTITY_NOT_KNOWN;
 }
 
-
 /*!
 \brief Returns true if this monomer is valid, false otherwise.
 
@@ -973,12 +959,12 @@ Monomer::validate(ErrorList *error_list_p) const
      mcsp_polChemDef->getIsotopicDataCstSPtr().get() == nullptr ||
      !mcsp_polChemDef->getIsotopicDataCstSPtr()->size())
     {
-      error_list_p->push_back("The PolChemDef or IsotopicData are not available");
-      qCritical()
-        << "The polymer chemistry definition member datum is nullptr or "
-           "its isotopic data are be either nullptr or empty. Monomer "
-           "validation "
-           "failed.";
+      error_list_p->push_back(
+        "The PolChemDef or IsotopicData are not available");
+      qDebug() << "The polymer chemistry definition member datum is nullptr or "
+                  "its isotopic data are be either nullptr or empty. Monomer "
+                  "validation "
+                  "failed.";
 
       m_isValid = false;
       return false;
@@ -986,14 +972,14 @@ Monomer::validate(ErrorList *error_list_p) const
 
   if(m_name.isEmpty())
     {
-      qCritical() << "The Monomer name is empty.";
+      qDebug() << "The Monomer name is empty.";
       error_list_p->push_back("The Monomer name is empty");
     }
 
   // qDebug() << "Now checking the code syntax.";
   if(!checkCodeSyntax())
     {
-      qCritical() << "The Monomer code does not pass the syntax test.";
+      qDebug() << "The Monomer code does not pass the syntax test.";
       error_list_p->push_back("The Monomer code does not pass the syntax test");
     }
 
@@ -1001,7 +987,7 @@ Monomer::validate(ErrorList *error_list_p) const
   if(!temp_formula.validate(mcsp_polChemDef->getIsotopicDataCstSPtr(),
                             error_list_p))
     {
-      qCritical() << "The Monomer formula failed to validate.";
+      qDebug() << "The Monomer formula failed to validate.";
       error_list_p->push_back("The Monomer formula failed to validate");
     }
 
@@ -1010,24 +996,26 @@ Monomer::validate(ErrorList *error_list_p) const
 
   if(!calculateMasses(mcsp_polChemDef->getIsotopicDataCstSPtr(), mono, avg))
     {
-      qCritical() << "Failed to calculate the Monomer masses.";
+      qDebug() << "Failed to calculate the Monomer masses.";
       error_list_p->push_back("Failed to calculate the Monomer masses");
     }
 
-  qDebug() << qSetRealNumberPrecision(6)
-           << "Validation calculated masses (not member data):" << mono << "-"
-           << avg;
+  // qDebug() << qSetRealNumberPrecision(6)
+  //          << "Validation calculated masses (not member data):" << mono <<
+  //          "-"
+  //          << avg;
 
   for(const ModifSPtr &modif_sp : m_modifs)
     {
       ErrorList local_error_list;
       if(!modif_sp->validate(&local_error_list))
         {
-          qCritical() << "Monomer's Modif" << modif_sp->getName()
-                      << "failed to validate successfully.";
+          qDebug() << "Monomer's Modif" << modif_sp->getName()
+                   << "failed to validate successfully.";
 
-          error_list_p->push_back(QString("Failed to validate Monomer's Modif %1")
-                                 .arg(modif_sp->getName()));
+          error_list_p->push_back(
+            QString("Failed to validate Monomer's Modif %1")
+              .arg(modif_sp->getName()));
         }
     }
 
@@ -1048,7 +1036,6 @@ Monomer::isValid() const
   return m_isValid;
 }
 
-
 //////////////// MASS OPERATIONS /////////////////////
 
 /*!
@@ -1081,7 +1068,7 @@ Monomer::calculateMasses(const IsotopicDataCstSPtr &isotopic_data_csp,
       if(local_isotopic_data_csp == nullptr ||
          local_isotopic_data_csp.get() == nullptr)
         {
-          qCritical() << "Failed to find usable isotopic data.";
+          qDebug() << "Failed to find usable isotopic data.";
           m_isValid = false;
           return m_isValid;
         }
@@ -1097,8 +1084,8 @@ Monomer::calculateMasses(const IsotopicDataCstSPtr &isotopic_data_csp,
 
   if(!ok)
     {
-      qCritical() << "Failed accounting masses for Monomer:" << m_name
-                  << "and formula:" << m_formula;
+      qDebug() << "Failed accounting masses for Monomer:" << m_name
+               << "and formula:" << m_formula;
       m_isValid = false;
       return m_isValid;
     }
@@ -1141,7 +1128,7 @@ Monomer::calculateMasses(const IsotopicDataCstSPtr &isotopic_data_csp,
       if(local_isotopic_data_csp == nullptr ||
          local_isotopic_data_csp.get() == nullptr)
         {
-          qCritical() << "Failed to find usable isotopic data.";
+          qDebug() << "Failed to find usable isotopic data.";
           m_isValid = false;
           return m_isValid;
         }
@@ -1157,8 +1144,8 @@ Monomer::calculateMasses(const IsotopicDataCstSPtr &isotopic_data_csp,
 
   if(!ok)
     {
-      qCritical() << "Failed accounting masses for Monomer:" << m_name
-                  << "and formula:" << m_formula;
+      qDebug() << "Failed accounting masses for Monomer:" << m_name
+               << "and formula:" << m_formula;
       m_isValid = false;
       return m_isValid;
     }
@@ -1219,7 +1206,6 @@ Monomer::accountMasses(double *mono_p, double *avg_p, int times) const
   return *this;
 }
 
-
 /*!
 \brief Increases \a mono and \a avg by the corresponding member masses first
 compounded by \a times.
@@ -1230,12 +1216,11 @@ const Monomer &
 Monomer::accountMasses(double &mono, double &avg, int times) const
 {
   mono += m_mono * times;
-  avg += m_avg * times;
+  avg  += m_avg * times;
 
   return *this;
 }
 
-
 /*!
 \brief Returns the mass of the type defined by \a mass_type.
 */
@@ -1247,13 +1232,12 @@ Monomer::getMass(Enums::MassType mass_type) const
   else if(mass_type == Enums::MassType::AVG)
     return m_avg;
 
-  qFatalStream()
-    << "Mass cannot be anything else than Enums::MassType::MONO or Enums::MassType::AVG.";
+  qFatalStream() << "Mass cannot be anything else than Enums::MassType::MONO "
+                    "or Enums::MassType::AVG.";
 
   return -1;
 }
 
-
 //////////////// FORMULA OPERATIONS /////////////////////
 
 /*
@@ -1390,7 +1374,7 @@ Monomer::renderXmlMnmElement(const QDomElement &element,
 
   if(element.tagName() != "mnm")
     {
-      qCritical() << "The expected <mnm> element is not found.";
+      qDebug() << "The expected <mnm> element is not found.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1401,8 +1385,8 @@ Monomer::renderXmlMnmElement(const QDomElement &element,
 
   if(child.isNull() || child.text().isEmpty())
     {
-      qCritical() << "The Monomer did not render correctly: problem with the "
-                     "<name> element.";
+      qDebug() << "The Monomer did not render correctly: problem with the "
+                  "<name> element.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1413,8 +1397,8 @@ Monomer::renderXmlMnmElement(const QDomElement &element,
 
   if(child.isNull())
     {
-      qCritical() << "The Monomer did not render correctly: problem with the "
-                     "<code> element.";
+      qDebug() << "The Monomer did not render correctly: problem with the "
+                  "<code> element.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1423,8 +1407,8 @@ Monomer::renderXmlMnmElement(const QDomElement &element,
 
   if(!checkCodeSyntax())
     {
-      qCritical() << "The Monomer did not render correctly: problem with the "
-                     "code text.";
+      qDebug() << "The Monomer did not render correctly: problem with the "
+                  "code text.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1433,8 +1417,8 @@ Monomer::renderXmlMnmElement(const QDomElement &element,
 
   if(child.isNull())
     {
-      qCritical() << "The Monomer did not render correctly: problem with the "
-                     "<formula> element.";
+      qDebug() << "The Monomer did not render correctly: problem with the "
+                  "<formula> element.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1443,9 +1427,8 @@ Monomer::renderXmlMnmElement(const QDomElement &element,
 
   if(!temp_formula.renderXmlFormulaElement(child))
     {
-      qCritical()
-        << "The Monomer did not render correctly: the formula did not "
-           "render correctly.";
+      qDebug() << "The Monomer did not render correctly: the formula did not "
+                  "render correctly.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1456,8 +1439,8 @@ Monomer::renderXmlMnmElement(const QDomElement &element,
   m_isValid = validate(&error_list);
   if(!m_isValid)
     {
-      qCritical() << "The Monomer did not validate successfully after "
-                     "rendering, with errors:";
+      qDebug() << "The Monomer did not validate successfully after "
+                  "rendering, with errors:";
       Utils::joinErrorList(error_list, ", ");
     }
   else
@@ -1469,16 +1452,15 @@ Monomer::renderXmlMnmElement(const QDomElement &element,
 
       if(!calculateMasses(nullptr))
         {
-          qCritical() << "The Monomer's masses could not be calculated.";
+          qDebug() << "The Monomer's masses could not be calculated.";
         }
     }
 
-  qDebug() << "Correctly rendered Monomer" << m_name << ":" << toString();
+  // qDebug() << "Correctly rendered Monomer" << m_name << ":" << toString();
 
   return m_isValid;
 }
 
-
 /*!
 \brief Formats this monomer's data as a string suitable to be used as an XML
 element in the polymer chemistry definition.
@@ -1556,7 +1538,6 @@ Monomer::formatXmlMnmElement(int offset, const QString &indent) const
   return text;
 }
 
-
 /*!
 \brief Parses into this monomer the XML monomer \a element passed as argument.
 
@@ -1621,7 +1602,7 @@ Monomer::renderXmlMonomerElement(const QDomElement &element,
 
   if(element.tagName() != "monomer")
     {
-      qCritical() << "The expected <monomer> element is not found.";
+      qDebug() << "The expected <monomer> element is not found.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1634,8 +1615,8 @@ Monomer::renderXmlMonomerElement(const QDomElement &element,
 
   if(child.isNull() || child.text().isEmpty())
     {
-      qCritical() << "The Monomer did not render correctly: problem with the "
-                     "<code> element.";
+      qDebug() << "The Monomer did not render correctly: problem with the "
+                  "<code> element.";
       m_isValid = false;
       return m_isValid;
     }
@@ -1651,8 +1632,8 @@ Monomer::renderXmlMonomerElement(const QDomElement &element,
 
   if(monomer_csp == nullptr)
     {
-      qCritical() << "The monomer's code is not found in the polymer chemistry "
-                     "definition.";
+      qDebug() << "The monomer's code is not found in the polymer chemistry "
+                  "definition.";
 
       m_isValid = false;
       return m_isValid;
@@ -1673,9 +1654,8 @@ Monomer::renderXmlMonomerElement(const QDomElement &element,
     {
       if(child.tagName() != "mdf")
         {
-          qCritical()
-            << "The Monomer did not render correctly: problem with the "
-               "<mdf> element.";
+          qDebug() << "The Monomer did not render correctly: problem with the "
+                      "<mdf> element.";
 
           m_isValid = false;
           return m_isValid;
@@ -1688,8 +1668,8 @@ Monomer::renderXmlMonomerElement(const QDomElement &element,
 
       if(!modif.calculateMasses(mcsp_polChemDef->getIsotopicDataCstSPtr()))
         {
-          qCritical() << "Failed to calculate masses for Monomer's Modif"
-                      << modif.getName();
+          qDebug() << "Failed to calculate masses for Monomer's Modif"
+                   << modif.getName();
 
           m_isValid = false;
           return m_isValid;
@@ -1701,9 +1681,8 @@ Monomer::renderXmlMonomerElement(const QDomElement &element,
       ErrorList error_list;
       if(!modif.validate(&error_list))
         {
-          qCritical() << "Failed to validate modification" << modif.getName()
-                      << "with errors:"
-                      << Utils::joinErrorList(error_list, ", ");
+          qDebug() << "Failed to validate modification" << modif.getName()
+                   << "with errors:" << Utils::joinErrorList(error_list, ", ");
 
           m_isValid = false;
           return m_isValid;
@@ -1718,8 +1697,8 @@ Monomer::renderXmlMonomerElement(const QDomElement &element,
 
       if(uuid.isEmpty())
         {
-          qCritical() << "The monomer could not be modified, with errors:"
-                      << Utils::joinErrorList(error_list, ", ");
+          qDebug() << "The monomer could not be modified, with errors:"
+                   << Utils::joinErrorList(error_list, ", ");
 
           m_isValid = false;
           return m_isValid;
@@ -1732,7 +1711,6 @@ Monomer::renderXmlMonomerElement(const QDomElement &element,
   return m_isValid;
 }
 
-
 /*!
 \brief Formats a string suitable to be used as an XML element in a
 polymer sequence file.
@@ -1824,7 +1802,6 @@ Monomer::formatXmlMonomerElement(int offset, const QString &indent) const
   return text;
 }
 
-
 //////////////// UTILS /////////////////////
 
 /*!
@@ -1845,7 +1822,8 @@ Monomer::storeModif(const ModifSPtr &modif_sp)
 
   // Do not store an item twice.
   if(hasModif(modif_sp) || !getUuidForModif(modif_sp).isEmpty())
-    qFatalStream() << "It is prohibited to store the same ModifSPtr more than once.";
+    qFatalStream()
+      << "It is prohibited to store the same ModifSPtr more than once.";
 
   qDebug() << "Ok, we can go on.";
 
@@ -1882,7 +1860,6 @@ Monomer::storeModif(const Modif &modif)
   return storeModif(modif_sp);
 }
 
-
 /*!
 \brief Returns true if \a modif_sp was found in the member container of Modif
 instances, false otherwise.
@@ -1910,7 +1887,8 @@ Monomer::hasModif(const ModifSPtr &modif_sp) const
                      });
 
       if(the_pair_iterator_cst != m_uuidModifPairs.cend())
-        qFatalStream() << "Inconsistency between m_modifs and m_uuidModifPairs.";
+        qFatalStream()
+          << "Inconsistency between m_modifs and m_uuidModifPairs.";
 
       return false;
     }
@@ -2005,7 +1983,7 @@ Monomer::getUuidForModif(const ModifSPtr &modif_sp) const
       // Sanity check
       if(hasModif(modif_sp))
         qFatalStream() << "Inconsistency between the m_modifs and the "
-                    "m_uuidModifPairs vectors.";
+                          "m_uuidModifPairs vectors.";
 
       return QString();
     }
@@ -2018,7 +1996,6 @@ Monomer::getUuidForModif(const ModifSPtr &modif_sp) const
   return (*the_iterator_cst).first;
 }
 
-
 /*!
 \brief Returns a container of QString instances that correspond to the UUID
 strings that identify all the Modif instances involved in this Monomer.
@@ -2035,7 +2012,8 @@ Monomer::getAllModifUuids() const
 
   // Sanity check
   if(the_uuid_strings.size() != m_modifs.size())
-    qFatalStream() << "Inconsistency between the <object>_s and <uuid-object> pairs.";
+    qFatalStream()
+      << "Inconsistency between the <object>_s and <uuid-object> pairs.";
 
   return the_uuid_strings;
 }
@@ -2064,7 +2042,6 @@ Monomer::cleanupModifs()
   qDebug() << "At end, count of UUID-Modif pairs:" << m_uuidModifPairs.size();
 }
 
-
 bool
 Monomer::removeModif(ModifSPtr modif_sp)
 {
@@ -2085,10 +2062,11 @@ Monomer::removeModif(ModifSPtr modif_sp)
 
   if(the_iterator_cst == m_modifs.end())
     {
-      qCritical() << "The ModifSPtr was not found in the container.";
+      qDebug() << "The ModifSPtr was not found in the container.";
 
       if(!uuid.isEmpty())
-        qFatalStream() << "Inconsistency between m_modifs and m_uuidModifPairs.";
+        qFatalStream()
+          << "Inconsistency between m_modifs and m_uuidModifPairs.";
 
       return false;
     }
