@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -132,8 +132,10 @@ this value would be \e 1.
  \list
  \li \a file_path: the path to the file containing the Monomer dictionary.
  \li \a input_chain_string_list: the list of sequences to be converted.
- \li \a input_code_length: the count of letters in the Monomer codes in the input string.
- \li \a output_code_length: the count of letters in the Monomer codes in the output string.
+ \li \a input_code_length: the count of letters in the Monomer codes in the
+ input string.
+ \li \a output_code_length: the count of letters in the Monomer codes in the
+ output string.
  \endlist
  */
 MonomerDictionary::MonomerDictionary(QString file_path,
@@ -192,7 +194,8 @@ MonomerDictionary::setOutputCodeLength(int code_length)
 }
 
 /*!
-\brief Return true if the \a line parsed is in the form X>Y, that is, that it specifies the kind of Monomer code translation.
+\brief Return true if the \a line parsed is in the form X>Y, that is, that it
+specifies the kind of Monomer code translation.
 */
 bool
 MonomerDictionary::isLineProperSectionDivider(const QString &line)
@@ -301,7 +304,8 @@ MonomerDictionary::skipSection(QTextStream *stream)
 }
 
 /*!
-\brief Parses the Monomer dictionary file section in \a stream and fills in the \l m_dictionaryHash with the translation pair.
+\brief Parses the Monomer dictionary file section in \a stream and fills in the
+\l m_dictionaryHash with the translation pair.
 */
 int
 MonomerDictionary::parseSection(QTextStream *stream)
@@ -373,7 +377,8 @@ MonomerDictionary::parseSection(QTextStream *stream)
 }
 
 /*!
-\brief Returns true if the Monomer dictionary file could be loaded successfully, false otherwise.
+\brief Returns true if the Monomer dictionary file could be loaded successfully,
+false otherwise.
 */
 bool
 MonomerDictionary::loadDictionary()
@@ -469,7 +474,8 @@ MonomerDictionary::loadDictionary()
 }
 
 /*!
-\brief Perform the actual translation from the input Monomer code form to the output Monomer code form on all the strings contained in \a chain_string_list.
+\brief Perform the actual translation from the input Monomer code form to the
+output Monomer code form on all the strings contained in \a chain_string_list.
 */
 QStringList *
 MonomerDictionary::translate(const QStringList &chain_string_list)
