@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -419,7 +419,7 @@ Oligomer::molecularMasses(double &mono, double &avg) const
 
   if(ionization_outcome == Enums::IonizationOutcome::FAILED)
     {
-      qCritical() << "Failed to deionize the analyte.";
+      qDebug() << "Failed to deionize the analyte.";
       return ionization_outcome;
     }
 
@@ -793,7 +793,7 @@ Oligomer::getLeftEndMonomerCstSPtr() const
 {
   if(mcsp_polymer == nullptr)
     {
-      qCritical() << "The polymer is not available.";
+      qDebug() << "The polymer is not available.";
       return nullptr;
     }
 
@@ -825,7 +825,7 @@ Oligomer::getRightEndMonomerCstSPtr() const
 {
   if(mcsp_polymer == nullptr)
     {
-      qCritical() << "The polymer is not available.";
+      qDebug() << "The polymer is not available.";
       return nullptr;
     }
 
@@ -856,7 +856,7 @@ Oligomer::getMonomerCstSPtrAt(std::size_t index) const
 {
   if(mcsp_polymer == nullptr)
     {
-      qCritical() << "The polymer is not available.";
+      qDebug() << "The polymer is not available.";
       return nullptr;
     }
 
@@ -865,8 +865,8 @@ Oligomer::getMonomerCstSPtrAt(std::size_t index) const
 
   if(!m_calcOptions.getIndexRangeCollectionCstRef().encompassIndex(index))
     {
-      qCritical() << "Asking for Monomer at index not encompassed by member "
-                     "IndexRangeCollection.";
+      qDebug() << "Asking for Monomer at index not encompassed by member "
+                  "IndexRangeCollection.";
     }
 
   if(index >= mcsp_polymer->getSequenceCstRef().size())
@@ -921,9 +921,9 @@ Oligomer::elementalComposition(const CalcOptions &calc_options,
     << "that has internal formula:" << m_formula.getActionFormula();
 
   if(calc_options.getSelectionType() == Enums::SelectionType::RESIDUAL_CHAINS)
-    qInfo() << "Enums::SelectionType::RESIDUAL_CHAINS";
+    qDebug() << "Enums::SelectionType::RESIDUAL_CHAINS";
   else
-    qInfo() << "Enums::SelectionType::OLIGOMERS";
+    qDebug() << "Enums::SelectionType::OLIGOMERS";
 
   qDebug() << "Going to call Polymer::elementalComposition() with CalcOptions:"
            << calc_options.toString() << "and ionizer:" << ionizer.toString();
@@ -1044,7 +1044,7 @@ Oligomer::calculateMasses(const CalcOptions &calc_options,
   if(!Polymer::accountMasses(
        mcsp_polymer.get(), local_calc_options, m_mono, m_avg))
     {
-      qCritical() << "Failed accounting masses of Polymer.";
+      qDebug() << "Failed accounting masses of Polymer.";
       return false;
     }
 
@@ -1099,7 +1099,7 @@ Oligomer::calculateMasses(const CalcOptions &calc_options,
     {
       if(ionizer.ionize(m_mono, m_avg) == Enums::IonizationOutcome::FAILED)
         {
-          qCritical() << "Failed to ionize the Oligomer.";
+          qDebug() << "Failed to ionize the Oligomer.";
           return false;
         }
     }
@@ -1138,7 +1138,7 @@ Oligomer::encompasses(std::size_t index) const
 {
   if(mcsp_polymer == nullptr)
     {
-      qCritical() << "The polymer is not available.";
+      qDebug() << "The polymer is not available.";
       return false;
     }
 
