@@ -2,7 +2,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009, ..., 2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -37,7 +37,6 @@
 /////////////////////// Local includes
 #include "MsXpS/libXpertMassCore/OligomerCollection.hpp"
 
-
 namespace MsXpS
 {
 namespace libXpertMassCore
@@ -119,7 +118,6 @@ OligomerCollection::OligomerCollection(const QString &name,
 {
 }
 
-
 /*!
 \brief Constructs an OligomerCollection instance as a copy of \a other.
 
@@ -137,7 +135,6 @@ OligomerCollection::OligomerCollection(const OligomerCollection &other)
     m_oligomers.emplace_back(std::make_shared<Oligomer>(*oligomer_sp.get()));
 }
 
-
 /*!
 \brief Destructs the OligomerCollection.
 */
@@ -155,7 +152,6 @@ OligomerCollection::setPolymer(PolymerCstQSPtr polymer_cqsp)
   mcsp_polymer = polymer_cqsp;
 }
 
-
 /*!
 \brief Returns the polymer.
 */
@@ -165,7 +161,6 @@ OligomerCollection::getPolymer() const
   return mcsp_polymer;
 }
 
-
 /*!
 \brief Sets the \a name.
 */
@@ -176,7 +171,6 @@ OligomerCollection::setName(const QString &name)
     m_name = name;
 }
 
-
 /*!
 \brief Returns the name.
 */
@@ -186,7 +180,6 @@ OligomerCollection::getName() const
   return m_name;
 }
 
-
 /*!
 \brief Sets the \a comment.
 */
@@ -197,7 +190,6 @@ OligomerCollection::setComment(const QString &comment)
     m_comment = comment;
 }
 
-
 /*!
 \brief Returns the comment.
 */
@@ -225,7 +217,6 @@ OligomerCollection::getOligomersRef()
   return m_oligomers;
 }
 
-
 /*!
 \brief Sets the type of mass \a mass_type to be dealt with by default.
 */
@@ -234,10 +225,10 @@ OligomerCollection::setMassType(Enums::MassType mass_type)
 {
   m_massType = mass_type;
   if(m_massType == Enums::MassType::BOTH)
-    qFatalStream() << "Programming error. The mass type cannot be Enums::MassType::BOTH.";
+    qFatalStream()
+      << "Programming error. The mass type cannot be Enums::MassType::BOTH.";
 }
 
-
 /*!
 \brief Returns the type of mass to be dealt with by default.
 */
@@ -293,7 +284,6 @@ OligomerCollection::findOligomerEncompassing(std::size_t monomer_index,
   return nullptr;
 }
 
-
 /*!
 \brief Returns the Oligomer instance that encompasses Monomer \a
 monomer_csp.
@@ -439,10 +429,10 @@ OligomerCollection::monoMassCompare(const OligomerSPtr o1_sp,
   // the element passed as first argument is considered to go before the second
   // in the specific strict weak ordering it defines.
 
-  return o1_sp->getMass(Enums::MassType::MONO) < o2_sp->getMass(Enums::MassType::MONO);
+  return o1_sp->getMass(Enums::MassType::MONO) <
+         o2_sp->getMass(Enums::MassType::MONO);
 }
 
-
 /*!
 \brief Returns true if the average mass of \a o1_sp is smaller than that of \a
 o2_sp, else returns false.
@@ -453,10 +443,10 @@ OligomerCollection::avgMassCompare(const OligomerSPtr o1_sp,
 {
   qDebug() << "o1_sp is:" << o1_sp.get() << "o2_sp is:" << o2_sp.get();
 
-  return o1_sp->getMass(Enums::MassType::AVG) < o2_sp->getMass(Enums::MassType::AVG);
+  return o1_sp->getMass(Enums::MassType::AVG) <
+         o2_sp->getMass(Enums::MassType::AVG);
 }
 
-
 /*!
 \brief Sorts the Oligomer instances in the member container according to
 ascending masses of the default member Enums::MassType.
@@ -497,7 +487,8 @@ OligomerCollection::size() const
 }
 
 /*!
-\brief Returns a text string representing this OligomerCollection's Oligomer instances.
+\brief Returns a text string representing this OligomerCollection's Oligomer
+instances.
 
 \sa Oligomer::toString
 */
@@ -541,7 +532,8 @@ OligomerCollection::operator=(const OligomerCollection &other)
 }
 
 /*!
-\brief Returns true if this OligomerCollection instance and \a other are identical, false otherwise.
+\brief Returns true if this OligomerCollection instance and \a other are
+identical, false otherwise.
 */
 bool
 OligomerCollection::operator==(const OligomerCollection &other) const
@@ -557,7 +549,8 @@ OligomerCollection::operator==(const OligomerCollection &other) const
 }
 
 /*!
- \brief Returns true if this OligomerCollection instance and \a other differ, false otherwise.
+ \brief Returns true if this OligomerCollection instance and \a other differ,
+ false otherwise.
 
  Returns the negated value returned from \l{operator==()}.
  */
