@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -1010,7 +1010,7 @@ PolChemDef::isChemicallyEquivalent(const PolChemDef &other) const
       ++other_modif_iterator_cst;
     }
 
-  qDebug() << "The Modif instances are identical.";
+  // qDebug() << "The Modif instances are identical.";
 
   if(m_monomers.size() != other.m_monomers.size())
     {
@@ -1039,7 +1039,7 @@ PolChemDef::isChemicallyEquivalent(const PolChemDef &other) const
       ++other_monomer_iterator_cst;
     }
 
-  qDebug() << "The Monomer instances are identical.";
+  // qDebug() << "The Monomer instances are identical.";
 
   if(m_crossLinkers.size() != other.m_crossLinkers.size())
     {
@@ -1073,7 +1073,7 @@ PolChemDef::isChemicallyEquivalent(const PolChemDef &other) const
       ++other_cross_linker_iterator_cst;
     }
 
-  qDebug() << "The CrossLinker instances are identical.";
+  // qDebug() << "The CrossLinker instances are identical.";
 
   if(m_cleavageAgents.size() != other.m_cleavageAgents.size())
     {
@@ -1110,7 +1110,7 @@ PolChemDef::isChemicallyEquivalent(const PolChemDef &other) const
       ++other_cleavage_agent_iterator_cst;
     }
 
-  qDebug() << "The CleavageAgent instances are identical.";
+  // qDebug() << "The CleavageAgent instances are identical.";
 
   if(m_fragmentationPathways.size() != other.m_fragmentationPathways.size())
     {
@@ -1145,7 +1145,7 @@ PolChemDef::isChemicallyEquivalent(const PolChemDef &other) const
       ++other_fragmentation_pathway_iterator_cst;
     }
 
-  qDebug() << "The FragmentationPathway instances are identical.";
+  // qDebug() << "The FragmentationPathway instances are identical.";
 
   return true;
 }
@@ -1276,7 +1276,8 @@ PolChemDef::loadIsotopicData(PolChemDefSPtr pol_chem_def_sp,
 
   if(local_file_path.isEmpty() || !local_file_info.exists())
     {
-      qDebug() << "Loading the isotopic data from the library.";
+      // qDebug() << "Loading the isotopic data from the library.";
+
       IsotopicDataLibraryHandler isotopic_data_handler(
         pol_chem_def_sp->msp_isotopicData);
 
@@ -1285,7 +1286,7 @@ PolChemDef::loadIsotopicData(PolChemDefSPtr pol_chem_def_sp,
     }
   else
     {
-      qDebug() << "Loading the isotopic data from file:" << local_file_path;
+      // qDebug() << "Loading the isotopic data from file:" << local_file_path;
 
       IsotopicDataUserConfigHandler isotopic_data_handler(
         pol_chem_def_sp->msp_isotopicData);
@@ -1594,8 +1595,8 @@ PolChemDef::renderXmlPolChemDefFileVersion1(PolChemDefSPtr pol_chem_def_sp)
   ErrorList error_list;
   if(!pol_chem_def_sp->m_ionizer.validate(&error_list))
     {
-      qCritical() << "The Ionizer is invalid,  with errors:"
-                  << Utils::joinErrorList(error_list, ", ");
+      qDebug() << "The Ionizer is invalid,  with errors:"
+               << Utils::joinErrorList(error_list, ", ");
       return false;
     }
 
@@ -1613,7 +1614,7 @@ PolChemDef::renderXmlPolChemDefFileVersion1(PolChemDefSPtr pol_chem_def_sp)
 
       if(indentedChild.tagName() != "mnm")
         {
-          qCritical() << "The expected <mnm> element was not found.";
+          qDebug() << "The expected <mnm> element was not found.";
           return false;
         }
 
@@ -1661,7 +1662,7 @@ PolChemDef::renderXmlPolChemDefFileVersion1(PolChemDefSPtr pol_chem_def_sp)
 
       if(!modif_sp->isValid())
         {
-          qCritical()
+          qDebug()
             << "Failed to render the Modif instance from an XML <mdf> element.";
           modif_sp.reset();
           return false;
@@ -1695,8 +1696,8 @@ PolChemDef::renderXmlPolChemDefFileVersion1(PolChemDefSPtr pol_chem_def_sp)
 
       if(!crossLinker_sp->isValid())
         {
-          qCritical() << "Failed to render the CrossLinker instance from an "
-                         "XML <clk> element.";
+          qDebug() << "Failed to render the CrossLinker instance from an "
+                      "XML <clk> element.";
           crossLinker_sp.reset();
           return false;
         }
@@ -1722,8 +1723,8 @@ PolChemDef::renderXmlPolChemDefFileVersion1(PolChemDefSPtr pol_chem_def_sp)
   child = child.nextSiblingElement();
   if(child.tagName() != "cleavespecs")
     {
-      qCritical() << "Failed to load PolChemDef file: <cleavespecs> element "
-                     "not found.";
+      qDebug() << "Failed to load PolChemDef file: <cleavespecs> element "
+                  "not found.";
       return false;
     }
 
@@ -1732,7 +1733,7 @@ PolChemDef::renderXmlPolChemDefFileVersion1(PolChemDefSPtr pol_chem_def_sp)
     {
       if(indentedChild.tagName() != "cls")
         {
-          qCritical()
+          qDebug()
             << "Failed to load PolChemDef file: <cls> element not found.";
           return false;
         }
@@ -1742,14 +1743,14 @@ PolChemDef::renderXmlPolChemDefFileVersion1(PolChemDefSPtr pol_chem_def_sp)
 
       if(!cleavage_agent_sp->isValid())
         {
-          qCritical() << "Failed to render the CleaveSpec instance from an "
-                         "XML <cls> element.";
+          qDebug() << "Failed to render the CleaveSpec instance from an "
+                      "XML <cls> element.";
           cleavage_agent_sp.reset();
           return false;
         }
 
-      qDebug() << "Rendered CleavageAgent: " << cleavage_agent_sp->getName()
-               << "with pattern:" << cleavage_agent_sp->getPattern();
+      // qDebug() << "Rendered CleavageAgent: " << cleavage_agent_sp->getName()
+      //          << "with pattern:" << cleavage_agent_sp->getPattern();
 
       pol_chem_def_sp->m_cleavageAgents.push_back(cleavage_agent_sp);
 
@@ -1757,17 +1758,17 @@ PolChemDef::renderXmlPolChemDefFileVersion1(PolChemDefSPtr pol_chem_def_sp)
       indentedChild = indentedChild.nextSiblingElement();
     }
 
-  qDebug() << "Size of CleavageAgent container:"
-           << pol_chem_def_sp->getCleavageAgentsCstRef().size()
-           << "pol chem def usage:" << pol_chem_def_sp.use_count();
+  // qDebug() << "Size of CleavageAgent container:"
+  //          << pol_chem_def_sp->getCleavageAgentsCstRef().size()
+  //          << "pol chem def usage:" << pol_chem_def_sp.use_count();
 
-  qDebug() << "Now starting the rendering of the <fragspecs> element.";
+  // qDebug() << "Now starting the rendering of the <fragspecs> element.";
 
   // <fragspecs>
   child = child.nextSiblingElement();
   if(child.tagName() != "fragspecs")
     {
-      qCritical()
+      qDebug()
         << "Failed to load PolChemDef file: <fragspecs> element not found.";
       return false;
     }
@@ -1777,7 +1778,7 @@ PolChemDef::renderXmlPolChemDefFileVersion1(PolChemDefSPtr pol_chem_def_sp)
     {
       if(indentedChild.tagName() != "fgs")
         {
-          qCritical()
+          qDebug()
             << "Failed to load PolChemDef file: <fgs> element not found.";
           return false;
         }
@@ -1788,8 +1789,8 @@ PolChemDef::renderXmlPolChemDefFileVersion1(PolChemDefSPtr pol_chem_def_sp)
 
       if(!fragmentation_pathway_sp->isValid())
         {
-          qCritical() << "Failed to render the FragSpec instance from an "
-                         "XML <fgs> element.";
+          qDebug() << "Failed to render the FragSpec instance from an "
+                      "XML <fgs> element.";
           fragmentation_pathway_sp.reset();
           return false;
         }
@@ -1803,12 +1804,13 @@ PolChemDef::renderXmlPolChemDefFileVersion1(PolChemDefSPtr pol_chem_def_sp)
       indentedChild = indentedChild.nextSiblingElement();
     }
 
-  qDebug() << "Size of FragmentationPathway container:"
-           << pol_chem_def_sp->getFragmentationPathwaysCstRef().size()
-           << "pol chem def usage:" << pol_chem_def_sp.use_count();
+  // qDebug() << "Size of FragmentationPathway container:"
+  //          << pol_chem_def_sp->getFragmentationPathwaysCstRef().size()
+  //          << "pol chem def usage:" << pol_chem_def_sp.use_count();
 
-  qDebug() << "Done rendering the PolChemDef file. Setting m_isValid to true "
-              "and returning it.";
+  // qDebug() << "Done rendering the PolChemDef file. Setting m_isValid to true
+  // "
+  //             "and returning it.";
 
   pol_chem_def_sp->m_isValid = true;
 
@@ -1831,7 +1833,7 @@ Returns true if the parsing was successful and false otherwise.
 bool
 PolChemDef::renderXmlPolChemDefFileVersion2(PolChemDefSPtr pol_chem_def_sp)
 {
-  qDebug() << "Rendering PolChemDef file VERSION 2.";
+  // qDebug() << "Rendering PolChemDef file VERSION 2.";
 
   if(pol_chem_def_sp == nullptr && pol_chem_def_sp.get() == nullptr)
     qFatalStream()
@@ -1960,7 +1962,7 @@ PolChemDef::renderXmlPolChemDefFileVersion2(PolChemDefSPtr pol_chem_def_sp)
   else
     text = element.attribute("version");
 
-  qDebug() << "The format of the definition:" << text;
+  // qDebug() << "The format of the definition:" << text;
 
   bool ok = false;
 
@@ -1968,9 +1970,9 @@ PolChemDef::renderXmlPolChemDefFileVersion2(PolChemDefSPtr pol_chem_def_sp)
 
   if(version != 2 || !ok)
     {
-      qDebug() << "Polymer chemistry definition file has bad "
-                  "version number:"
-               << version;
+      // qDebug() << "Polymer chemistry definition file has bad "
+      //             "version number:"
+      //          << version;
 
       return false;
     }
@@ -2011,7 +2013,7 @@ PolChemDef::renderXmlPolChemDefFileVersion2(PolChemDefSPtr pol_chem_def_sp)
   pol_chem_def_sp->m_codeLength = child.text().toInt(&ok);
   if(pol_chem_def_sp->m_codeLength == 0 && !ok)
     return false;
-  qDebug() << "Set the code length to" << pol_chem_def_sp->m_codeLength;
+  // qDebug() << "Set the code length to" << pol_chem_def_sp->m_codeLength;
 
   // <ionizerule>
   child = child.nextSiblingElement();
@@ -2031,12 +2033,12 @@ PolChemDef::renderXmlPolChemDefFileVersion2(PolChemDefSPtr pol_chem_def_sp)
   ErrorList error_list;
   if(!pol_chem_def_sp->m_ionizer.validate(&error_list))
     {
-      qCritical() << "The Ionizer is invalid,  with errors:"
-                  << Utils::joinErrorList(error_list, ", ");
+      qDebug() << "The Ionizer is invalid,  with errors:"
+               << Utils::joinErrorList(error_list, ", ");
       return false;
     }
 
-  qDebug() << "Now starting the rendering of the <monomers> element.";
+  // qDebug() << "Now starting the rendering of the <monomers> element.";
 
   // <monomers>
   child = child.nextSiblingElement();
@@ -2046,11 +2048,11 @@ PolChemDef::renderXmlPolChemDefFileVersion2(PolChemDefSPtr pol_chem_def_sp)
   indentedChild = child.firstChildElement();
   while(!indentedChild.isNull())
     {
-      qDebug() << "Now rendering one of all the mnm elements.";
+      // qDebug() << "Now rendering one of all the mnm elements.";
 
       if(indentedChild.tagName() != "mnm")
         {
-          qCritical() << "The expected <mnm> element was not found.";
+          qDebug() << "The expected <mnm> element was not found.";
           return false;
         }
 
@@ -2076,11 +2078,11 @@ PolChemDef::renderXmlPolChemDefFileVersion2(PolChemDefSPtr pol_chem_def_sp)
       indentedChild = indentedChild.nextSiblingElement();
     }
 
-  qDebug() << "Size of MonomerList:"
-           << pol_chem_def_sp->getMonomersCstRef().size()
-           << "pol chem def usage:" << pol_chem_def_sp.use_count();
+  // qDebug() << "Size of MonomerList:"
+  //          << pol_chem_def_sp->getMonomersCstRef().size()
+  //          << "pol chem def usage:" << pol_chem_def_sp.use_count();
 
-  qDebug() << "Now starting the rendering of the <modifs> element.";
+  // qDebug() << "Now starting the rendering of the <modifs> element.";
 
   // <modifs>
   child = child.nextSiblingElement();
@@ -2098,7 +2100,7 @@ PolChemDef::renderXmlPolChemDefFileVersion2(PolChemDefSPtr pol_chem_def_sp)
 
       if(!modif_sp->isValid())
         {
-          qCritical()
+          qDebug()
             << "Failed to render the Modif instance from an XML <mdf> element.";
           modif_sp.reset();
           return false;
@@ -2109,10 +2111,11 @@ PolChemDef::renderXmlPolChemDefFileVersion2(PolChemDefSPtr pol_chem_def_sp)
       indentedChild = indentedChild.nextSiblingElement();
     }
 
-  qDebug() << "Size of ModifList:" << pol_chem_def_sp->getModifsCstRef().size()
-           << "pol chem def usage:" << pol_chem_def_sp.use_count();
+  // qDebug() << "Size of ModifList:" <<
+  // pol_chem_def_sp->getModifsCstRef().size()
+  //          << "pol chem def usage:" << pol_chem_def_sp.use_count();
 
-  qDebug() << "Now starting the rendering of the <crosslinkers> element.";
+  // qDebug() << "Now starting the rendering of the <crosslinkers> element.";
 
   // <crosslinkers>
   // Note that crosslinkers have appeared since version 3.
@@ -2132,8 +2135,8 @@ PolChemDef::renderXmlPolChemDefFileVersion2(PolChemDefSPtr pol_chem_def_sp)
 
       if(!crossLinker_sp->isValid())
         {
-          qCritical() << "Failed to render the CrossLinker instance from an "
-                         "XML <clk> element.";
+          qDebug() << "Failed to render the CrossLinker instance from an "
+                      "XML <clk> element.";
           crossLinker_sp.reset();
           return false;
         }
@@ -2149,18 +2152,18 @@ PolChemDef::renderXmlPolChemDefFileVersion2(PolChemDefSPtr pol_chem_def_sp)
       indentedChild = indentedChild.nextSiblingElement();
     }
 
-  qDebug() << "Size of CrossLinker container:"
-           << pol_chem_def_sp->getCrossLinkersCstRef().size()
-           << "pol chem def usage:" << pol_chem_def_sp.use_count();
+  // qDebug() << "Size of CrossLinker container:"
+  //          << pol_chem_def_sp->getCrossLinkersCstRef().size()
+  //          << "pol chem def usage:" << pol_chem_def_sp.use_count();
 
-  qDebug() << "Now starting the rendering of the <cleavageagents> element.";
+  // qDebug() << "Now starting the rendering of the <cleavageagents> element.";
 
   // <cleavageagents>
   child = child.nextSiblingElement();
   if(child.tagName() != "cleavageagents")
     {
-      qCritical() << "Failed to load PolChemDef file: <cleavageagents> element "
-                     "not found.";
+      qDebug() << "Failed to load PolChemDef file: <cleavageagents> element "
+                  "not found.";
       return false;
     }
 
@@ -2169,20 +2172,21 @@ PolChemDef::renderXmlPolChemDefFileVersion2(PolChemDefSPtr pol_chem_def_sp)
     {
       if(indentedChild.tagName() != "cla")
         {
-          qCritical()
+          qDebug()
             << "Failed to load PolChemDef file: <cla> element not found.";
           return false;
         }
 
-      qDebug() << "Will allocate a new CleavageAgent instance->shared pointer.";
+      // qDebug() << "Will allocate a new CleavageAgent instance->shared
+      // pointer.";
 
       CleavageAgentSPtr cleavage_agent_sp = std::make_shared<CleavageAgent>(
         pol_chem_def_sp, indentedChild, version);
 
       if(!cleavage_agent_sp->isValid())
         {
-          qCritical() << "Failed to render the CleavageAgent instance from an "
-                         "XML <cla> element.";
+          qDebug() << "Failed to render the CleavageAgent instance from an "
+                      "XML <cla> element.";
           cleavage_agent_sp.reset();
           return false;
         }
@@ -2192,12 +2196,12 @@ PolChemDef::renderXmlPolChemDefFileVersion2(PolChemDefSPtr pol_chem_def_sp)
       indentedChild = indentedChild.nextSiblingElement();
     }
 
-  qDebug() << "Size of CleavageAgent container:"
-           << pol_chem_def_sp->getCleavageAgentsCstRef().size()
-           << "pol chem def usage:" << pol_chem_def_sp.use_count();
+  // qDebug() << "Size of CleavageAgent container:"
+  //          << pol_chem_def_sp->getCleavageAgentsCstRef().size()
+  //          << "pol chem def usage:" << pol_chem_def_sp.use_count();
 
-  qDebug()
-    << "Now starting the rendering of the <fragmentationpathways> element.";
+  // qDebug()
+  //   << "Now starting the rendering of the <fragmentationpathways> element.";
 
   // <fragmentationpathways>
   child = child.nextSiblingElement();
@@ -2209,7 +2213,7 @@ PolChemDef::renderXmlPolChemDefFileVersion2(PolChemDefSPtr pol_chem_def_sp)
     {
       if(indentedChild.tagName() != "fgp")
         {
-          qCritical()
+          qDebug()
             << "Failed to load PolChemDef file: <fgp> element not found.";
           return false;
         }
@@ -2220,7 +2224,7 @@ PolChemDef::renderXmlPolChemDefFileVersion2(PolChemDefSPtr pol_chem_def_sp)
 
       if(!fragmentation_pathway_sp->isValid())
         {
-          qCritical()
+          qDebug()
             << "Failed to render the FragmentationPathway instance from an "
                "XML <fgs> element.";
           fragmentation_pathway_sp.reset();
@@ -2233,12 +2237,13 @@ PolChemDef::renderXmlPolChemDefFileVersion2(PolChemDefSPtr pol_chem_def_sp)
       indentedChild = indentedChild.nextSiblingElement();
     }
 
-  qDebug() << "Size of FragmentationPathway container:"
-           << pol_chem_def_sp->getFragmentationPathwaysCstRef().size()
-           << "pol chem def usage:" << pol_chem_def_sp.use_count();
+  // qDebug() << "Size of FragmentationPathway container:"
+  //          << pol_chem_def_sp->getFragmentationPathwaysCstRef().size()
+  //          << "pol chem def usage:" << pol_chem_def_sp.use_count();
 
-  qDebug() << "Done rendering the PolChemDef file. Setting m_isValid to true "
-              "and returning it.";
+  // qDebug() << "Done rendering the PolChemDef file. Setting m_isValid to true
+  // "
+  //             "and returning it.";
 
   pol_chem_def_sp->m_isValid = true;
 
@@ -2388,7 +2393,7 @@ PolChemDef::renderXmlPolChemDefFile(PolChemDefSPtr pol_chem_def_sp)
   else
     text = element.attribute("version");
 
-  qDebug() << "The format of the definition:" << text;
+  // qDebug() << "The format of the definition:" << text;
 
   bool ok = false;
 
@@ -2403,10 +2408,10 @@ PolChemDef::renderXmlPolChemDefFile(PolChemDefSPtr pol_chem_def_sp)
       return false;
     }
 
-  file.close();
+  // FIXME, done already  file.close();
 
-  qDebug() << "The version of the Polymer Chemistry Definition file is:"
-           << version;
+  // qDebug() << "The version of the Polymer Chemistry Definition file is:"
+  //          << version;
 
   if(version == 1)
     return PolChemDef::renderXmlPolChemDefFileVersion1(pol_chem_def_sp);
