@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -34,7 +34,6 @@
 /////////////////////// Local includes
 #include "MsXpS/libXpertMassCore/Prop.hpp"
 
-
 namespace MsXpS
 {
 namespace libXpertMassCore
@@ -101,21 +100,19 @@ Prop::Prop()
 {
 }
 
-
 /*!
 \brief Constructs a Prop instance with \a name.
 */
-Prop::Prop(const QString &name) : m_name(name)
+Prop::Prop(const QString &name): m_name(name)
 {
 }
 
-
 /*!
 \brief Constructs a Prop instance as a copy of \a other.
 
 \note The data are not duplicated.
 */
-Prop::Prop(const Prop &other) : m_name(other.m_name)
+Prop::Prop(const Prop &other): m_name(other.m_name)
 {
   // We cannot duplicate the data because we do not know their type.
 }
@@ -139,7 +136,6 @@ Prop::setName(QString &name)
   m_name = name;
 }
 
-
 /*!
 \brief Returns the name.
  */
@@ -149,11 +145,11 @@ Prop::name()
   return m_name;
 }
 
-
 /*!
 \brief Sets the \a data.
 
-If mpa_data is non-nullptr,  deleteData() is called before assigning \a data to mpa_data.
+If mpa_data is non-nullptr,  deleteData() is called before assigning \a data to
+mpa_data.
 
 Ownership passes to this Prop instance.
 */
@@ -175,7 +171,6 @@ Prop::data() const
   return mpa_data;
 }
 
-
 /*!
 \brief Deletes the data.
 
@@ -218,7 +213,6 @@ Prop::renderXmlElement([[maybe_unused]] const QDomElement &element,
   return false;
 }
 
-
 /*!
 \brief Formats and returns a string representing this Prop instance.
 
@@ -235,7 +229,6 @@ Prop::formatXmlElement([[maybe_unused]] int offset,
   return QString();
 }
 
-
 //////////////////////// StringProp ////////////////////////
 //////////////////////// StringProp ////////////////////////
 
@@ -264,17 +257,16 @@ the same contents and then is set to the member mpa_data pointer.
 */
 StringProp::StringProp(const QString &name, const QString &data)
 {
-    m_name = name;
-    mpa_data = static_cast<void *>(new QString(data));
+  m_name   = name;
+  mpa_data = static_cast<void *>(new QString(data));
 }
 
-
 /*!
 \brief Constructs a StringProp instance as a copy of \a other.
 
 The member data, if non-, are first deleted.
 */
-StringProp::StringProp(const StringProp &other) : Prop(other)
+StringProp::StringProp(const StringProp &other): Prop(other)
 {
   if(mpa_data != nullptr)
     deleteData();
@@ -349,7 +341,6 @@ StringProp::cloneOut() const
   return new_p;
 }
 
-
 /*!
 \brief Parses the string-only property XML \a element using a \a{version}ed
 function.
@@ -403,7 +394,6 @@ StringProp::renderXmlElement(const QDomElement &element,
   return true;
 }
 
-
 /*!
 \brief Formats a string suitable to use as an XML element.
 
@@ -492,7 +482,6 @@ StringProp::formatXmlElement(int offset, const QString &indent)
   return text;
 }
 
-
 //////////////////////// IntProp ////////////////////////
 //////////////////////// IntProp ////////////////////////
 
@@ -521,16 +510,15 @@ allocated integer.
 The integer passed as \a data is used to dynamically allocate a new integer with
 the same contents and then is set to the member mpa_data pointer.
 */
-IntProp::IntProp(const QString &name, int data) : Prop(name)
+IntProp::IntProp(const QString &name, int data): Prop(name)
 {
   mpa_data = static_cast<void *>(new int(data));
 }
 
-
 /*!
 \brief Constructs a IntProp instance as a copy of \a other.
 */
-IntProp::IntProp(const IntProp &other) : Prop(other)
+IntProp::IntProp(const IntProp &other): Prop(other)
 {
   if(other.mpa_data != nullptr)
     {
@@ -539,7 +527,6 @@ IntProp::IntProp(const IntProp &other) : Prop(other)
     }
 }
 
-
 /*!
 \brief Destructs this IntProp instance.
 
@@ -590,7 +577,6 @@ IntProp::operator=(const IntProp &other)
   return *this;
 }
 
-
 /*!
 \brief Duplicates this IntProp instance and returns a pointer to it.
 */
@@ -602,7 +588,6 @@ IntProp::cloneOut() const
   return new_p;
 }
 
-
 /*!
 \brief Parses a integer property XML \a element using a \a{version}ed
 function.
@@ -647,7 +632,6 @@ IntProp::renderXmlElement(const QDomElement &element,
   return true;
 }
 
-
 /*!
 \brief Formats a string suitable to use as an XML element.
 
@@ -728,7 +712,6 @@ IntProp::formatXmlElement(int offset, const QString &indent)
   return text;
 }
 
-
 //////////////////////// DoubleProp ////////////////////////
 //////////////////////// DoubleProp ////////////////////////
 
@@ -757,16 +740,15 @@ allocated double.
 The integer passed as \a data is used to dynamically allocate a new double with
 the same contents and then is set to the member mpa_data pointer.
 */
-DoubleProp::DoubleProp(const QString &name, double data) : Prop(name)
+DoubleProp::DoubleProp(const QString &name, double data): Prop(name)
 {
   mpa_data = static_cast<void *>(new double(data));
 }
 
-
 /*!
 \brief Constructs a DoubleProp instance as a copy of \a other.
 */
-DoubleProp::DoubleProp(const DoubleProp &other) : Prop(other)
+DoubleProp::DoubleProp(const DoubleProp &other): Prop(other)
 {
   if(other.mpa_data != nullptr)
     {
@@ -775,7 +757,6 @@ DoubleProp::DoubleProp(const DoubleProp &other) : Prop(other)
     }
 }
 
-
 /*!
 \brief Destructs this DoubleProp instance.
 
@@ -786,7 +767,6 @@ DoubleProp::~DoubleProp()
   deleteData();
 }
 
-
 /*!
 \brief Deletes the member data.
 */
@@ -800,7 +780,6 @@ DoubleProp::deleteData()
     }
 }
 
-
 /*!
 \brief Assigns \a other to this DoubleProp instance.
 
@@ -828,7 +807,6 @@ DoubleProp::operator=(const DoubleProp &other)
   return *this;
 }
 
-
 /*!
 \brief Duplicates this DoubleProp instance and returns a pointer to it.
 */
@@ -840,7 +818,6 @@ DoubleProp::cloneOut() const
   return new_p;
 }
 
-
 /*!
 \brief Parses a double property XML \a element using a \a{version}ed
 function.
@@ -885,7 +862,6 @@ DoubleProp::renderXmlElement(const QDomElement &element,
   return true;
 }
 
-
 /*!
 \brief Formats a string suitable to use as an XML element.
 
@@ -966,7 +942,6 @@ DoubleProp::formatXmlElement(int offset, const QString &indent)
   return text;
 }
 
-
 /////////////////// NoDeletePointerProp ///////////////////
 /////////////////// NoDeletePointerProp ///////////////////
 
@@ -1003,7 +978,6 @@ NoDeletePointerProp::NoDeletePointerProp(const QString &name,
   mpa_data = no_delete_data_p;
 }
 
-
 /*!
 \brief Constructs a NoDeletePointerProp instance as a copy of \a other.
 */
@@ -1013,7 +987,6 @@ NoDeletePointerProp::NoDeletePointerProp(const NoDeletePointerProp &other)
   mpa_data = static_cast<void *>(other.mpa_data);
 }
 
-
 /*!
 \brief Destructs this NoDeletePointerProp instance.
 
@@ -1025,7 +998,6 @@ NoDeletePointerProp::~NoDeletePointerProp()
   deleteData();
 }
 
-
 /*!
 \brief Does not delete the member data.
 */
@@ -1035,7 +1007,6 @@ NoDeletePointerProp::deleteData()
   // We do not do anything here.
 }
 
-
 /*!
 \brief Assigns \a other to this NoDeletePointerProp instance.
 
@@ -1054,7 +1025,6 @@ NoDeletePointerProp::operator=(const NoDeletePointerProp &other)
   return *this;
 }
 
-
 /*!
 \brief Duplicates this NoDeletePointerProp instance and returns a pointer to it.
 */
