@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009, ..., 2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -126,7 +126,7 @@ Sequence::Sequence(PolChemDefCstSPtr pol_chem_def_csp,
       for(std::size_t index : failing_indices)
         indices_text += QString("%1, ").arg(index);
 
-      qCritical()
+      qDebug()
         << "There were errors making the monomers at the following indices:"
         << indices_text;
     }
@@ -154,8 +154,8 @@ Sequence::Sequence(const Sequence &other)
 
   if(!m_isValid)
     {
-      qCritical() << "The copy-constructed Sequence is not valid, with errors:"
-                  << Utils::joinErrorList(error_list, ", ");
+      qDebug() << "The copy-constructed Sequence is not valid, with errors:"
+               << Utils::joinErrorList(error_list, ", ");
     }
 }
 
@@ -231,8 +231,8 @@ Sequence::setSequence(const QString &sequence,
 
   m_isValid = validate(&error_list);
   {
-    qCritical() << "The Sequence is not valid, with errors:"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "The Sequence is not valid, with errors:"
+             << Utils::joinErrorList(error_list, ", ");
   }
 
   return result;
@@ -272,16 +272,16 @@ Sequence::appendSequence(const QString &sequence,
 
   if(result <= 0)
     {
-      qCritical() << "The sequence could not be converted into Monomer "
-                     "instances (error or empty sequence).";
+      qDebug() << "The sequence could not be converted into Monomer "
+                  "instances (error or empty sequence).";
     }
 
   ErrorList error_list;
 
   m_isValid = validate(&error_list);
   {
-    qCritical() << "The Sequence is not valid, with errors:"
-                << Utils::joinErrorList(error_list, ", ");
+    qDebug() << "The Sequence is not valid, with errors:"
+             << Utils::joinErrorList(error_list, ", ");
   }
 
   return result;
@@ -439,7 +439,7 @@ Sequence::makeMonomers(const QString &sequence_text,
   if(mcsp_polChemDef == nullptr || mcsp_polChemDef.get() == nullptr ||
      !mcsp_polChemDef->isValid())
     {
-      qCritical() << "The PolChemDef pointer is nullptr or not valid!";
+      qDebug() << "The PolChemDef pointer is nullptr or not valid!";
       m_isValid = false;
       return -1;
     }
@@ -483,8 +483,8 @@ Sequence::makeMonomers(const QString &sequence_text,
 
       if(pol_chem_def_monomer_csp == nullptr)
         {
-          qWarning() << "Monomer:" << code
-                     << "was not found in the monomer reference list.";
+          qDebug() << "Monomer:" << code
+                   << "was not found in the monomer reference list.";
 
           failing_indices.push_back(index);
           ++index;
@@ -894,9 +894,9 @@ Sequence::removeMonomerAt(std::size_t index)
 
   MonomerSPtr monomer_sp = m_monomers.at(index);
 
-  qDebug() << "The Monomer being removed at index:" << index
-           << "is:" << monomer_sp->getName()
-           << "with modification status:" << monomer_sp->isModified();
+  // qDebug() << "The Monomer being removed at index:" << index
+  //          << "is:" << monomer_sp->getName()
+  //          << "with modification status:" << monomer_sp->isModified();
 
   QString uuid = getUuidForMonomer(monomer_sp);
   if(uuid.isEmpty())
@@ -953,8 +953,7 @@ Sequence::modifyMonomer(std::size_t index,
 
   if(uuid.isEmpty() || error_list.size())
     {
-      qCritical() << "Monomer modification with Modif:" << modif_name
-                  << "failed";
+      qDebug() << "Monomer modification with Modif:" << modif_name << "failed";
       return false;
     }
 
@@ -1042,13 +1041,13 @@ Sequence::findForwardMotif(const Sequence &sequence_motif,
 
   if(!m_isValid)
     {
-      qCritical() << "The Sequence is not valid.";
+      qDebug() << "The Sequence is not valid.";
       return -1;
     }
 
   if(!size())
     {
-      qCritical() << "The Sequence is empty.";
+      qDebug() << "The Sequence is empty.";
       return 0;
     }
 
@@ -1057,7 +1056,7 @@ Sequence::findForwardMotif(const Sequence &sequence_motif,
 
   if(!sequence_motif.isValid())
     {
-      qCritical() << "The sequence motif to search for is not valid.";
+      qDebug() << "The sequence motif to search for is not valid.";
       return -1;
     }
 
@@ -1280,13 +1279,13 @@ Sequence::operator==(const Sequence &other)
 
   if(mcsp_polChemDef != other.mcsp_polChemDef)
     {
-      qInfo() << "Differing PolChemDef.";
+      qDebug() << "Differing PolChemDef.";
       return false;
     }
 
   if(m_monomers.size() != other.m_monomers.size())
     {
-      qInfo() << "Differing Monomer container size.";
+      qDebug() << "Differing Monomer container size.";
       return false;
     }
 
@@ -1335,7 +1334,7 @@ Sequence::validate(ErrorList *error_list_p) const
   if(mcsp_polChemDef == nullptr || mcsp_polChemDef.get() == nullptr ||
      !mcsp_polChemDef->isValid())
     {
-      qCritical() << "The PolChemDef is not available.";
+      qDebug() << "The PolChemDef is not available.";
       error_list_p->push_back(
         "The PolChemDef is not available, cannot validate the Sequence "
         "instance.");
@@ -1346,8 +1345,7 @@ Sequence::validate(ErrorList *error_list_p) const
       if(monomer_sp->isKnownByCodeInPolChemDef() !=
          Enums::PolChemDefEntityStatus::ENTITY_KNOWN)
         {
-          qCritical()
-            << "At least one Monomer was not found in the PolChemDef.";
+          qDebug() << "At least one Monomer was not found in the PolChemDef.";
           error_list_p->push_back(
             "At least one Monomer was not found in the PolChemDef");
         }
