@@ -104,6 +104,14 @@ QRegularExpression Utils::endOfLineRegExp = QRegularExpression("^\\s+$");
 */
 QString Utils::xmlIndentationToken = QString(" ");
 
+/*!
+\variable MsXpS::libXpertMassCore::Utils::configSettingsFilePath
+
+\brief String holding the QSettings-based configuration file path as set
+by the caller (the program linking to this library).
+*/
+QString MsXpS::libXpertMassCore::Utils::configSettingsFilePath;
+
 /*!
 \brief Constructs a Utils instance setting parent to \a parent.
 */
@@ -119,8 +127,8 @@ Utils::~Utils()
 }
 
 /*!
-\brief Configures the format of all the messages that are output using qInfo(),
-qWarning(), qCritical(), qFatalStream() and qDebug() using a number of
+\brief Configures the format of all the messages that are output using qDebug(),
+qDebug(), qDebug(), qFatalStream() and qDebug() using a number of
 parameters.
 
 \list
@@ -392,7 +400,7 @@ Utils::almostEqual(double value1, double value2, int decimal_places)
   // QString value2String = QString("%1").arg(value2,
   // 0, 'f', 60);
 
-  // qWarning() << __FILE__ << __LINE__ << __FUNCTION__
+  // qDebug() << __FILE__ << __LINE__ << __FUNCTION__
   //<< "value1:" << value1String << "value2:" << value2String;
 
   // The machine epsilon has to be scaled to the magnitude of the values used
@@ -415,7 +423,7 @@ Utils::almostEqual(double value1, double value2, int decimal_places)
   // QString scale_factorString = QString("%1").arg(scale_factor,
   // 0, 'f', 60);
 
-  // qWarning() << "diff_of_values:" << diff_of_valuesString << "sum_of_values:"
+  // qDebug() << "diff_of_values:" << diff_of_valuesString << "sum_of_values:"
   // << sum_of_valuesString << "epsilon:" << epsilonString << "scale_factor:" <<
   // scale_factorString;
 
@@ -423,7 +431,7 @@ Utils::almostEqual(double value1, double value2, int decimal_places)
              // unless the result is subnormal:
              || diff_of_values < std::numeric_limits<double>::min();
 
-  // qWarning() << __FILE__ << __LINE__ << __FUNCTION__
+  // qDebug() << __FILE__ << __LINE__ << __FUNCTION__
   //<< "returning res:" << res;
 
   return res;
@@ -536,16 +544,109 @@ When a text string is too long to be displayed in a line of reasonable
 length, inserts newline characters at positions calculated to yield a
 paragraph of the given \a width.
 
+Newline characters can be forced in the output stanza if they appear as
+""{[\n]}" in the initial text.
+
+This function is typically used to stanzify tooltip text strings.
+
 \sa stanzifyParagraphs()
 */
 QString
 Utils::stanzify(const QString &text, int width)
+{
+  // qDebug() << "The text to stanzify:" << text;
+
+  QString purified = text;
+
+  // First, replace all the existing newline chars with spaces.
+  // Note that when {[\n]} is found in the text, the newline is conserved.
+
+  purified = purified.replace("\n", " ");
+  // The '\n' inside the{[]} has been replaced by ' ', so we need to put ' '
+  // in that "{[ ]}" string!
+  purified = purified.replace("{[ ]}", "\n");
+  // No more than one space, please.
+  purified = purified.replace("  ", " ");
+
+  // qDebug() << "Purified text to stanzify:" << purified;
+
+  // "Number of points that will make the peak shape. \nTypically, an optimal
+  // value is in the 150 to 200 range"
+
+  int line_iter = 0;
+
+
+  for(int iter = 0; iter < purified.size(); ++iter, ++line_iter)
+    {
+      // qDebug() << "Iterating into iter:" << iter
+      //          << "which corresponds to text:" << purified.first(iter + 1)
+      //          << "line_iter:" << line_iter;
+
+      if(purified.at(iter) == '\n')
+        {
+          // qDebug() << "Found a newline, resetting line_iter to -1 so that at
+          // "
+          //             "next iteration it will be 0.";
+          line_iter = -1;
+          continue;
+        }
+
+      if(line_iter >= width - 1)
+        {
+          // qDebug() << "Reached the max index of " << width - 1
+          //          << "need to find a space by looking back in the string.";
+
+          --iter;
+
+          // qDebug() << "Back-iterated once and char is:" << purified.at(iter);
+
+          while(purified.at(iter) != ' ' && purified.at(iter) != '\n')
+            {
+              --iter;
+              // qDebug() << "Back-iterated once and char is:"
+              //          << purified.at(iter);
+            }
+
+          // qDebug() << "At iter" << iter
+          //          << "found a space char. Replacing it with a newline.";
+
+          purified.replace(iter, 1, '\n');
+
+          // qDebug() << "Resetting line_iter to -1 so that at next iteration it
+          // "
+          //             "will be 0.";
+
+          line_iter = -1;
+        }
+    }
+
+  // qDebug() << "Returning stanzified text:" << purified;
+
+  return purified;
+}
+
+/*!
+ * \brief Returns a string containing a paragraph-based version of the very long
+ * single-line \a text.
+ *
+ * When a text string is too long to be displayed in a line of reasonable
+ * length, inserts newline characters at positions calculated to yield a
+ * paragraph of the given \a width.
+ *
+ * \sa stanzifyParagraphs()
+ */
+QString
+Utils::stanzifyOld(const QString &text, int width)
 {
   QString result = text;
 
   // First, replace all the existing newline chars with spaces.
+  // Note that when {[\n]} is found in the text, the newline is conserved.
 
   result = result.replace("\n", " ");
+  result = result.replace("{[ ]}", "\n");
+  // No more than one space, please.
+  result = result.replace("  ", " ");
 
   int iter = width;
 
@@ -558,6 +659,11 @@ Utils::stanzify(const QString &text, int width)
       // Now iterate in reverse and search for a space where to insert a
       // newline
 
+      // If we encounter a newline, keep it and continue;
+
+      if(result.at(iter) == "\n")
+        continue;
+
       int jter = iter;
 
       for(; jter >= 0; --jter)
@@ -729,26 +835,25 @@ Utils::stringAsPointer(const QString &str)
 }
 
 /*!
-\brief Returns a string holding the the file path to the configuration settings
-for application \a module_name.
+\brief Sets the configuration settings file path to \a config_settings_file_path
+
+This initialization function needs to be called by the program that links to
+this library.
+
+The static Utils::configSettingsFilePath will then be available throughout the
+library code.
 */
-QString
-Utils::craftConfigSettingsFilePath(const QString &module_name)
+void
+Utils::initializeConfigSettingsFilePath(
+  const QString &config_settings_file_path)
 {
+  // This static variable now contains the config settings file path
+  // dictated by the application that links to this library and initializes
+  // the configuration settings file path.
+  Utils::configSettingsFilePath = config_settings_file_path;
 
-  // The configuration settings file for all the settings of the program
-
-  QString file_path =
-    QStandardPaths::writableLocation(QStandardPaths::ConfigLocation);
-
-  if(file_path.isEmpty())
-    file_path = QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
-
-  file_path = file_path + QDir::separator() + module_name;
-
-  file_path = file_path + QDir::separator() + "configSettings.ini";
-
-  return file_path;
+  // qDebug() << "The Utils::configSettingsFilePath has been set to "
+  //          << Utils::configSettingsFilePath;
 }
 
 /*!
@@ -816,7 +921,7 @@ Utils::isProcessRunningInWindows(const QString &process_name)
   PROCESSENTRY32 entry;
   entry.dwSize = sizeof(PROCESSENTRY32);
 
-  HANDLE snapshot = CreateToolhelp32Snapshot(TH32CS_SNAPPROCESS, NULL);
+  HANDLE snapshot = CreateToolhelp32Snapshot(TH32CS_SNAPPROCESS, 0);
 
   if(Process32First(snapshot, &entry))
     {
@@ -908,12 +1013,12 @@ Utils::registerJsConstructor(QJSEngine *engine)
 {
   if(!engine)
     {
-      qWarning() << "Cannot register Utils class: engine is null";
+      qDebug() << "Cannot register Utils class: engine is null";
       return;
     }
 
   // Register the meta object as a constructor
-  qDebug() << "Registering JS constructor for class Utils.";
+  // qDebug() << "Registering JS constructor for class Utils.";
 
   // The registration below makes it possible to allocate a Utils
   // instance using var the_utils = new Utils()
