@@ -2,7 +2,7 @@
  *
  * MsXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -680,6 +680,13 @@ std::map<Enums::MassDataType, QString> massDataTypeMap{
   {Enums::MassDataType::LAST, "LAST"}};
 
 
+/*!
+\brief Number of decimal places after the decimal symbol for unconfigured
+values.
+\ingroup Globals
+ */
+int DEFAULT_DEC_PLACES = 3;
+
 /*!
 \brief Number of decimal places after the decimal symbol for atom masses.
 \ingroup Globals
@@ -704,6 +711,38 @@ int POLYMER_DEC_PLACES = 3;
  */
 int PKA_PH_PI_DEC_PLACES = 2;
 
+/*!
+\brief Number of decimal places after the decimal symbol for m/z values.
+\ingroup Globals
+ */
+int MZ_DEC_PLACES = 3;
+
+/*!
+\brief Number of decimal places after the decimal symbol for delta m/z values.
+\ingroup Globals
+ */
+int DELTA_MZ_DEC_PLACES = 4;
+
+/*!
+\brief Number of decimal places after the decimal symbol for retention time
+values in minutes.
+\ingroup Globals
+ */
+int RT_MINUTES_DEC_PLACES = 2;
+
+/*!
+\brief Number of decimal places after the decimal symbol for retention time
+values in seconds.
+\ingroup Globals
+ */
+int RT_SECONDS_DEC_PLACES = 1;
+
+/*!
+\brief Number of decimal places after the decimal symbol for intensity values.
+\ingroup Globals
+ */
+int INTENSITY_DEC_PLACES = 0;
+
 /*!
     \typedef MsXpS::libXpertMassCore::ErrorList
     \relates QString
