@@ -2,7 +2,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -53,7 +53,6 @@
 /////////////////////// Local includes
 #include "MsXpS/export-import-config.h"
 
-
 namespace Ui
 {
 class DecimalPlacesOptionsDlg;
@@ -65,16 +64,16 @@ namespace libXpertMassGui
 {
 
 
-  /*  BEGIN CLASS JS REFERENCE
-   *  namespace: MsXpS::libXpertMassGui
-   *  class name: DecimalPlacesOptionsDlg
-   *
-   * BEGIN DESCRIPTION
-   * This class allows the user to configure the number of decimals
-   * to be used when textually representing the mass values of various
-   * chemical entities.
-   * END DESCRIPTION
-   */
+/*  BEGIN CLASS JS REFERENCE
+ *  namespace: MsXpS::libXpertMassGui
+ *  class name: DecimalPlacesOptionsDlg
+ *
+ * BEGIN DESCRIPTION
+ * This class allows the user to configure the number of decimals
+ * to be used when textually representing the mass values of various
+ * chemical entities.
+ * END DESCRIPTION
+ */
 
 class DECLSPEC DecimalPlacesOptionsDlg: public QDialog
 {
@@ -86,7 +85,9 @@ class DECLSPEC DecimalPlacesOptionsDlg: public QDialog
   Q_PROPERTY(int pkaPhPiDecPlaces MEMBER m_pkaPhPiDecPlaces)
 
   public:
-  DecimalPlacesOptionsDlg(QWidget *, const QString &configSettingsFilePath);
+  Q_INVOKABLE DecimalPlacesOptionsDlg();
+  Q_INVOKABLE DecimalPlacesOptionsDlg(const QString &configSettingsFilePath,
+                                      QWidget *parent_p = nullptr);
 
   ~DecimalPlacesOptionsDlg();
 
@@ -116,13 +117,11 @@ class DECLSPEC DecimalPlacesOptionsDlg: public QDialog
   bool fetchValidateInputData();
 };
 
-
-  /*  END CLASS JS REFERENCE
-   *  namespace: MsXpS::libXpertMassGui
-   *  class name: DecimalPlacesOptionsDlg
-   */
+/*  END CLASS JS REFERENCE
+ *  namespace: MsXpS::libXpertMassGui
+ *  class name: DecimalPlacesOptionsDlg
+ */
 
 } // namespace libXpertMassGui
 MSXPS_REGISTER_JS_CLASS(MsXpS::libXpertMassGui, DecimalPlacesOptionsDlg)
 } // namespace MsXpS
-
