@@ -60,6 +60,7 @@
 #include "MsXpS/libXpertMassCore/IsotopicDataUserConfigHandler.hpp"
 #include "MsXpS/libXpertMassCore/IsotopicDataManualConfigHandler.hpp"
 #include "MsXpS/libXpertMassCore/IsotopicClusterGenerator.hpp"
+#include "MsXpS/libXpertMassGui/IsotopicClusterShaperDlg.hpp"
 
 
 /////////////////////// libXpertMassGUI includes
@@ -69,7 +70,6 @@
 /////////////////////// Local includes
 #include "MsXpS/export-import-config.h"
 
-
 namespace Ui
 {
 class IsotopicClusterGeneratorDlg;
@@ -84,8 +84,7 @@ namespace libXpertMassGui
 class IsotopicDataTableViewModel;
 class IsotopicDataTableViewSortProxyModel;
 
-
-class DECLSPEC IsotopicClusterGeneratorDlg : public QDialog
+class DECLSPEC IsotopicClusterGeneratorDlg: public QDialog
 {
   Q_OBJECT
 
@@ -146,6 +145,10 @@ class DECLSPEC IsotopicClusterGeneratorDlg : public QDialog
 
   QWidget *mp_programWindow = nullptr;
 
+  // When the user wants to reuse the cluster shaper dialog, store the last
+  // shaper dialog in here.
+  IsotopicClusterShaperDlg *mp_isotopicClusterShaperDlg = nullptr;
+
   int m_normalizeIntensity      = std::numeric_limits<int>::min();
   double m_maxSummedProbability = 0.95;
   int m_charge                  = 1;
@@ -157,9 +160,9 @@ class DECLSPEC IsotopicClusterGeneratorDlg : public QDialog
   ///////////// Isotopic data for three different contexts ////////////
 
   // Isotopic data from the IsoSpec library tables
-  libXpertMassCore::IsotopicDataSPtr msp_isotopicDataLibrary = nullptr;
+  libXpertMassCore::IsotopicDataSPtr msp_isotopicDataLibrary          = nullptr;
   // Isotopic data from the user's personal file
-  libXpertMassCore::IsotopicDataSPtr msp_isotopicDataUserConfig = nullptr;
+  libXpertMassCore::IsotopicDataSPtr msp_isotopicDataUserConfig       = nullptr;
   // Isotopic data from the user's personal GUI-based manual config file
   libXpertMassCore::IsotopicDataSPtr msp_isotopicDataUserManualConfig = nullptr;
 
@@ -209,4 +212,3 @@ class DECLSPEC IsotopicClusterGeneratorDlg : public QDialog
 } // namespace libXpertMassGui
 
 } // namespace MsXpS
-
