@@ -51,7 +51,6 @@
 /////////////////////// Local includes
 #include "MsXpS/export-import-config.h"
 
-
 namespace MsXpS
 {
 
@@ -60,13 +59,13 @@ namespace libXpertMassGui
 
 class IsotopicClusterGeneratorDlg;
 
-class DECLSPEC IsotopicDataTableViewModel : public QAbstractTableModel
+class DECLSPEC IsotopicDataTableViewModel: public QAbstractTableModel
 {
   Q_OBJECT
 
   public:
-  IsotopicDataTableViewModel(QObject *object,
-                        libXpertMassCore::IsotopicDataSPtr isotopic_data_sp);
+  IsotopicDataTableViewModel(
+    QObject *object, libXpertMassCore::IsotopicDataSPtr isotopic_data_sp);
   virtual ~IsotopicDataTableViewModel();
 
   virtual const QWidget *parent() const;
@@ -100,7 +99,7 @@ class DECLSPEC IsotopicDataTableViewModel : public QAbstractTableModel
   void insertIsotopeRowBelow();
   void removeSelected();
 
-signals:
+  signals:
 
   void modifiedSignal();
 
@@ -116,4 +115,3 @@ signals:
 } // namespace libXpertMassGui
 
 } // namespace MsXpS
-
