@@ -50,7 +50,6 @@
 /////////////////////// Local includes
 #include "MsXpS/export-import-config.h"
 
-
 namespace Ui
 {
 class MassDataClientServerConfigDlg;
@@ -74,11 +73,11 @@ class DECLSPEC MassDataClientServerConfigDlg: public QDialog
   Q_PROPERTY(std::pair<QString, int> clientIpConfig MEMBER m_clientIpConfig)
 
   public:
-  MassDataClientServerConfigDlg(QWidget *parent,
-                                const QString &applicationName,
-                                const QString &description,
-                                std::pair<QString, int> server_ip_config = std::pair("",
-                                                                           0));
+  MassDataClientServerConfigDlg(
+    QWidget *parent,
+    const QString &applicationName,
+    const QString &description,
+    std::pair<QString, int> server_ip_config = std::pair("", 0));
 
   virtual ~MassDataClientServerConfigDlg();
 
