@@ -60,8 +60,6 @@
 /////////////////////// Local includes
 #include "MsXpS/export-import-config.h"
 
-
-
 namespace Ui
 {
 class MassPeakShaperConfigWidget;
@@ -83,13 +81,13 @@ class DECLSPEC MassPeakShaperConfigWidget: public QWidget
   Q_OBJECT
 
   Q_PROPERTY(double referencePeakMz MEMBER m_referencePeakMz)
-  Q_PROPERTY(
-    libXpertMassCore::MassPeakShaperConfig *config READ getConfig MEMBER mp_config)
+  Q_PROPERTY(libXpertMassCore::MassPeakShaperConfig *config READ getConfig
+               MEMBER mp_config)
   Q_PROPERTY(double normalizingIntensity MEMBER m_normalizingIntensity)
 
   public:
-  explicit MassPeakShaperConfigWidget(const libXpertMassCore::MassPeakShaperConfig &config,
-                             QWidget *parent_p);
+  explicit MassPeakShaperConfigWidget(
+    const libXpertMassCore::MassPeakShaperConfig &config, QWidget *parent_p);
 
   virtual ~MassPeakShaperConfigWidget();
 
@@ -120,13 +118,17 @@ class DECLSPEC MassPeakShaperConfigWidget: public QWidget
                 libXpertMassCore::Enums::MassPeakShapeType mass_peak_shape_type,
                 double resolution,
                 double fwhm,
-                int bin_size_divisor = 6,
+                int bin_size_divisor    = 6,
                 bool should_create_bins = true);
   Q_INVOKABLE void setBinSizeManually(double bin_size,
                                       bool should_create_bins = false);
   Q_INVOKABLE bool checkParameters();
   Q_INVOKABLE bool checkParameters(libXpertMassCore::ErrorList *error_list);
 
+  Q_INVOKABLE bool isReferencePeakMzKept() const;
+
+  Q_INVOKABLE QPair<double, double> getMzRangeValuePair() const;
+
   Q_INVOKABLE const libXpertMassCore::MassPeakShaperConfig *getConfig() const;
 
   static void registerJsConstructor(QJSEngine *engine);
@@ -139,8 +141,8 @@ class DECLSPEC MassPeakShaperConfigWidget: public QWidget
   void pointCountEditingFinished();
   void gaussianRadioButtonToggled(bool checked);
   void lorentzianRadioButtonToggled(bool checked);
-  void referencePeakMzEdited(const QString &text);
-  void noBinsCheckBoxStateChanged(int state);
+  void referencePeakMzValueChanged(double value);
+  void computeReferencePeakMzValue(double value);
 
   signals:
 
@@ -151,7 +153,11 @@ class DECLSPEC MassPeakShaperConfigWidget: public QWidget
   Ui::MassPeakShaperConfigWidget *mp_ui;
   QWidget *mp_parent = nullptr;
 
-  double m_referencePeakMz = 0.0;
+  double m_referencePeakMz   = 0.0;
+  bool m_keepReferencePeakMz = false;
+
+  double m_mzRangeStart = qQNaN();
+  double m_mzRangeStop  = qQNaN();
 
   libXpertMassCore::MassPeakShaperConfig *mp_config = nullptr;
   double m_normalizingIntensity = std::numeric_limits<double>::min();
@@ -171,4 +177,3 @@ MSXPS_REGISTER_JS_CLASS(MsXpS::libXpertMassGui, MassPeakShaperConfigWidget)
 
 } // namespace libXpertMassGui
 } // namespace MsXpS
-
