@@ -2,7 +2,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -38,7 +38,6 @@
 #include <QTreeWidgetItem>
 
 
-
 /////////////////////// libXpertMassCore includes
 
 
@@ -50,7 +49,6 @@
 /////////////////////// Local includes
 #include "MsXpS/export-import-config.h"
 
-
 namespace MsXpS
 {
 namespace libXpertMassGui
@@ -73,12 +71,12 @@ class DECLSPEC ScriptingObjectTreeWidgetItem: public QObject, QTreeWidgetItem
   void setColor(const QColor &color);
   void setScriptEntityType(ScriptEntityType type);
 
-  void setProperties(QObject *object        = Q_NULLPTR,
-                     const QString &comment = QString(),
-                     const QString &help    = QString(),
-                     const QColor &color    = Qt::black,
-                     ScriptEntityType entityType =
-                       ScriptEntityType::UndefinedEntity);
+  void setProperties(
+    QObject *object             = Q_NULLPTR,
+    const QString &comment      = QString(),
+    const QString &help         = QString(),
+    const QColor &color         = Qt::black,
+    ScriptEntityType entityType = ScriptEntityType::UndefinedEntity);
 
   public slots:
 
