@@ -3,7 +3,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -53,7 +53,6 @@
 /////////////////////// Local includes
 #include "MsXpS/export-import-config.h"
 
-
 namespace Ui
 {
 class ToleranceWidget;
@@ -65,7 +64,7 @@ namespace libXpertMassGui
 {
 
 
-class DECLSPEC ToleranceWidget : public QWidget
+class DECLSPEC ToleranceWidget: public QWidget
 {
   Q_OBJECT
 
@@ -93,18 +92,21 @@ class DECLSPEC ToleranceWidget : public QWidget
   signals:
   void nominalChangedSignal();
   void typeChangedSignal();
-  void toleranceChangedSignal(std::pair<double, libXpertMassCore::Tolerance::Type>);
+  void toleranceChangedSignal(
+    std::pair<double, libXpertMassCore::Tolerance::Type>);
 
   private:
   QString m_configSettingsFilePath;
 
   bool m_isInitialized = false;
 
-  libXpertMassCore::Tolerance *mp_tolerance = new libXpertMassCore::Tolerance(this);
+  libXpertMassCore::Tolerance *mp_tolerance =
+    new libXpertMassCore::Tolerance(this);
 
   Ui::ToleranceWidget *mp_ui;
 
-  void initializeTolerance(double nominal, libXpertMassCore::Tolerance::Type type);
+  void initializeTolerance(double nominal,
+                           libXpertMassCore::Tolerance::Type type);
   void initializeTolerance(const libXpertMassCore::Tolerance &tolerance);
   bool initializeToleranceFromSettings();
   void setupWidgetCommon();
