@@ -2,7 +2,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2018 Filippo Rusconi
+ * Copyright 2009--2026 by Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -85,9 +85,15 @@ printing out the mass of polymers (default = 3).
 printing out pH, pKa, pI values (default = 3).
 */
 
+/*!
+\brief Constructs a DecimalPlacesOptionsDlg instance with \a
+config_settings_file_path and setting \a parent.
 
+If \a config_settings_file_path points to a valid file, the settings are read
+from there and set to the the dialog widgets.
+*/
 DecimalPlacesOptionsDlg::DecimalPlacesOptionsDlg(
-  QWidget *parent, [[maybe_unused]] const QString &configSettingsFilePath)
+  [[maybe_unused]] const QString &config_settings_file_path, QWidget *parent)
   : QDialog(parent), mp_ui(new Ui::DecimalPlacesOptionsDlg)
 {
   mp_ui->setupUi(this);
@@ -103,25 +109,30 @@ DecimalPlacesOptionsDlg::DecimalPlacesOptionsDlg(
   // Make now the connections that we will rely upon when
   // reading places settings and set them to the widgets
   // which will be reported to the member data.
-  connect(
-    mp_ui->atomDecimalPlacesSpinBox, &QSpinBox::valueChanged, [&](int value) {
-      m_atomDecPlaces = value;
-    });
+  connect(mp_ui->atomDecimalPlacesSpinBox,
+          &QSpinBox::valueChanged,
+          this,
+          [&](int value) {
+            m_atomDecPlaces = value;
+          });
 
   connect(mp_ui->oligomerDecimalPlacesSpinBox,
           &QSpinBox::valueChanged,
+          this,
           [&](int value) {
             m_oligomerDecPlaces = value;
           });
 
   connect(mp_ui->polymerDecimalPlacesSpinBox,
           &QSpinBox::valueChanged,
+          this,
           [&](int value) {
             m_polymerDecPlaces = value;
           });
 
   connect(mp_ui->pKaPhPiDecimalPlacesSpinBox,
           &QSpinBox::valueChanged,
+          this,
           [&](int value) {
             m_pkaPhPiDecPlaces = value;
           });
@@ -147,10 +158,26 @@ DecimalPlacesOptionsDlg::DecimalPlacesOptionsDlg(
   settings.endGroup();
 }
 
+/*!
+\brief Constructs a DecimalPlacesOptionsDlg instance.
+
+The values for the various chemical entities are set from global values.
+*/
+DecimalPlacesOptionsDlg::DecimalPlacesOptionsDlg()
+  : DecimalPlacesOptionsDlg("", nullptr)
+{
+  // This constructor uses the construction delegate form (C++-11)
+  // by calling the other constructor in the member initializer list.
+}
+
 DecimalPlacesOptionsDlg::~DecimalPlacesOptionsDlg()
 {
 }
 
+/*!
+\brief Updates the decimal places values for \a atom, \a oligo, \a poly and \a
+ph_pka.
+*/
 void
 DecimalPlacesOptionsDlg::updateDecimalPlaces(int atom,
                                              int oligo,
@@ -183,6 +210,21 @@ DecimalPlacesOptionsDlg::closeEvent(QCloseEvent *event)
   settings.endGroup();
 }
 
+/*!
+\brief Validates all the decimal values set in the dialog window control.
+
+The values read from the graphical interface are set to the library global
+data:
+
+\list
+
+\li libXpertMassCore::ATOM_DEC_PLACES
+\li libXpertMassCore::OLIGOMER_DEC_PLACES
+\li libXpertMassCore::POLYMER_DEC_PLACES
+\li libXpertMassCore::PKA_PH_PI_DEC_PLACES
+
+\endlist
+*/
 void
 DecimalPlacesOptionsDlg::validate()
 {
@@ -219,7 +261,7 @@ DecimalPlacesOptionsDlg::registerJsConstructor(QJSEngine *engine)
 {
   if(!engine)
     {
-      qWarning()
+      qDebug()
         << "Cannot register DecimalPlacesOptionsDlg class: engine is null";
       return;
     }
