@@ -82,7 +82,6 @@
 #include "MsXpS/libXpertMassGui/IsotopicClusterGeneratorDlg.hpp"
 #include "MsXpS/libXpertMassGui/ColorSelector.hpp"
 #include "MsXpS/libXpertMassGui/IsotopicClusterGeneratorDlg.hpp"
-#include "MsXpS/libXpertMassGui/IsotopicClusterShaperDlg.hpp"
 
 #include "ui_IsotopicClusterGeneratorDlg.h"
 
@@ -116,7 +115,8 @@ The isotopic cluster is generated starting from a Formula.
 */
 
 /*!
-\variable MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::m_windowDescription
+\variable
+MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::m_windowDescription
 
 \brief The text to be used for the window title.
 */
@@ -138,7 +138,8 @@ responsible for its ionization.
 */
 
 /*!
-\variable MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::m_normalizeIntensity
+\variable
+MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::m_normalizeIntensity
 
 \brief The intensity value that the most intense peak in the cluster should
 have.
@@ -147,7 +148,8 @@ All the other peaks intensities are normalized against this value.
 */
 
 /*!
-\variable MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::m_maxSummedProbability
+\variable
+MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::m_maxSummedProbability
 
 \brief The sum of all the intensities of the cluster peaks should not exceed
 this value.
@@ -176,33 +178,38 @@ peak centroids.
 */
 
 /*!
-\variable MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::msp_isotopicDataLibrary
+\variable
+MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::msp_isotopicDataLibrary
 
 \brief The isotopic data from the IsoSpec library tables.
 */
 
 /*!
-\variable MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::msp_isotopicDataUserConfig
+\variable
+MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::msp_isotopicDataUserConfig
 
 \brief The isotopic data from the IsoSpec-like library tables as modified by
 the user.
 */
 
 /*!
-\variable MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::msp_isotopicDataUserManualConfig
+\variable
+MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::msp_isotopicDataUserManualConfig
 
 \brief The isotopic data from the user's manual configuration.
 */
 
 /*!
-\variable MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::mpa_libraryStaticTableViewModel
+\variable
+MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::mpa_libraryStaticTableViewModel
 
 \brief The table view model that manages the library static IsoSpec standard
 data.
 */
 
 /*!
-\variable MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::mpa_userStaticTableViewModel
+\variable
+MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::mpa_userStaticTableViewModel
 
 \brief The table view model that manages the library user-modified IsoSpec
 standard data.
@@ -216,7 +223,8 @@ isotopic cluster is later shaped into a mass spectrum.
 */
 
 /*!
-\variable MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::m_clusterGenerator
+\variable
+MsXpS::libXpertMassGui::IsotopicClusterGeneratorDlg::m_clusterGenerator
 
 \brief The isotopic cluster generator that will be used for the computations.
 */
@@ -255,8 +263,9 @@ IsotopicClusterGeneratorDlg::IsotopicClusterGeneratorDlg(
   // use the proper isotopic data handler depending on the context (library,
   // user config or manual config).
 
-  msp_isotopicDataLibrary    = std::make_shared<libXpertMassCore::IsotopicData>();
-  msp_isotopicDataUserConfig = std::make_shared<libXpertMassCore::IsotopicData>();
+  msp_isotopicDataLibrary = std::make_shared<libXpertMassCore::IsotopicData>();
+  msp_isotopicDataUserConfig =
+    std::make_shared<libXpertMassCore::IsotopicData>();
   msp_isotopicDataUserManualConfig =
     std::make_shared<libXpertMassCore::IsotopicData>();
 
@@ -275,7 +284,7 @@ void
 IsotopicClusterGeneratorDlg::closeEvent([[maybe_unused]] QCloseEvent *event)
 {
   writeSettings(
-    libXpertMassCore::Utils::craftConfigSettingsFilePath(m_applicationName));
+    MsXpS::libXpertMassCore::Utils::configSettingsFilePath);
 }
 
 /*!
@@ -284,7 +293,7 @@ IsotopicClusterGeneratorDlg::closeEvent([[maybe_unused]] QCloseEvent *event)
 IsotopicClusterGeneratorDlg::~IsotopicClusterGeneratorDlg()
 {
   writeSettings(
-    libXpertMassCore::Utils::craftConfigSettingsFilePath(m_applicationName));
+    MsXpS::libXpertMassCore::Utils::configSettingsFilePath);
   delete mp_ui;
 }
 
@@ -413,7 +422,7 @@ IsotopicClusterGeneratorDlg::setupDialog()
   mp_ui->ionChargeSpinBox->setValue(1);
 
   readSettings(
-    libXpertMassCore::Utils::craftConfigSettingsFilePath(m_applicationName));
+    MsXpS::libXpertMassCore::Utils::configSettingsFilePath);
 
   ///////////////// Connections for the different contexts /////////////////
 
@@ -728,7 +737,7 @@ IsotopicClusterGeneratorDlg::toIsotopicClusterShaper()
   // one pair (charge,cluster). In the present case, the dialog window allows
   // for only one elemental composition to perform the calculation, so we just
   // need to take the first (and in fact there must be only one) charge,cluster
-  // pair from the vector. We get the trace and we sent that to the peak shaper
+  // pair from the vector. We get the trace and we send that to the peak shaper
   // dialog. We also want to set the color that might have been set by the user
   // for plotting the trace.
 
@@ -740,41 +749,67 @@ IsotopicClusterGeneratorDlg::toIsotopicClusterShaper()
     return;
 
   // In the dialog window, only one formula is handled at a time.
-  assert(isotopic_cluster_charge_pairs.size() == 1);
+  Q_ASSERT(isotopic_cluster_charge_pairs.size() == 1);
 
   // Get the isotopic cluster as a Trace out of the pair.
   pappso::TraceCstSPtr isotopic_cluster_sp =
     isotopic_cluster_charge_pairs.front().first;
 
+
+  // The user might want to reuse the same isotopic cluster shaper dialog
+  // window, in which case the reuseIsotopicClusterShaperDlgCheckBox
+  // is checked.
+
+  IsotopicClusterShaperDlg *isotopic_cluster_shaper_dlg_p = nullptr;
+
+  bool reuse_isotopic_cluster_shaper_dlg =
+    mp_ui->reuseIsotopicClusterShaperDlgCheckBox->isChecked();
+
   // Make sure we pass the ProgramWindow pointer as the parent object of the
   // PeakShaperDlg, otherwise crash when using ConsoleWnd.
-  IsotopicClusterShaperDlg *isotopic_cluster_shaper_dlg_p =
-    new IsotopicClusterShaperDlg(mp_programWindow,
-                                 m_applicationName,
-                                 "Isotopic cluster shaper",
-                                 isotopic_cluster_sp,
-                                 m_normalizeIntensity);
+
+  if(reuse_isotopic_cluster_shaper_dlg &&
+     mp_isotopicClusterShaperDlg != nullptr)
+    {
+      isotopic_cluster_shaper_dlg_p = mp_isotopicClusterShaperDlg;
+      isotopic_cluster_shaper_dlg_p->setIsotopiCluster(isotopic_cluster_sp);
+    }
+  else
+    {
+      mp_isotopicClusterShaperDlg =
+        new IsotopicClusterShaperDlg(mp_programWindow,
+                                     m_applicationName,
+                                     "Isotopic cluster shaper",
+                                     isotopic_cluster_sp,
+                                     m_normalizeIntensity);
+
+      isotopic_cluster_shaper_dlg_p = mp_isotopicClusterShaperDlg;
+
+      // In that shaper dialog, when the computation has finished, the user may
+      // ask to display the spectrum. So the dialog window emits the signal
+      // below. We want to relay that signal to the other listeners, typically
+      // the program window, so that they can take action. If the program window
+      // is of massXpert, they'll have to craft a CBOR-encoded packet and serve
+      // it so that any listening program can display it (typically mineXpert).
+      // If that program window is of mineXpert, then simply display the mass
+      // spectrum in the mass spectra window...
+
+      // Note also that this connection must be made once per dialog! Which
+      // is why it is made only right after allocation of a new dialog window.
+      connect(isotopic_cluster_shaper_dlg_p,
+              &IsotopicClusterShaperDlg::displayMassSpectrumSignal,
+              [this](const QString &title,
+                     const QByteArray &color_byte_array,
+                     pappso::TraceCstSPtr trace) {
+                emit displayMassSpectrumSignal(title, color_byte_array, trace);
+              });
+    }
 
   isotopic_cluster_shaper_dlg_p->setColorByteArray(m_colorByteArray);
   isotopic_cluster_shaper_dlg_p->setMassSpectrumTitle(
     mp_ui->massSpectrumTitleLineEdit->text());
 
-  // In that shaper dialog, when the computation has finished, the user may ask
-  // to display the spectrum. So the dialog window emits the signal below. We
-  // want to relay that signal to the other listeners, typically the program
-  // window, so that they can take action. If the program window is of
-  // massXpert, they'll have to craft a CBOR-encoded packet and serve it so that
-  // any listening program can display it (typically mineXpert). If that program
-  // window is of mineXpert, then simply display the mass spectrum in the mass
-  // spectra window...
-  connect(isotopic_cluster_shaper_dlg_p,
-          &IsotopicClusterShaperDlg::displayMassSpectrumSignal,
-          [this](const QString &title,
-                 const QByteArray &color_byte_array,
-                 pappso::TraceCstSPtr trace) {
-            emit displayMassSpectrumSignal(title, color_byte_array, trace);
-          });
-
+  isotopic_cluster_shaper_dlg_p->showTabWidgetInputDataPage();
   isotopic_cluster_shaper_dlg_p->show();
   isotopic_cluster_shaper_dlg_p->raise();
   isotopic_cluster_shaper_dlg_p->activateWindow();
