@@ -90,7 +90,7 @@ obtained shapes are combined into a single mass spectrum.
 */
 
 /*!
-\variable
+\variable \
 MsXpS::libXpertMassGui::IsotopicClusterShaperDlg::mp_massPeakShaperConfigWidget
 
 \brief The widget where the mass peak shaping process configuration is done..
@@ -141,7 +141,7 @@ be traced.
 */
 
 /*!
-\variable
+\variable \
 MsXpS::libXpertMassGui::IsotopicClusterShaperDlg::m_mzIntegrationParams
 
 \brief The mass spectrum combination parameters (size of the bins, for example).
@@ -155,7 +155,7 @@ with at half maximum values to and from resolving power values.
 */
 
 /*!
-\variable
+\variable \
 MsXpS::libXpertMassGui::IsotopicClusterShaperDlg::m_normalizingIntensity
 
 \brief The intensity value that the most intense peak in the cluster should
@@ -280,7 +280,7 @@ IsotopicClusterShaperDlg::closeEvent(QCloseEvent *event)
   Q_UNUSED(event)
   // qDebug();
   writeSettings(
-    libXpertMassCore::Utils::craftConfigSettingsFilePath(m_applicationName));
+    MsXpS::libXpertMassCore::Utils::configSettingsFilePath);
 }
 
 /*!
@@ -289,7 +289,7 @@ IsotopicClusterShaperDlg::closeEvent(QCloseEvent *event)
 IsotopicClusterShaperDlg::~IsotopicClusterShaperDlg()
 {
   writeSettings(
-    libXpertMassCore::Utils::craftConfigSettingsFilePath(m_applicationName));
+    MsXpS::libXpertMassCore::Utils::configSettingsFilePath);
   delete mp_ui;
 }
 
@@ -368,7 +368,7 @@ IsotopicClusterShaperDlg::setupDialog()
     new MassPeakShaperConfigWidget(m_config, this);
   v_box_layout_p->addWidget(mp_massPeakShaperConfigWidget);
 
-  mp_ui->peakShapeConfigFrame->setLayout(v_box_layout_p);
+  mp_ui->peakShaperConfigFrame->setLayout(v_box_layout_p);
 
   // Set the message timer to be singleShot. This time is used to erase the text
   // shown in the message line edit widget after 3 seconds.
@@ -406,7 +406,7 @@ IsotopicClusterShaperDlg::setupDialog()
   // The values above are actually set in readSettings (with default values if
   // missing in the config settings.)
   readSettings(
-    libXpertMassCore::Utils::craftConfigSettingsFilePath(m_applicationName));
+    MsXpS::libXpertMassCore::Utils::configSettingsFilePath);
 
 
   // Always start the dialog with the first page of the tab widget,
@@ -425,8 +425,7 @@ IsotopicClusterShaperDlg::setupDialog()
   connect(mp_ui->checkParametersPushButton,
           &QPushButton::clicked,
           this,
-          qOverload<>(
-            &IsotopicClusterShaperDlg::checkParameters));
+          qOverload<>(&IsotopicClusterShaperDlg::checkParameters));
 
   connect(mp_ui->runPushButton,
           &QPushButton::clicked,
@@ -611,9 +610,42 @@ IsotopicClusterShaperDlg::checkParameters(
       return false;
     }
 
+  // There is a crucial sanity check: if the user has asked that the mz range
+  // be fixed, it is essential that the smallest/greatest m/z values encountered
+  // in the generated shapes are contained in that range, otherwise crash in
+  // the function that creates the bins.
+  //
+  // At the present time, we do not have the shapes already, but we have the
+  // centroids, we can already check them.
+
+  // Returns both first and second value = 0 if the
+  // user did not set this setting.
+  QPair<double, double> mz_range_value_pair =
+    mp_massPeakShaperConfigWidget->getMzRangeValuePair();
+  bool use_fixed_mz_range = (mz_range_value_pair.second != 0);
+
+  if(use_fixed_mz_range)
+    {
+      if((m_isotopicCluster.front().x < mz_range_value_pair.first) ||
+         (m_isotopicCluster.back().x > mz_range_value_pair.second))
+        {
+          QMessageBox::warning(
+            0,
+            tr("Peak shaper (Gaussian or Lorentzian)"),
+            QString("\nThe generated shapes encompass an m/z range that is\n"
+                    "outside of the configured fixed m/z range.\n\n"
+                    "The suggested fixed m/z range values: [%1-%2].\n")
+              .arg(m_isotopicCluster.front().x - 1, 0, 'f', 6)
+              .arg(m_isotopicCluster.back().x + 1, 0, 'f', 6),
+            QMessageBox::Ok);
+
+          return false;
+        }
+    }
+
   // At this point, because we have set all the relevant values to the
-  // m_config PeakShapeConfig, we can create the PeakShaper instances and set
-  // to them the m_config.
+  // m_config PeakShapeConfig, we can create the PeakShaper instances and
+  // set to them the m_config.
 
   if(!fillInThePeakShapers())
     {
@@ -640,6 +672,7 @@ IsotopicClusterShaperDlg::checkParameters(
 
   mp_ui->logPlainTextEdit->appendPlainText(m_config.toString());
 
+
   message("The configuration validated fine. Check the LOG tab for details.");
 
   // At this point we'll have some things to report to the LOG tab,
@@ -697,27 +730,70 @@ IsotopicClusterShaperDlg::run()
       return;
     }
 
-  // At this point all the data are set, we can start the computation on all
-  // the various peak shapers.
-
-  double minMz = std::numeric_limits<double>::max();
-  double maxMz = std::numeric_limits<double>::min();
 
   // Clear the map trace that will receive the results of the combinations.
   m_mapTrace.clear();
 
-  // Now actually shape a peak around each peak centroid (contained in each
-  // peak shaper).
+  // At this point all the data are set, we can start the computation on all
+  // the various peak shapers.
 
+  // At this point we need to think hard: When the user runs the shaper once
+  // on all the centroids of an isotopic cluster and then displays the
+  // spectrum, that spectrum is beautiful, because the bins have been computed
+  // on the leftmost / rightmost m/z values of the whole set of sub-spectra
+  // obtained for each isotopologue.
+
+  // Good.
+
+  // Now, if the user first runs a simulation, displays a nice spectrum, then
+  // computes another simulation and the user wants to combine this second
+  // isotopic cluster simulation spectrum into the nice first spectrum, there
+  // the problem arises: because it is almost never the case that the new
+  // simulation spectrum starts with the same m/z range values, the bins
+  // (if computed, again) are going to be shifted from the previous ones
+  // computed for the first mass spectrum. This reality has the effect that
+  // the combined mass spectrum will have horrendous spikes on to of the
+  // beautifully-shaped peaks of the first simulation spectrum.
+
+  // To avoid this effect, one should define the m/z range values and stick
+  // to them through all the mass spectra simulated for a given session
+  // of simulations that will need to be combined into a single spectrum.
+  // This is what the "Phase the bins to the m/z range" groupbox is for
+  // in the peak shaper configuration widget.
+
+  // Check this right now:
+
+  double mz_range_start = std::numeric_limits<double>::max();
+  double mz_range_stop  = std::numeric_limits<double>::min();
+
+  // Returns both first and second value = 0 if the
+  // user did not set this setting.
+  QPair<double, double> mz_range_value_pair =
+    mp_massPeakShaperConfigWidget->getMzRangeValuePair();
+  bool use_fixed_mz_range = (mz_range_value_pair.second != 0);
+
+  if(use_fixed_mz_range)
+    {
+      mz_range_start = mz_range_value_pair.first;
+      mz_range_stop  = mz_range_value_pair.second;
+    }
+
+  // Hold the extreme m/z values after having computed the set of
+  // isotopic peak shapes.
+  double smallest_mz_value = std::numeric_limits<double>::max();
+  double greatest_mz_value = std::numeric_limits<double>::min();
+
+  // Now start the actual processing of the centroid shapes.
   int processed = 0;
 
+  // Shape the peak around each centroid value.
   for(auto peak_shaper_sp : m_peakShapers)
     {
       if(!peak_shaper_sp->computePeakShape())
         {
           QMessageBox::warning(
             0,
-            tr("mineXpert: Peak shaper (Gaussian or Lorentzian)"),
+            tr("Peak shaper (Gaussian or Lorentzian)"),
             QString("Failed to compute a Trace for peak shape at m/z %1.")
               .arg(peak_shaper_sp->getPeakCentroid().x, QMessageBox::Ok));
 
@@ -727,20 +803,54 @@ IsotopicClusterShaperDlg::run()
       // Now that we have computed the full shape around the centroid, we'll
       // be able to extract the smallest and greatest mz values of the whole
       // shape. We will need these two bounds to craft the bins in the
-      // MzIntegrationParams object.
+      // MzIntegrationParams object. Note that we do this only if the
+      // user has not set a m/z range to be fixed already.
+
+      double mz_value;
 
       if(peak_shaper_sp->getTrace().size())
         {
-          double smallestMz = peak_shaper_sp->getTrace().front().x;
-          minMz             = std::min(smallestMz, minMz);
+          mz_value          = peak_shaper_sp->getTrace().front().x;
+          smallest_mz_value = std::min(mz_value, smallest_mz_value);
 
-          double greatestMz = peak_shaper_sp->getTrace().back().x;
-          maxMz             = std::max(greatestMz, maxMz);
+          mz_value          = peak_shaper_sp->getTrace().back().x;
+          greatest_mz_value = std::max(mz_value, greatest_mz_value);
         }
 
       ++processed;
     }
 
+  // There is a crucial sanity check: if the user has asked that the mz range
+  // be fixed, it is essential that the smallest/greatest m/z values
+  // encountered in the generated shapes are contained in that range,
+  // otherwise crash in the function that creates the bins.
+
+  if(use_fixed_mz_range)
+    {
+      if((smallest_mz_value < mz_range_start) ||
+         (greatest_mz_value > mz_range_stop))
+        {
+          QMessageBox::warning(
+            0,
+            tr("Peak shaper (Gaussian or Lorentzian)"),
+            QString("\nThe generated shapes encompass an m/z range that is\n"
+                    "outside of the configured fixed m/z range.\n\n"
+                    "The suggested fixed m/z range values: [%1-%2].\n")
+              .arg(smallest_mz_value, 0, 'f', 6)
+              .arg(greatest_mz_value, 0, 'f', 6),
+            QMessageBox::Ok);
+
+          return;
+        }
+    }
+  else
+    {
+      // We do no use a fixed m/z range, so we need to set the values
+      // for later consumption.
+      mz_range_start = smallest_mz_value;
+      mz_range_stop  = greatest_mz_value;
+    }
+
   // Now create the actual spectrum by combining all the shapes into a cluster
   // shape.
 
@@ -762,8 +872,8 @@ IsotopicClusterShaperDlg::run()
           qDebug() << "The bin size is FIXED.";
 
           m_mzIntegrationParams.initialize(
-            minMz,
-            maxMz,
+            mz_range_start,
+            mz_range_stop,
             pappso::MzIntegrationParams::BinningType::ARBITRARY,
             pappso::PrecisionFactory::getDaltonInstance(bin_size),
             /*binSizeDivisor, 1 = no-op*/ 1,
@@ -780,8 +890,8 @@ IsotopicClusterShaperDlg::run()
               qDebug() << "The mass peak width logic is FWHM.";
 
               m_mzIntegrationParams.initialize(
-                minMz,
-                maxMz,
+                mz_range_start,
+                mz_range_stop,
                 pappso::MzIntegrationParams::BinningType::ARBITRARY,
                 pappso::PrecisionFactory::getDaltonInstance(bin_size),
                 1,
@@ -793,8 +903,8 @@ IsotopicClusterShaperDlg::run()
             {
               qDebug() << "The mass peak width logic is RESOLUTION.";
               m_mzIntegrationParams.initialize(
-                minMz,
-                maxMz,
+                mz_range_start,
+                mz_range_stop,
                 pappso::MzIntegrationParams::BinningType::ARBITRARY,
                 pappso::PrecisionFactory::getResInstance(
                   m_config.getResolution()),
@@ -829,7 +939,7 @@ IsotopicClusterShaperDlg::run()
 
       qDebug() << "NO BINS requested.";
 
-      pappso::TracePlusCombiner trace_plus_combiner(-1);
+      pappso::TracePlusCombiner trace_plus_combiner(-1 /*decimal_places*/);
 
       for(auto mass_peak_shaper_sp : m_peakShapers)
         {
@@ -909,7 +1019,7 @@ IsotopicClusterShaperDlg::displayMassSpectrum()
 
   // Finally, publish the mass spectrum.
 
-  // qDebug() << "Going to write this trace:" << m_finalTrace.toString();
+  qDebug() << "Going to write this trace:" << m_finalTrace.toString();
 
   QString title = craftMassSpectrumName();
   emit displayMassSpectrumSignal(
@@ -974,6 +1084,10 @@ void
 IsotopicClusterShaperDlg::setIsotopiCluster(
   pappso::TraceCstSPtr isotopic_cluster_sp)
 {
+  // If this dialog window is reused, clear the data from a previous
+  // calculation.
+  m_isotopicCluster.clear();
+
   // Start by copying the centroids locally in the form of a Trace collecting
   // DataPoint objects.
   m_isotopicCluster.assign(isotopic_cluster_sp->begin(),
@@ -1004,11 +1118,24 @@ IsotopicClusterShaperDlg::setIsotopiCluster(
         }
     }
 
+  // We did this verification, but if the user wants that this dialog window
+  // be reused and has checked the mass peak shaper config widget's
+  // keepReferenceMassPushButton (acts like a check button),
+  // then, we are not going to modify neither the reference peak m/z value,
+  // nor do we set the m/z range values.
+
   // qDebug() << "Reference (most intense) peak's m/z value:" <<
   // m_referencePeakMz;
 
-  m_config.setReferencePeakMz(m_referencePeakMz);
-  mp_massPeakShaperConfigWidget->setReferencePeakMz(m_referencePeakMz);
+  if(mp_massPeakShaperConfigWidget->isReferencePeakMzKept())
+    {
+      // The user does not want the reference peak m/z value to be updated.
+    }
+  else
+    {
+      m_config.setReferencePeakMz(m_referencePeakMz);
+      mp_massPeakShaperConfigWidget->setReferencePeakMz(m_referencePeakMz);
+    }
 
   mp_ui->inputDataPointsPlainTextEdit->setPlainText(result_as_text);
 }
@@ -1037,6 +1164,16 @@ IsotopicClusterShaperDlg::setColorByteArray(QByteArray color_byte_array)
   colorizePushButton(mp_ui->colorSelectorPushButton, color_byte_array);
 }
 
+/*!
+\brief Set the input data tab the currently visible tab.
+*/
+void
+IsotopicClusterShaperDlg::showTabWidgetInputDataPage()
+{
+  mp_ui->tabWidget->setCurrentIndex(
+    static_cast<int>(TabWidgetPage::INPUT_DATA));
+}
+
 /*!
 \brief Colorizes the \a push_button_p push button with the color encoded in
 \a color_byte_array.
