@@ -171,7 +171,7 @@ MassDataClientServerConfigDlg::MassDataClientServerConfigDlg(
           });
 
   readSettings(
-    libXpertMassCore::Utils::craftConfigSettingsFilePath(m_applicationName));
+    MsXpS::libXpertMassCore::Utils::configSettingsFilePath);
 }
 
 /*!
@@ -180,7 +180,7 @@ MassDataClientServerConfigDlg::MassDataClientServerConfigDlg(
 MassDataClientServerConfigDlg::~MassDataClientServerConfigDlg()
 {
   writeSettings(
-    libXpertMassCore::Utils::craftConfigSettingsFilePath(m_applicationName));
+    MsXpS::libXpertMassCore::Utils::configSettingsFilePath);
 }
 
 /*!
@@ -394,8 +394,8 @@ MassDataClientServerConfigDlg::registerJsConstructor(QJSEngine *engine)
 {
   if(!engine)
     {
-      qWarning() << "Cannot register MassDataClientServerConfigDlg class: "
-                    "engine is null";
+      qDebug() << "Cannot register MassDataClientServerConfigDlg class: "
+                  "engine is null";
       return;
     }
 
