@@ -148,6 +148,9 @@ MassPeakShaperConfigWidget::~MassPeakShaperConfigWidget()
   qDebug() << "Stopping the timer.";
   if(msp_msgTimer.get())
     msp_msgTimer.reset();
+
+  writeSettings(MsXpS::libXpertMassCore::Utils::configSettingsFilePath);
+
   delete mp_ui;
 }
 
@@ -163,12 +166,21 @@ MassPeakShaperConfigWidget::writeSettings(
 
   settings.beginGroup("MassPeakShaperConfigWidget");
 
+  settings.setValue(
+    "massPeakShapeType",
+    static_cast<int>(libXpertMassCore::Enums::MassPeakShapeType::GAUSSIAN));
+
   settings.setValue("pointCount", mp_ui->pointCountSpinBox->value());
+
   settings.setValue("resolution", mp_ui->resolutionSpinBox->value());
+
   settings.setValue("fwhm", mp_ui->fwhmDoubleSpinBox->value());
+
   settings.setValue("binSize", mp_ui->binSizeDoubleSpinBox->value());
+
   settings.setValue("binSizeGroupBoxState",
                     mp_ui->binSizeGroupBox->isChecked());
+
   settings.setValue("fmwhToBinSizeDivisor",
                     mp_ui->fmwhToBinSizeDivisorSpinBox->value());
 
@@ -187,20 +199,39 @@ MassPeakShaperConfigWidget::readSettings(
   QSettings settings(config_settings_file_path, QSettings::IniFormat);
   settings.beginGroup("MassPeakShaperConfigWidget");
 
-  mp_ui->pointCountSpinBox->setValue(settings.value("pointCount", 150).toInt());
-  mp_ui->resolutionSpinBox->setValue(
-    settings.value("resolution", 45000).toInt());
-  mp_ui->fwhmDoubleSpinBox->setValue(settings.value("fwhm", 0).toDouble());
+  // By default we want a gaussian-type shape.
+  int default_mass_peak_shape_type =
+    static_cast<int>(libXpertMassCore::Enums::MassPeakShapeType::GAUSSIAN);
+  int stored_mass_peak_shape_type =
+    settings.value("massPeakShapeType", default_mass_peak_shape_type).toInt();
 
-  mp_ui->binSizeGroupBox->setChecked(
-    settings.value("binSizeGroupBoxState", 0).toInt());
+  mp_config->setMassPeakShapeType(
+    static_cast<libXpertMassCore::Enums::MassPeakShapeType>(
+      stored_mass_peak_shape_type));
+  if(mp_config->getMassPeakShapeType() ==
+     libXpertMassCore::Enums::MassPeakShapeType::GAUSSIAN)
+    mp_ui->gaussianRadioButton->setChecked(true);
+  else
+    mp_ui->lorentzianRadioButton->setChecked(true);
+
+  // Get the number of points used to craft the peak curve.
+  mp_ui->pointCountSpinBox->setValue(settings.value("pointCount", 200).toInt());
+  mp_config->setPointCount(mp_ui->pointCountSpinBox->value());
+
+  mp_ui->resolutionSpinBox->setValue(
+    settings.value("resolution", 40000).toInt());
+
+  mp_ui->fwhmDoubleSpinBox->setValue(settings.value("fwhm", 0).toDouble());
 
   mp_ui->binSizeDoubleSpinBox->setValue(
     settings.value("binSize", 0).toDouble());
 
+  mp_ui->binSizeGroupBox->setChecked(
+    settings.value("binSizeGroupBoxState", 0).toInt());
 
   mp_ui->fmwhToBinSizeDivisorSpinBox->setValue(
     settings.value("fwhmToBinSizeDivisor", 6).toInt());
+
   settings.endGroup();
 }
 
@@ -211,10 +242,9 @@ void
 MassPeakShaperConfigWidget::setReferencePeakMz(double mz)
 {
   m_referencePeakMz = mz;
-  mp_config->setReferencePeakMz(mz);
 
-  mp_ui->referenceMassLineEdit->setText(
-    QString::number(m_referencePeakMz, 'f', 12));
+  mp_config->setReferencePeakMz(mz);
+  mp_ui->referenceMzDoubleSpinBox->setValue(mz);
 }
 
 /*!
@@ -223,19 +253,7 @@ MassPeakShaperConfigWidget::setReferencePeakMz(double mz)
 double
 MassPeakShaperConfigWidget::getReferencePeakMz()
 {
-  if(m_referencePeakMz <= 0)
-    {
-      bool ok = false;
-
-      m_referencePeakMz = mp_ui->referenceMassLineEdit->text().toDouble(&ok);
-
-      if(!ok)
-        {
-          qDebug() << "Failed to convert string to double.";
-          return 0;
-        }
-    }
-
+  m_referencePeakMz = mp_ui->referenceMzDoubleSpinBox->value();
   return m_referencePeakMz;
 }
 
@@ -253,18 +271,12 @@ MassPeakShaperConfigWidget::setupWidget()
 {
   mp_ui->setupUi(this);
 
-  // Ranges for various numerical values
-  mp_ui->resolutionSpinBox->setRange(0, 2000000);
+  // Ranges for various numerical values (with defaults)
+  readSettings(MsXpS::libXpertMassCore::Utils::configSettingsFilePath);
+
+  mp_ui->resolutionSpinBox->setRange(0, 1000000);
   mp_ui->fwhmDoubleSpinBox->setRange(0, 10);
-  mp_ui->pointCountSpinBox->setRange(5, 1000);
-
-  // By default we want a gaussian-type shape.
-  mp_config->setMassPeakShapeType(
-    libXpertMassCore::Enums::MassPeakShapeType::GAUSSIAN);
-  mp_ui->gaussianRadioButton->setChecked(true);
-
-  // Get the number of points used to craft the peak curve.
-  mp_config->setPointCount(mp_ui->pointCountSpinBox->value());
+  mp_ui->fmwhToBinSizeDivisorSpinBox->setRange(1, 100);
 
   // Set the message timer to be singleShot. This time is used to erase the text
   // shown in the message line edit widget after 3 seconds.
@@ -274,10 +286,97 @@ MassPeakShaperConfigWidget::setupWidget()
     mp_ui->messageLineEdit->setText("");
   });
 
-  connect(mp_ui->referenceMassLineEdit,
-          &QLineEdit::textEdited,
+  // All the tooltips
+
+  QString tool_tip_string;
+
+  tool_tip_string =
+    "Number of points that will make the peak shape. {[\n]}"
+    "Typically, an optimal value is in the 150 to 200 range";
+  mp_ui->pointCountSpinBox->setToolTip(
+    libXpertMassCore::Utils::stanzify(tool_tip_string, 50));
+
+  tool_tip_string =
+    "This reference m/z value is used to compute the "
+    "FWHM based on a resolving power value. And vice versa";
+  mp_ui->referenceMzDoubleSpinBox->setToolTip(
+    libXpertMassCore::Utils::stanzify(tool_tip_string, 50));
+
+  tool_tip_string = "Resolving power of the mass spectrometer";
+  mp_ui->resolutionSpinBox->setToolTip(
+    libXpertMassCore::Utils::stanzify(tool_tip_string, 50));
+
+  tool_tip_string =
+    "Full width at half maximum (the width of the peak at 50 % height). This "
+    "value relates to the resolving power of the instrument";
+  mp_ui->fwhmDoubleSpinBox->setToolTip(
+    libXpertMassCore::Utils::stanzify(tool_tip_string, 50));
+
+  tool_tip_string =
+    "This divisor value is only used at the combination step. Each shaped "
+    "isotopic cluster centroid is combined into the same final mass spectrum "
+    "that represents the entire isotopic cluster. The highest this divisor "
+    "setting, the greatest the number of bins in the final spectrum; and thus, "
+    "the more the shape of the peak will resemble a pure Gaussian or "
+    "Lorentzian curve. {[\n]}"
+
+    "A good empirically determined value is 6 (when the number of points in "
+    "the Gaussian | Lorentzian is 200). {[\n]}"
+
+    "This somehow amounts to the idea that it takes at least 6 bins to make a "
+    "nicely shaped peak of the configured FWHM.";
+  mp_ui->fmwhToBinSizeDivisorSpinBox->setToolTip(
+    libXpertMassCore::Utils::stanzify(tool_tip_string, 50));
+
+  tool_tip_string = "Uncheck this check box if no binning is required";
+  mp_ui->binSizeLogicGroupBox->setToolTip(
+    libXpertMassCore::Utils::stanzify(tool_tip_string, 50));
+
+  tool_tip_string =
+    "Phasing the bins to a given m/z range means that, when performing "
+    "multiple simulations, that m/z range will be constant for each "
+    "simulation.  This means that upon combination of the different simulated "
+    "spectra, the binning will be optimal.";
+  mp_ui->mzRangeGroupBox->setToolTip(
+    libXpertMassCore::Utils::stanzify(tool_tip_string, 50));
+
+  tool_tip_string = "Left-most m/z value in the simulated spectrum";
+  mp_ui->mzRangeStartDoubleSpinBox->setToolTip(
+    libXpertMassCore::Utils::stanzify(tool_tip_string, 50));
+
+  tool_tip_string = "Right-most m/z value in the simulated spectrum";
+  mp_ui->mzRangeStopDoubleSpinBox->setToolTip(
+    libXpertMassCore::Utils::stanzify(tool_tip_string, 50));
+
+  tool_tip_string = "Check the check box and enter the fixed bin size";
+  mp_ui->binSizeGroupBox->setToolTip(
+    libXpertMassCore::Utils::stanzify(tool_tip_string, 50));
+
+  tool_tip_string =
+    "Set this parameter to a larger value if the peaks seem to be spiky";
+  mp_ui->binSizeDoubleSpinBox->setToolTip(
+    libXpertMassCore::Utils::stanzify(tool_tip_string, 50));
+
+  tool_tip_string =
+    "Check that all the entered parameters make a valid configuration";
+  mp_ui->checkParametersPushButton->setToolTip(
+    libXpertMassCore::Utils::stanzify(tool_tip_string, 50));
+
+
+  connect(mp_ui->mzRangeStartDoubleSpinBox,
+          &QDoubleSpinBox::valueChanged,
           this,
-          &MassPeakShaperConfigWidget::referencePeakMzEdited);
+          &MassPeakShaperConfigWidget::computeReferencePeakMzValue);
+
+  connect(mp_ui->mzRangeStopDoubleSpinBox,
+          &QDoubleSpinBox::valueChanged,
+          this,
+          &MassPeakShaperConfigWidget::computeReferencePeakMzValue);
+
+  connect(mp_ui->referenceMzDoubleSpinBox,
+          &QDoubleSpinBox::valueChanged,
+          this,
+          &MassPeakShaperConfigWidget::referencePeakMzValueChanged);
 
   connect(mp_ui->fmwhToBinSizeDivisorSpinBox,
           &QSpinBox::valueChanged,
@@ -313,31 +412,6 @@ MassPeakShaperConfigWidget::setupWidget()
           &QPushButton::clicked,
           this,
           qOverload<>(&MassPeakShaperConfigWidget::checkParameters));
-
-  connect(mp_ui->noBinsCheckBox,
-          &QCheckBox::checkStateChanged,
-          this,
-          &MassPeakShaperConfigWidget::noBinsCheckBoxStateChanged);
-}
-
-/*!
-\brief Signals that the check box widget has changed \a state.
-*/
-void
-MassPeakShaperConfigWidget::noBinsCheckBoxStateChanged(int state)
-{
-  if(state == Qt::Checked)
-    {
-      // The user does not want bins to be used.
-
-      mp_ui->binSizeLogicGroupBox->setEnabled(false);
-      mp_ui->binSizeDoubleSpinBox->setEnabled(false);
-    }
-  else
-    {
-      mp_ui->binSizeLogicGroupBox->setEnabled(true);
-      mp_ui->binSizeDoubleSpinBox->setEnabled(true);
-    }
 }
 
 /*!
@@ -352,11 +426,8 @@ MassPeakShaperConfigWidget::processBinSizeConfig()
   // and do they want to have the bin size configured manually or do they
   // expect that the bin size be determined automatically.
 
-  double bin_size            = 0;
-  bool set_bin_size_manually = mp_ui->binSizeGroupBox->isChecked();
-  bool no_bins               = mp_ui->noBinsCheckBox->isChecked();
-
-  bool ok = false;
+  double bin_size = 0;
+  bool no_bins    = !mp_ui->binSizeLogicGroupBox->isChecked();
 
   // First off, report the usage of bins. If no bins are to be calculated,
   // then it is not necessary to bother with the fwhm / bin_size factor (see
@@ -373,8 +444,11 @@ MassPeakShaperConfigWidget::processBinSizeConfig()
   else
     {
       mp_config->setWithBins(true);
+
       // qDebug() << "The user requests bins, either automatic of manual.";
 
+      bool set_bin_size_manually = mp_ui->binSizeGroupBox->isChecked();
+
       if(set_bin_size_manually)
         {
           // We are checking the manual settings configuration.
@@ -429,10 +503,11 @@ MassPeakShaperConfigWidget::processBinSizeConfig()
           // asked to compute the bin size = fwhm / divisor. An empirically good
           // value is 6.
           mp_config->setBinSizeDivisor(divisor);
-          // qDebug() << "Set bin a size divisor of" << ratio;
 
           mp_config->setBinSizeFixed(false);
 
+          bool ok = false;
+
           double bin_size = mp_config->binSize(&ok);
 
           if(!ok)
@@ -635,19 +710,38 @@ MassPeakShaperConfigWidget::pointCountEditingFinished()
 \brief Signals that the user edited the reference m/z value with text \a text.
 */
 void
-MassPeakShaperConfigWidget::referencePeakMzEdited(const QString &text)
+MassPeakShaperConfigWidget::referencePeakMzValueChanged(double value)
 {
-  bool ok = false;
-
-  double mz = text.toDouble(&ok);
-
-  if(!ok)
+  if(value <= 0)
     {
-      message("Please fix the reference peaks' m/z value.");
+      message("Please fix the reference peak's m/z value.");
       return;
     }
 
-  mp_config->setReferencePeakMz(mz);
+  mp_config->setReferencePeakMz(value);
+}
+
+void
+MassPeakShaperConfigWidget::computeReferencePeakMzValue(double value)
+{
+  Q_UNUSED(value)
+
+  // We update the referencePeakMzValue as the middle value of
+  // the mz range.
+
+  double mz_range_start = mp_ui->mzRangeStartDoubleSpinBox->value();
+  double m_range_stop   = mp_ui->mzRangeStopDoubleSpinBox->value();
+
+  mz_range_start = std::min(mz_range_start, m_range_stop);
+  m_range_stop   = std::max(mz_range_start, m_range_stop);
+
+  if(!m_range_stop)
+    return;
+
+  double middle_mz_range_value =
+    mz_range_start + 0.5 * (m_range_stop - mz_range_start);
+
+  mp_ui->referenceMzDoubleSpinBox->setValue(middle_mz_range_value);
 }
 
 /*!
@@ -779,7 +873,8 @@ MassPeakShaperConfigWidget::setParameters(
   int bin_size_divisor,
   bool should_create_bins)
 {
-  mp_ui->referenceMassLineEdit->setText(QString::number(reference_peak_mz));
+  mp_ui->referenceMzDoubleSpinBox->setValue(reference_peak_mz);
+
   mp_ui->pointCountSpinBox->setValue(point_count);
   if(mass_peak_shape_type ==
      libXpertMassCore::Enums::MassPeakShapeType::GAUSSIAN)
@@ -809,20 +904,19 @@ MassPeakShaperConfigWidget::setParameters(
     }
 
   if(!bin_size_divisor)
-    bin_size_divisor = 6;
+    bin_size_divisor = 1;
 
   mp_ui->fmwhToBinSizeDivisorSpinBox->setValue(bin_size_divisor);
 
-  mp_ui->noBinsCheckBox->setCheckState(should_create_bins ? Qt::Unchecked
-                                                          : Qt::Checked);
+  mp_ui->binSizeLogicGroupBox->setChecked(should_create_bins);
 }
 
 void
 MassPeakShaperConfigWidget::setBinSizeManually(double bin_size,
                                                bool should_create_bins)
 {
-  mp_ui->noBinsCheckBox->setCheckState(should_create_bins ? Qt::Unchecked
-                                                          : Qt::Checked);
+  mp_ui->binSizeLogicGroupBox->setChecked(should_create_bins);
+
   mp_ui->binSizeDoubleSpinBox->setValue(bin_size);
 }
 
@@ -865,11 +959,11 @@ MassPeakShaperConfigWidget::checkParameters(
   // need to check these parameters in a precise order because of these
   // inter-dependencies.
 
-  bool ok = false;
-  m_referencePeakMz =
-    QString(mp_ui->referenceMassLineEdit->text()).toDouble(&ok);
+  /////// The reference peak m/z value (for FWHM calculations) ////////
 
-  if(!ok || m_referencePeakMz <= 0)
+  m_referencePeakMz = mp_ui->referenceMzDoubleSpinBox->value();
+
+  if(m_referencePeakMz <= 0)
     {
       msg = "Please fill in the reference peak m/z value.";
       message(msg);
@@ -878,8 +972,6 @@ MassPeakShaperConfigWidget::checkParameters(
       qDebug() << msg;
     }
 
-  // We need to set back the reference peak centroid because the m_config was
-  // reset above.
   mp_config->setReferencePeakMz(m_referencePeakMz);
 
   // We will need this value for computations below.
@@ -1048,6 +1140,27 @@ MassPeakShaperConfigWidget::checkParameters(
   return true;
 }
 
+bool
+MassPeakShaperConfigWidget::isReferencePeakMzKept() const
+{
+  return mp_ui->keepReferenceMassPushButton->isChecked();
+}
+
+QPair<double, double>
+MassPeakShaperConfigWidget::getMzRangeValuePair() const
+{
+  if(mp_ui->mzRangeGroupBox->isChecked())
+    {
+      double mz_range_start = mp_ui->mzRangeStartDoubleSpinBox->value();
+      double mz_range_stop  = mp_ui->mzRangeStopDoubleSpinBox->value();
+
+      return QPair<double, double>(std::min(mz_range_start, mz_range_stop),
+                                   std::max(mz_range_start, mz_range_stop));
+    }
+
+  return QPair<double, double>(0, 0);
+}
+
 const libXpertMassCore::MassPeakShaperConfig *
 MassPeakShaperConfigWidget::getConfig() const
 {
@@ -1060,7 +1173,7 @@ MassPeakShaperConfigWidget::registerJsConstructor(QJSEngine *engine)
 {
   if(!engine)
     {
-      qWarning()
+      qDebug()
         << "Cannot register MassPeakShaperConfigWidget class: engine is null";
       return;
     }
