@@ -110,7 +110,6 @@ ToleranceWidget::ToleranceWidget(QWidget *parent_p,
   setupWidget(nominal, type);
 }
 
-
 /*!
 \brief Constructs a ToleranceWidget instance.
 
@@ -147,7 +146,6 @@ ToleranceWidget::~ToleranceWidget()
   delete mp_ui;
 }
 
-
 /*!
 \brief Writes the settings of this widget to \a config_settings_file_path for
 later restoration.
@@ -207,10 +205,9 @@ ToleranceWidget::getType() const
   return mp_tolerance->getType();
 }
 
-
 /*!
-\brief Initializes the libXpertMassCore::Tolerance member using \a nominal and \a
-type.
+\brief Initializes the libXpertMassCore::Tolerance member using \a nominal and
+\a type.
 */
 void
 ToleranceWidget::initializeTolerance(double nominal,
@@ -220,21 +217,20 @@ ToleranceWidget::initializeTolerance(double nominal,
   mp_tolerance->setType(type);
 }
 
-
 /*!
-\brief Initializes the libXpertMassCore::Tolerance member using \a nominal and \a
-type.
+\brief Initializes the libXpertMassCore::Tolerance member using \a nominal and
+\a type.
 */
 void
-ToleranceWidget::initializeTolerance(const libXpertMassCore::Tolerance &tolerance)
+ToleranceWidget::initializeTolerance(
+  const libXpertMassCore::Tolerance &tolerance)
 {
   mp_tolerance->initialize(tolerance);
 }
 
-
 /*!
-\brief Initializes the libXpertMassCore::Tolerance member using values read from the
-QSettings settings.
+\brief Initializes the libXpertMassCore::Tolerance member using values read from
+the QSettings settings.
 
 If the settings are not found, the libXpertMassCore::Tolerance member is left
 untouched and has thus default values set in the class declaration.
@@ -273,7 +269,6 @@ ToleranceWidget::initializeToleranceFromSettings()
   return true;
 }
 
-
 /*!
 \brief Sets this widget up for the common data.
 */
@@ -294,12 +289,11 @@ ToleranceWidget::setupWidgetCommon()
           &ToleranceWidget::typeComboBoxValueChanged);
 }
 
-
 /*!
 \brief Sets this widget up.
 
-First the libXpertMassCore::Tolerance member is initialized from QSettings settings,
-if possible. Then the values are set to the widgets.
+First the libXpertMassCore::Tolerance member is initialized from QSettings
+settings, if possible. Then the values are set to the widgets.
 */
 void
 ToleranceWidget::setupWidget()
@@ -308,7 +302,6 @@ ToleranceWidget::setupWidget()
   setupWidgetCommon();
 }
 
-
 /*!
 \brief Sets this widget up using \a nominal and \a type.
 
@@ -316,7 +309,8 @@ The libXpertMassCore::Tolerance member is initialized using the arguments
 and the values are set to the widgets.
 */
 void
-ToleranceWidget::setupWidget(double nominal, libXpertMassCore::Tolerance::Type type)
+ToleranceWidget::setupWidget(double nominal,
+                             libXpertMassCore::Tolerance::Type type)
 {
   initializeTolerance(nominal, type);
   setupWidgetCommon();
