@@ -31,9 +31,9 @@
  */
 /////////////////////// libXpertMassCore includes
 
-#include <libXpertMass/globals.hpp>
-#include <libXpertMass/Utils.hpp>
-#include <libXpertMass/PolChemDef.hpp>
+#include "MsXpS/libXpertMassCore/globals.hpp"
+#include "MsXpS/libXpertMassCore/Utils.hpp"
+#include "MsXpS/libXpertMassCore/PolChemDef.hpp"
 
 /////////////////////// Local includes
 #include "TestUtils.hpp"
@@ -103,8 +103,6 @@ TestUtils::initializePolChemDef(const QString &pol_chem_def_name, int version)
 
   m_isotopeCount = PolChemDef::loadIsotopicData(msp_polChemDef);
 
-  qDebug() << "20241110";
-
   if(!PolChemDef::renderXmlPolChemDefFile(msp_polChemDef))
     {
       qFatalStream() << "Failed to render the PolChemDef.";
