@@ -40,8 +40,8 @@
 
 
 /////////////////////// libXpertMassCore includes
-#include <libXpertMass/Isotope.hpp>
-#include <libXpertMass/PolChemDef.hpp>
+#include "MsXpS/libXpertMassCore/Isotope.hpp"
+#include "MsXpS/libXpertMassCore/PolChemDef.hpp"
 
 
 /////////////////////// Local includes
@@ -91,28 +91,28 @@ class DECLSPEC TestUtils
             "C",
             12.0,
             0.989211941850466902614869013632414862513542175292968750000000);
-  IsotopeQSPtr msp_isotopeC12 = std::make_shared<Isotope>(m_isotopeC12);
+  IsotopeQSPtr msp_isotopeC12 = QSharedPointer<Isotope>::create(m_isotopeC12);
 
   Isotope m_isotopeC13 =
     Isotope("carbon",
             "C",
             13.0033548352,
             0.010788058149533083507343178553128382191061973571777343750000);
-  IsotopeQSPtr msp_isotopeC13 = std::make_shared<Isotope>(m_isotopeC13);
+  IsotopeQSPtr msp_isotopeC13 = QSharedPointer<Isotope>::create(m_isotopeC13);
 
   Isotope m_isotopeN14 =
     Isotope("nitrogen",
             "N",
             14.0030740042,
             0.996358014567941707717579902237048372626304626464843750000000);
-  IsotopeQSPtr msp_isotopeN14 = std::make_shared<Isotope>(m_isotopeN14);
+  IsotopeQSPtr msp_isotopeN14 = QSharedPointer<Isotope>::create(m_isotopeN14);
 
   Isotope m_isotopeN15 =
     Isotope("nitrogen",
             "N",
             15.0001088994,
             0.003641985432058271465738386041266494430601596832275390625000);
-  IsotopeQSPtr msp_isotopeN15 = std::make_shared<Isotope>(m_isotopeN15);
+  IsotopeQSPtr msp_isotopeN15 = QSharedPointer<Isotope>::create(m_isotopeN15);
 
   std::size_t m_isotopeCount = 0;
 
