@@ -14,7 +14,7 @@
 
 /////////////////////// Local includes
 #include "TestUtils.hpp"
-#include <libXpertMass/ChemicalGroupRule.hpp>
+#include "MsXpS/libXpertMassCore/ChemicalGroupRule.hpp"
 
 namespace MsXpS
 {
