@@ -11,9 +11,9 @@
 
 /////////////////////// Local includes
 #include "TestUtils.hpp"
-#include <libXpertMass/CleavageAgent.hpp>
-#include <libXpertMass/Sequence.hpp>
-#include <libXpertMass/Monomer.hpp>
+#include "MsXpS/libXpertMassCore/CleavageAgent.hpp"
+#include "MsXpS/libXpertMassCore/Sequence.hpp"
+#include "MsXpS/libXpertMassCore/Monomer.hpp"
 
 namespace MsXpS
 {
@@ -23,7 +23,7 @@ namespace libXpertMassCore
 TestUtils test_utils_cleavage_agent_1_letter("protein-1-letter", 1);
 TestUtils test_utils_cleavage_agent_3_letters("protein-3-letters", 1);
 
-ErrorList error_list_cleavage_agent;
+ErrorList list_cleavage_agent;
 
 SCENARIO(
   "CleavageAgent objects can be constructed empty and then initialized "
@@ -37,9 +37,10 @@ SCENARIO(
   GIVEN("A CleavageAgent constructed with no parameter at all")
   {
     CleavageAgent cleavage_agent;
+    ErrorList error_list_cleavage_agent;
 
     REQUIRE_FALSE(cleavage_agent.isValid());
-    REQUIRE_FALSE(cleavage_agent.validate(error_list_cleavage_agent));
+    REQUIRE_FALSE(cleavage_agent.validate(&error_list_cleavage_agent));
 
     WHEN("The PolChemDef is set with the setter")
     {
@@ -50,7 +51,7 @@ SCENARIO(
       {
         REQUIRE(cleavage_agent.getPolchemDefCstSPtr() == pol_chem_def_csp);
         REQUIRE_FALSE(cleavage_agent.isValid());
-        REQUIRE_FALSE(cleavage_agent.validate(error_list_cleavage_agent));
+        REQUIRE_FALSE(cleavage_agent.validate(&error_list_cleavage_agent));
       }
 
       AND_WHEN("The name is set with the setter")
@@ -63,7 +64,7 @@ SCENARIO(
           "successfully")
         {
           REQUIRE_FALSE(cleavage_agent.isValid());
-          REQUIRE_FALSE(cleavage_agent.validate(error_list_cleavage_agent));
+          REQUIRE_FALSE(cleavage_agent.validate(&error_list_cleavage_agent));
         }
 
         AND_WHEN("The pattern is set")
@@ -75,10 +76,11 @@ SCENARIO(
             "objects (although no CleavageRule objects)")
           {
             QString expected_text = "Trypsin - K/;-K/P;R/ - 3 motifs - 0 rules";
-            REQUIRE(cleavage_agent.toString().toStdString() == expected_text.toStdString());
+            REQUIRE(cleavage_agent.toString().toStdString() ==
+                    expected_text.toStdString());
 
             REQUIRE(cleavage_agent.isValid());
-            REQUIRE(cleavage_agent.validate(error_list_cleavage_agent));
+            REQUIRE(cleavage_agent.validate(&error_list_cleavage_agent));
 
             REQUIRE(cleavage_agent.getMotifsCstRef().size() == 3);
 
@@ -96,7 +98,7 @@ SCENARIO(
             REQUIRE(cleavage_agent.getMotifsCstRef().at(0)->getOffset() == 1);
             REQUIRE(cleavage_agent.getMotifsCstRef().at(0)->isValid());
             REQUIRE(cleavage_agent.getMotifsCstRef().at(0)->validate(
-              error_list_cleavage_agent));
+              &error_list_cleavage_agent));
 
             REQUIRE(cleavage_agent.getMotifsCstRef()
                       .at(1)
@@ -108,7 +110,7 @@ SCENARIO(
             REQUIRE(cleavage_agent.getMotifsCstRef().at(1)->getOffset() == 1);
             REQUIRE(cleavage_agent.getMotifsCstRef().at(1)->isValid());
             REQUIRE(cleavage_agent.getMotifsCstRef().at(1)->validate(
-              error_list_cleavage_agent));
+              &error_list_cleavage_agent));
 
             REQUIRE(cleavage_agent.getMotifsCstRef()
                       .at(2)
@@ -120,7 +122,7 @@ SCENARIO(
             REQUIRE(cleavage_agent.getMotifsCstRef().at(2)->getOffset() == 1);
             REQUIRE(cleavage_agent.getMotifsCstRef().at(2)->isValid());
             REQUIRE(cleavage_agent.getMotifsCstRef().at(2)->validate(
-              error_list_cleavage_agent));
+              &error_list_cleavage_agent));
           }
         }
       }
@@ -144,6 +146,8 @@ SCENARIO(
       pol_chem_def_csp, "Homoseryl", "A", "+CH3COOH", "M", "-CH2S+O");
     cleavage_agent.getRulesRef().push_back(cleavage_rule_sp);
 
+    ErrorList error_list_cleavage_agent;
+
     cleavage_rule_sp = std::make_shared<CleavageRule>(pol_chem_def_csp,
                                                       "Heteroseryl",
                                                       "C",
@@ -155,7 +159,7 @@ SCENARIO(
     THEN("The CleavageAgent is valid and validates successfully")
     {
       REQUIRE(cleavage_agent.isValid());
-      REQUIRE(cleavage_agent.validate(error_list_cleavage_agent));
+      REQUIRE(cleavage_agent.validate(&error_list_cleavage_agent));
 
       REQUIRE(cleavage_agent.getMotifsCstRef().size() == 3);
 
@@ -167,7 +171,7 @@ SCENARIO(
       REQUIRE(cleavage_agent.getMotifsCstRef().at(0)->getOffset() == 1);
       REQUIRE(cleavage_agent.getMotifsCstRef().at(0)->isValid());
       REQUIRE(cleavage_agent.getMotifsCstRef().at(0)->validate(
-        error_list_cleavage_agent));
+        &error_list_cleavage_agent));
 
       REQUIRE(
         cleavage_agent.getMotifsCstRef().at(1)->getMotif().toStdString() ==
@@ -177,7 +181,7 @@ SCENARIO(
       REQUIRE(cleavage_agent.getMotifsCstRef().at(1)->getOffset() == 1);
       REQUIRE(cleavage_agent.getMotifsCstRef().at(1)->isValid());
       REQUIRE(cleavage_agent.getMotifsCstRef().at(1)->validate(
-        error_list_cleavage_agent));
+        &error_list_cleavage_agent));
 
       REQUIRE(
         cleavage_agent.getMotifsCstRef().at(2)->getMotif().toStdString() ==
@@ -187,71 +191,65 @@ SCENARIO(
       REQUIRE(cleavage_agent.getMotifsCstRef().at(2)->getOffset() == 1);
       REQUIRE(cleavage_agent.getMotifsCstRef().at(2)->isValid());
       REQUIRE(cleavage_agent.getMotifsCstRef().at(2)->validate(
-        error_list_cleavage_agent));
+        &error_list_cleavage_agent));
 
       REQUIRE(cleavage_agent.getRulesCstRef().size() == 2);
     }
 
-    WHEN(
-      "Two other CleavageAgent are either copy-constructed or "
-      "assignment-copied")
+    WHEN("Two other CleavageAgent are pseudo-copy-constructed")
     {
-      CleavageAgent other_cleavage_agent(cleavage_agent);
-      CleavageAgent new_cleavage_agent;
-      new_cleavage_agent = other_cleavage_agent;
+      CleavageAgent other_cleavage_agent(cleavage_agent, Q_NULLPTR);
 
       THEN("They are identical to the original one")
       {
-        REQUIRE(new_cleavage_agent.isValid());
-        REQUIRE(new_cleavage_agent.validate(error_list_cleavage_agent));
+        REQUIRE(other_cleavage_agent.isValid());
+        REQUIRE(other_cleavage_agent.validate(&error_list_cleavage_agent));
 
-        REQUIRE(new_cleavage_agent.getMotifsCstRef().size() == 3);
+        REQUIRE(other_cleavage_agent.getMotifsCstRef().size() == 3);
 
-        REQUIRE(new_cleavage_agent.getMotifsCstRef()
+        REQUIRE(other_cleavage_agent.getMotifsCstRef()
                   .at(0)
                   ->getMotif()
                   .toStdString() == "K");
         REQUIRE(
-          new_cleavage_agent.getMotifsCstRef().at(0)->getCleavageAction() ==
+          other_cleavage_agent.getMotifsCstRef().at(0)->getCleavageAction() ==
           Enums::CleavageAction::CLEAVE);
-        REQUIRE(new_cleavage_agent.getMotifsCstRef().at(0)->getOffset() == 1);
-        REQUIRE(new_cleavage_agent.getMotifsCstRef().at(0)->isValid());
-        REQUIRE(new_cleavage_agent.getMotifsCstRef().at(0)->validate(
-          error_list_cleavage_agent));
+        REQUIRE(other_cleavage_agent.getMotifsCstRef().at(0)->getOffset() == 1);
+        REQUIRE(other_cleavage_agent.getMotifsCstRef().at(0)->isValid());
+        REQUIRE(other_cleavage_agent.getMotifsCstRef().at(0)->validate(
+          &error_list_cleavage_agent));
 
-        REQUIRE(new_cleavage_agent.getMotifsCstRef()
+        REQUIRE(other_cleavage_agent.getMotifsCstRef()
                   .at(1)
                   ->getMotif()
                   .toStdString() == "KP");
         REQUIRE(
-          new_cleavage_agent.getMotifsCstRef().at(1)->getCleavageAction() ==
+          other_cleavage_agent.getMotifsCstRef().at(1)->getCleavageAction() ==
           Enums::CleavageAction::NO_CLEAVE);
-        REQUIRE(new_cleavage_agent.getMotifsCstRef().at(1)->getOffset() == 1);
-        REQUIRE(new_cleavage_agent.getMotifsCstRef().at(1)->isValid());
-        REQUIRE(new_cleavage_agent.getMotifsCstRef().at(1)->validate(
-          error_list_cleavage_agent));
+        REQUIRE(other_cleavage_agent.getMotifsCstRef().at(1)->getOffset() == 1);
+        REQUIRE(other_cleavage_agent.getMotifsCstRef().at(1)->isValid());
+        REQUIRE(other_cleavage_agent.getMotifsCstRef().at(1)->validate(
+          &error_list_cleavage_agent));
 
-        REQUIRE(new_cleavage_agent.getMotifsCstRef()
+        REQUIRE(other_cleavage_agent.getMotifsCstRef()
                   .at(2)
                   ->getMotif()
                   .toStdString() == "R");
         REQUIRE(
-          new_cleavage_agent.getMotifsCstRef().at(2)->getCleavageAction() ==
+          other_cleavage_agent.getMotifsCstRef().at(2)->getCleavageAction() ==
           Enums::CleavageAction::CLEAVE);
-        REQUIRE(new_cleavage_agent.getMotifsCstRef().at(2)->getOffset() == 1);
-        REQUIRE(new_cleavage_agent.getMotifsCstRef().at(2)->isValid());
-        REQUIRE(new_cleavage_agent.getMotifsCstRef().at(2)->validate(
-          error_list_cleavage_agent));
+        REQUIRE(other_cleavage_agent.getMotifsCstRef().at(2)->getOffset() == 1);
+        REQUIRE(other_cleavage_agent.getMotifsCstRef().at(2)->isValid());
+        REQUIRE(other_cleavage_agent.getMotifsCstRef().at(2)->validate(
+          &error_list_cleavage_agent));
 
-        REQUIRE(new_cleavage_agent.getRulesCstRef().size() == 2);
+        REQUIRE(other_cleavage_agent.getRulesCstRef().size() == 2);
       }
 
       THEN("The comparison operators return correct results")
       {
-        REQUIRE(new_cleavage_agent == cleavage_agent);
-        REQUIRE_FALSE(new_cleavage_agent != cleavage_agent);
-        REQUIRE(new_cleavage_agent == new_cleavage_agent);
-        REQUIRE_FALSE(new_cleavage_agent != new_cleavage_agent);
+        REQUIRE(other_cleavage_agent == cleavage_agent);
+        REQUIRE_FALSE(other_cleavage_agent != cleavage_agent);
       }
 
       AND_WHEN("One CleavageAgent's name is modified")
@@ -260,8 +258,8 @@ SCENARIO(
 
         THEN("The comparison operators return correct results")
         {
-          REQUIRE_FALSE(new_cleavage_agent == cleavage_agent);
-          REQUIRE(new_cleavage_agent != cleavage_agent);
+          REQUIRE_FALSE(other_cleavage_agent == cleavage_agent);
+          REQUIRE(other_cleavage_agent != cleavage_agent);
         }
       }
 
@@ -275,15 +273,15 @@ SCENARIO(
         THEN("The comparison operators return correct results")
         {
 
-          REQUIRE_FALSE(new_cleavage_agent == cleavage_agent);
-          REQUIRE(new_cleavage_agent != cleavage_agent);
+          REQUIRE_FALSE(other_cleavage_agent == cleavage_agent);
+          REQUIRE(other_cleavage_agent != cleavage_agent);
         }
       }
 
       AND_WHEN("One CleavageAgent's motif is modified")
       {
-        cleavage_agent = new_cleavage_agent;
-        REQUIRE(new_cleavage_agent == cleavage_agent);
+        cleavage_agent.initialize(other_cleavage_agent);
+        REQUIRE(other_cleavage_agent == cleavage_agent);
 
         cleavage_agent.getMotifsRef().front()->setMotif("M");
 
@@ -298,15 +296,15 @@ SCENARIO(
         {
           // The cleavage agents are still the same, because the
           // Motif is actually MonomerSPtr which are shared.
-          REQUIRE(new_cleavage_agent == cleavage_agent);
-          REQUIRE_FALSE(new_cleavage_agent != cleavage_agent);
+          REQUIRE(other_cleavage_agent == cleavage_agent);
+          REQUIRE_FALSE(other_cleavage_agent != cleavage_agent);
         }
       }
 
       AND_WHEN("One CleavageAgent's cleavage rule is modified")
       {
-        cleavage_agent = new_cleavage_agent;
-        REQUIRE(new_cleavage_agent == cleavage_agent);
+        cleavage_agent.initialize(other_cleavage_agent);
+        REQUIRE(other_cleavage_agent == cleavage_agent);
 
         cleavage_agent.getRulesRef().front()->setLeftCode("G");
 
@@ -319,23 +317,23 @@ SCENARIO(
           "stored as a vector of CleavageRuleSPtr and the modification is done "
           "to the managed object")
         {
-          REQUIRE(new_cleavage_agent == cleavage_agent);
-          REQUIRE_FALSE(new_cleavage_agent != cleavage_agent);
+          REQUIRE(other_cleavage_agent == cleavage_agent);
+          REQUIRE_FALSE(other_cleavage_agent != cleavage_agent);
         }
       }
 
       AND_WHEN("One CleavageAgent's cleavage rule is removed")
       {
-        cleavage_agent = new_cleavage_agent;
-        REQUIRE(new_cleavage_agent == cleavage_agent);
+        cleavage_agent.initialize(other_cleavage_agent);
+        REQUIRE(other_cleavage_agent == cleavage_agent);
 
         cleavage_agent.getRulesRef().erase(
           cleavage_agent.getRulesRef().begin());
 
         THEN("The two CleavageAgent instances are different")
         {
-          REQUIRE_FALSE(new_cleavage_agent == cleavage_agent);
-          REQUIRE(new_cleavage_agent != cleavage_agent);
+          REQUIRE_FALSE(other_cleavage_agent == cleavage_agent);
+          REQUIRE(other_cleavage_agent != cleavage_agent);
         }
       }
     }
@@ -401,7 +399,6 @@ SCENARIO(
   }
 }
 
-
 SCENARIO(
   "CleavageAgent objects can be initialized from a <cls> XML element and "
   "can export themselves as <cla>",
@@ -494,6 +491,8 @@ SCENARIO(
   {
     CleavageAgent cleavage_agent(pol_chem_def_csp);
 
+    ErrorList error_list_cleavage_agent;
+
     AND_WHEN("Initializing it with an XML <cls> element")
     {
       REQUIRE(cleavage_agent.renderXmlClsElement(cleavage_agent_element,
@@ -505,7 +504,7 @@ SCENARIO(
         THEN("The CleavageAgent is valid and validates successfully")
         {
           REQUIRE(cleavage_agent.isValid());
-          REQUIRE(cleavage_agent.validate(error_list_cleavage_agent));
+          REQUIRE(cleavage_agent.validate(&error_list_cleavage_agent));
           REQUIRE(cleavage_agent.getName().toStdString() == "CyanogenBromide");
           REQUIRE(cleavage_agent.getPattern().toStdString() == "M/A");
 
@@ -519,7 +518,7 @@ SCENARIO(
           REQUIRE(cleavage_agent.getMotifsCstRef().at(0)->getOffset() == 1);
           REQUIRE(cleavage_agent.getMotifsCstRef().at(0)->isValid());
           REQUIRE(cleavage_agent.getMotifsCstRef().at(0)->validate(
-            error_list_cleavage_agent));
+            &error_list_cleavage_agent));
 
           REQUIRE(cleavage_agent.getRulesCstRef().size() == 1);
 
@@ -527,8 +526,8 @@ SCENARIO(
 
           CleavageRuleCstSPtr cleavage_rule_csp =
             cleavage_agent.getCleavageRuleCstSPtrByName("Homoseryl");
-            REQUIRE(cleavage_rule_csp != nullptr);
-          REQUIRE(cleavage_rule_csp->validate(error_list_cleavage_agent));
+          REQUIRE(cleavage_rule_csp != nullptr);
+          REQUIRE(cleavage_rule_csp->validate(&error_list_cleavage_agent));
           REQUIRE(cleavage_rule_csp->getName().toStdString() == "Homoseryl");
           REQUIRE(cleavage_rule_csp->getLeftCode().toStdString() == "M");
           REQUIRE(cleavage_rule_csp->getLeftFormula()
@@ -542,7 +541,7 @@ SCENARIO(
           CleavageRuleSPtr cleavage_rule_sp =
             cleavage_agent.getCleavageRuleSPtrByName("Homoseryl");
           REQUIRE(cleavage_rule_sp != nullptr);
-          REQUIRE(cleavage_rule_sp->validate(error_list_cleavage_agent));
+          REQUIRE(cleavage_rule_sp->validate(&error_list_cleavage_agent));
           REQUIRE(cleavage_rule_sp->getName().toStdString() == "Homoseryl");
           REQUIRE(cleavage_rule_sp->getLeftCode().toStdString() == "M");
           REQUIRE(cleavage_rule_sp->getLeftFormula()
@@ -568,6 +567,7 @@ SCENARIO(
     }
   }
 }
+
 SCENARIO(
   "CleavageAgent objects can be initialized from a <cla> XML element and "
   "can "
@@ -646,6 +646,8 @@ SCENARIO(
     "re-mnm-code><re-formula>-CH3COOH</re-formula></clr></cla>";
   expected_cla_string = Utils::unspacify(expected_cla_string);
 
+  ErrorList error_list_cleavage_agent;
+
   REQUIRE(document_string.toStdString() == expected_cla_string.toStdString());
 
   WHEN("Creating a CleavageAgent only with PolChemDef")
@@ -663,7 +665,7 @@ SCENARIO(
         THEN("The CleavageAgent is valid and validates successfully")
         {
           REQUIRE(cleavage_agent.isValid());
-          REQUIRE(cleavage_agent.validate(error_list_cleavage_agent));
+          REQUIRE(cleavage_agent.validate(&error_list_cleavage_agent));
           REQUIRE(cleavage_agent.getName().toStdString() == "CyanogenBromide");
           REQUIRE(cleavage_agent.getPattern().toStdString() == "M/A");
 
@@ -677,14 +679,14 @@ SCENARIO(
           REQUIRE(cleavage_agent.getMotifsCstRef().at(0)->getOffset() == 1);
           REQUIRE(cleavage_agent.getMotifsCstRef().at(0)->isValid());
           REQUIRE(cleavage_agent.getMotifsCstRef().at(0)->validate(
-            error_list_cleavage_agent));
+            &error_list_cleavage_agent));
 
           REQUIRE(cleavage_agent.getRulesCstRef().size() == 1);
 
           CleavageRuleSPtr cleavage_rule_sp =
             cleavage_agent.getCleavageRuleSPtrByName("Homoseryl");
           REQUIRE(cleavage_rule_sp != nullptr);
-          REQUIRE(cleavage_rule_sp->validate(error_list_cleavage_agent));
+          REQUIRE(cleavage_rule_sp->validate(&error_list_cleavage_agent));
           REQUIRE(cleavage_rule_sp->getName().toStdString() == "Homoseryl");
           REQUIRE(cleavage_rule_sp->getLeftCode().toStdString() == "M");
           REQUIRE(cleavage_rule_sp->getLeftFormula()
