@@ -21,13 +21,12 @@
 /////////////////////// Local includes
 #include "tests-config.h"
 #include "TestUtils.hpp"
-#include <libXpertMass/globals.hpp>
-#include <libXpertMass/Polymer.hpp>
-#include <libXpertMass/CrossLink.hpp>
-#include <libXpertMass/CalcOptions.hpp>
-#include <libXpertMass/CleavageConfig.hpp>
-#include <libXpertMass/Cleaver.hpp>
-
+#include "MsXpS/libXpertMassCore/globals.hpp"
+#include "MsXpS/libXpertMassCore/Polymer.hpp"
+#include "MsXpS/libXpertMassCore/CrossLink.hpp"
+#include "MsXpS/libXpertMassCore/CalcOptions.hpp"
+#include "MsXpS/libXpertMassCore/CleavageConfig.hpp"
+#include "MsXpS/libXpertMassCore/Cleaver.hpp"
 
 namespace MsXpS
 {
@@ -37,10 +36,7 @@ TestUtils test_utils_1_letter_cleaver("protein-1-letter", 1);
 
 ErrorList error_list_cleaver;
 
-
-SCENARIO(
-  "Cleaver instances can be copy-constructed",
-  "[Cleaver]")
+SCENARIO("Cleaver instances can be copy-constructed", "[Cleaver]")
 {
   test_utils_1_letter_cleaver.initializeXpertmassLibrary();
 
@@ -56,7 +52,7 @@ SCENARIO(
     "A Polymer instance (as a shared pointer) is first created and data are "
     "loaded from an XML file")
   {
-    PolymerSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
+    PolymerQSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
     REQUIRE(polymer_sp->renderXmlPolymerFile(polymer_file_path));
     REQUIRE(polymer_sp->size() == 240);
 
@@ -97,17 +93,15 @@ SCENARIO(
         THEN("Both Cleaver instances should be identical")
         {
           REQUIRE(other_cleaver.getCleaveAgentName().toStdString() ==
-            cleaver.getCleaveAgentName().toStdString());
+                  cleaver.getCleaveAgentName().toStdString());
 
           REQUIRE(other_cleaver == cleaver);
         }
       }
-
     }
   }
 }
 
-
 SCENARIO(
   "Construction of a Cleaver and use with a Polymer without CrossLink "
   "instances",
@@ -127,7 +121,7 @@ SCENARIO(
     "A Polymer instance (as a shared pointer) is first created and data are "
     "loaded from an XML file")
   {
-    PolymerSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
+    PolymerQSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
     REQUIRE(polymer_sp->renderXmlPolymerFile(polymer_file_path));
     REQUIRE(polymer_sp->size() == 240);
 
@@ -484,7 +478,7 @@ SCENARIO(
     "A Polymer instance (as a shared pointer) is first created and data are "
     "loaded from an XML file")
   {
-    PolymerSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
+    PolymerQSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
     REQUIRE(polymer_sp->renderXmlPolymerFile(polymer_file_path));
     REQUIRE(polymer_sp->size() == 153);
 
@@ -604,7 +598,7 @@ SCENARIO(
     "A Polymer instance (as a shared pointer) is first created and data are "
     "loaded from an XML file")
   {
-    PolymerSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
+    PolymerQSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
 
     REQUIRE(polymer_sp->renderXmlPolymerFile(polymer_file_path));
     REQUIRE(polymer_sp->size() == 153);
@@ -726,7 +720,7 @@ SCENARIO(
     "A Polymer instance (as a shared pointer) is first created and data are "
     "loaded from an XML file")
   {
-    PolymerSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
+    PolymerQSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
     REQUIRE(polymer_sp->renderXmlPolymerFile(polymer_file_path));
     REQUIRE(polymer_sp->size() == 352);
     REQUIRE(polymer_sp->getCrossLinksCstRef().size() == 7);
