@@ -21,7 +21,7 @@
 /////////////////////// Local includes
 #include "tests-config.h"
 #include "TestUtils.hpp"
-#include <libXpertMass/CrossLinker.hpp>
+#include "MsXpS/libXpertMassCore/CrossLinker.hpp"
 
 namespace MsXpS
 {
@@ -82,7 +82,7 @@ SCENARIO("Construction of a CrossLinker with a proper XML element",
       REQUIRE(cross_linker.getPolChemDefCstSPtr() == pol_chem_def_csp);
 
       error_list_cross_linker.clear();
-      REQUIRE(cross_linker.validate(error_list_cross_linker));
+      REQUIRE(cross_linker.validate(&error_list_cross_linker));
       REQUIRE(cross_linker.isValid());
       REQUIRE(cross_linker.getName().toStdString() == "CFP-chromophore");
       REQUIRE(cross_linker.getFormula().toStdString() == "");
@@ -226,7 +226,7 @@ SCENARIO(
     THEN("It is invalid and does not validate successfully")
     {
       error_list_cross_linker.clear();
-      REQUIRE_FALSE(cross_linker.validate(error_list_cross_linker));
+      REQUIRE_FALSE(cross_linker.validate(&error_list_cross_linker));
       REQUIRE_FALSE(cross_linker.isValid());
     }
 
@@ -258,7 +258,7 @@ SCENARIO(
         REQUIRE(cross_linker.getModifsCstRef().size() == 0);
 
         error_list_cross_linker.clear();
-        REQUIRE_FALSE(cross_linker.validate(error_list_cross_linker));
+        REQUIRE_FALSE(cross_linker.validate(&error_list_cross_linker));
         REQUIRE_FALSE(cross_linker.isValid());
       }
     }
@@ -274,7 +274,7 @@ SCENARIO(
     THEN("It is invalid and does not validate successfully")
     {
       error_list_cross_linker.clear();
-      REQUIRE_FALSE(cross_linker.validate(error_list_cross_linker));
+      REQUIRE_FALSE(cross_linker.validate(&error_list_cross_linker));
       REQUIRE_FALSE(cross_linker.isValid());
     }
 
@@ -301,7 +301,7 @@ SCENARIO(
         "data")
       {
         error_list_cross_linker.clear();
-        REQUIRE(cross_linker.validate(error_list_cross_linker));
+        REQUIRE(cross_linker.validate(&error_list_cross_linker));
         REQUIRE(cross_linker.isValid());
         REQUIRE(cross_linker.getName().toStdString() == "CFP-chromophore");
         REQUIRE(cross_linker.getFormula().toStdString() == "");
@@ -348,7 +348,7 @@ SCENARIO(
     THEN("It is invalid and does not validate successfully")
     {
       error_list_cross_linker.clear();
-      REQUIRE_FALSE(cross_linker.validate(error_list_cross_linker));
+      REQUIRE_FALSE(cross_linker.validate(&error_list_cross_linker));
       REQUIRE_FALSE(cross_linker.isValid());
     }
 
@@ -377,7 +377,7 @@ SCENARIO(
       THEN("It is not valid because the XML element is failing")
       {
         error_list_cross_linker.clear();
-        REQUIRE_FALSE(cross_linker.validate(error_list_cross_linker));
+        REQUIRE_FALSE(cross_linker.validate(&error_list_cross_linker));
         REQUIRE_FALSE(cross_linker.isValid());
       }
     }
@@ -409,7 +409,7 @@ SCENARIO(
       THEN("It is not valid because the XML element is failing")
       {
         error_list_cross_linker.clear();
-        REQUIRE_FALSE(cross_linker.validate(error_list_cross_linker));
+        REQUIRE_FALSE(cross_linker.validate(&error_list_cross_linker));
         REQUIRE_FALSE(cross_linker.isValid());
       }
     }
@@ -482,7 +482,7 @@ SCENARIO("Construction of a CrossLinker starting from empty with the setters",
     THEN("It is invalid and does not validate successfully")
     {
       error_list_cross_linker.clear();
-      REQUIRE_FALSE(cross_linker.validate(error_list_cross_linker));
+      REQUIRE_FALSE(cross_linker.validate(&error_list_cross_linker));
       REQUIRE_FALSE(cross_linker.isValid());
     }
 
@@ -511,7 +511,7 @@ SCENARIO("Construction of a CrossLinker starting from empty with the setters",
         "data")
       {
         error_list_cross_linker.clear();
-        REQUIRE(cross_linker.validate(error_list_cross_linker));
+        REQUIRE(cross_linker.validate(&error_list_cross_linker));
         REQUIRE(cross_linker.isValid());
         REQUIRE(cross_linker.getName().toStdString() == "CFP-chromophore");
         REQUIRE(cross_linker.getFormula().toStdString() == "");
@@ -561,7 +561,7 @@ SCENARIO("CrossLinker instances can be set and removed Modif instances",
       "data")
     {
       error_list_cross_linker.clear();
-      REQUIRE(cross_linker.validate(error_list_cross_linker));
+      REQUIRE(cross_linker.validate(&error_list_cross_linker));
       REQUIRE(cross_linker.isValid());
       REQUIRE(cross_linker.getName().toStdString() == "CFP-chromophore");
       REQUIRE(cross_linker.getFormula().toStdString() == "-H2O");
@@ -686,7 +686,7 @@ SCENARIO(
       "data")
     {
       error_list_cross_linker.clear();
-      REQUIRE(cross_linker.validate(error_list_cross_linker));
+      REQUIRE(cross_linker.validate(&error_list_cross_linker));
       REQUIRE(cross_linker.isValid());
       REQUIRE(cross_linker.getName().toStdString() == "CFP-chromophore");
       REQUIRE(cross_linker.getFormula().toStdString() == "-H2O");
@@ -702,7 +702,7 @@ SCENARIO(
 
       THEN("All the members should be identical in both instances")
       {
-        REQUIRE(new_cross_linker.validate(error_list_cross_linker));
+        REQUIRE(new_cross_linker.validate(&error_list_cross_linker));
         REQUIRE(new_cross_linker.isValid());
         REQUIRE(new_cross_linker.getName().toStdString() == "CFP-chromophore");
         REQUIRE(new_cross_linker.getFormula().toStdString() == "-H2O");
@@ -732,7 +732,7 @@ SCENARIO(
 
       THEN("All the members should be identical in both instances")
       {
-        REQUIRE(new_cross_linker.validate(error_list_cross_linker));
+        REQUIRE(new_cross_linker.validate(&error_list_cross_linker));
         REQUIRE(new_cross_linker.isValid());
         REQUIRE(new_cross_linker.getName().toStdString() == "CFP-chromophore");
         REQUIRE(new_cross_linker.getFormula().toStdString() == "-H2O");
@@ -823,7 +823,7 @@ SCENARIO(
       "data")
     {
       error_list_cross_linker.clear();
-      REQUIRE(cross_linker.validate(error_list_cross_linker));
+      REQUIRE(cross_linker.validate(&error_list_cross_linker));
       REQUIRE(cross_linker.isValid());
       REQUIRE(cross_linker.getName().toStdString() == "CFP-chromophore");
       REQUIRE(cross_linker.getFormula().toStdString() == "");
