@@ -18,17 +18,16 @@
 
 
 /////////////////////// libXpertMassCore includes
-#include <libXpertMass/Utils.hpp>
-#include <libXpertMass/Isotope.hpp>
-#include <libXpertMass/IsotopicDataLibraryHandler.hpp>
-#include <libXpertMass/Formula.hpp>
+#include "MsXpS/libXpertMassCore/Utils.hpp"
+#include "MsXpS/libXpertMassCore/Isotope.hpp"
+#include "MsXpS/libXpertMassCore/IsotopicDataLibraryHandler.hpp"
+#include "MsXpS/libXpertMassCore/Formula.hpp"
 
 
 /////////////////////// Local includes
 #include "tests-config.h"
 #include "TestUtils.hpp"
 
-
 namespace MsXpS
 {
 namespace libXpertMassCore
@@ -49,7 +48,7 @@ SCENARIO("Construction of Formula with no action-formula string", "[Formula]")
   IsotopicDataCstSPtr isotopic_data_csp = nullptr;
 
   REQUIRE(loaded_isotope_count + non_isotope_skipped_items ==
-          IsoSpec::isospec_number_of_isotopic_entries);
+          static_cast<qsizetype>(IsoSpec::isospec_number_of_isotopic_entries));
 
   isotopic_data_csp = isotopic_data_library_handler.getIsotopicData();
   REQUIRE(isotopic_data_csp->size() == loaded_isotope_count);
@@ -69,7 +68,7 @@ SCENARIO("Construction of Formula with no action-formula string", "[Formula]")
 
       THEN("The formula cannot validate succesfully")
       {
-        REQUIRE_FALSE(formula.validate(isotopic_data_csp, error_list_formula));
+        REQUIRE_FALSE(formula.validate(isotopic_data_csp, &error_list_formula));
         REQUIRE_FALSE(formula.isValid());
       }
     }
@@ -179,7 +178,7 @@ SCENARIO("Construction of Formula with no action-formula string", "[Formula]")
         QString new_action_formula_string =
           test_utils_formula.m_actionFormulaStringMetAlaDipeptidyl;
         new_action_formula_string += "+Hh2O";
-        bool result = formula.appendActionFormula("+Hh2O");
+        bool result                = formula.appendActionFormula("+Hh2O");
 
         // qDebug() << "The action-formula:" << formula.getActionFormula();
         // qDebug() << "The action-formula with title:"
@@ -201,7 +200,7 @@ SCENARIO("Construction of Formula with no action-formula string", "[Formula]")
           THEN("The validation fails")
           {
             REQUIRE_FALSE(
-              formula.validate(isotopic_data_csp, error_list_formula));
+              formula.validate(isotopic_data_csp, &error_list_formula));
           }
 
           AND_WHEN("The masses are accounted")
@@ -224,7 +223,7 @@ SCENARIO("Construction of Formula with no action-formula string", "[Formula]")
         QString new_action_formula_string =
           test_utils_formula.m_actionFormulaStringMetAlaDipeptidyl;
         new_action_formula_string += "+H2O";
-        bool result = formula.appendActionFormula("+H2O");
+        bool result                = formula.appendActionFormula("+H2O");
 
         THEN("The formula is changed")
         {
@@ -353,15 +352,16 @@ SCENARIO(
 
       IsotopicDataCstSPtr isotopic_data_csp = nullptr;
 
-      REQUIRE(loaded_isotope_count + non_isotope_skipped_items ==
-              IsoSpec::isospec_number_of_isotopic_entries);
+      REQUIRE(
+        loaded_isotope_count + non_isotope_skipped_items ==
+        static_cast<qsizetype>(IsoSpec::isospec_number_of_isotopic_entries));
 
       isotopic_data_csp = isotopic_data_library_handler.getIsotopicData();
       REQUIRE(isotopic_data_csp->size() == loaded_isotope_count);
 
       THEN("The formula validates succesfully")
       {
-        REQUIRE(formula.validate(isotopic_data_csp, error_list_formula));
+        REQUIRE(formula.validate(isotopic_data_csp, &error_list_formula));
         REQUIRE(formula.isValid());
       }
     }
@@ -522,11 +522,8 @@ SCENARIO(
   Formula titled_formula_MA_dipeptidyl(
     test_utils_formula.m_actionFormulaStringMetAlaDipeptidylTitled);
 
-  WHEN("Checked without forcing an index even for single atoms")
+  WHEN("Checked")
   {
-    formula_MA_dipeptidyl.setForceCountIndex(false);
-    titled_formula_MA_dipeptidyl.setForceCountIndex(false);
-
     THEN("Checking succeeds")
     {
       REQUIRE(formula_MA_dipeptidyl.checkSyntax());
@@ -539,29 +536,9 @@ SCENARIO(
       REQUIRE_FALSE(titled_formula_MA_dipeptidyl.isValid());
     }
   }
-
-  AND_WHEN("Checked with forcing an index even for single atoms")
-  {
-    formula_MA_dipeptidyl.setForceCountIndex(true);
-    titled_formula_MA_dipeptidyl.setForceCountIndex(true);
-
-    THEN("Checking fails")
-    {
-
-      REQUIRE(formula_MA_dipeptidyl.checkSyntax() == false);
-      REQUIRE(titled_formula_MA_dipeptidyl.checkSyntax() == false);
-    }
-
-    THEN("The formula is not valid")
-    {
-      REQUIRE_FALSE(formula_MA_dipeptidyl.isValid());
-      REQUIRE_FALSE(titled_formula_MA_dipeptidyl.isValid());
-    }
-  }
   AND_WHEN("Checking an invalid Formula starting with a cipher")
   {
     Formula formula("3Cz3H12O6N14L2");
-    formula.setForceCountIndex(false);
 
     THEN("Checking fails")
     {
@@ -574,14 +551,12 @@ SCENARIO(
       REQUIRE_FALSE(titled_formula_MA_dipeptidyl.isValid());
     }
   }
-
   AND_WHEN(
     "Checking an invalid Formula ending not with an alphabetic character or "
     "a "
     "number")
   {
     Formula formula("Cz3H12O6N14L2§");
-    formula.setForceCountIndex(false);
 
     THEN("Checking fails")
     {
@@ -610,7 +585,7 @@ SCENARIO(
   IsotopicDataCstSPtr isotopic_data_csp = nullptr;
 
   REQUIRE(loaded_isotope_count + non_isotope_skipped_items ==
-          IsoSpec::isospec_number_of_isotopic_entries);
+          static_cast<qsizetype>(IsoSpec::isospec_number_of_isotopic_entries));
 
   isotopic_data_csp = isotopic_data_library_handler.getIsotopicData();
   REQUIRE(isotopic_data_csp->size() == loaded_isotope_count);
@@ -642,11 +617,11 @@ SCENARIO(
       "function)")
     {
       REQUIRE(
-        formula_MA_dipeptidyl.validate(isotopic_data_csp, error_list_formula));
+        formula_MA_dipeptidyl.validate(isotopic_data_csp, &error_list_formula));
       REQUIRE(formula_MA_dipeptidyl.isValid());
 
       REQUIRE(titled_formula_MA_dipeptidyl.validate(isotopic_data_csp,
-                                                    error_list_formula));
+                                                    &error_list_formula));
       REQUIRE(titled_formula_MA_dipeptidyl.isValid());
 
       THEN(
@@ -690,12 +665,16 @@ SCENARIO(
       "Explicitely validated with reset and store set to true, the Formula "
       "creates + and - subformulas")
     {
-      REQUIRE(formula_MA_dipeptidyl.validate(
-        isotopic_data_csp, /*store*/ true, /*reset*/ true, error_list_formula));
+      REQUIRE(formula_MA_dipeptidyl.validate(isotopic_data_csp,
+                                             /*store*/ true,
+                                             /*reset*/ true,
+                                             &error_list_formula));
       REQUIRE(formula_MA_dipeptidyl.isValid());
 
-      REQUIRE(titled_formula_MA_dipeptidyl.validate(
-        isotopic_data_csp, /*store*/ true, /*reset*/ true, error_list_formula));
+      REQUIRE(titled_formula_MA_dipeptidyl.validate(isotopic_data_csp,
+                                                    /*store*/ true,
+                                                    /*reset*/ true,
+                                                    &error_list_formula));
       REQUIRE(titled_formula_MA_dipeptidyl.isValid());
 
       THEN("The + and - sub formulas are checked")
@@ -752,13 +731,13 @@ SCENARIO(
         REQUIRE(formula_MA_dipeptidyl.validate(isotopic_data_csp,
                                                /*store*/ true,
                                                /*reset*/ false,
-                                               error_list_formula));
+                                               &error_list_formula));
         REQUIRE(formula_MA_dipeptidyl.isValid());
 
         REQUIRE(titled_formula_MA_dipeptidyl.validate(isotopic_data_csp,
                                                       /*store*/ true,
                                                       /*reset*/ false,
-                                                      error_list_formula));
+                                                      &error_list_formula));
         REQUIRE(titled_formula_MA_dipeptidyl.isValid());
 
         THEN("The + and - sub formulas are checked")
@@ -823,7 +802,7 @@ SCENARIO("Formula validation can fail in a number of ways", "[Formula]")
   IsotopicDataCstSPtr isotopic_data_csp = nullptr;
 
   REQUIRE(loaded_isotope_count + non_isotope_skipped_items ==
-          IsoSpec::isospec_number_of_isotopic_entries);
+          static_cast<qsizetype>(IsoSpec::isospec_number_of_isotopic_entries));
 
   isotopic_data_csp = isotopic_data_library_handler.getIsotopicData();
   REQUIRE(isotopic_data_csp->size() == loaded_isotope_count);
@@ -842,10 +821,10 @@ SCENARIO("Formula validation can fail in a number of ways", "[Formula]")
     WHEN("Explicitely validated against reference isotopic data")
     {
       REQUIRE_FALSE(
-        invalid_formula.validate(isotopic_data_csp, error_list_formula));
+        invalid_formula.validate(isotopic_data_csp, &error_list_formula));
 
       REQUIRE_FALSE(invalid_formula_with_title.validate(isotopic_data_csp,
-                                                        error_list_formula));
+                                                        &error_list_formula));
 
       THEN("They persit to be invalid")
       {
@@ -871,9 +850,9 @@ SCENARIO("Formula validation can fail in a number of ways", "[Formula]")
         AND_WHEN("The formula is explicitely validated")
         {
           REQUIRE(
-            invalid_formula.validate(isotopic_data_csp, error_list_formula));
+            invalid_formula.validate(isotopic_data_csp, &error_list_formula));
           REQUIRE(invalid_formula_with_title.validate(isotopic_data_csp,
-                                                      error_list_formula));
+                                                      &error_list_formula));
 
           THEN("It becomes valid because the new formula was correct")
           {
@@ -891,7 +870,6 @@ SCENARIO("Formula validation can fail in a number of ways", "[Formula]")
               REQUIRE(invalid_formula.getActionFormula().toStdString() == "");
               REQUIRE(invalid_formula.getPlusFormula().toStdString() == "");
               REQUIRE(invalid_formula.getMinusFormula().toStdString() == "");
-              REQUIRE(invalid_formula.isForceCountIndex() == false);
               REQUIRE(invalid_formula.getSymbolCountMapCstRef().size() == 0);
             }
           }
@@ -915,7 +893,7 @@ SCENARIO(
   IsotopicDataCstSPtr isotopic_data_csp = nullptr;
 
   REQUIRE(loaded_isotope_count + non_isotope_skipped_items ==
-          IsoSpec::isospec_number_of_isotopic_entries);
+          static_cast<qsizetype>(IsoSpec::isospec_number_of_isotopic_entries));
 
   isotopic_data_csp = isotopic_data_library_handler.getIsotopicData();
   REQUIRE(isotopic_data_csp->size() == loaded_isotope_count);
@@ -927,8 +905,10 @@ SCENARIO(
 
     WHEN("That formula is validated succesfully with store set to true")
     {
-      REQUIRE(formula_MA_dipeptidyl.validate(
-        isotopic_data_csp, /*store*/ true, /*reset*/ true, error_list_formula));
+      REQUIRE(formula_MA_dipeptidyl.validate(isotopic_data_csp,
+                                             /*store*/ true,
+                                             /*reset*/ true,
+                                             &error_list_formula));
       REQUIRE(formula_MA_dipeptidyl.isValid());
 
       THEN("The sub-formulas need to be correct")
@@ -987,7 +967,7 @@ SCENARIO("Various ways to account a Formula for its masses (mono, avg)",
   IsotopicDataCstSPtr isotopic_data_csp = nullptr;
 
   REQUIRE(loaded_isotope_count + non_isotope_skipped_items ==
-          IsoSpec::isospec_number_of_isotopic_entries);
+          static_cast<qsizetype>(IsoSpec::isospec_number_of_isotopic_entries));
 
   isotopic_data_csp = isotopic_data_library_handler.getIsotopicData();
   REQUIRE(isotopic_data_csp->size() == loaded_isotope_count);
@@ -1002,7 +982,7 @@ SCENARIO("Various ways to account a Formula for its masses (mono, avg)",
       REQUIRE(formula_MA_dipeptidyl.validate(isotopic_data_csp,
                                              /*store*/ true,
                                              /*reset*/ false,
-                                             error_list_formula));
+                                             &error_list_formula));
 
       THEN("It becomes valid")
       {
@@ -1016,7 +996,7 @@ SCENARIO("Various ways to account a Formula for its masses (mono, avg)",
         "That formula is validated with adequate options, its other member "
         "data are updated")
       {
-        formula_MA_dipeptidyl.validate(isotopic_data_csp, error_list_formula);
+        formula_MA_dipeptidyl.validate(isotopic_data_csp, &error_list_formula);
 
         THEN("The + and - sub formulas are checked")
         {
@@ -1091,8 +1071,9 @@ SCENARIO("Various ways to account a Formula for its masses (mono, avg)",
               REQUIRE_FALSE(another_formula != formula_MA_dipeptidyl);
 
               REQUIRE(another_formula.getSymbolCountMapCstRef().size() ==
-               formula_MA_dipeptidyl.getSymbolCountMapCstRef().size());
-              REQUIRE(another_formula.getSymbolCountMapCstRef() == formula_MA_dipeptidyl.getSymbolCountMapCstRef());
+                      formula_MA_dipeptidyl.getSymbolCountMapCstRef().size());
+              REQUIRE(another_formula.getSymbolCountMapCstRef() ==
+                      formula_MA_dipeptidyl.getSymbolCountMapCstRef());
 
               //  This is the formula:
               // "+C5H11N1O2S1-H2O+C3H7N1O2-H2O"
@@ -1104,48 +1085,64 @@ SCENARIO("Various ways to account a Formula for its masses (mono, avg)",
               //  "C8H14N2O2S1"
               // So we can check the atom symbol count map.
 
-              qDebug() <<  "Compare atom symbol count for C";
-              auto iter = formula_MA_dipeptidyl.getSymbolCountMapCstRef().find("C");
-              auto another_iter = another_formula.getSymbolCountMapCstRef().find("C");
+              qDebug() << "Compare atom symbol count for C";
+              auto iter =
+                formula_MA_dipeptidyl.getSymbolCountMapCstRef().find("C");
+              auto another_iter =
+                another_formula.getSymbolCountMapCstRef().find("C");
 
-              REQUIRE(iter !=  formula_MA_dipeptidyl.getSymbolCountMapCstRef().end());
-              REQUIRE(another_iter !=  another_formula.getSymbolCountMapCstRef().end());
+              REQUIRE(iter !=
+                      formula_MA_dipeptidyl.getSymbolCountMapCstRef().end());
+              REQUIRE(another_iter !=
+                      another_formula.getSymbolCountMapCstRef().end());
 
               REQUIRE((*iter).second == (*another_iter).second);
 
-              qDebug() <<  "Compare atom symbol count for H";
+              qDebug() << "Compare atom symbol count for H";
               iter = formula_MA_dipeptidyl.getSymbolCountMapCstRef().find("H");
-              another_iter = another_formula.getSymbolCountMapCstRef().find("H");
+              another_iter =
+                another_formula.getSymbolCountMapCstRef().find("H");
 
-              REQUIRE(iter !=  formula_MA_dipeptidyl.getSymbolCountMapCstRef().end());
-              REQUIRE(another_iter !=  another_formula.getSymbolCountMapCstRef().end());
+              REQUIRE(iter !=
+                      formula_MA_dipeptidyl.getSymbolCountMapCstRef().end());
+              REQUIRE(another_iter !=
+                      another_formula.getSymbolCountMapCstRef().end());
 
               REQUIRE((*iter).second == (*another_iter).second);
 
-              qDebug() <<  "Compare atom symbol count for N";
+              qDebug() << "Compare atom symbol count for N";
               iter = formula_MA_dipeptidyl.getSymbolCountMapCstRef().find("N");
-              another_iter = another_formula.getSymbolCountMapCstRef().find("N");
+              another_iter =
+                another_formula.getSymbolCountMapCstRef().find("N");
 
-              REQUIRE(iter !=  formula_MA_dipeptidyl.getSymbolCountMapCstRef().end());
-              REQUIRE(another_iter !=  another_formula.getSymbolCountMapCstRef().end());
+              REQUIRE(iter !=
+                      formula_MA_dipeptidyl.getSymbolCountMapCstRef().end());
+              REQUIRE(another_iter !=
+                      another_formula.getSymbolCountMapCstRef().end());
 
               REQUIRE((*iter).second == (*another_iter).second);
 
-              qDebug() <<  "Compare atom symbol count for O";
+              qDebug() << "Compare atom symbol count for O";
               iter = formula_MA_dipeptidyl.getSymbolCountMapCstRef().find("O");
-              another_iter = another_formula.getSymbolCountMapCstRef().find("O");
+              another_iter =
+                another_formula.getSymbolCountMapCstRef().find("O");
 
-              REQUIRE(iter !=  formula_MA_dipeptidyl.getSymbolCountMapCstRef().end());
-              REQUIRE(another_iter !=  another_formula.getSymbolCountMapCstRef().end());
+              REQUIRE(iter !=
+                      formula_MA_dipeptidyl.getSymbolCountMapCstRef().end());
+              REQUIRE(another_iter !=
+                      another_formula.getSymbolCountMapCstRef().end());
 
               REQUIRE((*iter).second == (*another_iter).second);
 
-              qDebug() <<  "Compare atom symbol count for S";
+              qDebug() << "Compare atom symbol count for S";
               iter = formula_MA_dipeptidyl.getSymbolCountMapCstRef().find("S");
-              another_iter = another_formula.getSymbolCountMapCstRef().find("S");
+              another_iter =
+                another_formula.getSymbolCountMapCstRef().find("S");
 
-              REQUIRE(iter !=  formula_MA_dipeptidyl.getSymbolCountMapCstRef().end());
-              REQUIRE(another_iter !=  another_formula.getSymbolCountMapCstRef().end());
+              REQUIRE(iter !=
+                      formula_MA_dipeptidyl.getSymbolCountMapCstRef().end());
+              REQUIRE(another_iter !=
+                      another_formula.getSymbolCountMapCstRef().end());
 
               REQUIRE((*iter).second == (*another_iter).second);
             }
@@ -1238,7 +1235,7 @@ SCENARIO("Formula instances can be scrutinized in various ways", "[Formula]")
   IsotopicDataCstSPtr isotopic_data_csp = nullptr;
 
   REQUIRE(loaded_isotope_count + non_isotope_skipped_items ==
-          IsoSpec::isospec_number_of_isotopic_entries);
+          static_cast<qsizetype>(IsoSpec::isospec_number_of_isotopic_entries));
 
   isotopic_data_csp = isotopic_data_library_handler.getIsotopicData();
   REQUIRE(isotopic_data_csp->size() == loaded_isotope_count);
@@ -1253,7 +1250,7 @@ SCENARIO("Formula instances can be scrutinized in various ways", "[Formula]")
       REQUIRE(formula_MA_dipeptidyl.validate(isotopic_data_csp,
                                              /*store*/ true,
                                              /*reset*/ false,
-                                             error_list_formula));
+                                             &error_list_formula));
 
       THEN("It becomes valid")
       {
