@@ -11,7 +11,7 @@
 
 /////////////////////// Local includes
 #include "TestUtils.hpp"
-#include <libXpertMass/FragmentationPathway.hpp>
+#include "MsXpS/libXpertMassCore/FragmentationPathway.hpp"
 
 namespace MsXpS
 {
@@ -39,7 +39,7 @@ SCENARIO(
 
     REQUIRE_FALSE(fragmentation_pathway.isValid());
     REQUIRE_FALSE(
-      fragmentation_pathway.validate(error_list_fragmentation_pathway));
+      fragmentation_pathway.validate(&error_list_fragmentation_pathway));
 
     // <fgs>
     //   <name>a</name>
@@ -67,7 +67,7 @@ SCENARIO(
       {
         REQUIRE_FALSE(fragmentation_pathway.isValid());
         REQUIRE_FALSE(
-          fragmentation_pathway.validate(error_list_fragmentation_pathway));
+          fragmentation_pathway.validate(&error_list_fragmentation_pathway));
       }
 
       AND_WHEN("The name is set with the setter")
@@ -80,7 +80,7 @@ SCENARIO(
         {
           REQUIRE_FALSE(fragmentation_pathway.isValid());
           REQUIRE_FALSE(
-            fragmentation_pathway.validate(error_list_fragmentation_pathway));
+            fragmentation_pathway.validate(&error_list_fragmentation_pathway));
 
           AND_THEN("A FragmentationPathway can be gotten from the PolChemDef")
           {
@@ -103,7 +103,7 @@ SCENARIO(
           {
             REQUIRE_FALSE(fragmentation_pathway.isValid());
             REQUIRE_FALSE(
-              fragmentation_pathway.validate(error_list_fragmentation_pathway));
+              fragmentation_pathway.validate(&error_list_fragmentation_pathway));
           }
 
           AND_WHEN("The formula is set with one of the setters")
@@ -116,7 +116,7 @@ SCENARIO(
             {
               REQUIRE(fragmentation_pathway.isValid());
               REQUIRE(fragmentation_pathway.validate(
-                error_list_fragmentation_pathway));
+                &error_list_fragmentation_pathway));
             }
             AND_WHEN("The formula is set with other of the setters")
             {
@@ -128,7 +128,7 @@ SCENARIO(
               {
                 REQUIRE(fragmentation_pathway.isValid());
                 REQUIRE(fragmentation_pathway.validate(
-                  error_list_fragmentation_pathway));
+                  &error_list_fragmentation_pathway));
               }
 
               AND_WHEN("The comment is set with the setter")
@@ -141,7 +141,7 @@ SCENARIO(
                 {
                   REQUIRE(fragmentation_pathway.isValid());
                   REQUIRE(fragmentation_pathway.validate(
-                    error_list_fragmentation_pathway));
+                    &error_list_fragmentation_pathway));
                 }
 
                 AND_WHEN("A correct FragmentationRule is added")
@@ -172,7 +172,7 @@ SCENARIO(
                   {
                     REQUIRE(fragmentation_pathway.isValid());
                     REQUIRE(fragmentation_pathway.validate(
-                      error_list_fragmentation_pathway));
+                      &error_list_fragmentation_pathway));
 
                     REQUIRE(fragmentation_pathway.getName().toStdString() ==
                             "a");
@@ -229,7 +229,7 @@ SCENARIO(
     THEN("The FragmentationPathway is valid and does validate successfully")
     {
       REQUIRE(fragmentation_pathway.isValid());
-      REQUIRE(fragmentation_pathway.validate(error_list_fragmentation_pathway));
+      REQUIRE(fragmentation_pathway.validate(&error_list_fragmentation_pathway));
 
       REQUIRE(fragmentation_pathway.getName().toStdString() == "a");
       REQUIRE(fragmentation_pathway.getFragEnd() == Enums::FragEnd::LE);
@@ -258,7 +258,7 @@ SCENARIO(
       {
         REQUIRE(new_fragmentation_pathway.isValid());
         REQUIRE(
-          new_fragmentation_pathway.validate(error_list_fragmentation_pathway));
+          new_fragmentation_pathway.validate(&error_list_fragmentation_pathway));
 
         REQUIRE(new_fragmentation_pathway.getName().toStdString() == "a");
         REQUIRE(new_fragmentation_pathway.getFragEnd() == Enums::FragEnd::LE);
@@ -341,7 +341,7 @@ SCENARIO(
     THEN("The FragmentationPathway is valid and does validate successfully")
     {
       REQUIRE(fragmentation_pathway.isValid());
-      REQUIRE(fragmentation_pathway.validate(error_list_fragmentation_pathway));
+      REQUIRE(fragmentation_pathway.validate(&error_list_fragmentation_pathway));
 
       REQUIRE(fragmentation_pathway.getName().toStdString() == "a");
       REQUIRE(fragmentation_pathway.getFragEnd() == Enums::FragEnd::LE);
@@ -362,7 +362,7 @@ SCENARIO(
       {
         REQUIRE(new_fragmentation_pathway.isValid());
         REQUIRE(
-          new_fragmentation_pathway.validate(error_list_fragmentation_pathway));
+          new_fragmentation_pathway.validate(&error_list_fragmentation_pathway));
 
         REQUIRE(new_fragmentation_pathway.getName().toStdString() == "a");
         REQUIRE(new_fragmentation_pathway.getFragEnd() == Enums::FragEnd::LE);
@@ -394,7 +394,7 @@ SCENARIO(
       {
         REQUIRE(new_fragmentation_pathway.isValid());
         REQUIRE(
-          new_fragmentation_pathway.validate(error_list_fragmentation_pathway));
+          new_fragmentation_pathway.validate(&error_list_fragmentation_pathway));
 
         REQUIRE(new_fragmentation_pathway.getName().toStdString() == "a");
         REQUIRE(new_fragmentation_pathway.getFragEnd() == Enums::FragEnd::LE);
@@ -552,7 +552,7 @@ SCENARIO(
         {
           REQUIRE(fragmentation_pathway.isValid());
           REQUIRE(
-            fragmentation_pathway.validate(error_list_fragmentation_pathway));
+            fragmentation_pathway.validate(&error_list_fragmentation_pathway));
 
           REQUIRE(fragmentation_pathway.getName().toStdString() == "a");
           REQUIRE(fragmentation_pathway.getFragEnd() == Enums::FragEnd::LE);
