@@ -21,13 +21,12 @@
 /////////////////////// Local includes
 #include "tests-config.h"
 #include "TestUtils.hpp"
-#include <libXpertMass/globals.hpp>
-#include <libXpertMass/Polymer.hpp>
-#include <libXpertMass/CrossLink.hpp>
-#include <libXpertMass/CalcOptions.hpp>
-#include <libXpertMass/FragmentationConfig.hpp>
-#include <libXpertMass/Fragmenter.hpp>
-
+#include "MsXpS/libXpertMassCore/globals.hpp"
+#include "MsXpS/libXpertMassCore/Polymer.hpp"
+#include "MsXpS/libXpertMassCore/CrossLink.hpp"
+#include "MsXpS/libXpertMassCore/CalcOptions.hpp"
+#include "MsXpS/libXpertMassCore/FragmentationConfig.hpp"
+#include "MsXpS/libXpertMassCore/Fragmenter.hpp"
 
 namespace MsXpS
 {
@@ -37,6 +36,90 @@ TestUtils test_utils_1_letter_fragmenter("protein-1-letter", 1);
 
 ErrorList error_list_fragmenter;
 
+SCENARIO("Construction of a Fragmenter", "[Fragmenter]")
+{
+  test_utils_1_letter_fragmenter.initializeXpertmassLibrary();
+
+  PolChemDefCstSPtr pol_chem_def_csp =
+    test_utils_1_letter_fragmenter.msp_polChemDef;
+
+  QString polymer_file_path = QString("%1/polymer-sequences/%2")
+                                .arg(TESTS_INPUT_DIR)
+                                .arg("chicken-telokin.mxp");
+
+  PolymerQSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
+  REQUIRE(polymer_sp->renderXmlPolymerFile(polymer_file_path));
+  REQUIRE(polymer_sp->size() == 157);
+
+  FragmentationConfig immo_frag_config(polymer_sp->getPolChemDefCstSPtr(),
+                                       "imm",
+                                       "-C1O1",
+                                       Enums::FragEnd::NE,
+                                       "immonium ions",
+                                       /*sequence_embedded*/ false);
+
+  FragmentationConfig a_frag_config(polymer_sp->getPolChemDefCstSPtr(),
+                                    "a",
+                                    "-C1O1H1",
+                                    Enums::FragEnd::LE,
+                                    "a series ions",
+                                    /*sequence_embedded*/ false);
+
+  FragmentationConfig b_frag_config(polymer_sp->getPolChemDefCstSPtr(),
+                                    "b",
+                                    "-H1",
+                                    Enums::FragEnd::LE,
+                                    "b series ions",
+                                    /*sequence_embedded*/ false);
+
+  std::vector<FragmentationConfig> frag_configs = {immo_frag_config,
+                                                   a_frag_config};
+
+  CalcOptions calc_options(/*deep_calculation*/ false,
+                           Enums::MassType::BOTH,
+                           Enums::CapType::BOTH,
+                           Enums::ChemicalEntity::NONE,
+                           Enums::ChemicalEntity::NONE);
+  calc_options.setIndexRange(0, 239);
+
+  Ionizer ionizer(polymer_sp->getPolChemDefCstSPtr()->getIsotopicDataCstSPtr(),
+                  Formula("+H"),
+                  1,
+                  1);
+
+  Fragmenter fragmenter(polymer_sp,
+                        polymer_sp->getPolChemDefCstSPtr(),
+                        frag_configs,
+                        calc_options,
+                        ionizer);
+
+  fragmenter.addFragmentationConfig(b_frag_config);
+
+  WHEN("Checking member data, like the fragmentation configs")
+  {
+    const std::vector<FragmentationConfig> &check_cst_frag_configs =
+      fragmenter.getFragmentationConfigsCstRef();
+    const std::vector<FragmentationConfig> &check_frag_configs =
+      fragmenter.getFragmentationConfigsRef();
+
+    const Ionizer &check_cst_ionizer = fragmenter.getIonizerCstRef();
+    const Ionizer &check_ionizer     = fragmenter.getIonizerRef();
+
+    const CalcOptions &check_cst_calc_options =
+      fragmenter.getCalcOptionsCstRef();
+    const CalcOptions &check_calc_options = fragmenter.getCalcOptionsRef();
+
+    THEN("The data are set correctly")
+    {
+      REQUIRE(frag_configs.size() == check_cst_frag_configs.size() - 1);
+      REQUIRE(frag_configs.size() == check_frag_configs.size() - 1);
+      REQUIRE(ionizer == check_cst_ionizer);
+      REQUIRE(ionizer == check_ionizer);
+      REQUIRE(calc_options == check_cst_calc_options);
+      REQUIRE(calc_options == check_calc_options);
+    }
+  }
+}
 
 SCENARIO(
   "Construction of a Fragmenter and use with a Polymer without CrossLink "
@@ -53,7 +136,7 @@ SCENARIO(
                                 .arg(TESTS_INPUT_DIR)
                                 .arg("chicken-telokin.mxp");
 
-  PolymerSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
+  PolymerQSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
   REQUIRE(polymer_sp->renderXmlPolymerFile(polymer_file_path));
   REQUIRE(polymer_sp->size() == 157);
 
@@ -143,6 +226,22 @@ SCENARIO(
           oligomer_sp->getFormulaCstRef().getActionFormula().toStdString() ==
           "C5H13N2");
       }
+      AND_WHEN(
+        "The remaining oligomers are transferred to that same container "
+        "(std::move())")
+      {
+        OligomerCollection dest_oligomers;
+
+        std::size_t count = fragmenter.transferOligomers(
+          fragmenter.getOligomerCollectionRef(), dest_oligomers);
+
+        THEN("The Oligomer instances have been moved")
+        {
+          REQUIRE(count == 25);
+          REQUIRE(fragmenter.getOligomerCollectionCstRef().size() == 0);
+          REQUIRE(dest_oligomers.size() == 25);
+        }
+      }
     }
   }
 
@@ -432,7 +531,8 @@ SCENARIO(
     }
   }
 
-  GIVEN("Left end fragmentation, multiprotonation, Enums::ChemicalEntity::MODIF")
+  GIVEN(
+    "Left end fragmentation, multiprotonation, Enums::ChemicalEntity::MODIF")
   {
     FragmentationPathway fragmentation_pathway(
       polymer_sp->getPolChemDefCstSPtr(),
@@ -520,7 +620,8 @@ SCENARIO(
   }
 
   GIVEN(
-    "Left end fragmentation, multiprotonation, Enums::ChemicalEntity::MODIF and "
+    "Left end fragmentation, multiprotonation, Enums::ChemicalEntity::MODIF "
+    "and "
     "Enums::ChemicalEntity::LEFT_END_MODIF")
   {
     FragmentationPathway fragmentation_pathway(
@@ -609,7 +710,8 @@ SCENARIO(
   }
 
   GIVEN(
-    "Left end fragmentation, multiprotonation, Enums::ChemicalEntity::MODIF and "
+    "Left end fragmentation, multiprotonation, Enums::ChemicalEntity::MODIF "
+    "and "
     "Enums::ChemicalEntity::LEFT_END_MODIF with added -H2O and -NH3 additinal "
     "decompositions")
   {
@@ -653,8 +755,6 @@ SCENARIO(
 
     WHEN("The fragmentation is asked for")
     {
-      qDebug() << "BEGIN HERE";
-
       REQUIRE(fragmenter.fragment());
 
       THEN(
@@ -883,7 +983,8 @@ SCENARIO(
     }
   }
 
-  GIVEN("Right end fragmentation, multiprotonation, Enums::ChemicalEntity::MODIF")
+  GIVEN(
+    "Right end fragmentation, multiprotonation, Enums::ChemicalEntity::MODIF")
   {
     FragmentationPathway fragmentation_pathway(
       polymer_sp->getPolChemDefCstSPtr(),
@@ -971,7 +1072,8 @@ SCENARIO(
   }
 
   GIVEN(
-    "Right end fragmentation, multiprotonation, Enums::ChemicalEntity::MODIF and "
+    "Right end fragmentation, multiprotonation, Enums::ChemicalEntity::MODIF "
+    "and "
     "Enums::ChemicalEntity::RIGHT_END_MODIF")
   {
     FragmentationPathway fragmentation_pathway(
