@@ -18,11 +18,11 @@
 
 
 /////////////////////// libXpertMassCore includes
-#include <libXpertMass/Formula.hpp>
-#include <libXpertMass/Ionizer.hpp>
-#include <libXpertMass/IsotopicDataLibraryHandler.hpp>
-#include <libXpertMass/Sequence.hpp>
-#include <libXpertMass/Monomer.hpp>
+#include "MsXpS/libXpertMassCore/Formula.hpp"
+#include "MsXpS/libXpertMassCore/Ionizer.hpp"
+#include "MsXpS/libXpertMassCore/IsotopicDataLibraryHandler.hpp"
+#include "MsXpS/libXpertMassCore/Sequence.hpp"
+#include "MsXpS/libXpertMassCore/Monomer.hpp"
 
 /////////////////////// Local includes
 #include "tests-config.h"
@@ -44,8 +44,8 @@ SCENARIO("An Ionizer is used to attach charges to chemical entities",
 
   IsotopicDataLibraryHandler isotopic_data_lib_handler;
   isotopic_data_lib_handler.setFileName("the_file_name.dat");
-  std::size_t count_non_isotope_skipped_items = 0;
-  std::size_t loaded_isotope_count =
+  qsizetype count_non_isotope_skipped_items = 0;
+  qsizetype loaded_isotope_count =
     isotopic_data_lib_handler.loadData(count_non_isotope_skipped_items);
   IsotopicDataCstSPtr isotopic_data_csp =
     isotopic_data_lib_handler.getIsotopicData();
@@ -182,8 +182,8 @@ SCENARIO(
 
   IsotopicDataLibraryHandler isotopic_data_lib_handler;
   isotopic_data_lib_handler.setFileName("the_file_name.dat");
-  std::size_t count_non_isotope_skipped_items = 0;
-  std::size_t loaded_isotope_count =
+  qsizetype count_non_isotope_skipped_items = 0;
+  qsizetype loaded_isotope_count =
     isotopic_data_lib_handler.loadData(count_non_isotope_skipped_items);
   IsotopicDataCstSPtr isotopic_data_csp =
     isotopic_data_lib_handler.getIsotopicData();
@@ -240,8 +240,8 @@ SCENARIO("An Ionizer can output a text string describing itself", "[Ionizer]")
 
   IsotopicDataLibraryHandler isotopic_data_lib_handler;
   isotopic_data_lib_handler.setFileName("the_file_name.dat");
-  std::size_t count_non_isotope_skipped_items = 0;
-  std::size_t loaded_isotope_count =
+  qsizetype count_non_isotope_skipped_items = 0;
+  qsizetype loaded_isotope_count =
     isotopic_data_lib_handler.loadData(count_non_isotope_skipped_items);
   IsotopicDataCstSPtr isotopic_data_csp =
     isotopic_data_lib_handler.getIsotopicData();
@@ -308,8 +308,8 @@ SCENARIO(
 
   IsotopicDataLibraryHandler isotopic_data_lib_handler;
   isotopic_data_lib_handler.setFileName("the_file_name.dat");
-  std::size_t count_non_isotope_skipped_items = 0;
-  std::size_t loaded_isotope_count =
+  qsizetype count_non_isotope_skipped_items = 0;
+  qsizetype loaded_isotope_count =
     isotopic_data_lib_handler.loadData(count_non_isotope_skipped_items);
   IsotopicDataCstSPtr isotopic_data_csp =
     isotopic_data_lib_handler.getIsotopicData();
@@ -383,8 +383,8 @@ SCENARIO("An Ionizer documents itself as an XML element", "[Ionizer]")
 
   IsotopicDataLibraryHandler isotopic_data_lib_handler;
   isotopic_data_lib_handler.setFileName("the_file_name.dat");
-  std::size_t count_non_isotope_skipped_items = 0;
-  std::size_t loaded_isotope_count =
+  qsizetype count_non_isotope_skipped_items = 0;
+  qsizetype loaded_isotope_count =
     isotopic_data_lib_handler.loadData(count_non_isotope_skipped_items);
   IsotopicDataCstSPtr isotopic_data_csp =
     isotopic_data_lib_handler.getIsotopicData();
