@@ -15,7 +15,7 @@
 
 
 /////////////////////// libXpertMassCore includes
-#include <libXpertMass/Isotope.hpp>
+#include "MsXpS/libXpertMassCore/Isotope.hpp"
 
 
 /////////////////////// Local includes
@@ -60,19 +60,18 @@ SCENARIO("Isotope construction with correct arguments", "[Isotope]")
         REQUIRE(isotope_1.isValid());
 
         REQUIRE(isotope_1.validate(&error_list));
-        REQUIRE(error_list_p->size() == 0);
+        REQUIRE(error_list.size() == 0);
       }
 
       WHEN("A new Isotope is assignment operator constructed")
       {
-        Isotope new_isotope;
-        new_isotope = isotope_1;
+        Isotope new_isotope(isotope_1, Q_NULLPTR);
 
         THEN("The new instance should be identical to the first one")
         {
           REQUIRE(new_isotope == isotope_1);
           REQUIRE(new_isotope.validate(&error_list));
-          REQUIRE(error_list_p->size() == 0);
+          REQUIRE(error_list.size() == 0);
         }
 
         THEN("An Isotope instance == compared to itself should return true")
@@ -85,12 +84,6 @@ SCENARIO("Isotope construction with correct arguments", "[Isotope]")
           REQUIRE_FALSE((isotope_1 != isotope_1));
         }
       }
-
-      WHEN(
-        "An Isotope is assigned to itself, a reference to itself is returned")
-      {
-        REQUIRE((isotope_1 = isotope_1) == isotope_1);
-      }
     }
 
     AND_WHEN(
@@ -123,7 +116,7 @@ SCENARIO("Isotope construction with correct arguments", "[Isotope]")
           QVector<QString> error_list;
 
           REQUIRE(isotope_2.validate(&error_list));
-          REQUIRE(error_list_p->size() == 0);
+          REQUIRE(error_list.size() == 0);
         }
 
         AND_THEN("Both isotopes are identical")
@@ -152,7 +145,7 @@ SCENARIO("Isotope construction with correct arguments", "[Isotope]")
           QVector<QString> error_list;
 
           REQUIRE(isotope_3.validate(&error_list));
-          REQUIRE(error_list_p->size() == 0);
+          REQUIRE(error_list.size() == 0);
         }
 
         AND_THEN("Both isotopes are identical")
@@ -181,7 +174,7 @@ SCENARIO("Isotope construction with correct arguments", "[Isotope]")
           QVector<QString> error_list;
 
           REQUIRE(isotope_4.validate(&error_list));
-          REQUIRE(error_list_p->size() == 0);
+          REQUIRE(error_list.size() == 0);
         }
 
         AND_THEN("Both isotopes are identical")
@@ -886,7 +879,7 @@ SCENARIO("Failed validation of Isotope instances report error strings",
     {
       REQUIRE(isotope_1.isValid());
       REQUIRE(isotope_1.validate(&error_list));
-      REQUIRE(!error_list_p->size());
+      REQUIRE(!error_list.size());
     }
 
     AND_WHEN("The symbol is crippled")
@@ -896,7 +889,7 @@ SCENARIO("Failed validation of Isotope instances report error strings",
       THEN("Validation should return an informative string")
       {
         REQUIRE_FALSE(isotope_1.validate(&error_list));
-        REQUIRE(error_list_p->size() == 1);
+        REQUIRE(error_list.size() == 1);
         REQUIRE(error_list.front().toStdString() ==
                 "Failed to validate the element's symbol.");
       }
@@ -912,7 +905,7 @@ SCENARIO("Failed validation of Isotope instances report error strings",
         error_list.clear();
 
         REQUIRE_FALSE(isotope_1.validate(&error_list));
-        REQUIRE(error_list_p->size() == 2);
+        REQUIRE(error_list.size() == 2);
         REQUIRE(error_list.front().toStdString() ==
                 "Failed to validate the element's symbol.");
         REQUIRE(error_list.back().toStdString() ==
