@@ -15,8 +15,8 @@
 
 
 /////////////////////// libXpertMassCore includes
-#include <libXpertMass/Isotope.hpp>
-#include <libXpertMass/IsotopicData.hpp>
+#include "MsXpS/libXpertMassCore/Isotope.hpp"
+#include "MsXpS/libXpertMassCore/IsotopicData.hpp"
 
 /////////////////////// Local includes
 #include "TestUtils.hpp"
@@ -97,7 +97,7 @@ SCENARIO(
 
       THEN("It cannot validate because there is only one isotope")
       {
-        REQUIRE_FALSE(isotopic_data.validateBySymbol("C", error_list));
+        REQUIRE_FALSE(isotopic_data.validateBySymbol("C", &error_list));
       }
 
       THEN(
@@ -145,7 +145,7 @@ SCENARIO(
           THEN("Cumulated probabilities for isotopes C and N equal 1")
           {
             REQUIRE(isotopic_data.getCumulatedProbabilitiesBySymbol(
-                      "C", error_list) == 1);
+                      "C", &error_list) == 1);
           }
         }
 
@@ -159,9 +159,9 @@ SCENARIO(
             REQUIRE(isotopic_data.getIsotopeCountBySymbol("N") == 2);
 
             REQUIRE(isotopic_data.getCumulatedProbabilitiesBySymbol(
-                      "C", error_list) == 1);
+                      "C", &error_list) == 1);
             REQUIRE(isotopic_data.getCumulatedProbabilitiesBySymbol(
-                      "N", error_list) == 1);
+                      "N", &error_list) == 1);
           }
         }
       }
@@ -210,7 +210,7 @@ SCENARIO(
 
       THEN("It cannot validate because there is only one isotope")
       {
-        REQUIRE_FALSE(isotopic_data.validateBySymbol("C", error_list));
+        REQUIRE_FALSE(isotopic_data.validateBySymbol("C", &error_list));
       }
 
       THEN("Getting masses is possible because the maps have been updated")
@@ -230,8 +230,8 @@ SCENARIO(
         THEN("All sorts of validations should be successful")
         {
           REQUIRE(isotopic_data.validate(&error_list));
-          REQUIRE(isotopic_data.validateBySymbol("C", error_list));
-          REQUIRE(isotopic_data.validateBySymbol("N", error_list));
+          REQUIRE(isotopic_data.validateBySymbol("C", &error_list));
+          REQUIRE(isotopic_data.validateBySymbol("N", &error_list));
 
           int count = 0;
 
@@ -249,9 +249,9 @@ SCENARIO(
           REQUIRE(isotopic_data.getIsotopeCountBySymbol("N") == 2);
 
           REQUIRE(isotopic_data.getCumulatedProbabilitiesBySymbol(
-                    "C", error_list) == 1);
+                    "C", &error_list) == 1);
           REQUIRE(isotopic_data.getCumulatedProbabilitiesBySymbol(
-                    "N", error_list) == 1);
+                    "N", &error_list) == 1);
         }
       }
     }
@@ -318,13 +318,13 @@ SCENARIO(
         // Check by the symbol-based iterator pair, which ensures that
         // the average mass calculation involved two immediately consecutive
         // isotopes.
-        REQUIRE_THAT(isotopic_data.getMonoMass(iter_pair, error_list),
+        REQUIRE_THAT(isotopic_data.getMonoMass(iter_pair, &error_list),
                      Catch::Matchers::WithinAbs(12.0, 0.0000000001));
-        REQUIRE_THAT(isotopic_data.computeAvgMass(iter_pair, error_list),
+        REQUIRE_THAT(isotopic_data.computeAvgMass(iter_pair, &error_list),
                      Catch::Matchers::WithinAbs(12.0108242503, 0.0000000001));
 
         REQUIRE(
-          isotopic_data.getCumulatedProbabilities(iter_pair, error_list) == 1);
+          isotopic_data.getCumulatedProbabilities(iter_pair, &error_list) == 1);
 
         REQUIRE_THAT(
           iter_pair.first->get()->getProbability(),
@@ -356,16 +356,16 @@ SCENARIO(
         // Check by the symbol-based iterator pair, which ensures that
         // the average mass calculation involved two immediately consecutive
         // isotopes.
-        REQUIRE_THAT(isotopic_data.getMonoMass(iter_pair, error_list),
+        REQUIRE_THAT(isotopic_data.getMonoMass(iter_pair, &error_list),
                      Catch::Matchers::WithinAbs(14.0030740042, 0.0000000001));
-        REQUIRE_THAT(isotopic_data.computeAvgMass(iter_pair, error_list),
+        REQUIRE_THAT(isotopic_data.computeAvgMass(iter_pair, &error_list),
                      Catch::Matchers::WithinAbs(14.0067051908, 0.0000000001));
 
         REQUIRE_THAT(isotopic_data.getAvgMassBySymbol("N", ok),
                      Catch::Matchers::WithinAbs(14.0067051908, 0.0000000001));
 
         REQUIRE(
-          isotopic_data.getCumulatedProbabilities(iter_pair, error_list) == 1);
+          isotopic_data.getCumulatedProbabilities(iter_pair, &error_list) == 1);
       }
     }
   }
@@ -398,12 +398,12 @@ SCENARIO("Accessing Isotope instances using iterators", "[IsotopicData]")
 
       THEN("The masses might be asked")
       {
-        REQUIRE_THAT(isotopic_data.getMonoMass(iter_pair, error_list),
+        REQUIRE_THAT(isotopic_data.getMonoMass(iter_pair, &error_list),
                      Catch::Matchers::WithinAbs(12.0, 0.0000000001));
-        REQUIRE_THAT(isotopic_data.computeAvgMass(iter_pair, error_list),
+        REQUIRE_THAT(isotopic_data.computeAvgMass(iter_pair, &error_list),
                      Catch::Matchers::WithinAbs(12.0108242503, 0.0000000001));
         REQUIRE_THAT(
-          isotopic_data.getCumulatedProbabilities(iter_pair, error_list),
+          isotopic_data.getCumulatedProbabilities(iter_pair, &error_list),
           Catch::Matchers::WithinAbs(1, 0.0000000001));
       }
     }
@@ -415,12 +415,12 @@ SCENARIO("Accessing Isotope instances using iterators", "[IsotopicData]")
 
       THEN("The masses might be asked")
       {
-        REQUIRE_THAT(isotopic_data.getMonoMass(iter_pair, error_list),
+        REQUIRE_THAT(isotopic_data.getMonoMass(iter_pair, &error_list),
                      Catch::Matchers::WithinAbs(12.0, 0.0000000001));
-        REQUIRE_THAT(isotopic_data.computeAvgMass(iter_pair, error_list),
+        REQUIRE_THAT(isotopic_data.computeAvgMass(iter_pair, &error_list),
                      Catch::Matchers::WithinAbs(12.0108242503, 0.0000000001));
         REQUIRE_THAT(
-          isotopic_data.getCumulatedProbabilities(iter_pair, error_list),
+          isotopic_data.getCumulatedProbabilities(iter_pair, &error_list),
           Catch::Matchers::WithinAbs(1, 0.0000000001));
       }
     }
@@ -498,15 +498,15 @@ SCENARIO("Isotopes can be removed from IsotopicData", "[IsotopicData]")
       // Check by the symbol-based iterator pair, which ensures that
       // the average mass calculation involved two immediately consecutive
       // isotopes.
-      REQUIRE_THAT(isotopic_data.getMonoMass(iter_pair, error_list),
+      REQUIRE_THAT(isotopic_data.getMonoMass(iter_pair, &error_list),
                    Catch::Matchers::WithinAbs(14.0030740042, 0.0000000001));
-      REQUIRE_THAT(isotopic_data.computeAvgMass(iter_pair, error_list),
+      REQUIRE_THAT(isotopic_data.computeAvgMass(iter_pair, &error_list),
                    Catch::Matchers::WithinAbs(14.0067051908, 0.0000000001));
 
       REQUIRE_THAT(isotopic_data.getAvgMassBySymbol("N", ok),
                    Catch::Matchers::WithinAbs(14.0067051908, 0.0000000001));
 
-      REQUIRE(isotopic_data.getCumulatedProbabilities(iter_pair, error_list) ==
+      REQUIRE(isotopic_data.getCumulatedProbabilities(iter_pair, &error_list) ==
               1);
     }
   }
@@ -587,19 +587,19 @@ SCENARIO("IsotopicData can be validated in various ways", "[IsotopicData]")
     {
       bool result = isotopic_data.validate(&error_list);
       REQUIRE(result);
-      REQUIRE(error_list_p->size() == 0);
+      REQUIRE(error_list.size() == 0);
     }
 
     AND_THEN(
       "The isotopic data can be validated by symbol (more powerful checks)")
     {
-      bool result = isotopic_data.validateBySymbol("C", error_list);
+      bool result = isotopic_data.validateBySymbol("C", &error_list);
       REQUIRE(result);
-      REQUIRE(error_list_p->size() == 0);
+      REQUIRE(error_list.size() == 0);
 
-      result = isotopic_data.validateBySymbol("N", error_list);
+      result = isotopic_data.validateBySymbol("N", &error_list);
       REQUIRE(result);
-      REQUIRE(error_list_p->size() == 0);
+      REQUIRE(error_list.size() == 0);
     }
   }
 }
