@@ -18,9 +18,9 @@
 
 
 /////////////////////// libXpertMassCore includes
-#include <libXpertMass/Isotope.hpp>
-#include <libXpertMass/IsotopicData.hpp>
-#include <libXpertMass/IsotopicDataLibraryHandler.hpp>
+#include "MsXpS/libXpertMassCore/Isotope.hpp"
+#include "MsXpS/libXpertMassCore/IsotopicData.hpp"
+#include "MsXpS/libXpertMassCore/IsotopicDataLibraryHandler.hpp"
 
 
 /////////////////////// Local includes
@@ -64,8 +64,8 @@ SCENARIO("IsotopicDataLibraryHandler loads data from IsoSpec++'s tables",
 
   AND_WHEN("Loading isotopic data from library")
   {
-    std::size_t count_non_isotope_skipped_items = 0;
-    std::size_t loaded_isotope_count =
+    qsizetype count_non_isotope_skipped_items = 0;
+    qsizetype loaded_isotope_count =
       isotopic_data_lib_handler.loadData(count_non_isotope_skipped_items);
 
     THEN("The number of isotopes loaded is checked")
@@ -105,8 +105,8 @@ SCENARIO("IsotopicDataLibraryHandler writes data to file",
 
   WHEN("Data have been loaded, the data are checked")
   {
-    std::size_t non_isotope_skipped_items = 0;
-    std::size_t loaded_isotope_count =
+    qsizetype non_isotope_skipped_items = 0;
+    qsizetype loaded_isotope_count =
       isotopic_data_lib_handler.loadData(non_isotope_skipped_items);
 
     THEN("The number of isotopes loaded is checked")
