@@ -17,9 +17,9 @@
 
 
 /////////////////////// libXpertMassCore includes
-#include <libXpertMass/Isotope.hpp>
-#include <libXpertMass/IsotopicData.hpp>
-#include <libXpertMass/IsotopicDataManualConfigHandler.hpp>
+#include "MsXpS/libXpertMassCore/Isotope.hpp"
+#include "MsXpS/libXpertMassCore/IsotopicData.hpp"
+#include "MsXpS/libXpertMassCore/IsotopicDataManualConfigHandler.hpp"
 
 
 /////////////////////// Local includes
