@@ -20,9 +20,9 @@
 /////////////////////// Local includes
 // #include "tests-config.h"
 #include "TestUtils.hpp"
-#include <libXpertMass/globals.hpp>
-#include <libXpertMass/Polymer.hpp>
-#include <libXpertMass/Oligomer.hpp>
+#include "MsXpS/libXpertMassCore/globals.hpp"
+#include "MsXpS/libXpertMassCore/Polymer.hpp"
+#include "MsXpS/libXpertMassCore/Oligomer.hpp"
 
 
 namespace MsXpS
@@ -46,7 +46,7 @@ SCENARIO("Oligomer instances are initialized with a reference Polymer",
                                 .arg(TESTS_INPUT_DIR)
                                 .arg("chicken-telokin.mxp");
 
-  PolymerSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
+  PolymerQSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
 
   REQUIRE(polymer_sp->renderXmlPolymerFile(polymer_file_path));
 
@@ -185,7 +185,7 @@ SCENARIO("Oligomer instances can be ionized,  deionized and reionized",
   QString polymer_file_path = QString("%1/polymer-sequences/%2")
                                 .arg(TESTS_INPUT_DIR)
                                 .arg("chicken-telokin.mxp");
-  PolymerSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
+  PolymerQSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
 
   REQUIRE(polymer_sp->renderXmlPolymerFile(polymer_file_path));
 
@@ -366,7 +366,7 @@ SCENARIO("Oligomer instances can be configured with different IndexRanges",
   QString polymer_file_path = QString("%1/polymer-sequences/%2")
                                 .arg(TESTS_INPUT_DIR)
                                 .arg("chicken-telokin.mxp");
-  PolymerSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
+  PolymerQSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
 
   REQUIRE(polymer_sp->renderXmlPolymerFile(polymer_file_path));
 
@@ -565,7 +565,7 @@ SCENARIO(
   QString polymer_file_path = QString("%1/polymer-sequences/%2")
                                 .arg(TESTS_INPUT_DIR)
                                 .arg("chicken-telokin.mxp");
-  PolymerSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
+  PolymerQSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
 
   REQUIRE(polymer_sp->renderXmlPolymerFile(polymer_file_path));
 
@@ -761,7 +761,7 @@ SCENARIO(
   QString polymer_file_path = QString("%1/polymer-sequences/%2")
                                 .arg(TESTS_INPUT_DIR)
                                 .arg("chicken-telokin.mxp");
-  PolymerSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
+  PolymerQSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
 
   REQUIRE(polymer_sp->renderXmlPolymerFile(polymer_file_path));
 
@@ -880,7 +880,7 @@ SCENARIO("Oligomer instances can be set CrossLink instances", "[Oligomer]")
   QString polymer_file_path = QString("%1/polymer-sequences/%2")
                                 .arg(TESTS_INPUT_DIR)
                                 .arg("chicken-telokin.mxp");
-  PolymerSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
+  PolymerQSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
 
   REQUIRE(polymer_sp->renderXmlPolymerFile(polymer_file_path));
 
