@@ -20,9 +20,9 @@
 /////////////////////// Local includes
 // #include "tests-config.h"
 #include "TestUtils.hpp"
-#include <libXpertMass/globals.hpp>
-#include <libXpertMass/Polymer.hpp>
-#include <libXpertMass/OligomerCollection.hpp>
+#include "MsXpS/libXpertMassCore/globals.hpp"
+#include "MsXpS/libXpertMassCore/Polymer.hpp"
+#include "MsXpS/libXpertMassCore/OligomerCollection.hpp"
 
 
 namespace MsXpS
