@@ -21,15 +21,15 @@
 
 /////////////////////// Local includes
 #include "TestUtils.hpp"
-#include <libXpertMass/PolChemDefSpec.hpp>
-#include <libXpertMass/PolChemDef.hpp>
-#include <libXpertMass/globals.hpp>
-#include <libXpertMass/IsotopicData.hpp>
-#include <libXpertMass/Monomer.hpp>
-#include <libXpertMass/Modif.hpp>
-#include <libXpertMass/CrossLinker.hpp>
-#include <libXpertMass/CleavageAgent.hpp>
-#include <libXpertMass/FragmentationPathway.hpp>
+#include "MsXpS/libXpertMassCore/PolChemDefSpec.hpp"
+#include "MsXpS/libXpertMassCore/PolChemDef.hpp"
+#include "MsXpS/libXpertMassCore/globals.hpp"
+#include "MsXpS/libXpertMassCore/IsotopicData.hpp"
+#include "MsXpS/libXpertMassCore/Monomer.hpp"
+#include "MsXpS/libXpertMassCore/Modif.hpp"
+#include "MsXpS/libXpertMassCore/CrossLinker.hpp"
+#include "MsXpS/libXpertMassCore/CleavageAgent.hpp"
+#include "MsXpS/libXpertMassCore/FragmentationPathway.hpp"
 
 namespace MsXpS
 {
@@ -356,7 +356,7 @@ SCENARIO("Loading a PolChemDef version 1", "[PolChemDef]")
       REQUIRE(monomer_csp->getName().toStdString() == "Glycine");
       REQUIRE(monomer_csp->getCode().toStdString() == "G");
       REQUIRE(monomer_csp->getFormula().toStdString() == "C2H3N1O1");
-      REQUIRE(monomer_csp->validate(error_list_pol_chem_def));
+      REQUIRE(monomer_csp->validate(&error_list_pol_chem_def));
       double mono;
       double avg;
       REQUIRE(monomer_csp->calculateMasses(
@@ -366,7 +366,7 @@ SCENARIO("Loading a PolChemDef version 1", "[PolChemDef]")
       REQUIRE(monomer_csp->getName().toStdString() == "DiaminoPimelic");
       REQUIRE(monomer_csp->getCode().toStdString() == "O");
       REQUIRE(monomer_csp->getFormula().toStdString() == "C7H12N2O3");
-      REQUIRE(monomer_csp->validate(error_list_pol_chem_def) == true);
+      REQUIRE(monomer_csp->validate(&error_list_pol_chem_def) == true);
       REQUIRE(monomer_csp->calculateMasses(
         pol_chem_def_sp->getIsotopicDataCstSPtr(), mono, avg));
 
@@ -374,7 +374,7 @@ SCENARIO("Loading a PolChemDef version 1", "[PolChemDef]")
       REQUIRE(monomer_csp->getName().toStdString() == "Aspartate");
       REQUIRE(monomer_csp->getCode().toStdString() == "D");
       REQUIRE(monomer_csp->getFormula().toStdString() == "C4H5N1O3");
-      REQUIRE(monomer_csp->validate(error_list_pol_chem_def) == true);
+      REQUIRE(monomer_csp->validate(&error_list_pol_chem_def) == true);
       REQUIRE(monomer_csp->calculateMasses(
         pol_chem_def_sp->getIsotopicDataCstSPtr(), mono, avg));
 
@@ -382,7 +382,7 @@ SCENARIO("Loading a PolChemDef version 1", "[PolChemDef]")
       REQUIRE(monomer_csp->getName().toStdString() == "Proline");
       REQUIRE(monomer_csp->getCode().toStdString() == "P");
       REQUIRE(monomer_csp->getFormula().toStdString() == "C5H7N1O1");
-      REQUIRE(monomer_csp->validate(error_list_pol_chem_def) == true);
+      REQUIRE(monomer_csp->validate(&error_list_pol_chem_def) == true);
       REQUIRE(monomer_csp->calculateMasses(
         pol_chem_def_sp->getIsotopicDataCstSPtr(), mono, avg));
     }
@@ -398,7 +398,7 @@ SCENARIO("Loading a PolChemDef version 1", "[PolChemDef]")
       REQUIRE(modif_cspp->getFormula().toStdString() == "C2H2O1");
       REQUIRE(modif_cspp->getTargets().toStdString() == ";K;");
       REQUIRE(modif_cspp->getMaxCount() == 1);
-      REQUIRE(modif_cspp->validate(error_list_pol_chem_def) == true);
+      REQUIRE(modif_cspp->validate(&error_list_pol_chem_def) == true);
       double mono;
       double avg;
       REQUIRE(modif_cspp->calculateMasses(
@@ -409,7 +409,7 @@ SCENARIO("Loading a PolChemDef version 1", "[PolChemDef]")
       REQUIRE(modif_cspp->getFormula().toStdString() == "C2H2O2");
       REQUIRE(modif_cspp->getTargets().toStdString() == ";C;");
       REQUIRE(modif_cspp->getMaxCount() == 1);
-      REQUIRE(modif_cspp->validate(error_list_pol_chem_def) == true);
+      REQUIRE(modif_cspp->validate(&error_list_pol_chem_def) == true);
       REQUIRE(modif_cspp->calculateMasses(
                 pol_chem_def_sp->getIsotopicDataCstSPtr(), mono, avg) == true);
 
@@ -418,7 +418,7 @@ SCENARIO("Loading a PolChemDef version 1", "[PolChemDef]")
       REQUIRE(modif_cspp->getFormula().toStdString() == "-H3");
       REQUIRE(modif_cspp->getTargets().toStdString() == ";Y;F;W;");
       REQUIRE(modif_cspp->getMaxCount() == 1);
-      REQUIRE(modif_cspp->validate(error_list_pol_chem_def) == true);
+      REQUIRE(modif_cspp->validate(&error_list_pol_chem_def) == true);
       REQUIRE(modif_cspp->calculateMasses(
                 pol_chem_def_sp->getIsotopicDataCstSPtr(), mono, avg) == true);
 
@@ -427,7 +427,7 @@ SCENARIO("Loading a PolChemDef version 1", "[PolChemDef]")
       REQUIRE(modif_cspp->getFormula().toStdString() == "C1O1");
       REQUIRE(modif_cspp->getTargets().toStdString() == "*");
       REQUIRE(modif_cspp->getMaxCount() == 1);
-      REQUIRE(modif_cspp->validate(error_list_pol_chem_def) == true);
+      REQUIRE(modif_cspp->validate(&error_list_pol_chem_def) == true);
       REQUIRE(modif_cspp->calculateMasses(
                 pol_chem_def_sp->getIsotopicDataCstSPtr(), mono, avg) == true);
 
@@ -436,7 +436,7 @@ SCENARIO("Loading a PolChemDef version 1", "[PolChemDef]")
       REQUIRE(modif_cspp->getFormula().toStdString() == "C2H3N1O1");
       REQUIRE(modif_cspp->getTargets().toStdString() == ";E;");
       REQUIRE(modif_cspp->getMaxCount() == 34);
-      REQUIRE(modif_cspp->validate(error_list_pol_chem_def) == true);
+      REQUIRE(modif_cspp->validate(&error_list_pol_chem_def) == true);
       REQUIRE(modif_cspp->calculateMasses(
                 pol_chem_def_sp->getIsotopicDataCstSPtr(), mono, avg) == true);
 
@@ -445,7 +445,7 @@ SCENARIO("Loading a PolChemDef version 1", "[PolChemDef]")
       REQUIRE(modif_cspp->getFormula().toStdString() == "H1O3P1");
       REQUIRE(modif_cspp->getTargets().toStdString() == ";S;T;Y;");
       REQUIRE(modif_cspp->getMaxCount() == 1);
-      REQUIRE(modif_cspp->validate(error_list_pol_chem_def) == true);
+      REQUIRE(modif_cspp->validate(&error_list_pol_chem_def) == true);
       REQUIRE(modif_cspp->calculateMasses(
                 pol_chem_def_sp->getIsotopicDataCstSPtr(), mono, avg) == true);
     }
