@@ -18,7 +18,7 @@
 
 
 /////////////////////// libXpertMassCore includes
-#include <libXpertMass/PolChemDefSpec.hpp>
+#include "MsXpS/libXpertMassCore/PolChemDefSpec.hpp"
 
 
 /////////////////////// Local includes
