@@ -20,8 +20,8 @@
 /////////////////////// Local includes
 // #include "tests-config.h"
 #include "TestUtils.hpp"
-#include <libXpertMass/globals.hpp>
-#include <libXpertMass/Polymer.hpp>
+#include "MsXpS/libXpertMassCore/globals.hpp"
+#include "MsXpS/libXpertMassCore/Polymer.hpp"
 
 namespace MsXpS
 {
@@ -49,7 +49,7 @@ SCENARIO(
 
     WHEN("A Polymer is allocated as a SPtr and totally unconfigured")
     {
-      PolymerSPtr polymer_sp = Polymer::createSPtr();
+      PolymerQSPtr polymer_sp = Polymer::createSPtr();
 
       THEN("The Polymer is not valid and does not validate successfully")
       {
@@ -160,7 +160,7 @@ SCENARIO("Polymer instances can be constructed and initialized in one go",
 
     WHEN("A Polymer is allocated as a SPtr with valid parameters")
     {
-      PolymerSPtr polymer_sp = Polymer::createSPtr(
+      PolymerQSPtr polymer_sp = Polymer::createSPtr(
         pol_chem_def_csp, "Test name", "Test code", "Rusconi");
 
       polymer_sp->setFilePath(
@@ -194,10 +194,10 @@ SCENARIO("Polymer instances can be constructed and initialized in one go",
       {
         REQUIRE_FALSE(polymer_sp->getLeftEndModifCstRef().isValid());
         REQUIRE_FALSE(
-          polymer_sp->getLeftEndModifCstRef().validate(error_list_polymer));
+          polymer_sp->getLeftEndModifCstRef().validate(&error_list_polymer));
         REQUIRE_FALSE(polymer_sp->getRightEndModifCstRef().isValid());
         REQUIRE_FALSE(
-          polymer_sp->getRightEndModifCstRef().validate(error_list_polymer));
+          polymer_sp->getRightEndModifCstRef().validate(&error_list_polymer));
       }
 
       AND_WHEN("Setting the left end modification by name")
@@ -208,7 +208,7 @@ SCENARIO("Polymer instances can be constructed and initialized in one go",
         {
           REQUIRE(polymer_sp->getLeftEndModifCstRef().isValid());
           REQUIRE(
-            polymer_sp->getLeftEndModifCstRef().validate(error_list_polymer));
+            polymer_sp->getLeftEndModifCstRef().validate(&error_list_polymer));
           REQUIRE(polymer_sp->getLeftEndModifCstRef().getName().toStdString() ==
                   "Acetylation");
         }
@@ -221,7 +221,7 @@ SCENARIO("Polymer instances can be constructed and initialized in one go",
           {
             REQUIRE(polymer_sp->getRightEndModifCstRef().isValid());
             REQUIRE(polymer_sp->getRightEndModifCstRef().validate(
-              error_list_polymer));
+              &error_list_polymer));
             REQUIRE(
               polymer_sp->getRightEndModifCstRef().getName().toStdString() ==
               "AmidationGlu");
@@ -269,7 +269,7 @@ SCENARIO("Polymer instances can be modified on their left and/or right ends",
       "A Polymer is allocated as a SPtr with valid parameters and a sequence "
       "is set")
     {
-      PolymerSPtr polymer_sp = Polymer::createSPtr(
+      PolymerQSPtr polymer_sp = Polymer::createSPtr(
         pol_chem_def_csp,
         "Test name",
         "Test code",
@@ -326,7 +326,7 @@ SCENARIO("Polymer instances can be initialized from files on disk", "[Polymer]")
 
   GIVEN("A polymer sequence file loaded from disk")
   {
-    PolymerSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
+    PolymerQSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
 
     REQUIRE(polymer_sp->renderXmlPolymerFile(polymer_file_path));
 
@@ -379,6 +379,9 @@ SCENARIO("Polymer instances can be initialized from files on disk", "[Polymer]")
                           "\"protonation\"+H",
                           /*charge*/ 1,
                           /*level*/ 1);
+
+          // qDebug() << "The ionizer:" << ionizer.toString();
+
           polymer_sp->setIonizer(ionizer);
 
           polymer_sp->ionize();
@@ -516,7 +519,7 @@ SCENARIO("Construction of a Polymer with 7 CrossLink instances right from file",
 
   GIVEN("A Polymer instance created by loading an XML file")
   {
-    PolymerSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
+    PolymerQSPtr polymer_sp = Polymer::createSPtr(pol_chem_def_csp);
     REQUIRE(polymer_sp->renderXmlPolymerFile(polymer_file_path));
     REQUIRE(polymer_sp->size() == 352);
 
