@@ -14,8 +14,8 @@
 
 /////////////////////// Local includes
 #include "TestUtils.hpp"
-#include <libXpertMass/Sequence.hpp>
-#include <libXpertMass/Monomer.hpp>
+#include "MsXpS/libXpertMassCore/Sequence.hpp"
+#include "MsXpS/libXpertMassCore/Monomer.hpp"
 
 namespace MsXpS
 {
@@ -101,7 +101,7 @@ SCENARIO("Sequence objects can be copy-constructed", "[Sequence]")
 
     THEN("The Sequence is valid")
     {
-      REQUIRE(sequence.validate(error_list_sequence));
+      REQUIRE(sequence.validate(&error_list_sequence));
       REQUIRE(sequence.isValid());
       REQUIRE(sequence.size() == 157);
     }
@@ -134,7 +134,7 @@ SCENARIO("Sequence objects can be assignment-configured", "[Sequence]")
 
     THEN("The Sequence is valid")
     {
-      REQUIRE(sequence.validate(error_list_sequence));
+      REQUIRE(sequence.validate(&error_list_sequence));
       REQUIRE(sequence.isValid());
     }
 
@@ -148,7 +148,7 @@ SCENARIO("Sequence objects can be assignment-configured", "[Sequence]")
 
       THEN("The new Sequence is valid and is identical to the initial one")
       {
-        REQUIRE(new_sequence.validate(error_list_sequence));
+        REQUIRE(new_sequence.validate(&error_list_sequence));
         REQUIRE(new_sequence.isValid());
         REQUIRE(new_sequence == sequence);
       }
@@ -971,7 +971,7 @@ SCENARIO(
       MonomerSPtr serine_7_sp = std::const_pointer_cast<Monomer>(serine_7_csp);
       REQUIRE(serine_7_sp->modify(*phospho_up.get(),
                                   /* override modif count */ false,
-                                  error_list_sequence) != nullptr);
+                                  &error_list_sequence) != nullptr);
 
       AND_WHEN(
         "Asking for the monomer index-based range without specifying that "
@@ -1108,7 +1108,7 @@ SCENARIO("A sequence can compute a checksum", "[Sequence]")
             std::const_pointer_cast<Monomer>(serine_7_csp);
           REQUIRE(serine_7_sp->modify(*phospho_up.get(),
                                       /* override modif count */ false,
-                                      error_list_sequence) != nullptr);
+                                      &error_list_sequence) != nullptr);
 
           THEN(
             "The new checksum with modifs must be different than the one "
